// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = eval('(function() { try { return Module || {} } catch(e) { return {} } })()');
// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}
// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };
  var nodeFS = require('fs');
  var nodePath = require('path');
  Module['read'] = function(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };
  Module['readBinary'] = function(filename) { return Module['read'](filename, true) };
  Module['load'] = function(f) {
    globalEval(read(f));
  };
  Module['arguments'] = process['argv'].slice(2);
  module.exports = Module;
}
else if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm
  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function() { throw 'no read() available (jsc?)' };
  }
  Module['readBinary'] = function(f) {
    return read(f, 'binary');
  };
  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  this['Module'] = Module;
}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };
  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  if (ENVIRONMENT_IS_WEB) {
    Module['print'] = function(x) {
      console.log(x);
    };
    Module['printErr'] = function(x) {
      console.log(x);
    };
    this['Module'] = Module;
  } else if (ENVIRONMENT_IS_WORKER) {
    // We can do very little here...
    var TRY_USE_DUMP = false;
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}
function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***
// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];
// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];
// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}
// === Auto-generated preamble library stuff ===
//========================================
// Runtime code shared with compiler
//========================================
var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (type == 'i64' || type == 'double' || vararg) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    var index = 0;
    type.flatIndexes = type.fields.map(function(field) {
      index++;
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        if (field[1] === '0') {
          // this is [0 x something]. When inside another structure like here, it must be at the end,
          // and it adds no size
          // XXX this happens in java-nbody for example... assert(index === type.fields.length, 'zero-length in the middle!');
          size = 0;
          alignSize = type.alignSize || QUANTUM_SIZE;
        } else {
          size = Types.types[field].flatSize;
          alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
        }
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2 + 2*i;
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;
      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }
      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          Math.floor((codePoint - 0x10000) / 0x400) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+7)>>3)<<3); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+7)>>3)<<3); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = ((((DYNAMICTOP)+7)>>3)<<3); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>(0))))+((+(((high)>>>(0))))*(+(4294967296)))) : ((+(((low)>>>(0))))+((+(((high)|(0))))*(+(4294967296))))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}
//========================================
// Runtime essentials
//========================================
var __THREW__ = 0; // Used in checking for thrown exceptions.
var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;
var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}
var globalScope = this;
// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;
// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = Module['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}
// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;
// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;
// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;
var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;
// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === 'string' ? types : null;
  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }
  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }
  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }
  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later
    setValue(ret+i, curr, type);
    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }
  return ret;
}
Module['allocate'] = allocate;
function Pointer_stringify(ptr, /* optional */ length) {
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;
  var ret = '';
  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;
// Memory management
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}
var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value, or (2) set Module.TOTAL_MEMORY before the program runs.');
}
var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 67108864;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;
// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');
var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);
// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');
Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;
function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}
var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited
var runtimeInitialized = false;
function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}
function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}
function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}
function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;
function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;
function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;
function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;
function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;
// Tools
// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;
function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;
// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;
function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}
if (!Math['imul']) Math['imul'] = function(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];
// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledInit = false, calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;
Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data
function loadMemoryInitializer(filename) {
  function applyData(data) {
    HEAPU8.set(data, STATIC_BASE);
  }
  // always do this asynchronously, to keep shell and web as similar as possible
  addOnPreRun(function() {
    if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
      applyData(Module['readBinary'](filename));
    } else {
      Browser.asyncLoad(filename, function(data) {
        applyData(data);
      }, function(data) {
        throw 'could not load memory initializer ' + filename;
      });
    }
  });
}
// === Body ===
STATIC_BASE = 8;
STATICTOP = STATIC_BASE + 2677696;
/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } });
var _stdout;
var _stderr;
var _stdout = _stdout=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stderr = _stderr=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
/* memory initializer */ allocate([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,240,92,1,0,208,145,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,0,0,0,10,0,0,0,40,0,0,0,10,0,0,0,64,0,0,0,10,0,0,0,90,0,0,0,88,71,1,0,48,0,0,0,36,1,0,0,8,0,0,0,96,0,0,0,8,0,0,0,114,0,0,0,90,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,80,126,1,0,144,132,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,117,1,0,216,152,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,109,1,0,216,152,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,65,1,0,232,57,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,103,1,0,168,96,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,50,1,0,40,46,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,89,1,0,144,132,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,40,1,0,232,57,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,82,1,0,24,75,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,35,1,0,168,140,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,250,0,0,24,75,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,1,1,0,144,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,8,1,0,0,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,160,200,17,0,96,209,17,0,1,0,0,0,1,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,1,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,0,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,13,0,0,0,15,0,0,0,17,0,0,0,19,0,0,0,23,0,0,0,27,0,0,0,31,0,0,0,35,0,0,0,43,0,0,0,51,0,0,0,59,0,0,0,67,0,0,0,83,0,0,0,99,0,0,0,115,0,0,0,131,0,0,0,163,0,0,0,195,0,0,0,227,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,13,0,0,0,17,0,0,0,25,0,0,0,33,0,0,0,49,0,0,0,65,0,0,0,97,0,0,0,129,0,0,0,193,0,0,0,1,1,0,0,129,1,0,0,1,2,0,0,1,3,0,0,1,4,0,0,1,6,0,0,1,8,0,0,1,12,0,0,1,16,0,0,1,24,0,0,1,32,0,0,1,48,0,0,1,64,0,0,1,96,0,0,0,0,0,0,0,0,0,0,232,173,0,0,216,113,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,88,101,1,0,216,113,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,157,0,0,216,113,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,255,0,0,208,225,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,246,0,0,184,244,0,0,184,241,0,0,240,237,0,0,248,232,0,0,200,230,0,0,184,228,0,0,192,226,0,0,168,224,0,0,200,222,0,0,248,220,0,0,80,219,0,0,16,217,0,0,128,214,0,0,104,210,0,0,48,208,0,0,128,206,0,0,8,205,0,0,32,204,0,0,8,203,0,0,240,201,0,0,104,200,0,0,120,199,0,0,152,197,0,0,216,194,0,0,64,193,0,0,224,191,0,0,128,190,0,0,128,189,0,0,88,188,0,0,96,187,0,0,200,185,0,0,120,184,0,0,152,182,0,0,208,178,0,0,168,147,40,0,168,147,40,0,96,175,0,0,168,147,40,0,168,147,40,0,48,174,0,0,0,173,0,0,192,171,0,0,208,170,0,0,24,169,0,0,168,147,40,0,168,147,40,0,168,147,40,0,168,147,40,0,168,147,40,0,56,68,1,0,96,15,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,16,36,1,0,112,32,1,0,154,2,0,0,88,28,1,0,216,24,1,0,16,39,0,0,184,19,1,0,176,13,1,0,17,39,0,0,224,8,1,0,8,5,1,0,18,39,0,0,56,1,1,0,184,253,0,0,0,0,0,0,15,0,0,0,0,0,0,0,48,163,0,0,232,148,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,195,0,0,56,180,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,233,0,0,176,211,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,67,1,0,56,15,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,0,0,184,211,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,80,1,0,112,144,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,78,1,0,64,144,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,147,1,0,88,155,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,195,0,0,24,180,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,186,0,0,0,188,0,0,0,190,0,0,0,192,0,0,0,40,15,1,0,0,0,0,0,88,10,1,0,1,0,0,0,128,6,1,0,2,0,0,0,104,2,1,0,3,0,0,0,232,254,0,0,4,0,0,0,128,251,0,0,5,0,0,0,120,248,0,0,6,0,0,0,88,245,0,0,7,0,0,0,216,242,0,0,8,0,0,0,128,239,0,0,9,0,0,0,208,233,0,0,10,0,0,0,176,231,0,0,11,0,0,0,176,229,0,0,12,0,0,0,112,227,0,0,13,0,0,0,152,225,0,0,14,0,0,0,96,223,0,0,15,0,0,0,208,221,0,0,16,0,0,0,240,219,0,0,17,0,0,0,128,218,0,0,18,0,0,0,248,215,0,0,19,0,0,0,160,211,0,0,20,0,0,0,80,209,0,0,21,0,0,0,240,206,0,0,22,0,0,0,88,205,0,0,23,0,0,0,112,204,0,0,24,0,0,0,104,203,0,0,25,0,0,0,72,202,0,0,26,0,0,0,208,200,0,0,27,0,0,0,208,199,0,0,28,0,0,0,80,198,0,0,29,0,0,0,56,195,0,0,30,0,0,0,144,193,0,0,31,0,0,0,64,192,0,0,32,0,0,0,232,190,0,0,33,0,0,0,208,189,0,0,34,0,0,0,200,188,0,0,35,0,0,0,192,187,0,0,36,0,0,0,56,186,0,0,37,0,0,0,248,184,0,0,38,0,0,0,24,183,0,0,39,0,0,0,32,180,0,0,40,0,0,0,152,177,0,0,41,0,0,0,0,176,0,0,42,0,0,0,144,174,0,0,43,0,0,0,120,173,0,0,44,0,0,0,48,172,0,0,45,0,0,0,48,171,0,0,46,0,0,0,192,169,0,0,47,0,0,0,32,168,0,0,48,0,0,0,152,166,0,0,49,0,0,0,32,163,0,0,50,0,0,0,56,161,0,0,51,0,0,0,160,159,0,0,52,0,0,0,120,158,0,0,53,0,0,0,56,157,0,0,54,0,0,0,64,156,0,0,55,0,0,0,114,101,99,117,114,115,105,118,101,32,115,104,117,116,100,111,119,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,5,1,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,1,1,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,137,1,0,48,131,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,123,125,41,40,39,58,0,0,2,0,0,0,120,0,0,0,34,0,0,0,216,125,1,0,120,110,1,0,32,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,128,63,0,0,128,191,0,0,128,63,40,0,0,0,56,0,0,0,80,0,0,0,104,0,0,0,140,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,176,204,0,0,216,113,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,165,0,0,0,151,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,221,0,0,216,151,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,219,0,0,216,151,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,218,0,0,216,151,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,215,0,0,216,151,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,99,1,0,136,146,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,66,1,0,32,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,58,1,0,208,75,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,83,1,0,208,75,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,97,1,0,64,90,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,13,1,0,168,140,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,65,1,0,168,140,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,61,1,0,168,140,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,69,1,0,88,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,51,1,0,200,46,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,14,1,0,56,9,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,223,0,0,216,151,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,231,0,0,216,151,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,229,0,0,216,151,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,227,0,0,216,151,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,225,0,0,216,151,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,144,0,0,216,113,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,217,0,0,48,214,0,0,40,210,0,0,216,207,0,0,96,206,0,0,248,204,0,0,16,204,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,111,114,109,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,56,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,55,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,15,1,0,152,149,1,0,32,149,1,0,152,147,1,0,160,146,1,0,168,145,1,0,240,144,1,0,88,144,1,0,24,142,1,0,200,141,1,0,72,140,1,0,184,138,1,0,0,138,1,0,144,137,1,0,224,136,1,0,80,136,1,0,200,135,1,0,104,135,1,0,0,135,1,0,208,132,1,0,56,132,1,0,176,131,1,0,96,131,1,0,224,130,1,0,104,130,1,0,24,130,1,0,208,129,1,0,120,129,1,0,96,128,1,0,96,126,1,0,176,125,1,0,192,124,1,0,48,124,1,0,136,123,1,0,176,122,1,0,0,0,0,0,1,0,0,0,32,122,1,0,1,0,0,0,7,0,0,0,64,121,1,0,8,0,0,0,8,0,0,0,48,151,1,0,16,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,2,0,0,0,1,1,0,0,4,1,0,0,4,2,0,0,4,3,0,0,4,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,3,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,160,200,17,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,9,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,104,100,1,0,152,150,40,0,176,146,1,0,160,150,40,0,240,69,1,0,88,150,40,0,128,16,1,0,40,150,40,0,0,235,0,0,72,150,40,0,176,212,0,0,8,150,40,0,232,195,0,0,128,150,40,0,200,180,0,0,24,150,40,0,240,163,0,0,16,150,40,0,144,149,0,0,200,150,40,0,208,166,1,0,216,150,40,0,32,154,1,0,208,150,40,0,88,142,1,0,144,150,40,0,144,133,1,0,224,150,40,0,80,127,1,0,168,150,40,0,176,118,1,0,136,150,40,0,136,110,1,0,80,150,40,0,40,104,1,0,184,150,40,0,96,97,1,0,176,150,40,0,72,90,1,0,192,150,40,0,112,83,1,0,120,150,40,0,216,75,1,0,32,150,40,0,120,66,1,0,48,150,40,0,176,58,1,0,64,150,40,0,192,51,1,0,112,150,40,0,208,46,1,0,56,150,40,0,88,41,1,0,104,150,40,0,112,36,1,0,96,150,40,0,0,0,0,0,0,0,0,0,248,194,0,0,240,178,0,0,144,162,0,0,104,148,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,48,119,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,32,117,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,80,116,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,32,115,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,176,114,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,48,114,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,168,113,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,88,113,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,8,113,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,144,112,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,240,110,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,176,109,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,88,109,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,120,108,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,216,107,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,144,107,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,32,107,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,128,106,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,48,106,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,216,105,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,104,104,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,32,103,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,96,102,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,152,101,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,96,101,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,48,119,1,0,122,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,32,117,1,0,97,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,80,116,1,0,47,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,32,115,1,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,176,114,1,0,17,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,48,114,1,0,18,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,168,113,1,0,20,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,88,113,1,0,19,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,8,113,1,0,120,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,144,112,1,0,115,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,240,110,1,0,113,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,176,109,1,0,119,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,88,109,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,120,108,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,216,107,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,144,107,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,32,107,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,128,106,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,48,106,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,216,105,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,104,104,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,32,103,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,96,102,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,152,101,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,96,101,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,25,0,0,0,40,101,1,0,32,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,26,0,0,0,192,100,1,0,108,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,27,0,0,0,136,100,1,0,29,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,28,0,0,0,32,100,1,0,27,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,29,0,0,0,128,99,1,0,102,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,30,0,0,0,224,97,1,0,27,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,31,0,0,0,120,96,1,0,32,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,32,0,0,0,168,95,1,0,31,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,33,0,0,0,208,94,1,0,114,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,34,0,0,0,96,94,1,0,111,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,35,0,0,0,176,93,1,0,112,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,36,0,0,0,48,93,1,0,107,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,37,0,0,0,208,92,1,0,104,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,38,0,0,0,128,92,1,0,109,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,39,0,0,0,32,92,1,0,110,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,40,0,0,0,184,90,1,0,121,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,41,0,0,0,72,89,1,0,116,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,42,0,0,0,208,88,1,0,117,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,43,0,0,0,0,88,1,0,33,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,44,0,0,0,176,87,1,0,99,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,45,0,0,0,136,87,1,0,34,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,46,0,0,0,240,86,1,0,105,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,47,0,0,0,160,86,1,0,101,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,48,0,0,0,0,86,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,49,0,0,0,152,85,1,0,14,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,50,0,0,0,224,83,1,0,13,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,51,0,0,0,184,82,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,52,0,0,0,48,82,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,53,0,0,0,104,81,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,54,0,0,0,32,81,1,0,36,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,55,0,0,0,168,80,1,0,26,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,152,49,1,0,64,138,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,0,0,0,20,1,0,0,39,0,0,0,19,1,0,0,38,0,0,0,17,1,0,0,40,0,0,0,18,1,0,0,13,0,0,0,13,0,0,0,9,0,0,0,9,0,0,0,45,0,0,0,21,1,0,0,46,0,0,0,127,0,0,0,16,0,0,0,47,1,0,0,16,0,0,0,48,1,0,0,17,0,0,0,50,1,0,0,35,0,0,0,23,1,0,0,36,0,0,0,22,1,0,0,34,0,0,0,25,1,0,0,33,0,0,0,24,1,0,0,18,0,0,0,52,1,0,0,32,0,0,0,32,0,0,0,27,0,0,0,27,0,0,0,8,0,0,0,8,0,0,0,13,0,0,0,15,1,0,0,107,0,0,0,14,1,0,0,109,0,0,0,13,1,0,0,106,0,0,0,12,1,0,0,111,0,0,0,11,1,0,0,192,0,0,0,96,0,0,0,19,0,0,0,19,0,0,0,96,0,0,0,0,1,0,0,97,0,0,0,1,1,0,0,98,0,0,0,2,1,0,0,99,0,0,0,3,1,0,0,100,0,0,0,4,1,0,0,101,0,0,0,5,1,0,0,102,0,0,0,6,1,0,0,103,0,0,0,7,1,0,0,104,0,0,0,8,1,0,0,105,0,0,0,9,1,0,0,48,0,0,0,48,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,50,0,0,0,51,0,0,0,51,0,0,0,52,0,0,0,52,0,0,0,53,0,0,0,53,0,0,0,54,0,0,0,54,0,0,0,55,0,0,0,55,0,0,0,56,0,0,0,56,0,0,0,57,0,0,0,57,0,0,0,112,0,0,0,26,1,0,0,113,0,0,0,27,1,0,0,114,0,0,0,28,1,0,0,115,0,0,0,29,1,0,0,116,0,0,0,30,1,0,0,117,0,0,0,31,1,0,0,118,0,0,0,32,1,0,0,119,0,0,0,33,1,0,0,120,0,0,0,34,1,0,0,121,0,0,0,35,1,0,0,122,0,0,0,36,1,0,0,123,0,0,0,37,1,0,0,65,0,0,0,97,0,0,0,66,0,0,0,98,0,0,0,67,0,0,0,99,0,0,0,68,0,0,0,100,0,0,0,69,0,0,0,101,0,0,0,70,0,0,0,102,0,0,0,71,0,0,0,103,0,0,0,72,0,0,0,104,0,0,0,73,0,0,0,105,0,0,0,74,0,0,0,106,0,0,0,75,0,0,0,107,0,0,0,76,0,0,0,108,0,0,0,77,0,0,0,109,0,0,0,78,0,0,0,110,0,0,0,79,0,0,0,111,0,0,0,80,0,0,0,112,0,0,0,81,0,0,0,113,0,0,0,82,0,0,0,114,0,0,0,83,0,0,0,115,0,0,0,84,0,0,0,116,0,0,0,85,0,0,0,117,0,0,0,86,0,0,0,118,0,0,0,87,0,0,0,119,0,0,0,88,0,0,0,120,0,0,0,89,0,0,0,121,0,0,0,90,0,0,0,122,0,0,0,0,0,0,0,0,0,0,0,112,107,1,0,0,101,1,0,160,93,1,0,88,87,1,0,128,80,1,0,48,71,1,0,56,62,1,0,16,55,1,0,192,48,1,0,8,44,1,0,48,38,1,0,200,34,1,0,232,30,1,0,80,27,1,0,96,23,1,0,120,17,1,0,109,0,0,0,107,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,111,0,0,0,110,0,0,0,109,0,0,0,108,0,0,0,107,0,0,0,106,0,0,0,104,0,0,0,102,0,0,0,111,0,0,0,109,0,0,0,107,0,0,0,105,0,0,0,103,0,0,0,101,0,0,0,99,0,0,0,97,0,0,0,224,181,0,0,80,165,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,192,0,0,0,96,202,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,254,0,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,72,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0].concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,9,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,14,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,216,133,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,127,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,66,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,76,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,119,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,111,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,73,1,0,120,150,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,127,1,0,120,150,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,18,1,0,152,236,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,104,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,208,5,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,168,1,0,80,165,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,122,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,155,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,150,0,0,80,165,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,213,0,0,0,197,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,150,6,191,0,0,0,0,68,196,89,63,240,190,226,190,171,150,116,62,109,59,93,63,246,41,151,190,0,0,0,0,154,150,116,63,122,55,158,190,0,0,0,63,189,27,79,63,234,91,38,190,95,150,134,62,104,120,115,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,68,196,89,63,79,150,6,63,246,41,23,190,239,112,55,63,18,133,46,63,246,41,23,62,239,112,55,63,18,133,46,63,0,0,0,0,79,150,6,63,68,196,89,63,122,55,158,62,0,0,0,63,189,27,79,63,79,150,6,63,0,0,0,0,68,196,89,63,246,41,151,62,0,0,0,0,154,150,116,63,240,190,226,62,171,150,116,62,109,59,93,63,234,91,38,62,95,150,134,62,104,120,115,63,18,133,46,191,246,41,23,62,239,112,55,63,189,27,79,191,122,55,158,62,0,0,0,63,20,121,22,191,51,196,217,62,73,45,48,63,68,196,89,191,79,150,6,63,0,0,0,0,109,59,93,191,240,190,226,62,171,150,116,62,239,112,55,191,18,133,46,63,246,41,23,62,73,45,48,191,20,121,22,63,51,196,217,62,0,0,0,191,189,27,79,63,122,55,158,62,171,150,116,190,109,59,93,63,240,190,226,62,51,196,217,190,73,45,48,63,20,121,22,63,239,112,55,191,18,133,46,63,246,41,23,190,0,0,0,191,189,27,79,63,122,55,158,190,79,150,6,191,68,196,89,63,0,0,0,0,0,0,0,0,68,196,89,63,79,150,6,191,171,150,116,190,109,59,93,63,240,190,226,190,0,0,0,0,154,150,116,63,246,41,151,190,95,150,134,190,104,120,115,63,234,91,38,190,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,154,150,116,63,246,41,151,62,95,150,134,190,104,120,115,63,234,91,38,62,171,150,116,62,109,59,93,63,240,190,226,62,95,150,134,62,104,120,115,63,234,91,38,62,0,0,0,63,189,27,79,63,122,55,158,62,171,150,116,62,109,59,93,63,240,190,226,190,95,150,134,62,104,120,115,63,234,91,38,190,0,0,0,63,189,27,79,63,122,55,158,190,68,196,89,63,79,150,6,63,0,0,0,0,239,112,55,63,18,133,46,63,246,41,23,62,239,112,55,63,18,133,46,63,246,41,23,190,79,150,6,63,68,196,89,63,0,0,0,0,51,196,217,62,73,45,48,63,20,121,22,63,109,59,93,63,240,190,226,62,171,150,116,62,73,45,48,63,20,121,22,63,51,196,217,62,189,27,79,63,122,55,158,62,0,0,0,63,18,133,46,63,246,41,23,62,239,112,55,63,20,121,22,63,51,196,217,62,73,45,48,63,154,150,116,63,246,41,151,62,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,104,120,115,63,234,91,38,62,95,150,134,62,68,196,89,63,79,150,6,191,0,0,0,0,154,150,116,63,246,41,151,190,0,0,0,0,109,59,93,63,240,190,226,190,171,150,116,62,104,120,115,63,234,91,38,190,95,150,134,62,189,27,79,63,122,55,158,190,0,0,0,63,18,133,46,63,246,41,23,190,239,112,55,63,68,196,89,63,0,0,0,0,79,150,6,63,109,59,93,63,240,190,226,62,171,150,116,190,189,27,79,63,122,55,158,62,0,0,0,191,104,120,115,63,234,91,38,62,95,150,134,190,79,150,6,63,0,0,0,0,68,196,89,191,18,133,46,63,246,41,23,62,239,112,55,191,18,133,46,63,246,41,23,190,239,112,55,191,68,196,89,63,0,0,0,0,79,150,6,191,189,27,79,63,122,55,158,190,0,0,0,191,109,59,93,63,240,190,226,190,171,150,116,190,104,120,115,63,234,91,38,190,95,150,134,190,246,41,23,62,239,112,55,63,18,133,46,191,122,55,158,62,0,0,0,63,189,27,79,191,51,196,217,62,73,45,48,63,20,121,22,191,240,190,226,62,171,150,116,62,109,59,93,191,20,121,22,63,51,196,217,62,73,45,48,191,73,45,48,63,20,121,22,63,51,196,217,190,246,41,23,190,239,112,55,63,18,133,46,191,122,55,158,190,0,0,0,63,189,27,79,191,0,0,0,0,79,150,6,63,68,196,89,191,79,150,6,191,0,0,0,0,68,196,89,191,240,190,226,190,171,150,116,62,109,59,93,191,246,41,151,190,0,0,0,0,154,150,116,191,234,91,38,190,95,150,134,62,104,120,115,191,0,0,0,0,0,0,0,0,0,0,128,191,246,41,151,62,0,0,0,0,154,150,116,191,234,91,38,62,95,150,134,62,104,120,115,191,240,190,226,190,171,150,116,190,109,59,93,191,122,55,158,190,0,0,0,191,189,27,79,191,234,91,38,190,95,150,134,190,104,120,115,191,0,0,0,0,68,196,89,191,79,150,6,191,246,41,23,190,239,112,55,191,18,133,46,191,246,41,23,62,239,112,55,191,18,133,46,191,0,0,0,0,79,150,6,191,68,196,89,191,122,55,158,62,0,0,0,191,189,27,79,191,240,190,226,62,171,150,116,190,109,59,93,191,234,91,38,62,95,150,134,190,104,120,115,191,171,150,116,62,109,59,93,191,240,190,226,190,0,0,0,63,189,27,79,191,122,55,158,190,51,196,217,62,73,45,48,191,20,121,22,191,239,112,55,63,18,133,46,191,246,41,23,190,73,45,48,63,20,121,22,191,51,196,217,190,20,121,22,63,51,196,217,190,73,45,48,191,0,0,0,0,154,150,116,191,246,41,151,190,0,0,0,0,0,0,128,191,0,0,0,0,95,150,134,62,104,120,115,191,234,91,38,190,0,0,0,0,68,196,89,191,79,150,6,63,0,0,0,0,154,150,116,191,246,41,151,62,171,150,116,62,109,59,93,191,240,190,226,62,95,150,134,62,104,120,115,191,234,91,38,62,0,0,0,63,189,27,79,191,122,55,158,62,239,112,55,63,18,133,46,191,246,41,23,62,79,150,6,63,68,196,89,191,0,0,0,0,171,150,116,190,109,59,93,191,240,190,226,190,0,0,0,191,189,27,79,191,122,55,158,190,95,150,134,190,104,120,115,191,234,91,38,190,68,196,89,191,79,150,6,191,0,0,0,0,239,112,55,191,18,133,46,191,246,41,23,190,239,112,55,191,18,133,46,191,246,41,23,62,79,150,6,191,68,196,89,191,0,0,0,0,0,0,0,191,189,27,79,191,122,55,158,62,171,150,116,190,109,59,93,191,240,190,226,62,95,150,134,190,104,120,115,191,234,91,38,62,109,59,93,191,240,190,226,190,171,150,116,62,189,27,79,191,122,55,158,190,0,0,0,63,73,45,48,191,20,121,22,191,51,196,217,62,18,133,46,191,246,41,23,190,239,112,55,63,240,190,226,190,171,150,116,190,109,59,93,63,20,121,22,191,51,196,217,190,73,45,48,63,122,55,158,190,0,0,0,191,189,27,79,63,246,41,23,190,239,112,55,191,18,133,46,63,51,196,217,190,73,45,48,191,20,121,22,63,234,91,38,190,95,150,134,190,104,120,115,63,240,190,226,62,171,150,116,190,109,59,93,63,234,91,38,62,95,150,134,190,104,120,115,63,122,55,158,62,0,0,0,191,189,27,79,63,246,41,23,62,239,112,55,191,18,133,46,63,0,0,0,0,79,150,6,191,68,196,89,63,51,196,217,62,73,45,48,191,20,121,22,63,20,121,22,63,51,196,217,190,73,45,48,63,73,45,48,63,20,121,22,191,51,196,217,62,154,150,116,191,246,41,151,62,0,0,0,0,104,120,115,191,234,91,38,62,95,150,134,62,0,0,128,191,0,0,0,0,0,0,0,0,68,196,89,191,0,0,0,0,79,150,6,63,154,150,116,191,246,41,151,190,0,0,0,0,104,120,115,191,234,91,38,190,95,150,134,62,109,59,93,191,240,190,226,62,171,150,116,190,104,120,115,191,234,91,38,62,95,150,134,190,189,27,79,191,122,55,158,62,0,0,0,191,109,59,93,191,240,190,226,190,171,150,116,190,104,120,115,191,234,91,38,190,95,150,134,190,189,27,79,191,122,55,158,190,0,0,0,191,18,133,46,191,246,41,23,62,239,112,55,191,18,133,46,191,246,41,23,190,239,112,55,191,68,196,89,191,0,0,0,0,79,150,6,191,73,45,48,191,20,121,22,63,51,196,217,190,20,121,22,191,51,196,217,62,73,45,48,191,51,196,217,190,73,45,48,63,20,121,22,191,51,196,217,190,73,45,48,191,20,121,22,191,20,121,22,191,51,196,217,190,73,45,48,191,73,45,48,191,20,121,22,191,51,196,217,190,200,142,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,160,25,1,0,216,20,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,33,1,0,0,29,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,1,1,0,184,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,23,1,0,192,23,1,0,160,23,1,0,64,23,1,0,24,23,1,0,216,22,1,0,144,22,1,0,64,23,1,0,8,22,1,0,200,19,1,0,24,19,1,0,64,23,1,0,208,18,1,0,32,18,1,0,0,18,1,0,72,17,1,0,96,16,1,0,224,15,1,0,128,15,1,0,64,15,1,0,232,13,1,0,224,12,1,0,144,12,1,0,56,12,1,0,16,12,1,0,64,11,1,0,24,11,1,0,216,10,1,0,136,10,1,0,104,10,1,0,8,9,1,0,64,23,1,0,48,233,0,0,48,133,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,144,1,0,120,153,1,0,72,75,1,0,192,19,1,0,16,238,0,0,144,214,0,0,144,197,0,0,144,182,0,0,152,165,0,0,16,151,0,0,160,168,1,0,16,156,1,0,56,143,1,0,96,134,1,0,88,128,1,0,184,119,1,0,192,111,1,0,32,105,1,0,208,98,1,0,80,91,1,0,176,84,1,0,40,77,1,0,32,67,1,0,184,59,1,0,208,52,1,0,208,52,1,0,208,52,1,0,208,52,1,0,208,52,1,0,208,52,1,0,104,47,1,0,8,42,1,0,64,37,1,0,184,33,1,0,104,29,1,0,24,26,1,0,136,21,1,0,24,15,1,0,72,10,1,0,112,6,1,0,88,2,1,0,216,254,0,0,112,251,0,0,112,248,0,0,80,245,0,0,208,242,0,0,120,239,0,0,200,233,0,0,168,231,0,0,168,229,0,0,104,227,0,0,144,225,0,0,88,223,0,0,200,221,0,0,232,219,0,0,120,218,0,0,240,215,0,0,152,211,0,0,72,209,0,0,232,206,0,0,80,205,0,0,104,204,0,0,96,203,0,0,64,202,0,0,200,200,0,0,200,199,0,0,79,0,0,0,0,0,0,0,168,54,0,0,0,0,0,0,168,1,0,0,120,0,0,0,240,1,0,0,194,1,0,0,90,0,0,0,168,1,0,0,106,0,0,0,208,0,0,0,190,1,0,0,192,1,0,0,122,0,0,0,14,2,0,0,10,0,0,0,108,1,0,0,100,0,0,0,60,1,0,0,132,0,0,0,78,1,0,0,94,1,0,0,244,1,0,0,72,1,0,0,84,1,0,0,6,1,0,0,82,1,0,0,64,0,0,0,176,0,0,0,252,0,0,0,66,0,0,0,198,1,0,0,248,0,0,0,86,0,0,0,98,0,0,0,70,1,0,0,168,1,0,0,20,2,0,0,248,1,0,0,122,1,0,0,4,1,0,0,22,2,0,0,168,1,0,0,188,1,0,0,238,0,0,0,168,1,0,0,138,1,0,0,146,1,0,0,162,0,0,0,68,0,0,0,106,1,0,0,244,0,0,0,102,1,0,0,168,1,0,0,162,1,0,0,104,0,0,0,164,1,0,0,218,0,0,0,226,0,0,0,130,0,0,0,202,1,0,0,182,1,0,0,78,0,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,168,1,0,0,242,0,0,0,148,0,0,0,54,1,0,0,134,1,0,0,168,1,0,0,6,0,0,0,236,0,0,0,254,1,0,0,72,1,0,0,244,1,0,0,148,0,0,0,142,0,0,0,0,0,0,0,0,0,0,0,0,0,36,64,0,0,0,0,0,0,89,64,0,0,0,0,0,136,195,64,0,0,0,0,132,215,151,65,0,128,224,55,121,195,65,67,23,110,5,181,181,184,147,70,245,249,63,233,3,79,56,77,50,29,48,249,72,119,130,90,60,191,115,127,221,79,21,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,102,0,0,0,0,102,0,0,0,0,0,0,0,0,0,103,0,0,0,0,0,101,102,0,0,0,0,0,0,0,0,101,0,0,102,99,0,97,101,0,0,0,0,0,0,0,0,97,0,99,101,100,0,97,101,0,0,0,0,0,0,0,0,97,0,100,101,100,0,100,101,0,0,105,100,105,105,0,100,100,0,100,101,99,0,104,101,0,98,100,0,100,104,0,0,104,98,99,101,0,0,103,101,99,105,100,0,100,103,99,0,103,105,0,101,0,0,102,98,105,103,104,106,104,103,105,106,102,103,0,98,0,0,98,0,102,101,102,102,102,102,102,102,98,101,0,0,0,0,0,0,98,0,100,99,100,102,98,99,0,0,0,0,0,0,0,0,0,0,98,0,98,102,0,0,0,0,0,0,0,0,0,0,0,0,97,0,97,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,8,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,137,80,78,71,13,10,26,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,107,1,0,48,131,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,231,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,135,1,0,216,151,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,1,0,216,113,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,64,159,1,0,32,157,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,48,1,0,0,0,0,0,4,0,0,0,56,0,0,0,106,0,0,0,74,0,0,0,24,0,0,0,66,0,0,0,30,0,0,0,10,0,0,0,98,0,0,0,82,0,0,0,100,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,0,128,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,142,1,0,0,156,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,119,1,0,72,111,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,168,1,0,0,156,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,134,1,0,0,128,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,182,0,0,176,19,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,197,0,0,176,19,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,69,1,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,15,1,0,200,10,1,0,232,6,1,0,216,2,1,0,96,255,0,0,224,251,0,0,216,248,0,0,176,245,0,0,96,243,0,0,168,240,0,0,56,234,0,0,224,231,0,0,232,229,0,0,208,227,0,0,176,225,0,0,136,223,0,0,8,222,0,0,24,220,0,0,208,218,0,0,176,216,0,0,0,212,0,0,104,209,0,0,8,207,0,0,208,205,0,0,144,204,0,0,136,203,0,0,136,202,0,0,248,200,0,0,8,200,0,0,32,199,0,0,168,195,0,0,192,193,0,0,112,192,0,0,64,191,0,0,0,190,0,0,240,188,0,0,16,188,0,0,72,186,0,0,96,185,0,0,24,184,0,0,120,180,0,0,216,177,0,0,64,176,0,0,184,174,0,0,176,173,0,0,80,172,0,0,80,171,0,0,240,169,0,0,168,168,0,0,40,167,0,0,176,163,0,0,96,161,0,0,224,159,0,0,160,158,0,0,96,157,0,0,96,156,0,0,160,155,0,0,8,154,0,0,48,153,0,0,56,152,0,0,48,149,0,0,88,147,0,0,56,146,0,0,40,145,0,0,88,144,0,0,120,143,0,0,192,142,0,0,184,141,0,0,0,141,0,0,192,169,1,0,136,166,1,0,80,165,1,0,128,164,1,0,184,163,1,0,224,162,1,0,8,162,1,0,72,0,0,0,92,0,0,0,124,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,32,177,0,0,9,0,0,0,120,102,1,0,13,0,0,0,200,35,1,0,27,0,0,0,40,250,0,0,32,0,0,0,136,222,0,0,8,0,0,0,200,202,0,0,17,1,0,0,72,188,0,0,18,1,0,0,176,171,0,0,19,1,0,0,248,155,0,0,20,1,0,0,32,143,0,0,52,1,0,0,160,161,1,0,51,1,0,0,240,146,1,0,50,1,0,0,176,136,1,0,49,1,0,0,96,130,1,0,48,1,0,0,168,122,1,0,47,1,0,0,192,113,1,0,26,1,0,0,48,107,1,0,27,1,0,0,216,100,1,0,28,1,0,0,64,93,1,0,29,1,0,0,8,87,1,0,30,1,0,0,32,80,1,0,31,1,0,0,8,70,1,0,32,1,0,0,200,61,1,0,33,1,0,0,152,54,1,0,34,1,0,0,136,48,1,0,35,1,0,0,176,43,1,0,36,1,0,0,32,38,1,0,37,1,0,0,176,34,1,0,21,1,0,0,200,30,1,0,127,0,0,0,64,27,1,0,25,1,0,0,56,23,1,0,24,1,0,0,152,16,1,0,22,1,0,0,56,11,1,0,23,1,0,0,16,7,1,0,67,1,0,0,48,3,1,0,68,1,0,0,120,255,0,0,69,1,0,0,48,252,0,0,70,1,0,0,16,249,0,0,71,1,0,0,232,245,0,0,72,1,0,0,120,243,0,0,73,1,0,0,216,240,0,0,74,1,0,0,16,235,0,0,75,1,0,0,8,232,0,0,76,1,0,0,40,230,0,0,77,1,0,0,0,228,0,0,78,1,0,0,200,225,0,0,79,1,0,0,184,223,0,0,80,1,0,0,32,222,0,0,81,1,0,0,88,220,0,0,82,1,0,0,248,218,0,0,83,1,0,0,224,216,0,0,84,1,0,0,200,212,0,0,85,1,0,0,144,209,0,0,86,1,0,0,40,207,0,0,87,1,0,0,248,205,0,0,88,1,0,0,168,204,0,0,89,1,0,0,192,203,0,0,90,1,0,0,160,202,0,0,91,1,0,0,48,201,0,0,92,1,0,0,40,200,0,0,93,1,0,0,80,199,0,0,94,1,0,0,0,196,0,0,95,1,0,0,224,193,0,0,96,1,0,0,144,192,0,0,97,1,0,0,112,191,0,0,98,1,0,0,32,190,0,0,99,1,0,0,32,189,0,0,100,1,0,0,32,188,0,0,101,1,0,0,120,186,0,0,102,1,0,0,128,185,0,0,103,1,0,0,72,184,0,0,104,1,0,0,192,180,0,0,105,1,0,0,248,177,0,0,106,1,0,0,88,176,0,0,107,1,0,0,224,174,0,0,108,1,0,0,192,173,0,0,109,1,0,0,120,172,0,0,110,1,0,0,104,171,0,0,19,0,0,0,40,170,0,0,70,1,0,0,192,168,0,0,71,1,0,0,80,167,0,0,59,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,160,200,17,0,96,209,17,0,32,218,17,0,224,226,17,0,160,235,17,0,96,244,17,0,32,253,17,0,224,5,18,0,20,0,0,0,88,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,0,0,0,0,224,163,1,0,10,0,0,0,16,130,1,0,20,1,0,0,112,113,1,0,19,1,0,0,56,142,0,0,17,1,0,0,8,146,1,0,18,1,0,0,72,151,1,0,13,0,0,0,168,149,1,0,15,1,0,0,40,149,1,0,9,0,0,0,176,147,1,0,21,1,0,0,168,146,1,0,127,0,0,0,184,145,1,0,23,1,0,0,0,145,1,0,22,1,0,0,104,144,1,0,47,1,0,0,40,142,1,0,48,1,0,0,160,140,1,0,50,1,0,0,216,138,1,0,52,1,0,0,16,138,1,0,32,0,0,0,176,137,1,0,27,0,0,0,248,136,1,0,14,1,0,0,128,136,1,0,13,1,0,0,224,135,1,0,14,1,0,0,152,135,1,0,13,1,0,0,56,135,1,0,26,1,0,0,40,133,1,0,27,1,0,0,72,132,1,0,28,1,0,0,208,131,1,0,29,1,0,0,112,131,1,0,30,1,0,0,40,131,1,0,31,1,0,0,144,130,1,0,32,1,0,0,72,130,1,0,33,1,0,0,240,129,1,0,34,1,0,0,168,129,1,0,35,1,0,0,72,129,1,0,36,1,0,0,192,126,1,0,37,1,0,0,208,125,1,0,48,0,0,0,16,125,1,0,49,0,0,0,120,124,1,0,50,0,0,0,240,123,1,0,51,0,0,0,224,122,1,0,52,0,0,0,120,122,1,0,53,0,0,0,168,121,1,0,54,0,0,0,32,121,1,0,55,0,0,0,168,120,1,0,56,0,0,0,240,117,1,0,57,0,0,0,224,116,1,0,24,1,0,0,192,115,1,0,25,1,0,0,24,115,1,0,0,1,0,0,160,114,1,0,1,1,0,0,224,113,1,0,2,1,0,0,208,113,1,0,3,1,0,0,144,113,1,0,4,1,0,0,40,113,1,0,5,1,0,0,192,112,1,0,6,1,0,0,112,112,1,0,7,1,0,0,48,110,1,0,8,1,0,0,128,109,1,0,9,1,0,0,224,108,1,0,46,0,0,0,32,108,1,0,45,1,0,0,184,107,1,0,44,1,0,0,64,107,1,0,8,0,0,0,240,106,1,0,12,1,0,0,72,106,1,0,11,1,0,0,248,105,1,0,60,1,0,0,176,105,1,0,46,1,0,0,208,103,1,0,96,0,0,0,136,102,1,0,96,0,0,0,0,102,1,0,19,0,0,0,128,101,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,32,95,1,0,104,31,1,0,0,0,0,0,1,0,0,0,0,0,0,0,88,246,0,0,192,220,0,0,1,0,0,0,1,0,0,0,0,0,0,0,88,201,0,0,184,186,0,0,2,0,0,0,1,0,0,0,0,0,0,0,144,170,0,0,168,154,0,0,3,0,0,0,1,0,0,0,0,0,0,0,56,142,0,0,176,160,1,0,4,0,0,0,1,0,0,0,0,0,0,0,8,146,1,0,0,136,1,0,5,0,0,0,1,0,0,0,0,0,0,0,16,130,1,0,0,122,1,0,6,0,0,0,1,0,0,0,0,0,0,0,112,113,1,0,144,106,1,0,7,0,0,0,1,0,0,0,0,0,0,0,152,100,1,0,216,92,1,0,8,0,0,0,1,0,0,0,0,0,0,0,176,86,1,0,216,79,1,0,9,0,0,0,1,0,0,0,0,0,0,0,104,69,1,0,56,61,1,0,10,0,0,0,1,0,0,0,0,0,0,0,56,54,1,0,80,48,1,0,11,0,0,0,1,0,0,0,0,0,0,0,96,43,1,0,208,37,1,0,12,0,0,0,1,0,0,0,0,0,0,0,144,34,1,0,136,30,1,0,13,0,0,0,1,0,0,0,0,0,0,0,48,27,1,0,248,22,1,0,14,0,0,0,1,0,0,0,0,0,0,0,8,16,1,0,248,10,1,0,15,0,0,0,1,0,0,0,0,0,0,0,8,7,1,0,8,3,1,0,16,0,0,0,1,0,0,0,0,0,0,0,104,255,0,0,8,252,0,0,17,0,0,0,1,0,0,0,0,0,0,0,240,248,0,0,192,245,0,0,18,0,0,0,1,0,0,0,0,0,0,0,104,243,0,0,192,240,0,0,19,0,0,0,1,0,0,0,0,0,0,0,96,234,0,0,240,231,0,0,20,0,0,0,1,0,0,0,0,0,0,0,24,230,0,0,232,227,0,0,21,0,0,0,1,0,0,0,0,0,0,0,184,225,0,0,160,223,0,0,22,0,0,0,1,0,0,0,0,0,0,0,16,222,0,0,48,220,0,0,23,0,0,0,1,0,0,0,0,0,0,0,232,218,0,0,200,216,0,0,24,0,0,0,1,0,0,0,1,0,0,0,32,212,0,0,120,209,0,0,25,0,0,0,1,0,0,0,2,0,0,0,16,207,0,0,224,205,0,0,26,0,0,0,1,0,0,0,1,0,0,0,152,204,0,0,176,203,0,0,27,0,0,0,1,0,0,0,1,0,0,0,144,202,0,0,16,201,0,0,28,0,0,0,1,0,0,0,2,0,0,0,16,200,0,0,56,199,0,0,29,0,0,0,1,0,0,0,2,0,0,0,176,195,0,0,208,193,0,0,30,0,0,0,1,0,0,0,2,0,0,0,120,192,0,0,88,191,0,0,31,0,0,0,1,0,0,0,2,0,0,0,8,190,0,0,8,189,0,0,32,0,0,0,1,0,0,0,1,0,0,0,24,188,0,0,96,186,0,0,33,0,0,0,1,0,0,0,2,0,0,0,104,185,0,0,48,184,0,0,34,0,0,0,1,0,0,0,2,0,0,0,128,180,0,0,232,177,0,0,35,0,0,0,1,0,0,0,2,0,0,0,72,176,0,0,208,174,0,0,36,0,0,0,1,0,0,0,2,0,0,0,184,173,0,0,104,172,0,0,37,0,0,0,1,0,0,0,2,0,0,0,88,171,0,0,8,170,0,0,38,0,0,0,1,0,0,0,2,0,0,0,176,168,0,0,64,167,0,0,39,0,0,0,1,0,0,0,2,0,0,0,184,163,0,0,120,161,0,0,40,0,0,0,1,0,0,0,2,0,0,0,232,159,0,0,184,158,0,0,41,0,0,0,1,0,0,0,2,0,0,0,104,157,0,0,112,156,0,0,42,0,0,0,1,0,0,0,2,0,0,0,168,155,0,0,24,154,0,0,43,0,0,0,1,0,0,0,2,0,0,0,56,153,0,0,72,152,0,0,44,0,0,0,1,0,0,0,2,0,0,0,56,149,0,0,112,147,0,0,45,0,0,0,1,0,0,0,2,0,0,0,64,146,0,0,64,145,0,0,46,0,0,0,1,0,0,0,2,0,0,0,96,144,0,0,144,143,0,0,47,0,0,0,1,0,0,0,2,0,0,0,200,142,0,0,208,141,0,0,48,0,0,0,1,0,0,0,2,0,0,0,8,141,0,0,216,169,1,0,49,0,0,0,1,0,0,0,2,0,0,0,152,166,1,0,96,165,1,0,50,0,0,0,1,0,0,0,2,0,0,0,136,164,1,0,200,163,1,0,51,0,0,0,1,0,0,0,2,0,0,0,232,162,1,0,24,162,1,0,52,0,0,0,1,0,0,0,2,0,0,0,80,161,1,0,232,159,1,0,53,0,0,0,1,0,0,0,2,0,0,0,184,158,1,0,8,157,1,0,54,0,0,0,1,0,0,0,1,0,0,0,208,153,1,0,0,152,1,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,78,1,0,40,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,43,1,0,216,113,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,203,0,0,216,113,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,7,0,0,0,4,0,0,0,16,0,0,0,216,15,1,0,192,120,1,0,192,119,1,0,160,117,1,0,184,116,1,0,112,115,1,0,200,114,1,0,72,114,1,0,200,113,1,0,120,113,1,0,32,113,1,0,168,112,1,0,200,111,1,0,248,109,1,0,120,109,1,0,200,108,1,0,24,108,1,0,168,107,1,0,56,107,1,0,224,106,1,0,64,106,1,0,232,105,1,0,40,105,1,0,96,103,1,0,128,102,1,0,240,101,1,0,120,101,1,0,56,101,1,0,224,100,1,0,160,100,1,0,48,100,1,0,208,99,1,0,216,98,1,0,176,96,1,0,192,95,1,0,8,95,1,0,120,94,1,0,0,0,0,0,1,0,0,0,224,93,1,0,1,0,0,0,5,0,0,0,72,93,1,0,6,0,0,0,6,0,0,0,248,92,1,0,12,0,0,0,4,0,0,0,240,151,1,0,16,0,0,0,1,0,0,0,48,151,1,0,17,0,0,0,1,0,0,0,208,147,40,0,88,25,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,62,0,0,0,4,0,0,0,232,104,1,0,0,0,0,0,34,0,0,0,6,0,0,0,104,0,0,0,78,0,0,0,2,0,0,0,6,0,0,0,58,0,0,0,60,0,0,0,0,0,0,0,102,0,0,0,8,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,2,0,0,0,50,0,0,0,114,0,0,0,2,0,0,0,10,0,0,0,22,0,0,0,14,0,0,0,90,0,0,0,78,0,0,0,80,0,0,0,42,0,0,0,38,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,152,48,0,0,2,0,0,0,56,48,0,0,0,0,0,0,36,48,0,0,8,0,0,0,35,48,0,0,8,0,0,0,34,48,0,0,8,0,0,0,33,48,0,0,8,0,0,0,51,48,0,0,4,0,0,0,56,48,0,0,0,0,0,0,48,0,0,0,224,1,0,0,2,0,0,0,48,0,0,0,14,0,0,0,36,0,0,0,2,0,0,0,232,0,0,0,4,0,0,0,2,0,0,0,44,0,0,0,52,1,0,0,22,0,0,0,100,0,0,0,44,0,0,0,2,0,0,0,0,0,0,0,120,103,1,0,40,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,80,0,0,0,88,0,0,0,96,0,0,0,112,0,0,0,120,0,0,0,0,0,0,0,120,211,0,0,216,151,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,72,1,0,192,142,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,190,0,0,216,113,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,151,1,0,144,139,1,0,16,132,1,0,0,0,0,0,0,0,0,0,0,0,0,0,56,161,1,0,0,0,0,0,1,0,0,0,208,159,1,0,1,0,0,0,8,0,0,0,160,158,1,0,9,0,0,0,7,0,0,0,248,156,1,0,16,0,0,0,7,0,0,0,184,153,1,0,23,0,0,0,8,0,0,0,240,151,1,0,31,0,0,0,1,0,0,0,48,151,1,0,32,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,152,155,9,0,104,155,9,0,0,0,0,0,2,0,0,0,152,155,9,0,128,155,9,0,104,155,9,0,0,0,0,0,2,0,0,0,128,155,9,0,152,155,9,0,104,155,9,0,1,0,0,0,128,155,9,0,104,155,9,0,0,0,0,0,1,0,0,0,1,0,0,0,152,155,9,0,104,155,9,0,0,0,0,0,1,0,0,0,128,155,9,0,104,155,9,0,0,0,0,0,0,0,0,0,1,0,0,0,128,155,9,0,152,155,9,0,0,0,0,0,2,0,0,0,128,155,9,0,104,155,9,0,152,155,9,0,0,0,0,0,2,0,0,0,152,155,9,0,104,155,9,0,128,155,9,0,1,0,0,0,152,155,9,0,128,155,9,0,0,0,0,0,0,0,0,0,1,0,0,0,104,155,9,0,128,155,9,0,0,0,0,0,1,0,0,0,104,155,9,0,152,155,9,0,0,0,0,0,0,0,0,0,1,0,0,0,104,155,9,0,128,155,9,0,0,0,0,0,2,0,0,0,104,155,9,0,152,155,9,0,128,155,9,0,0,0,0,0,2,0,0,0,104,155,9,0,128,155,9,0,152,155,9,0,1,0,0,0,104,155,9,0,152,155,9,0,0,0,0,0,0,0,0,0,1,0,0,0,128,155,9,0,152,155,9,0,0,0,0,0,1,0,0,0,128,155,9,0,104,155,9,0,0,0,0,0,1,0,0,0,1,0,0,0,104,155,9,0,128,155,9,0,0,0,0,0,1,0,0,0,152,155,9,0,128,155,9,0,0,0,0,0,1,0,0,0,1,0,0,0,128,155,9,0,152,155,9,0,0,0,0,0,1,0,0,0,104,155,9,0,152,155,9,0,0,0,0,0,0,0,0,0,1,0,0,0,152,155,9,0,104,155,9,0,0,0,0,0,1,0,0,0,152,155,9,0,128,155,9,0,0,0,0,0,205,204,76,62,205,204,204,61,205,204,76,61,51,51,51,63,205,204,76,61,205,204,76,61,154,153,153,62,51,51,51,63,0,0,0,63,205,204,76,61,205,204,76,61,51,51,51,63,0,0,0,63,205,204,76,61,205,204,204,62,51,51,51,63,0,64,0,0,0,0,0,0,0,192,0,0,0,128,0,0,0,128,0,0,0,192,0,0,0,0,0,0,0,64,0,0,184,224,0,0,128,123,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,149,1,0,216,113,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,123,1,0,216,113,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,0,0,80,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,48,1,0,80,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([8,228,0,0,128,123,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,130,0,0,0,80,0,0,0,50,0,0,0,128,0,0,0,0,0,0,0,25,0,0,0,5,0,0,0,150,0,0,0,255,0,0,0,80,0,0,0,0,0,0,0,150,0,0,0,130,0,0,0,80,0,0,0,50,0,0,0,0,0,0,0,64,28,1,0,184,24,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,32,1,0,168,140,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,16,66,32,99,48,132,64,165,80,198,96,231,112,8,129,41,145,74,161,107,177,140,193,173,209,206,225,239,241,49,18,16,2,115,50,82,34,181,82,148,66,247,114,214,98,57,147,24,131,123,179,90,163,189,211,156,195,255,243,222,227,98,36,67,52,32,4,1,20,230,100,199,116,164,68,133,84,106,165,75,181,40,133,9,149,238,229,207,245,172,197,141,213,83,54,114,38,17,22,48,6,215,118,246,102,149,86,180,70,91,183,122,167,25,151,56,135,223,247,254,231,157,215,188,199,196,72,229,88,134,104,167,120,64,8,97,24,2,40,35,56,204,201,237,217,142,233,175,249,72,137,105,153,10,169,43,185,245,90,212,74,183,122,150,106,113,26,80,10,51,58,18,42,253,219,220,203,191,251,158,235,121,155,88,139,59,187,26,171,166,108,135,124,228,76,197,92,34,44,3,60,96,12,65,28,174,237,143,253,236,205,205,221,42,173,11,189,104,141,73,157,151,126,182,110,213,94,244,78,19,62,50,46,81,30,112,14,159,255,190,239,221,223,252,207,27,191,58,175,89,159,120,143,136,145,169,129,202,177,235,161,12,209,45,193,78,241,111,225,128,16,161,0,194,48,227,32,4,80,37,64,70,112,103,96,185,131,152,147,251,163,218,179,61,195,28,211,127,227,94,243,177,2,144,18,243,34,210,50,53,66,20,82,119,98,86,114,234,181,203,165,168,149,137,133,110,245,79,229,44,213,13,197,226,52,195,36,160,20,129,4,102,116,71,100,36,84,5,68,219,167,250,183,153,135,184,151,95,231,126,247,29,199,60,215,211,38,242,54,145,6,176,22,87,102,118,118,21,70,52,86,76,217,109,201,14,249,47,233,200,153,233,137,138,185,171,169,68,88,101,72,6,120,39,104,192,24,225,8,130,56,163,40,125,203,92,219,63,235,30,251,249,139,216,155,187,171,154,187,117,74,84,90,55,106,22,122,241,10,208,26,179,42,146,58,46,253,15,237,108,221,77,205,170,189,139,173,232,157,201,141,38,124,7,108,100,92,69,76,162,60,131,44,224,28,193,12,31,239,62,255,93,207,124,223,155,175,186,191,217,143,248,159,23,110,54,126,85,78,116,94,147,46,178,62,209,14,240,30,0,0,0,0,100,16,183,29,200,32,110,59,172,48,217,38,144,65,220,118,244,81,107,107,88,97,178,77,60,113,5,80,32,131,184,237,68,147,15,240,232,163,214,214,140,179,97,203,176,194,100,155,212,210,211,134,120,226,10,160,28,242,189,189,0,0,0,0,255,0,0,0,85,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,168,114,1,0,216,113,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,56,1,0,144,49,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,165,1,0,64,138,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,149,0,0,184,166,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,255,0,0,240,130,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,145,1,0,96,69,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,212,0,0,208,195,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,237,0,0,176,19,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,232,0,0,56,210,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,194,0,0,200,178,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,153,1,0,64,142,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,214,0,0,176,19,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,146,1,0,224,153,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,180,0,0,216,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,1,0,96,69,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,13,1,0,168,140,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,19,1,0,168,140,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,75,1,0,176,19,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,141,1,0,144,132,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,165,1,0,216,152,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,162,0,0,64,148,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,234,0,0,96,69,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,133,1,0,8,127,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,16,1,0,2,0,0,0,232,234,0,0,3,0,0,0,152,212,0,0,5,0,0,0,216,195,0,0,4,0,0,0,160,200,17,0,96,209,17,0,32,218,17,0,224,226,17,0,160,235,17,0,96,244,17,0,32,253,17,0,224,5,18,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,48,30,1,0,200,244,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,168,0,0,80,200,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,219,0,0,80,200,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,153,0,0,48,92,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,185,0,0,80,200,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,86,0,0,0,92,0,0,0,116,0,0,0,2,0,0,0,16,128,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,16,66,8,32,0,0,74,41,0,0,0,0,0,0,168,175,212,87,0,0,128,248,226,232,35,0,0,0,136,170,168,138,0,0,192,164,100,82,116,0,0,132,16,0,0,0,0,0,136,8,33,132,32,8,0,130,32,132,16,34,2,0,0,144,234,42,1,0,0,0,16,242,9,1,0,0,0,0,0,0,32,2,0,0,0,240,1,0,0,0,0,0,0,0,32,0,0,16,34,68,136,16,1,0,192,197,88,99,116,0,0,128,24,66,8,113,0,0,192,69,200,68,248,0,0,192,69,200,96,116,0,0,0,49,149,62,66,0,0,224,135,240,96,116,0,0,128,137,240,98,116,0,0,224,67,132,8,17,0,0,192,197,232,98,116,0,0,192,197,232,33,50,0,0,0,0,2,0,1,0,0,0,0,2,0,17,0,0,0,64,54,24,4,0,0,0,128,15,62,0,0,0,0,4,131,77,0,0,0,192,69,136,8,32,0,0,192,135,214,122,240,0,0,128,16,165,92,140,0,0,224,197,248,98,124,0,0,192,197,16,66,116,0,0,224,164,24,99,58,0,0,224,135,240,66,248,0,0,224,135,240,66,8,0,0,192,197,144,99,244,0,0,32,198,248,99,140,0,0,192,17,66,8,113,0,0,128,67,8,33,124,0,0,32,166,50,74,138,0,0,32,132,16,66,248,0,0,32,198,189,107,141,0,0,96,206,90,107,206,0,0,192,197,24,99,116,0,0,224,197,248,66,8,0,0,192,197,24,99,246,0,0,224,197,248,98,140,0,0,192,197,224,96,116,0,0,224,19,66,8,33,0,0,32,198,24,99,116,0,0,32,198,168,20,33,0,0,32,214,90,149,82,0,0,32,70,69,84,140,0,0,32,198,232,8,33,0,0,224,67,68,68,248,0,0,78,8,33,132,16,14,0,33,8,65,8,66,16,0,14,33,132,16,66,14,0,128,168,8,0,0,0,0,0,0,0,0,0,31,0,128,32,0,0,0,0,0,0,0,7,125,244,0,0,33,132,23,99,124,0,0,0,0,31,66,240,0,0,16,66,31,99,244,0,0,0,0,23,127,240,0,0,92,136,39,132,16,0,0,0,0,23,99,244,208,1,33,132,23,99,140,0,0,128,0,67,8,33,0,0,0,1,134,16,66,232,0,66,8,169,140,146,0,0,134,16,66,8,33,0,0,0,128,85,107,173,0,0,0,128,23,99,140,0,0,0,0,23,99,116,0,0,0,128,23,99,124,33,0,0,0,31,99,244,16,2,0,128,54,67,8,0,0,0,0,31,28,124,0,0,64,8,39,132,224,0,0,0,128,24,99,244,0,0,0,128,24,149,34,0,0,0,128,88,171,82,0,0,0,128,168,136,138,0,0,0,128,24,99,244,208,1,0,128,143,136,248,0,0,136,16,34,8,33,8,0,132,16,66,8,33,4,0,130,16,130,8,33,2,0,0,0,96,50,0,0,0,0,0,0,0,0,0,0,63,132,16,66,8,225,3,0,0,0,0,0,0,0,0,0,0,0,64,4,0,152,16,71,8,33,68,0,0,0,0,0,80,10,0,0,0,0,0,168,0,0,132,124,66,8,33,4,0,132,124,242,9,33,4,0,68,1,0,0,0,0,0,0,72,69,84,2,0,0,138,0,31,62,124,0,0,0,0,68,4,65,0,0,192,166,148,83,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,32,0,0,0,0,0,8,17,0,0,0,0,0,74,81,0,0,0,0,0,148,42,0,0,0,0,0,0,0,192,24,0,0,0,0,0,0,62,0,0,0,0,0,0,62,0,0,0,0,0,64,21,0,0,0,0,128,175,149,2,0,0,138,0,31,28,124,0,0,0,0,130,32,34,0,0,0,0,155,114,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,10,196,24,29,33,0,0,0,0,0,0,0,0,0,128,0,66,8,33,0,0,0,32,174,20,71,0,0,152,16,79,68,248,0,0,0,4,47,165,15,0,0,32,70,71,62,33,0,0,132,16,2,8,33,4,0,152,16,23,163,35,100,0,64,1,0,0,0,0,0,192,135,86,90,240,0,0,4,49,197,0,0,0,0,0,0,34,147,36,0,0,0,0,224,33,132,0,0,0,0,0,0,0,0,0,192,135,84,74,240,0,0,224,3,0,0,0,0,0,128,56,2,0,0,0,0,0,16,242,9,249,0,0,6,17,225,0,0,0,0,6,25,100,0,0,0,0,136,0,0,0,0,0,0,0,0,41,165,116,34,0,192,223,107,41,165,148,2,0,0,64,0,0,0,0,0,0,0,0,96,136,0,196,16,226,0,0,0,0,68,41,2,0,0,0,0,0,128,36,137,76,0,0,48,166,68,168,22,1,0,48,166,68,137,148,1,0,81,46,85,168,22,1,0,128,0,130,96,116,0,0,130,0,226,92,140,0,0,68,0,226,92,140,0,0,68,1,226,92,140,0,0,84,1,226,92,140,0,0,64,1,226,92,140,0,0,196,17,226,92,140,0,0,128,59,231,83,202,0,0,192,197,16,66,116,68,0,130,128,31,94,248,0,0,68,128,31,94,248,0,0,68,129,31,94,248,0,0,64,129,31,94,248,0,0,130,0,71,8,113,0,0,68,0,71,8,113,0,0,68,1,71,8,113,0,0,64,1,71,8,113,0,0,192,73,241,132,116,0,0,84,129,89,107,206,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,84,1,23,99,116,0,0,64,1,23,99,116,0,0,0,68,69,84,4,0,0,0,48,169,173,108,0,0,130,128,24,99,116,0,0,68,128,24,99,116,0,0,68,129,24,99,116,0,0,64,129,24,99,116,0,0,136,196,24,29,33,0,0,64,8,39,165,19,2,0,192,73,233,164,116,1,0,130,0,7,125,244,0,0,68,0,7,125,244,0,0,68,1,7,125,244,0,0,84,1,7,125,244,0,0,64,1,7,125,244,0,0,196,17,7,125,244,0,0,0,0,139,124,178,0,0,0,0,31,66,240,68,0,130,0,23,127,240,0,0,68,0,23,127,240,0,0,68,1,23,127,240,0,0,64,1,23,127,240,0,0,130,0,67,8,33,0,0,68,0,67,8,33,0,0,68,1,67,8,33,0,0,64,1,67,8,33,0,0,192,34,232,99,116,0,0,84,129,23,99,140,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,170,0,23,99,116,0,0,64,1,23,99,116,0,0,0,16,240,1,1,0,0,0,48,169,173,108,0,0,130,128,24,99,244,0,0,68,128,24,99,244,0,0,68,129,24,99,244,0,0,64,129,24,99,244,0,0,68,128,24,99,244,208,1,32,132,23,99,124,33,0,64,129,24,99,244,208,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,16,66,8,32,0,0,74,41,0,0,0,0,0,0,168,175,212,87,0,0,128,248,226,232,35,0,0,0,136,170,168,138,0,0,192,164,100,82,116,0,0,132,16,0,0,0,0,0,136,8,33,132,32,8,0,130,32,132,16,34,2,0,0,144,234,42,1,0,0,0,16,242,9,1,0,0,0,0,0,0,32,2,0,0,0,240,1,0,0,0,0,0,0,0,32,0,0,16,34,68,136,16,1,0,192,197,88,99,116,0,0,128,24,66,8,113,0,0,192,69,200,68,248,0,0,192,69,200,96,116,0,0,0,49,149,62,66,0,0,224,135,240,96,116,0,0,128,137,240,98,116,0,0,224,67,132,8,17,0,0,192,197,232,98,116,0,0,192,197,232,33,50,0,0,0,0,2,0,1,0,0,0,0,2,0,17,0,0,0,64,54,24,4,0,0,0,128,15,62,0,0,0,0,4,131,77,0,0,0,192,69,136,8,32,0,0,192,135,214,122,240,0,0,128,16,165,92,140,0,0,224,197,248,98,124,0,0,192,197,16,66,116,0,0,224,164,24,99,58,0,0,224,135,240,66,248,0,0,224,135,240,66,8,0,0,192,197,144,99,244,0,0,32,198,248,99,140,0,0,192,17,66,8,113,0,0,128,67,8,33,124,0,0,32,166,50,74,138,0,0,32,132,16,66,248,0,0,32,198,189,107,141,0,0,96,206,90,107,206,0,0,192,197,24,99,116,0,0,224,197,248,66,8,0,0,192,197,24,99,246,0,0,224,197,248,98,140,0,0,192,197,224,96,116,0,0,224,19,66,8,33,0,0,32,198,24,99,116,0,0,32,198,168,20,33,0,0,32,214,90,149,82,0,0,32,70,69,84,140,0,0,32,198,232,8,33,0,0,224,67,68,68,248,0,0,78,8,33,132,16,14,0,33,8,65,8,66,16,0,14,33,132,16,66,14,0,128,168,8,0,0,0,0,0,0,0,0,0,31,0,128,32,0,0,0,0,0,0,0,7,125,244,0,0,33,132,23,99,124,0,0,0,0,31,66,240,0,0,16,66,31,99,244,0,0,0,0,23,127,240,0,0,92,136,39,132,16,0,0,0,0,23,99,244,208,1,33,132,23,99,140,0,0,128,0,67,8,33,0,0,0,1,134,16,66,232,0,66,8,169,140,146,0,0,134,16,66,8,33,0,0,0,128,85,107,173,0,0,0,128,23,99,140,0,0,0,0,23,99,116,0,0,0,128,23,99,124,33,0,0,0,31,99,244,16,2,0,128,54,67,8,0,0,0,0,31,28,124,0,0,64,8,39,132,224,0,0,0,128,24,99,244,0,0,0,128,24,149,34,0,0,0,128,88,171,82,0,0,0,128,168,136,138,0,0,0,128,24,99,244,208,1,0,128,143,136,248,0,0,136,16,34,8,33,8,0,132,16,66,8,33,4,0,130,16,130,8,33,2,0,0,0,96,50,0,0,0,0,0,0,0,0,0,0,63,132,16,66,8,225,3,0,0,0,0,0,0,0,0,0,0,0,64,4,0,152,16,71,8,33,68,0,0,0,0,0,80,10,0,0,0,0,0,168,0,0,132,124,66,8,33,4,0,132,124,242,9,33,4,0,68,1,0,0,0,0,0,0,72,69,84,2,0,0,138,0,31,62,124,0,0,0,0,68,4,65,0,0,192,166,148,83,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,32,0,0,0,0,0,8,17,0,0,0,0,0,74,81,0,0,0,0,0,148,42,0,0,0,0,0,0,0,192,24,0,0,0,0,0,0,62,0,0,0,0,0,0,62,0,0,0,0,0,64,21,0,0,0,0,128,175,149,2,0,0,138,0,31,28,124,0,0,0,0,130,32,34,0,0,0,0,155,114,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,10,196,24,29,33,0,0,0,0,0,0,0,0,0,128,0,66,8,33,0,0,0,32,174,20,71,0,0,152,16,79,68,248,0,0,0,4,47,165,15,0,0,32,70,71,62,33,0,0,132,16,2,8,33,4,0,152,16,23,163,35,100,0,64,1,0,0,0,0,0,192,135,86,90,240,0,0,4,49,197,0,0,0,0,0,0,34,147,36,0,0,0,0,224,33,132,0,0,0,0,0,0,0,0,0,192,135,84,74,240,0,0,224,3,0,0,0,0,0,128,56,2,0,0,0,0,0,16,242,9,249,0,0,6,17,225,0,0,0,0,6,25,100,0,0,0,0,136,0,0,0,0,0,0,0,0,41,165,116,34,0,192,223,107,41,165,148,2,0,0,64,0,0,0,0,0,0,0,0,96,136,0,196,16,226,0,0,0,0,68,41,2,0,0,0,0,0,128,36,137,76,0,0,48,166,68,168,22,1,0,48,166,68,137,148,1,0,81,46,85,168,22,1,0,128,0,130,96,116,0,0,130,0,226,92,140,0,0,68,0,226,92,140,0,0,68,1,226,92,140,0,0,84,1,226,92,140,0,0,64,1,226,92,140,0,0,196,17,226,92,140,0,0,128,59,231,83,202,0,0,192,197,16,66,116,68,0,130,128,31,94,248,0,0,68,128,31,94,248,0,0,68,129,31,94,248,0,0,64,129,31,94,248,0,0,130,0,71,8,113,0,0,68,0,71,8,113,0,0,68,1,71,8,113,0,0,64,1,71,8,113,0,0,192,73,241,132,116,0,0,84,129,89,107,206,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,84,1,23,99,116,0,0,64,1,23,99,116,0,0,0,68,69,84,4,0,0,0,48,169,173,108,0,0,130,128,24,99,116,0,0,68,128,24,99,116,0,0,68,129,24,99,116,0,0,64,129,24,99,116,0,0,136,196,24,29,33,0,0,64,8,39,165,19,2,0,192,73,233,164,116,1,0,130,0,7,125,244,0,0,68,0,7,125,244,0,0,68,1,7,125,244,0,0,84,1,7,125,244,0,0,64,1,7,125,244,0,0,196,17,7,125,244,0,0,0,0,139,124,178,0,0,0,0,31,66,240,68,0,130,0,23,127,240,0,0,68,0,23,127,240,0,0,68,1,23,127,240,0,0,64,1,23,127,240,0,0,130,0,67,8,33,0,0,68,0,67,8,33,0,0,68,1,67,8,33,0,0,64,1,67,8,33,0,0,192,34,232,99,116,0,0,84,129,23,99,140,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,170,0,23,99,116,0,0,64,1,23,99,116,0,0,0,16,240,1,1,0,0,0,48,169,173,108,0,0,130,128,24,99,244,0,0,68,128,24,99,244,0,0,68,129,24,99,244,0,0,64,129,24,99,244,0,0,68,128,24,99,244,208,1,32,132,23,99,124,33,0,64,129,24,99,244,208,1,152,87,1,0,16,87,1,0,216,86,1,0,16,86,1,0,168,85,1,0,184,84,1,0,240,82,1,0,72,82,1,0,168,81,1,0,56,81,1,0,184,80,1,0,56,80,1,0,232,79,1,0,152,79,1,0,24,79,1,0,48,77,1,0,32,75,1,0,96,74,1,0,192,73,1,0,88,72,1,0,112,71,1,0,128,70,1,0,176,69,1,0,224,68,1,0,72,68,1,0,40,67,1,0,176,65,1,0,184,64,1,0,136,63,1,0,240,62,1,0,152,62,1,0,224,61,1,0,88,61,1,0,184,60,1,0,80,60,1,0,192,59,1,0,240,57,1,0,24,57,1,0,32,94,1,0,96,93,1,0,8,93,1,0,152,92,1,0,56,92,1,0,208,91,1,0,192,89,1,0,240,88,1,0,0,0,0,0,0,0,0,0,176,214,0,0,104,117,1,0,1,0,0,0,0,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,0,0,24,238,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,65,0,0,0,0,6,0,0,0,24,0,0,0,38,0,0,0,102,0,0,0,80,0,0,0,26,0,0,0,78,0,0,0,16,151,1,0,6,0,0,0,4,0,0,0,28,0,0,0,18,0,0,0,104,0,0,0,62,0,0,0,108,0,0,0,54,0,0,0,24,0,0,0,152,125,1,0,0,0,0,0,0,0,0,0,144,105,0,0,184,105,0,0,52,58,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,169,170,63,49,54,58,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,142,227,63,49,54,58,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,205,204,204,63,49,54,58,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,137,136,136,63,67,111,110,102,105,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,113,117,97,114,101,32,112,105,120,101,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,111,114,101,32,112,114,111,118,105,100,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,117,115,116,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,247,0,0,208,244,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,253,0,0,192,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,4,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,4,0,0,0,2,0,0,0,7,0,0,0,3,0,0,0,6,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,1,0,0,0,253,255,255,255,1,0,0,0,252,255,255,255,1,0,0,0,251,255,255,255,1,0,0,0,250,255,255,255,1,0,0,0,249,255,255,255,2,0,0,0,255,255,255,255,2,0,0,0,253,255,255,255,3,0,0,0,0,0,0,0,3,0,0,0,253,255,255,255,5,0,0,0,0,0,0,0,7,0,0,0,255,255,255,255,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,241,255,255,255,0,0,0,0,248,255,255,255,1,0,0,0,251,255,255,255,0,0,0,0,252,255,255,255,1,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,3,0,0,0,253,255,255,255,6,0,0,0,254,255,255,255,1,0,0,0,254,255,255,255,3,0,0,0,254,255,255,255,5,0,0,0,254,255,255,255,7,0,0,0,254,255,255,255,9,0,0,0,254,255,255,255,11,0,0,0,254,255,255,255,13,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,0,0,0,0,242,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,1,0,0,0,253,255,255,255,1,0,0,0,252,255,255,255,1,0,0,0,251,255,255,255,1,0,0,0,250,255,255,255,2,0,0,0,0,0,0,0,2,0,0,0,254,255,255,255,2,0,0,0,252,255,255,255,3,0,0,0,254,255,255,255,4,0,0,0,254,255,255,255,7,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,255,255,255,0,0,0,0,249,255,255,255,0,0,0,0,251,255,255,255,1,0,0,0,252,255,255,255,2,0,0,0,253,255,255,255,1,0,0,0,253,255,255,255,4,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,2,0,0,0,254,255,255,255,4,0,0,0,254,255,255,255,6,0,0,0,254,255,255,255,8,0,0,0,254,255,255,255,10,0,0,0,254,255,255,255,12,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,0,0,0,0,243,255,255,255,0,0,0,0,243,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,1,0,0,0,253,255,255,255,1,0,0,0,252,255,255,255,1,0,0,0,251,255,255,255,1,0,0,0,250,255,255,255,2,0,0,0,255,255,255,255,2,0,0,0,253,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,255,255,255,0,0,0,0,249,255,255,255,1,0,0,0,251,255,255,255,2,0,0,0,252,255,255,255,3,0,0,0,253,255,255,255,2,0,0,0,253,255,255,255,5,0,0,0,254,255,255,255,1,0,0,0,254,255,255,255,3,0,0,0,254,255,255,255,5,0,0,0,254,255,255,255,7,0,0,0,254,255,255,255,9,0,0,0,254,255,255,255,11,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,0,0,0,0,244,255,255,255,0,0,0,0,244,255,255,255,0,0,0,0,244,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,1,0,0,0,253,255,255,255,1,0,0,0,252,255,255,255,1,0,0,0,251,255,255,255,2,0,0,0,0,0,0,0,2,0,0,0,254,255,255,255,3,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,255,255,255,0,0,0,0,250,255,255,255,0,0,0,0,252,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,3,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,2,0,0,0,254,255,255,255,4,0,0,0,254,255,255,255,6,0,0,0,254,255,255,255,8,0,0,0,254,255,255,255,10,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,0,0,0,0,245,255,255,255,0,0,0,0,245,255,255,255,0,0,0,0,245,255,255,255,0,0,0,0,245,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,1,0,0,0,253,255,255,255,1,0,0,0,252,255,255,255,1,0,0,0,251,255,255,255,2,0,0,0,255,255,255,255,2,0,0,0,253,255,255,255,3,0,0,0,254,255,255,255,5,0,0,0,255,255,255,255,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,245,255,255,255,0,0,0,0,250,255,255,255,1,0,0,0,252,255,255,255,1,0,0,0,253,255,255,255,1,0,0,0,253,255,255,255,4,0,0,0,254,255,255,255,1,0,0,0,254,255,255,255,3,0,0,0,254,255,255,255,5,0,0,0,254,255,255,255,7,0,0,0,254,255,255,255,9,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,5,0,0,0,0,0,0,0,246,255,255,255,0,0,0,0,246,255,255,255,0,0,0,0,246,255,255,255,0,0,0,0,246,255,255,255,0,0,0,0,246,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,1,0,0,0,253,255,255,255,1,0,0,0,252,255,255,255,2,0,0,0,0,0,0,0,2,0,0,0,254,255,255,255,3,0,0,0,255,255,255,255,5,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,246,255,255,255,0,0,0,0,251,255,255,255,0,0,0,0,252,255,255,255,2,0,0,0,253,255,255,255,2,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,2,0,0,0,254,255,255,255,4,0,0,0,254,255,255,255,6,0,0,0,254,255,255,255,8,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,6,0,0,0,0,0,0,0,247,255,255,255,0,0,0,0,247,255,255,255,0,0,0,0,247,255,255,255,0,0,0,0,247,255,255,255,0,0,0,0,247,255,255,255,0,0,0,0,247,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,1,0,0,0,253,255,255,255,1,0,0,0,252,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,0,0,0,0,4,0,0,0,255,255,255,255,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,255,255,255,0,0,0,0,251,255,255,255,1,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,3,0,0,0,254,255,255,255,1,0,0,0,254,255,255,255,3,0,0,0,254,255,255,255,5,0,0,0,254,255,255,255,7,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,7,0,0,0,0,0,0,0,248,255,255,255,0,0,0,0,248,255,255,255,0,0,0,0,248,255,255,255,0,0,0,0,248,255,255,255,0,0,0,0,248,255,255,255,0,0,0,0,248,255,255,255,0,0,0,0,248,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,1,0,0,0,253,255,255,255,2,0,0,0,0,0,0,0,2,0,0,0,254,255,255,255,4,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,255,255,255,0,0,0,0,252,255,255,255,0,0,0,0,253,255,255,255,1,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,2,0,0,0,254,255,255,255,4,0,0,0,254,255,255,255,6,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,8,0,0,0,0,0,0,0,249,255,255,255,0,0,0,0,249,255,255,255,0,0,0,0,249,255,255,255,0,0,0,0,249,255,255,255,0,0,0,0,249,255,255,255,0,0,0,0,249,255,255,255,0,0,0,0,249,255,255,255,0,0,0,0,249,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,1,0,0,0,253,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,249,255,255,255,0,0,0,0,252,255,255,255,1,0,0,0,253,255,255,255,2,0,0,0,254,255,255,255,1,0,0,0,254,255,255,255,3,0,0,0,254,255,255,255,5,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,9,0,0,0,0,0,0,0,250,255,255,255,0,0,0,0,250,255,255,255,0,0,0,0,250,255,255,255,0,0,0,0,250,255,255,255,0,0,0,0,250,255,255,255,0,0,0,0,250,255,255,255,0,0,0,0,250,255,255,255,0,0,0,0,250,255,255,255,0,0,0,0,250,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,2,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,2,0,0,0,254,255,255,255,4,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,10,0,0,0,0,0,0,0,251,255,255,255,0,0,0,0,251,255,255,255,0,0,0,0,251,255,255,255,0,0,0,0,251,255,255,255,0,0,0,0,251,255,255,255,0,0,0,0,251,255,255,255,0,0,0,0,251,255,255,255,0,0,0,0,251,255,255,255,0,0,0,0,251,255,255,255,0,0,0,0,251,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,254,255,255,255,2,0,0,0,255,255,255,255,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,251,255,255,255,0,0,0,0,253,255,255,255,1,0,0,0,254,255,255,255,1,0,0,0,254,255,255,255,3,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,10,0,0,0,255,255,255,255,11,0,0,0,0,0,0,0,252,255,255,255,0,0,0,0,252,255,255,255])
.concat([0,0,0,0,252,255,255,255,0,0,0,0,252,255,255,255,0,0,0,0,252,255,255,255,0,0,0,0,252,255,255,255,0,0,0,0,252,255,255,255,0,0,0,0,252,255,255,255,0,0,0,0,252,255,255,255,0,0,0,0,252,255,255,255,0,0,0,0,252,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,252,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,2,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,10,0,0,0,255,255,255,255,11,0,0,0,255,255,255,255,12,0,0,0,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,253,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,253,255,255,255,0,0,0,0,254,255,255,255,1,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,10,0,0,0,255,255,255,255,11,0,0,0,255,255,255,255,12,0,0,0,255,255,255,255,13,0,0,0,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,254,255,255,255,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,10,0,0,0,255,255,255,255,11,0,0,0,255,255,255,255,12,0,0,0,255,255,255,255,13,0,0,0,255,255,255,255,14,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,1,0,0,0,255,255,255,255,2,0,0,0,255,255,255,255,3,0,0,0,255,255,255,255,4,0,0,0,255,255,255,255,5,0,0,0,255,255,255,255,6,0,0,0,255,255,255,255,7,0,0,0,255,255,255,255,8,0,0,0,255,255,255,255,9,0,0,0,255,255,255,255,10,0,0,0,255,255,255,255,11,0,0,0,255,255,255,255,12,0,0,0,255,255,255,255,13,0,0,0,255,255,255,255,14,0,0,0,255,255,255,255,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,242,255,255,255,255,255,255,255,243,255,255,255,255,255,255,255,244,255,255,255,255,255,255,255,245,255,255,255,255,255,255,255,246,255,255,255,255,255,255,255,247,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,243,255,255,255,255,255,255,255,244,255,255,255,255,255,255,255,245,255,255,255,255,255,255,255,246,255,255,255,255,255,255,255,247,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,255,255,255,255,244,255,255,255,255,255,255,255,245,255,255,255,255,255,255,255,246,255,255,255,255,255,255,255,247,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,255,255,255,255,253,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,3,0,0,0,255,255,255,255,245,255,255,255,255,255,255,255,246,255,255,255,255,255,255,255,247,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,254,255,255,255,254,255,255,255,0,0,0,0,252,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,255,255,255,255,246,255,255,255,255,255,255,255,247,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,253,255,255,255,254,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,251,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,255,255,255,255,247,255,255,255,255,255,255,255,248,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,252,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,0,0,0,0,253,255,255,255,0,0,0,0,250,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,6,0,0,0,255,255,255,255,248,255,255,255,255,255,255,255,249,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,251,255,255,255,254,255,255,255,253,255,255,255,254,255,255,255,255,255,255,255,253,255,255,255,254,255,255,255,252,255,255,255,255,255,255,255,249,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,0,0,0,255,255,255,255,249,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,250,255,255,255,254,255,255,255,252,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,0,0,0,0,253,255,255,255,255,255,255,255,252,255,255,255,0,0,0,0,248,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,0,255,255,255,255,250,255,255,255,255,255,255,255,251,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,249,255,255,255,254,255,255,255,251,255,255,255,254,255,255,255,253,255,255,255,254,255,255,255,255,255,255,255,253,255,255,255,253,255,255,255,253,255,255,255,0,0,0,0,251,255,255,255,255,255,255,255,247,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,9,0,0,0,255,255,255,255,251,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,248,255,255,255,254,255,255,255,250,255,255,255,254,255,255,255,252,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,0,0,0,0,253,255,255,255,254,255,255,255,252,255,255,255,254,255,255,255,251,255,255,255,0,0,0,0,246,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,10,0,0,0,255,255,255,255,252,255,255,255,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,247,255,255,255,254,255,255,255,249,255,255,255,254,255,255,255,251,255,255,255,254,255,255,255,253,255,255,255,254,255,255,255,255,255,255,255,253,255,255,255,252,255,255,255,253,255,255,255,255,255,255,255,252,255,255,255,255,255,255,255,250,255,255,255,255,255,255,255,245,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,11,0,0,0,255,255,255,255,253,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,246,255,255,255,254,255,255,255,248,255,255,255,254,255,255,255,250,255,255,255,254,255,255,255,252,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,0,0,0,0,253,255,255,255,253,255,255,255,253,255,255,255,0,0,0,0,252,255,255,255,0,0,0,0,250,255,255,255,0,0,0,0,244,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,12,0,0,0,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,245,255,255,255,254,255,255,255,247,255,255,255,254,255,255,255,249,255,255,255,254,255,255,255,251,255,255,255,254,255,255,255,253,255,255,255,254,255,255,255,255,255,255,255,253,255,255,255,251,255,255,255,253,255,255,255,254,255,255,255,252,255,255,255,253,255,255,255,251,255,255,255,254,255,255,255,249,255,255,255,255,255,255,255,243,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,0,0,0,0,6,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,6,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,0,0,0,0,13,0,0,0,0,0,0,0,13,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,254,255,255,255,244,255,255,255,254,255,255,255,246,255,255,255,254,255,255,255,248,255,255,255,254,255,255,255,250,255,255,255,254,255,255,255,252,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,0,0,0,0,253,255,255,255,252,255,255,255,253,255,255,255,255,255,255,255,252,255,255,255,254,255,255,255,251,255,255,255,255,255,255,255,249,255,255,255,0,0,0,0,242,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,6,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,14,0,0,0,255,255,255,255,0,0,0,0,254,255,255,255,243,255,255,255,254,255,255,255,245,255,255,255,254,255,255,255,247,255,255,255,254,255,255,255,249,255,255,255,254,255,255,255,251,255,255,255,254,255,255,255,253,255,255,255,254,255,255,255,255,255,255,255,253,255,255,255,250,255,255,255,253,255,255,255,253,255,255,255,253,255,255,255,0,0,0,0,252,255,255,255,255,255,255,255,251,255,255,255,0,0,0,0,248,255,255,255,255,255,255,255,241,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,7,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,7,0,0,0,1,0,0,0,6,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,254,255,255,255,242,255,255,255,254,255,255,255,244,255,255,255,254,255,255,255,246,255,255,255,254,255,255,255,248,255,255,255,254,255,255,255,250,255,255,255,254,255,255,255,252,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,0,0,0,0,253,255,255,255,251,255,255,255,253,255,255,255,254,255,255,255,252,255,255,255,252,255,255,255,252,255,255,255,0,0,0,0,250,255,255,255,254,255,255,255,248,255,255,255,0,0,0,0,240,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,7,0,0,0,1,0,0,0,6,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,109,51,0,0,0,0,0,118,111,108,117,109,101,95,117,112,0,0,0,0,0,0,0,45,37,115,32,37,105,10,0,105,110,112,117,116,95,100,101,98,117,103,95,101,110,97,98,108,101,0,0,0,0,0,0,37,105,32,100,101,109,111,40,115,41,32,105,110,32,108,111,111,112,10,0,0,0,0,0,103,102,120,47,99,111,109,112,108,101,116,101,46,108,109,112,0,0,0,0,0,0,0,0,77,117,116,101,32,65,117,100,105,111,0,0,0,0,0,0,115,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,109,111,118,105,101,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,67,108,97,117,115,116,114,111,112,104,111,98,111,112,111,108,105,115,0,0,0,0,0,0,69,110,97,98,108,101,32,104,111,116,107,101,121,115,0,0,103,102,120,47,98,111,120,95,98,114,46,108,109,112,0,0,66,97,100,32,107,101,121,95,100,101,115,116,0,0,0,0,37,115,58,32,115,107,105,110,119,105,100,116,104,32,110,111,116,32,109,117,108,116,105,112,108,101,32,111,102,32,52,0,105,110,112,117,116,95,100,117,116,121,95,99,121,99,108,101,0,0,0,0,0,0,0,0,117,112,0,0,0,0,0,0,77,97,120,32,37,105,32,100,101,109,111,115,32,105,110,32,100,101,109,111,108,111,111,112,10,0,0,0,0,0,0,0,103,102,120,47,114,97,110,107,105,110,103,46,108,109,112,0,68,105,115,107,32,73,109,97,103,101,32,65,112,112,101,110,100,0,0,0,0,0,0,0,115,99,97,108,101,95,121,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,117,110,109,117,116,101,32,97,117,100,105,111,46,10,0,0,0,100,109,50,0,0,0,0,0,101,110,97,98,108,101,95,104,111,116,107,101,121,0,0,0,37,115,32,105,115,32,117,110,98,111,117,110,100,44,32,104,105,116,32,70,52,32,116,111,32,115,101,116,46,10,0,0,109,97,112,32,115,116,97,114,116,10,0,0,0,0,0,0,105,110,112,117,116,95,116,117,114,98,111,95,112,101,114,105,111,100,0,0,0,0,0,0,76,65,76,84,0,0,0,0,68,101,109,111,32,109,101,115,115,97,103,101,32,62,32,77,65,88,95,77,83,71,76,69,78,0,0,0,0,0,0,0,37,51,105,0,0,0,0,0,68,105,115,107,32,73,110,100,101,120,0,0,0,0,0,0,115,99,97,108,101,95,120,0,65,117,100,105,111,32,117,110,109,117,116,101,100,46,0,0,80,108,97,99,101,32,111,102,32,84,119,111,32,68,101,97,116,104,115,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,0,0,0,0,0,117,110,98,105,110,100,97,108,108,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,82,79,84,65,84,73,79,78,58,32,37,117,10,0,0,0,0,103,111,100,109,111,100,101,32,79,70,70,10,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,115,105,122,101,0,0,0,0,0,0,0,102,114,97,109,101,32,37,105,58,32,37,115,10,0,0,0,84,105,109,101,32,58,37,51,105,58,37,105,37,105,0,0,69,115,116,105,109,97,116,101,100,32,77,111,110,105,116,111,114,32,70,80,83,0,0,0,115,99,97,108,101,0,0,0,111,102,102,0,0,0,0,0,65,117,100,105,111,32,109,117,116,101,100,46,0,0,0,0,100,109,49,0,0,0,0,0,115,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,117,110,98,105,110,100,0,0,115,97,109,101,108,101,118,101,108,0,0,0,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,112,97,116,104,0,0,0,0,0,0,0,67,97,110,39,116,32,108,111,97,100,32,37,115,10,0,0,83,101,99,114,101,116,115,32,58,37,51,105,32,47,37,51,105,0,0,0,0,0,0,0,67,114,111,112,32,79,118,101,114,115,99,97,110,32,40,114,101,108,111,97,100,41,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,88,77,76,58,32,73,110,118,97,108,105,100,32,112,114,111,112,101,114,116,121,32,102,111,114,32,102,105,108,116,101,114,46,10,0,0,86,111,108,117,109,101,58,32,37,46,49,102,32,100,66,0,83,104,117,98,45,78,105,103,103,117,114,97,116,104,39,115,32,80,105,116,0,0,0,0,78,101,116,112,108,97,121,32,102,108,105,112,32,112,108,97,121,101,114,115,0,0,0,0,98,105,110,100,0,0,0,0,115,116,100,105,110,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,0,0,67,118,97,114,95,82,101,103,105,115,116,101,114,86,97,114,105,97,98,108,101,58,32,37,115,32,105,115,32,97,32,99,111,109,109,97,110,100,10,0,61,61,61,32,67,111,110,102,105,103,32,61,61,61,10,0,37,100,0,0,0,0,0,0,78,111,32,118,105,101,119,116,104,105,110,103,32,111,110,32,109,97,112,10,0,0,0,0,77,111,110,115,116,101,114,115,58,37,51,105,32,47,37,51,105,0,0,0,0,0,0,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,89,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,76,73,78,69,65,82,46,10,0,0,0,0,0,0,0,110,111,0,0,0,0,0,0,101,110,100,0,0,0,0,0,110,101,116,112,108,97,121,95,102,108,105,112,95,112,108,97,121,101,114,115,0,0,0,0,98,105,110,100,32,34,37,115,34,32,34,37,115,34,10,0,82,101,116,114,111,65,114,99,104,58,32,65,100,106,117,115,116,105,110,103,32,97,115,112,101,99,116,32,114,97,116,105,111,32,116,111,32,37,46,50,102,10,0,0,0,0,0,0,101,120,101,99,32,60,102,105,108,101,110,97,109,101,62,32,58,32,101,120,101,99,117,116,101,32,97,32,115,99,114,105,112,116,32,102,105,108,101,10,0,0,0,0,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,112,111,114,116,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,45,37,109,37,100,45,37,72,37,77,37,83,46,0,0,118,105,101,119,116,104,105,110,103,0,0,0,0,0,0,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,88,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,78,69,65,82,69,83,84,46,10,0,0,0,0,0,0,121,101,115,0,0,0,0,0,84,104,101,32,78,97,109,101,108,101,115,115,32,67,105,116,121,0,0,0,0,0,0,0,65,117,100,105,111,32,109,117,116,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,67,111,114,114,117,112,116,101,100,32,100,97,116,97,32,102,105,108,101,46,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,82,65,77,32,97,108,108,111,99,97,116,101,100,46,32,32,84,114,121,32,115,116,97,114,116,105,110,103,32,117,115,105,110,103,32,34,45,109,101,109,32,49,54,34,32,111,110,32,116,104,101,32,99,111,109,109,97,110,100,32,108,105,110,101,46,0,0,0,0,112,114,111,103,115,47,98,111,108,116,51,46,109,100,108,0,48,46,48,50,0,0,0,0,97,109,109,111,95,112,108,97,115,109,97,0,0,0,0,0,114,95,97,109,109,111,112,108,97,115,109,97,0,0,0,0,71,97,109,101,112,97,100,32,116,121,112,101,59,32,103,97,109,101,112,97,100,124,100,117,97,108,45,97,110,97,108,111,103,0,0,0,0,0,0,0,86,83,121,110,99,32,83,119,97,112,32,73,110,116,101,114,118,97,108,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,76,85,84,32,102,105,108,116,101,114,32,116,121,112,101,46,10,0,0,37,115,58,32,98,97,100,114,101,97,100,10,0,0,0,0,48,0,0,0,0,0,0,0,117,110,99,111,110,110,101,99,116,101,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,98,32,109,111,117,115,101,32,115,116,97,116,101,58,32,37,115,46,10,0,0,0,0,0,0,0,99,117,101,32,0,0,0,0,101,52,109,56,0,0,0,0,97,117,100,105,111,95,109,117,116,101,0,0,0,0,0,0,112,108,97,121,118,111,108,0,99,108,95,121,97,119,115,112,101,101,100,0,0,0,0,0,98,105,110,100,32,99,111,109,109,97,110,100,32,116,111,111,32,108,111,110,103,32,40,77,65,88,32,61,32,37,100,41,0,0,0,0,0,0,0,0,110,101,116,0,0,0,0,0,103,108,67,111,112,121,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,112,108,97,121,101,114,115,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,105,110,32,118,101,99,52,32,99,111,108,111,114,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,105,110,118,95,115,110,97,105,108,103,117,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,72,87,32,114,101,110,100,101,114,32,70,66,79,32,35,37,117,44,32,101,114,114,111,114,58,32,48,120,37,117,46,10,0,0,0,0,114,95,100,114,97,119,102,108,97,116,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,108,111,97,100,0,0,0,0,0,114,95,100,114,97,119,101,110,116,105,116,105,101,115,0,0,67,79,82,69,32,79,80,84,73,79,78,83,0,0,0,0,78,101,97,114,101,115,116,0,37,115,0,0,0,0,0,0,51,0,0,0,0,0,0,0,115,116,121,108,101,0,0,0,83,85,66,95,86,0,0,0,97,109,109,111,95,99,101,108,108,115,49,0,0,0,0,0,37,115,58,32,98,97,100,32,100,101,115,116,105,110,97,116,105,111,110,0,0,0,0,0,114,95,97,109,109,111,109,117,108,116,105,0,0,0,0,0,66,108,97,99,107,32,70,114,97,109,101,32,73,110,115,101,114,116,105,111,110,0,0,0,111,118,101,114,108,97,121,37,117,95,110,97,109,101,0,0,110,101,97,114,101,115,116,0,82,101,116,114,111,65,114,99,104,58,32,37,115,10,0,0,67,111,110,110,101,99,116,105,110,103,32,116,111,46,46,46,10,37,115,32,64,32,37,115,10,10,0,0,0,0,0,0,60,33,45,45,0,0,0,0,37,115,47,37,115,0,0,0,37,115,58,32,111,118,101,114,108,97,112,112,105,110,103,32,108,117,109,112,115,32,105,110,32,37,115,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,117,109,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,0,0,0,0,65,122,117,114,101,32,65,103,111,110,121,0,0,0,0,0,68,83,80,32,99,111,110,102,105,103,0,0,0,0,0,0,34,37,115,34,32,105,115,32,110,111,116,32,98,111,117,110,100,10,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,115,97,118,101,0,0,0,0,0,97,109,109,111,95,109,117,108,116,105,95,114,111,99,107,101,116,115,0,0,0,0,0,0,114,95,97,109,109,111,108,97,118,97,0,0,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,32,70,114,97,109,101,115,0,0,0,0,108,105,110,101,97,114,0,0,82,101,116,114,111,65,114,99,104,58,32,85,110,112,97,117,115,101,100,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,101,52,109,55,0,0,0,0,100,115,112,95,99,111,110,102,105,103,0,0,0,0,0,0,34,37,115,34,32,61,32,34,37,115,34,10,0,0,0,0,97,109,109,111,95,114,111,99,107,101,116,115,49,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,105,110,100,101,120,0,0,0,0,99,104,97,115,101,95,98,97,99,107,0,0,0,0,0,0,114,95,116,101,97,109,98,111,114,100,0,0,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,102,105,108,101,110,97,109,101,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,97,117,115,101,100,46,10,0,0,0,0,0,84,104,101,32,80,97,105,110,32,77,97,122,101,0,0,0,84,97,107,101,32,115,99,114,101,101,110,115,104,111,116,0,103,102,120,47,98,111,120,95,109,114,46,108,109,112,0,0,98,105,110,100,32,60,107,101,121,62,32,91,99,111,109,109,97,110,100,93,32,58,32,97,116,116,97,99,104,32,97,32,99,111,109,109,97,110,100,32,116,111,32,97,32,107,101,121,10,0,0,0,0,0,0,0,37,115,58,32,73,110,118,97,108,105,100,32,35,32,111,102,32,115,107,105,110,115,58,32,37,100,0,0,0,0,0,0,98,108,111,99,107,95,115,114,97,109,95,111,118,101,114,119,114,105,116,101,0,0,0,0,83,116,97,114,116,32,98,117,116,116,111,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,77,111,118,105,101,32,102,111,114,109,97,116,32,115,101,101,109,115,32,116,111,32,104,97,118,101,32,97,32,100,105,102,102,101,114,101,110,116,32,115,101,114,105,97,108,105,122,101,114,32,118,101,114,115,105,111,110,46,32,87,105,108,108,32,109,111,115,116,32,108,105,107,101,108,121,32,102,97,105,108,46,10,0,0,97,109,109,111,95,108,97,118,97,95,110,97,105,108,115,0,114,95,97,103,114,97,118,49,0,0,0,0,0,0,0,0,86,83,121,110,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,73,68,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,82,101,97,99,104,101,100,32,101,110,100,32,111,102,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,0,0,0,101,52,109,54,0,0,0,0,115,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,34,37,115,34,32,105,115,110,39,116,32,97,32,118,97,108,105,100,32,107,101,121,10,0,103,102,120,47,98,111,120,95,116,108,46,108,109,112,0,0,99,104,101,97,116,95,115,101,116,116,105,110,103,115,95,112,97,116,104,0,0,0,0,0,82,73,71,72,84,65,82,82,79,87,0,0,0,0,0,0,97,109,109,111,95,110,97,105,108,115,49,0,0,0,0,0,114,95,115,104,105,101,108,100,49,0,0,0,0,0,0,0,82,111,116,97,116,105,111,110,0,0,0,0,0,0,0,0,102,105,108,116,101,114,0,0,109,101,110,117,95,116,111,103,103,108,101,0,0,0,0,0,82,101,119,105,110,100,105,110,103,46,0,0,0,0,0,0,72,101,108,108,39,115,32,65,116,114,105,117,109,0,0,0,67,104,101,97,116,32,116,111,103,103,108,101,0,0,0,0,117,110,98,105,110,100,32,60,107,101,121,62,32,58,32,114,101,109,111,118,101,32,99,111,109,109,97,110,100,115,32,102,114,111,109,32,97,32,107,101,121,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,77,69,83,83,65,71,69,58,32,37,115,10,0,0,0,0,0,32,32,32,37,115,10,0,0,99,104,101,97,116,95,100,97,116,97,98,97,115,101,95,112,97,116,104,0,0,0,0,0,97,109,109,111,95,115,104,101,108,108,115,49,0,0,0,0,114,95,112,108,97,115,109,97,0,0,0,0,0,0,0,0,84,111,103,103,108,101,32,70,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,103,114,97,98,95,109,111,117,115,101,95,116,111,103,103,108,101,0,0,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,46,0,0,0,0,101,52,109,53,0,0,0,0,99,104,101,97,116,95,116,111,103,103,108,101,0,0,0,0,111,110,0,0,0,0,0,0,60,85,78,75,78,79,87,78,32,75,69,89,78,85,77,62,0,0,0,0,0,0,0,0,37,115,58,32,32,66,97,100,32,115,105,103,110,98,105,116,115,0,0,0,0,0,0,0,116,101,97,109,112,108,97,121,0,0,0,0,0,0,0,0,97,117,116,111,115,97,118,101,95,105,110,116,101,114,118,97,108,0,0,0,0,0,0,0,75,105,99,107,101,100,32,98,121,32,37,115,10,0,0,0,114,95,109,117,108,116,105,114,111,99,107,0,0,0,0,0,67,117,115,116,111,109,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,84,111,111,32,109,97,110,121,32,116,101,120,116,117,114,101,32,105,109,97,103,101,115,46,32,73,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,37,115,58,32,105,110,118,97,108,105,100,32,115,116,114,105,110,103,32,111,102,102,115,101,116,32,37,100,32,40,37,100,32,116,111,32,37,100,32,118,97,108,105,100,41,10,0,0,100,105,115,107,95,110,101,120,116,0,0,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,32,114,101,119,105,110,100,46,0,0,0,0,0,84,104,101,32,80,97,108,97,99,101,32,111,102,32,72,97,116,101,0,0,0,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,45,0,0,0,60,75,69,89,32,78,79,84,32,70,79,85,78,68,62,0,112,97,117,115,101,95,110,111,110,97,99,116,105,118,101,0,67,97,110,39,116,32,114,101,103,105,115,116,101,114,32,118,97,114,105,97,98,108,101,32,37,115,44,32,97,108,108,114,101,97,100,121,32,100,101,102,105,110,101,100,10,0,0,0,59,0,0,0,0,0,0,0,75,105,99,107,101,100,32,98,121,32,37,115,58,32,37,115,10,0,0,0,0,0,0,0,37,102,0,0,0,0,0,0,114,95,103,114,101,110,0,0,65,115,112,101,99,116,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,65,77,32,97,100,100,114,101,115,115,32,115,112,101,99,105,102,105,99,101,100,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,100,105,115,107,95,101,106,101,99,116,95,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,10,0,0,0,0,0,0,0,101,52,109,52,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,109,105,110,117,115,0,0,0,0,0,0,0,37,115,32,124,124,32,70,80])
.concat([83,58,32,37,54,46,49,102,32,124,124,32,70,114,97,109,101,115,58,32,37,100,0,0,115,97,121,32,34,37,115,34,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,117,100,105,111,32,114,97,116,101,32,99,111,110,116,114,111,108,32,119,97,115,32,100,101,115,105,114,101,100,44,32,98,117,116,32,100,114,105,118,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,110,101,101,100,101,100,32,102,101,97,116,117,114,101,115,46,10,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,102,97,115,116,102,111,114,119,97,114,100,95,114,97,116,105,111,0,0,0,0,0,0,0,102,105,108,101,95,112,97,116,104,46,99,0,0,0,0,0,67,111,110,115,111,108,101,0,114,95,115,117,112,101,114,108,97,118,97,0,0,0,0,0,73,110,116,101,103,101,114,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,105,110,112,117,116,32,115,108,111,116,32,102,111,114,32,105,109,112,111,114,116,46,10,0,0,0,0,66,97,100,32,111,112,99,111,100,101,32,37,105,0,0,0,111,118,101,114,108,97,121,95,110,101,120,116,0,0,0,0,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,0,0,0,84,104,101,32,69,108,100,101,114,32,71,111,100,32,83,104,114,105,110,101,0,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,43,0,0,0,115,97,121,95,116,101,97,109,32,34,37,115,34,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,89,111,117,32,109,117,115,116,32,104,97,118,101,32,116,104,101,32,114,101,103,105,115,116,101,114,101,100,32,118,101,114,115,105,111,110,32,116,111,32,117,115,101,32,109,111,100,105,102,105,101,100,32,103,97,109,101,115,0,0,0,0,0,0,115,108,111,119,109,111,116,105,111,110,95,114,97,116,105,111,0,0,0,0,0,0,0,0,37,115,58,32,115,118,95,110,117,109,97,114,101,97,110,111,100,101,115,32,61,61,32,65,82,69,65,95,78,79,68,69,83,0,0,0,0,0,0,0,37,115,58,32,98,97,100,32,115,105,122,101,58,32,37,105,0,0,0,0,0,0,0,0,112,114,111,103,115,47,98,111,108,116,50,46,109,100,108,0,99,108,95,98,111,98,0,0,35,0,0,0,0,0,0,0,114,95,108,97,118,97,0,0,103,97,109,101,112,97,100,0,83,104,97,100,101,114,32,79,112,116,105,111,110,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,66,97,100,32,98,117,105,108,116,105,110,32,99,97,108,108,32,110,117,109,98,101,114,0,37,115,58,32,78,69,84,95,71,101,116,77,101,115,115,97,103,101,32,102,97,105,108,101,100,10,0,0,0,0,0,0,118,111,108,117,109,101,95,100,111,119,110,0,0,0,0,0,115,118,95,110,111,115,116,101,112,0,0,0,0,0,0,0,67,108,105,101,110,116,32,37,115,32,99,111,110,110,101,99,116,101,100,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,77,105,99,114,111,115,111,102,116,32,80,67,77,32,102,111,114,109,97,116,32,111,110,108,121,10,0,0,0,0,0,0,101,52,109,51,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,112,108,117,115,0,0,0,0,0,0,0,0,112,108,97,121,0,0,0,0,50,46,48,0,0,0,0,0,114,97,109,0,0,0,0,0,37,115,10,0,0,0,0,0,103,108,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,66,97,100,32,109,97,120,99,108,105,101,110,116,115,32,40,37,117,41,32,102,114,111,109,32,115,101,114,118,101,114,10,0,0,0,0,0,0,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,105,110,118,95,110,97,105,108,103,117,110,0,0,0,0,0,79,69,83,95,112,97,99,107,101,100,95,100,101,112,116,104,95,115,116,101,110,99,105,108,0,0,0,0,0,0,0,0,114,95,97,109,98,105,101,110,116,0,0,0,0,0,0,0,119,98,0,0,0,0,0,0,114,101,119,105,110,100,95,103,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,49,0,0,0,0,0,0,0,68,73,83,75,32,79,80,84,73,79,78,83,0,0,0,0,76,105,110,101,97,114,0,0,10,69,68,73,67,84,32,37,105,58,10,0,0,0,0,0,71,76,83,76,0,0,0,0,115,101,110,115,105,116,105,118,105,116,121,0,0,0,0,0,83,85,66,95,70,0,0,0,98,101,103,105,110,32,105,115,32,110,111,116,32,118,97,108,105,100,32,102,114,111,109,32,116,104,101,32,99,111,110,115,111,108,101,10,0,0,0,0,37,115,58,32,110,111,116,32,97,32,99,108,105,101,110,116,0,0,0,0,0,0,0,0,114,95,105,110,118,98,97,114,50,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,83,99,97,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,110,102,105,103,32,107,101,121,58,32,37,115,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,111,114,32,73,68,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,78,85,76,76,32,102,117,110,99,116,105,111,110,0,0,0,118,111,108,117,109,101,95,117,112,0,0,0,0,0,0,0,79,70,70,0,0,0,0,0,108,111,99,97,108,0,0,0,61,34,0,0,0,0,0,0,70,111,114,99,105,110,103,32,67,68,32,116,114,97,99,107,32,116,111,32,37,105,10,0,37,115,58,32,98,97,100,32,108,117,109,112,32,101,120,116,101,110,116,115,32,105,110,32,37,115,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,84,104,101,32,84,111,119,101,114,32,111,102,32,68,101,115,112,97,105,114,0,0,0,0,80,114,101,118,105,111,117,115,32,115,104,97,100,101,114,0,83,69,77,73,67,79,76,79,78,0,0,0,0,0,0,0,37,115,32,101,110,116,101,114,101,100,32,116,104,101,32,103,97,109,101,10,0,0,0,0,114,101,119,105,110,100,95,98,117,102,102,101,114,95,115,105,122,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,37,51,105,58,37,115,10,0,114,95,105,110,118,98,97,114,49,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,70,105,108,116,101,114,0,0,0,0,0,0,0,101,113,117,97,108,0,0,0,97,115,115,105,103,110,109,101,110,116,32,116,111,32,119,111,114,108,100,32,101,110,116,105,116,121,0,0,0,0,0,0,101,110,97,98,108,101,95,104,111,116,107,101,121,0,0,0,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,97,118,101,32,115,116,97,116,101,115,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,101,52,109,50,0,0,0,0,115,104,97,100,101,114,95,112,114,101,118,0,0,0,0,0,77,87,72,69,69,76,68,79,87,78,0,0,0,0,0,0,83,112,97,119,110,32,110,111,116,32,118,97,108,105,100,32,45,45,32,97,108,108,114,101,97,100,121,32,115,112,97,119,110,101,100,10,0,0,0,0,99,104,97,115,101,95,116,121,112,101,0,0,0,0,0,0,114,101,119,105,110,100,95,101,110,97,98,108,101,0,0,0,115,118,99,95,102,105,116,122,95,115,112,97,119,110,115,116,97,116,105,99,115,111,117,110,100,50,0,0,0,0,0,0,37,115,32,104,97,115,32,119,114,111,110,103,32,118,101,114,115,105,111,110,32,110,117,109,98,101,114,32,40,37,105,32,115,104,111,117,108,100,32,98,101,32,37,105,41,0,0,0,115,98,95,101,115,104,108,100,0,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,0,0,0,0,0,0,109,97,115,107,0,0,0,0,37,115,58,32,112,114,111,103,115,32,101,120,101,99,117,116,105,111,110,32,114,117,110,110,105,110,103,32,97,119,97,121,32,40,37,105,32,108,101,102,116,41,10,0,0,0,0,0,115,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,0,0,84,104,101,32,83,101,119,97,103,101,32,83,121,115,116,101,109,0,0,0,0,0,0,0,78,101,120,116,32,115,104,97,100,101,114,0,0,0,0,0,103,102,120,47,98,111,120,95,116,114,46,108,109,112,0,0,77,87,72,69,69,76,85,80,0,0,0,0,0,0,0,0,115,112,97,119,110,32,105,115,32,110,111,116,32,118,97,108,105,100,32,102,114,111,109,32,116,104,101,32,99,111,110,115,111,108,101,10,0,0,0,0,37,115,58,32,105,110,116,101,114,118,97,108,32,60,61,32,48,0,0,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,115,99,97,108,101,0,0,0,0,0,115,116,97,114,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,115,116,97,116,101,32,102,114,111,109,32,109,111,118,105,101,46,10,0,0,0,115,118,99,95,102,105,116,122,95,115,112,97,119,110,115,116,97,116,105,99,50,0,0,0,115,98,95,119,115,117,105,116,0,0,0,0,0,0,0,0,83,104,97,100,101,114,32,80,97,115,115,101,115,0,0,0,105,110,112,117,116,95,115,108,111,116,0,0,0,0,0,0,114,117,110,97,119,97,121,32,108,111,111,112,32,101,114,114,111,114,0,0,0,0,0,0,110,101,116,112,108,97,121,95,102,108,105,112,95,112,108,97,121,101,114,115,0,0,0,0,37,115,46,98,115,118,0,0,101,52,109,49,0,0,0,0,115,104,97,100,101,114,95,110,101,120,116,0,0,0,0,0,80,65,85,83,69,0,0,0,112,114,101,115,112,97,119,110,32,110,111,116,32,118,97,108,105,100,32,45,45,32,97,108,108,114,101,97,100,121,32,115,112,97,119,110,101,100,10,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,111,112,97,99,105,116,121,0,0,0,76,69,70,84,65,82,82,79,87,0,0,0,0,0,0,0,115,118,99,95,102,105,116,122,95,115,112,97,119,110,98,97,115,101,108,105,110,101,50,0,105,110,118,97,37,105,95,112,114,111,120,0,0,0,0,0,76,111,97,100,32,83,104,97,100,101,114,32,80,114,101,115,101,116,0,0,0,0,0,0,119,114,97,109,0,0,0,0,80,82,95,69,120,101,99,117,116,101,80,114,111,103,114,97,109,58,32,78,85,76,76,32,102,117,110,99,116,105,111,110,0,0,0,0,0,0,0,0,97,117,100,105,111,95,109,117,116,101,0,0,0,0,0,0,37,115,37,117,46,98,115,118,0,0,0,0,0,0,0,0,84,104,101,32,72,97,117,110,116,101,100,32,72,97,108,108,115,0,0,0,0,0,0,0,82,101,115,101,116,32,103,97,109,101,0,0,0,0,0,0,65,85,88,51,50,0,0,0,112,114,101,115,112,97,119,110,32,105,115,32,110,111,116,32,118,97,108,105,100,32,102,114,111,109,32,116,104,101,32,99,111,110,115,111,108,101,10,0,46,114,101,116,114,111,97,114,99,104,45,99,111,114,101,45,111,112,116,105,111,110,115,46,99,102,103,0,0,0,0,0,35,37,45,50,117,32,37,45,49,54,46,49,54,115,32,32,37,51,105,32,32,37,50,105,58,37,48,50,105,58,37,48,50,105,10,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,0,0,0,115,118,99,95,102,105,116,122,95,102,111,103,0,0,0,0,105,110,118,97,37,105,95,112,114,111,120,95,103,114,101,110,0,0,0,0,0,0,0,0,68,101,102,97,117,108,116,32,70,105,108,116,101,114,0,0,115,101,109,97,110,116,105,99,0,0,0,0,0,0,0,0,80,82,95,69,120,101,99,117,116,101,80,114,111,103,114,97,109,58,32,108,111,99,97,108,115,32,115,116,97,99,107,32,117,110,100,101,114,102,108,111,119,10,0,0,0,0,0,0,100,115,112,95,99,111,110,102,105,103,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,0,101,51,109,55,0,0,0,0,114,101,115,101,116,0,0,0,65,85,88,51,49,0,0,0,67,68,65,117,100,105,111,95,73,110,105,116,58,32,78,111,32,67,68,32,105,110,32,112,108,97,121,101,114,46,10,0,116,105,109,101,108,105,109,105,116,0,0,0,0,0,0,0,37,115,32,117,110,112,97,117,115,101,100,32,116,104,101,32,103,97,109,101,10,0,0,0,48,46,54,50,0,0,0,0,111,118,101,114,108,97,121,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,115,118,99,95,102,105,116,122,95,98,102,0,0,0,0,0,105,110,118,97,37,105,95,103,114,101,110,95,112,114,111,120,0,0,0,0,0,0,0,0,65,112,112,108,121,32,83,104,97,100,101,114,32,67,104,97,110,103,101,115,0,0,0,0,105,100,0,0,0,0,0,0,112,114,111,103,32,115,116,97,99,107,32,117,110,100,101,114,102,108,111,119,0,0,0,0,115,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,67,104,97,109,98,101,114,115,32,111,102,32,84,111,114,109,101,110,116,0,0,0,0,0,70,114,97,109,101,97,100,118,97,110,99,101,0,0,0,0,65,85,88,51,48,0,0,0,37,115,32,112,97,117,115,101,100,32,116,104,101,32,103,97,109,101,10,0,0,0,0,0,114,103,117,105,95,98,114,111,119,115,101,114,95,100,105,114,101,99,116,111,114,121,0,0,37,102,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,101,110,100,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,78,111,32,67,111,114,101,0,115,118,99,95,102,105,116,122,95,115,107,121,98,111,120,0,105,110,118,97,37,105,95,109,106,111,108,110,105,114,0,0,37,115,32,40,37,100,44,32,37,100,32,58,32,37,52,117,120,37,52,117,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,111,111,32,109,97,110,121,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,115,32,46,46,46,10,0,0,0,0,0,80,82,95,69,120,101,99,117,116,101,80,114,111,103,114,97,109,58,32,108,111,99,97,108,115,32,115,116,97,99,107,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,99,104,101,97,116,95,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,108,121,32,115,104,97,100,101,114,46,10,0,0,0,0,101,51,109,54,0,0,0,0,102,114,97,109,101,95,97,100,118,97,110,99,101,0,0,0,65,85,88,50,57,0,0,0,80,97,117,115,101,32,110,111,116,32,97,108,108,111,119,101,100,46,10,0,0,0,0,0,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,110,32,101,120,105,115,116,105,110,103,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,84,65,66,0,0,0,0,0,105,110,118,97,37,105,95,108,97,115,101,114,0,0,0,0,83,101,116,32,66,111,116,116,111,109,45,82,105,103,104,116,32,67,111,114,110,101,114,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,80,121,116,104,111,110,32,115,99,114,105,112,116,46,10,0,0,0,0,0,0,0,0,115,116,97,99,107,32,111,118,101,114,102,108,111,119,0,0,99,104,101,97,116,95,105,110,100,101,120,95,109,105,110,117,115,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,0,87,105,110,100,32,84,117,110,110,101,108,115,0,0,0,0,80,97,117,115,101,32,116,111,103,103,108,101,0,0,0,0,65,85,88,50,56,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,100,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,67,97,110,39,116,32,115,117,105,99,105,100,101,32,45,45,32,97,108,108,114,101,97,100,121,32,100,101,97,100,33,10,0,0,0,0,0,0,0,0,80,108,97,121,105,110,103,32,115,104,97,114,101,119,97,114,101,32,118,101,114,115,105,111,110,46,10,0,0,0,0,0,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,0,0,0,0,87,97,114,110,105,110,103,58,32,102,105,120,101,100,32,117,112,32,108,105,110,107,32,105,110,32,37,115,10,0,0,0,37,115,58,32,98,97,100,32,115,105,122,101,0,0,0,0,112,114,111,103,115,47,98,111,108,116,46,109,100,108,0,0,50,46,48,0,0,0,0,0,115,118,99,95,99,117,116,115,99,101,110,101,0,0,0,0,105,110,118,50,95,112,114,111,120,0,0,0,0,0,0,0,82,101,115,111,108,117,116,105,111,110,32,40,114,101,115,116,97,114,116,41,59,32,51,50,48,120,50,48,48,124,51,50,48,120,50,52,48,124,51,50,48,120,52,56,48,124,51,54,48,120,50,48,48,124,51,54,48,120,50,52,48,124,51,54,48,120,52,48,48,124,51,54,48,120,52,56,48,124,52,48,48,120,50,50,52,124,52,56,48,120,50,55,50,124,53,49,50,120,50,50,52,124,53,49,50,120,50,52,48,124,53,49,50,120,51,56,52,124,53,49,50,120,53,49,50,124,54,52,48,120,50,50,52,124,54,52,48,120,50,52,48,124,54,52,48,120,52,52,56,124,54,52,48,120,52,56,48,124,55,50,48,120,53,55,54,124,56,48,48,120,52,56,48,124,56,48,48,120,54,48,48,124,57,54,48,120,55,50,48,124,49,48,50,52,120,55,54,56,0,0,83,101,116,32,85,112,112,101,114,45,76,101,102,116,32,67,111,114,110,101,114,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,108,97,110,103,117,97,103,101,32,105,115,32,110,111,116,32,80,121,116,104,111,110,46,10,0,0,0,0,80,114,111,103,114,97,109,32,101,114,114,111,114,0,0,0,49,48,0,0,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,112,108,117,115,0,0,0,0,0,0,0,0,50,48,48,48,0,0,0,0,48,46,54,50,0,0,0,0,83,104,97,100,101,114,32,35,37,117,58,32,34,37,115,34,46,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,102,109,116,32,99,104,117,110,107,10,0,0,0,0,0,0,101,51,109,53,0,0,0,0,112,97,117,115,101,95,116,111,103,103,108,101,0,0,0,0,45,115,105,109,115,111,117,110,100,0,0,0,0,0,0,0,99,108,95,109,111,118,101,115,112,101,101,100,107,101,121,0,115,105,122,101,100,111,119,110,0,0,0,0,0,0,0,0,65,85,88,50,55,0,0,0,103,108,84,101,120,73,109,97,103,101,51,68,79,69,83,0,83,101,114,118,101,114,32,114,101,116,117,114,110,101,100,32,117,110,107,110,111,119,110,32,112,114,111,116,111,99,111,108,32,118,101,114,115,105,111,110,32,37,105,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,116,97,116,101,32,116,114,97,99,107,101,114,46,10,0,0,0,0,0,0,95,99,108,95,99,111,108,111,114,0,0,0,0,0,0,0,105,110,118,95,115,115,104,111,116,103,117,110,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,77,97,120,32,116,101,120,116,117,114,101,32,115,105,122,101,58,32,37,100,32,112,120,44,32,114,101,110,100,101,114,98,117,102,102,101,114,32,115,105,122,101,58,32,37,117,32,112,120,46,10,0,0,0,0,37,105,32,112,111,105,110,116,115,32,114,101,97,100,10,0,114,95,102,117,108,108,98,114,105,103,104,116,0,0,0,0,99,111,114,101,95,111,112,116,105,111,110,115,95,112,97,116,104,0,0,0,0,0,0,0,114,95,119,97,116,101,114,119,97,114,112,0,0,0,0,0,65,85,68,73,79,32,79,80,84,73,79,78,83,0,0,0,78,47,65,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,66,105,116,32,100,101,112,116,104,32,111,102,32,84,71,65,32,105,109,97,103,101,32,105,115,32,119,114,111,110,103,46,32,79,110,108,121,32,51,50,45,98,105,116,32,97,110,100,32,50,52,45,98,105,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,70,82,69,69,10,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,108,111,111,107,115,116,114,97,102,101,0,0,0,0,0,0,65,68,68,95,86,0,0,0,115,118,99,95,115,101,108,108,115,99,114,101,101,110,0,0,99,104,97,110,103,101,108,101,118,101,108,32,37,115,10,0,105,110,118,50,95,112,114,111,120,95,103,114,101,110,0,0,37,115,32,40,37,52,117,120,37,52,117,44,32,37,117,32,120,32,37,117,32,115,99,97,108,101,41,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,111,118,101,114,108,97,121,0,0,0,0,0,0,0,112,111,105,110,116,101,114,0,99,108,97,115,115,0,0,0,37,115,10,0,0,0,0,0,115,104,97,100,101,114,95,112,114,101,118,0,0,0,0,0,79,78,0,0,0,0,0,0,76,111,111,107,105,110,103,32,102,111,114,32,81,117,97,107,101,32,115,101,114,118,101,114,115,46,46,46,10,0,0,0,32,10,9,12,11,13,0,0,82,101,116,114,111,65,114,99,104,58,32,9,9,37,115,10,0,0,0,0,0,0,0,0,37,115,58,32,37,115,32,104,97,115,32,119,114,111,110,103,32,118,101,114,115,105,111,110,32,110,117,109,98,101,114,32,40,37,105,32,115,104,111,117,108,100,32,98,101,32,37,105,32,111,114,32,37,105,41,0,67,97,110,32,110,111,116,32,114,101,99,111,114,100,32,45,32,97,108,114,101,97,100,121,32,99,111,110,110,101,99,116,101,100,32,116,111,32,115,101,114,118,101,114,10,67,108,105,101,110,116,32,100,101,109,111,32,114,101,99,111,114,100,105,110,103,32,109,117,115,116,32,98,101,32,115,116,97,114,116,101,100,32,98,101,102,111,114,101,32,99,111,110,110,101,99,116,105,110,103,10,0,0,0,46,99,103,112,0,0,0,0,83,97,116,97,110,39,115,32,68,97,114,107,32,68,101,108,105,103,104,116,0,0,0,0,77,111,118,105,101,32,114,101,99,111,114,100,32,116,111,103,103,108,101,0,0,0,0,0,65,85,88,50,54,0,0,0,99,111,108,111,114,32,60,48,45,49,51,62,32,91,48,45,49,51,93,10,0,0,0,0,108,105,98,114,101,116,114,111,95,112,97,116,104,0,0,0,115,118,99,95,99,100,116,114,97,99,107,0,0,0,0,0,105,110,118,50,95,103,114,101,110,95,112,114,111,120,0,0,83,101,116,32,115,99,97,108,101,0,0,0,0,0,0,0,39,37,53,46,49,102,32,37,53,46,49,102,32,37,53,46,49,102,39,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,97,108,114,101,97,100,121,32,105,109,112,111,114,116,101,100,46,10,0,0,37,55,105,32,37,115,10,0,115,104,97,100,101,114,95,110,101,120,116,0,0,0,0,0,46,99,103,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,117,115,101,115,32,116,104,114,101,97,100,101,100,32,97,117,100,105,111,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,0,101,51,109,52,0,0,0,0,109,111,118,105,101,95,114,101,99,111,114,100,95,116,111,103,103,108,101,0,0,0,0,0,65,85,88,50,53,0,0,0,34,99,111,108,111,114,34,32,105,115,32,34,37,105,32,37,105,34,10,0,0,0,0,0,105,110,112,117,116,95,106,111,121,112,97,100,95,100,114,105,118,101,114,0,0,0,0,0,99,104,97,115,101,95,97,99,116,105,118,101,0,0,0,0,115,118,99,95,102,105,110,97,108,101,0,0,0,0,0,0,105,110,118,50,95,109,106,111,108,110,105,114,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,67,71,80,32,102,97,105,108,101,100,46,10,0,0,37,53,46,49,102,0,0,0,63,63,63,0,0,0,0,0,37,49,50,115,32,58,32,37,115,10,0,0,0,0,0,0,114,101,115,101,116,0,0,0,46,115,104,97,100,101,114,0,84,104,101,32,84,111,109,98,32,111,102,32,84,101,114,114,111,114,0,0,0,0,0,0,82,101,119,105,110,100,0,0,103,102,120,47,98,111,120,95,98,109,46,108,109,112,0,0,65,85,88,50,52,0,0,0,58,32,0,0,0,0,0,0,105,110,112,117,116,95,100,114,105,118,101,114,0,0,0,0,37,115,58,32,73,110,118,97,108,105,100,32,35,32,111,102,32,102,114,97,109,101,115,58,32,37,100,0,0,0,0,0,83,101,108,101,99,116,32,98,117,116,116,111,110,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,82,67,51,50,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,82,79,77,32,102,105,108,101,32,97,110,100,32,115,97,118,101,100,32,82,79,77,32,99,104,101,99,107,115,117,109,32,105,110,32,114,101,112,108,97,121,32,102,105,108,101,32,104,101,97,100,101,114,59,32,114,101,112,108,97,121,32,104,105,103,104,108,121,32,108,105,107,101,108,121,32,116,111,32,100,101,115,121,110,99,32,111,110,32,112,108,97,121,98,97,99,107,46,10,0,115,118,99,95,105,110,116,101,114,109,105,115,115,105,111,110,0,0,0,0,0,0,0,0,105,110,118,50,95,108,97,115,101,114,0,0,0,0,0,0,78,47,65,32,40,115,116,111,99,107,41,0,0,0,0,0,46,37,115,0,0,0,0,0,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,0,60,78,79,32,70,85,78,67,84,73,79,78,62,10,0,0,102,114,97,109,101,95,97,100,118,97,110,99,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,111,116,32,105,110,118,97,108,105,100,32,100,105,115,107,32,105,110,100,101,120,32,102,114,111,109,32,108,105,98,114,101,116,114,111,46,10,0,0,0,0,0,101,51,109,51,0,0,0,0,114,101,119,105,110,100,0,0,65,85,88,50,51,0,0,0,37,115,0,0,0,0,0,0,97,117,100,105,111,95,100,115,112,95,112,108,117,103,105,110,0,0,0,0,0,0,0,0,68,79,87,78,65,82,82,79,87,0,0,0,0,0,0,0,115,118,99,95,115,112,97,119,110,115,116,97,116,105,99,115,111,117,110,100,0,0,0,0,105,110,118,95,112,114,111,120,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,0,37,115,40,41,0,0,0,0,114,101,112,101,97,116,0,0,60,78,79,32,83,84,65,67,75,62,10,0,0,0,0,0,112,97,117,115,101,95,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,66,83,82,77,58,32,37,115,10,0,0,0,0,84,104,101,32,86,97,117,108,116,115,32,111,102,32,90,105,110,0,0,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,45,0,0,0,0,0,0,0,0,65,85,88,50,50,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,86,65,82,73,65,66,76,69,83,46,10,0,0,0,0,0,0,112,108,97,121,101,114,115,58,32,37,105,32,97,99,116,105,118,101,32,40,37,105,32,109,97,120,41,10,10,0,0,0,97,117,100,105,111,95,100,114,105,118,101,114,0,0,0,0,115,118,99,95,102,111,117,110,100,115,101,99,114,101,116,0,105,110,118,95,112,114,111,120,95,103,114,101,110,0,0,0,37,115,32,40,37,115,41,0,101,110,116,105,116,121,32,37,105,0,0,0,0,0,0,0,99,108,97,109,112,95,116,111,95,101,100,103,101,0,0,0,10,0,0,0,0,0,0,0,109,111,118,105,101,95,114,101,99,111,114,100,95,116,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,83,82,77,58,32,37,115,10,0,0,0,0,101,51,109,50,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,100,101,99,114,101,97,115,101,0,0,0,0,0,65,85,88,50,49,0,0,0,102,114,97,103,108,105,109,105,116,0,0,0,0,0,0,0,37,99,60,37,115,62,32,0,67,68,32,65,117,100,105,111,32,73,110,105,116,105,97,108,105,122,101,100,10,0,0,0,103,102,120,47,99,111,110,98,97,99,107,46,108,109,112,0,118,105,100,101,111,95,103,108,95,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,115,118,99,95,107,105,108,108,101,100,109,111,110,115,116,101,114,0,0,0,0,0,0,0,105,110,118,95,103,114,101,110,95,112,114,111,120,0,0,0,60,85,115,101,32,116,104,105,115,32,100,105,114,101,99,116,111,114,121,62,0,0,0,0,98,97,100,32,116,121,112,101,32,37,105,0,0,0,0,0,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,0,37,115,0,0,0,0,0,0,114,101,119,105,110,100,0,0,37,115,58,32,104,105,116,32,116,104,101,32,101,110,100,32,111,102,32,109,101,109,111,114,121,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,83,117,102,97,109,105,32,116,117,114,98,111,32,65,47,66,32,82,65,77,46,10,0,0,0,0,0,0,0,0,84,101,114,109,105,110,97,116,105,111,110,32,67,101,110,116,114,97,108,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,43,0,0,0,0,0,0,0,0,65,85,88,50,48,0,0,0,37,99,37,115,58,32,0,0,104,111,115,116,58,32,32,32,32,37,115,10,0,0,0,0,118,105,100,101,111,95,100,114,105,118,101,114,0,0,0,0,37,48,50,120,0,0,0,0,100,101,97,116,104,109,97,116,99,104,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,101,110,100,105,110,103,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,0,115,118,99,95,99,101,110,116,101,114,112,114,105,110,116,0,105,110,118,95,109,106,111,108,110,105,114,0,0,0,0,0,48,0,0,0,0,0,0,0,37,115,124,122,105,112,0,0,37,102,32,37,102,32,37,102,0,0,0,0,0,0,0,0,97,98,115,111,108,117,116,101,0,0,0,0,0,0,0,0,98,114,97,110,99,104,32,37,105,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,100,101,99,114,101,97,115,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,83,82,77,58,32,37,115,10,0,0,0,0,101,51,109,49,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,105,110,99,114,101,97,115,101,0,0,0,0,0,65,85,88,49,57,0,0,0,69,120,101,58,32,49,54,58,52,50,58,53,49,32,83,101,112,32,49,53,32,50,48,49,51,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,114,101,115,97,109,112,108,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,115,116,117,102,102,99,109,100,115,32,58,32,101,120,101,99,117,116,101,32,99,111,109,109,97,110,100,32,108,105,110,101,32,112,97,114,97,109,101,116,101,114,115,10,0,0,0,0,97,117,100,105,111,95,118,111,108,117,109,101,0,0,0,0,114,98,0,0,0,0,0,0,115,118,99,95,115,105,103,110,111,110,110,117,109,0,0,0,105,110,118,95,108,97,115,101,114,0,0,0,0,0,0,0,99,102,103,0,0,0,0,0,37,102,0,0,0,0,0,0,118,105,101,119,112,111,114,116,0,0,0,0,0,0,0,0,37,115,98,114,97,110,99,104,32,37,105,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,105,110,99,114,101,97,115,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,32,37,115,10,0,0,0,0,85,110,100,101,114,101,97,114,116,104,0,0,0,0,0,0,81,117,105,116,32,82,101,116,114,111,65,114,99,104,0,0,65,85,88,49,56,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,32,98,117,102,102,101,114,46,10,0,0,86,101,114,115,105,111,110,32,84,121,114,81,117,97,107,101,45,37,115,10,0,0,0,0,103,102,120,47,112,111,112,46,108,109,112,0,0,0,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,95,100,101,108,116,97,0,0,0,0,0,0,0,0,37,115,58,32,101,110,99,111,117,110,116,101,114,101,100,32,78,85,76,76,32,108,105,110,107,0,0,0,0,0,0,0,37,115,58,32,116,114,97,115,104,101,100,32,115,101,110,116,105,110,97,108,0,0,0,0,119,101,97,112,111,110,115,47,114,95,101,120,112,51,46,119,97,118,0,0,0,0,0,0,99,108,95,114,111,108,108,97,110,103,108,101,0,0,0,0,115,118,99,95,115,101,116,112,97,117,115,101,0,0,0,0,115,99,111,114,101,98,97,114,0,0,0,0,0,0,0,0,114,101,115,111,108,117,116,105,111,110,0,0,0,0,0,0,99,103,124,103,108,115,108,0,118,111,105,100,0,0,0,0,115,111,117,114,99,101,0,0,32,0,0,0,0,0,0,0,115,118,95,97,99,99,101,108,101,114,97,116,101,0,0,0,101,120,105,116,95,101,109,117,108,97,116,111,114,0,0,0,115,118,95,109,97,120,118,101,108,111,99,105,116,121,0,0,37,99,10,86,69,82,83,73,79,78,32,84,121,114,81,117,97,107,101,45,37,115,32,83,69,82,86,69,82,32,40,37,105,32,67,82,67,41,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,66,83,88,32,40,80,41,82,65,77,46,10,0,0,102,109,116,32,0,0,0,0,101,50,109,55,0,0,0,0,101,120,105,116,95,101,109,117,108,97,116,111,114,0,0,0,45,110,111,115,111,117,110,100,0,0,0,0,0,0,0,0,51,53,48,0,0,0,0,0,80,76,84,69,0,0,0,0,115,105,122,101,117,112,0,0,103,108,71,101,116,66,117,102,102,101,114,80,111,105,110,116,101,114,118,79,69,83,0,0,65,85,88,49,55,0,0,0,83,101,114,118,101,114,105,110,102,111,32,112,97,99,107,101,116,32,114,101,99,101,105,118,101,100,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,76,85,84,115,46,10,0,0,0,0,0,0,0,0,37,115,32,114,101,110,97,109,101,100,32,116,111,32,37,115,10,0,0,0,0,0,0,0,105,110,118,95,115,104,111,116,103,117,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,32,72,87,32,114,101,110,100,101,114,32,40,37,117,32,120,32,37,117,41,46,10,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,102,114,101,101,32,112,97,114,116,105,99,108,101,115,10,0,0,0,0,0,0,48,0,0,0,0,0,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,0,0,0,0,0,0,50,0,0,0,0,0,0,0,83,72,65,68,69,82,32,79,80,84,73,79,78,83,0,0,37,117,0,0,0,0,0,0,37,115,58,32,110,111,32,115,117,99,104,32,115,107,105,110,32,35,32,37,100,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,84,71,65,32,112,105,120,101,108,115,46,10,0,0,0,0,37,105,40,37,115,41,0,0,115,104,97,100,101,114,0,0,108,111,111,107,115,112,114,105,110,103,0,0,0,0,0,0,65,68,68,95,70,0,0,0,115,118,99,95,116,101,109,112,95,101,110,116,105,116,121,0,37,115,58,32,111,118,101,114,102,108,111,119,32,40,115,116,114,105,110,103,32,116,114,117,110,99,97,116,101,100,41,10,0,0,0,0,0,0,0,0,105,98,97,114,0,0,0,0,99,103,112,124,103,108,115,108,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,111,118,101,114,108,97,121,32,99,97,108,108,101,100,58,32,34,37,115,34,46,10,0,0,0,0,37,105,0,0,0,0,0,0,115,99,97,108,101,95,37,115,37,117,0,0,0,0,0,0,37,115,32,0,0,0,0,0,116,111,103,103,108,101,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,67,104,101,97,116,58,32,35,37,117,32,91,37,115,93,58,32,37,115,0,0,0,0,0,37,115,58,32,110,111,116,32,97,99,116,105,118,101,0,0,60,47,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,80,111,115,115,105,98,108,101,32,118,97,108,117,101,115,58,10,0,0,0,37,115,58,32,37,115,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,0,82,101,108,97,116,105,118,101,32,112,97,116,104,110,97,109,101,115,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,71,97,109,101,98,111,121,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,84,104,101,32,68,105,115,109,97,108,32,79,117,98,108,105,101,116,116,101,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,116,111,103,103,108,101,0,0,0,0,0,0,0,65,85,88,49,54,0,0,0,117,110,99,111,110,110,101,99,116,101,100,0,0,0,0,0,97,117,100,105,111,95,115,121,110,99,0,0,0,0,0,0,115,118,99,95,115,112,97,119,110,98,97,115,101,108,105,110,101,0,0,0,0,0,0,0,115,98,97,114,0,0,0,0,47,0,0,0,0,0,0,0,67,97,110,39,116,32,102,105,110,100,32,102,117,110,99,116,105,111,110,32,37,115,10,0,115,99,97,108,101,95,116,121,112,101,95,37,115,37,117,0,66,73,84,79,82,0,0,0,115,97,118,101,95,115,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,84,67,58,32,37,115,10,0,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,0,0,0,0,0])
.concat([101,50,109,54,0,0,0,0,116,111,103,103,108,101,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,65,85,88,49,53,0,0,0,95,99,108,95,110,97,109,101,0,0,0,0,0,0,0,0,97,117,100,105,111,95,108,97,116,101,110,99,121,0,0,0,48,0,0,0,0,0,0,0,37,115,58,32,111,118,101,114,102,108,111,119,10,0,0,0,79,66,83,79,76,69,84,69,32,115,118,99,95,115,112,97,119,110,98,105,110,97,114,121,0,0,0,0,0,0,0,0,45,115,104,111,119,115,99,111,114,101,115,0,0,0,0,0,37,99,32,37,45,42,46,42,115,32,37,45,42,115,0,0,67,97,110,39,116,32,102,105,110,100,32,102,105,101,108,100,32,37,115,10,0,0,0,0,121,0,0,0,0,0,0,0,66,73,84,65,78,68,0,0,108,111,97,100,95,115,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,37,115,10,0,0,0,0,0,84,104,101,32,87,105,122,97,114,100,39,115,32,77,97,110,115,101,0,0,0,0,0,0,83,97,118,101,32,115,116,97,116,101,0,0,0,0,0,0,103,102,120,47,98,111,120,95,109,109,50,46,108,109,112,0,65,85,88,49,52,0,0,0,34,110,97,109,101,34,32,105,115,32,34,37,115,34,10,0,97,117,100,105,111,95,100,101,118,105,99,101,0,0,0,0,115,101,108,101,99,116,0,0,37,115,58,32,105,110,118,97,108,105,100,32,118,101,114,116,101,120,32,105,110,100,101,120,32,40,37,100,32,111,102,32,37,100,41,32,105,110,32,37,115,10,0,0,0,0,0,0,37,115,58,32,37,100,32,105,115,32,62,32,102,117,108,108,32,98,117,102,102,101,114,32,115,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,118,105,101,32,102,105,108,101,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,66,83,86,49,32,102,105,108,101,46,10,0,0,0,0,0,0,115,118,99,95,115,112,97,119,110,115,116,97,116,105,99,0,43,115,104,111,119,115,99,111,114,101,115,0,0,0,0,0,82,105,103,104,116,32,83,116,105,99,107,0,0,0,0,0,66,97,100,32,101,100,105,99,116,32,110,117,109,98,101,114,10,0,0,0,0,0,0,0,120,0,0,0,0,0,0,0,79,82,0,0,0,0,0,0,104,111,108,100,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,114,101,103,117,108,97,114,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,101,50,109,53,0,0,0,0,115,97,118,101,95,115,116,97,116,101,0,0,0,0,0,0,65,85,88,49,51,0,0,0,108,111,99,97,108,0,0,0,97,117,100,105,111,95,98,108,111,99,107,95,102,114,97,109,101,115,0,0,0,0,0,0,85,80,65,82,82,79,87,0,37,115,58,32,111,118,101,114,102,108,111,119,32,119,105,116,104,111,117,116,32,97,108,108,111,119,111,118,101,114,102,108,111,119,32,115,101,116,32,40,37,100,32,62,32,37,100,41,0,0,0,0,0,0,0,0,115,118,99,95,100,97,109,97,103,101,0,0,0,0,0,0,102,97,99,101,95,113,117,97,100,0,0,0,0,0,0,0,68,117,97,108,32,65,110,97,108,111,103,0,0,0,0,0,115,116,101,112,32,32,32,32,32,32,58,37,51,105,10,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,37,117,0,0,0,0,0,65,78,68,0,0,0,0,0,116,111,103,103,108,101,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,102,97,105,108,101,100,0,0,84,104,101,32,69,98,111,110,32,70,111,114,116,114,101,115,115,0,0,0,0,0,0,0,104,111,115,116,95,102,114,97,109,101,114,97,116,101,0,0,76,111,97,100,32,115,116,97,116,101,0,0,0,0,0,0,65,85,88,49,50,0,0,0,70,105,114,115,116,32,116,111,107,101,110,32,105,115,110,39,116,32,97,32,98,114,97,99,101,0,0,0,0,0,0,0,78,47,65,0,0,0,0,0,109,97,112,58,32,32,32,32,32,37,115,10,0,0,0,0,97,117,100,105,111,95,111,117,116,95,114,97,116,101,0,0,45,100,105,98,111,110,108,121,0,0,0,0,0,0,0,0,115,118,99,95,112,97,114,116,105,99,108,101,0,0,0,0,102,97,99,101,95,105,110,118,50,0,0,0,0,0,0,0,76,101,102,116,32,83,116,105,99,107,0,0,0,0,0,0,116,111,117,99,104,32,32,32,32,32,58,37,51,105,10,0,63,0,0,0,0,0,0,0,71,79,84,79,0,0,0,0,114,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,115,117,99,99,101,101,100,101,100,0,0,0,0,0,0,0,101,50,109,52,0,0,0,0,108,111,97,100,95,115,116,97,116,101,0,0,0,0,0,0,65,85,88,49,49,0,0,0,115,101,114,118,101,114,112,114,111,102,105,108,101,0,0,0,123,0,0,0,0,0,0,0,99,100,0,0,0,0,0,0,37,115,58,32,98,97,100,32,99,111,111,114,100,105,110,97,116,101,115,0,0,0,0,0,97,117,100,105,111,95,101,110,97,98,108,101,0,0,0,0,45,110,111,109,111,117,115,101,0,0,0,0,0,0,0,0,115,118,99,95,117,112,100,97,116,101,99,111,108,111,114,115,0,0,0,0,0,0,0,0,102,97,99,101,95,105,110,118,117,108,50,0,0,0,0,0,85,110,107,110,111,119,110,0,118,105,101,119,32,32,32,32,32,32,58,37,51,105,10,0,112,121,116,104,111,110,0,0,83,84,65,84,69,0,0,0,114,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,109,101,110,117,95,110,117,109,99,97,99,104,101,112,105,99,115,32,61,61,32,77,65,88,95,67,65,67,72,69,68,95,80,73,67,83,0,0,0,0,37,115,58,32,37,105,32,62,32,99,97,99,104,101,32,115,105,122,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,117,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,32,37,115,46,10,0,67,114,121,112,116,32,111,102,32,68,101,99,97,121,0,0,70,97,115,116,32,102,111,114,119,97,114,100,32,104,111,108,100,0,0,0,0,0,0,0,65,85,88,49,48,0,0,0,100,95,115,117,98,100,105,118,49,54,0,0,0,0,0,0,76,111,97,100,103,97,109,101,32,98,117,102,102,101,114,32,111,118,101,114,102,108,111,119,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,37,117,95,106,111,121,112,97,100,95,105,110,100,101,120,0,0,0,0,0,48,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,45,110,111,106,111,121,0,0,37,53,100,32,116,111,116,97,108,95,99,104,97,110,110,101,108,115,10,0,0,0,0,0,115,118,99,95,115,116,111,112,115,111,117,110,100,0,0,0,102,97,99,101,95,105,110,118,105,115,0,0,0,0,0,0,102,97,108,115,101,0,0,0,83,117,112,101,114,83,99,111,112,101,0,0,0,0,0,0,115,97,121,58,0,0,0,0,97,99,116,105,118,101,32,32,32,32,58,37,51,105,10,0,116,114,97,110,115,105,116,105,111,110,95,112,114,101,118,105,111,117,115,0,0,0,0,0,67,65,76,76,56,0,0,0,114,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,46,97,117,116,111,0,0,0,101,50,109,51,0,0,0,0,104,111,108,100,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,0,0,65,85,88,57,0,0,0,0,67,111,117,108,100,110,39,116,32,108,111,97,100,32,109,97,112,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,37,115,58,32,99,111,109,109,97,110,100,32,116,114,117,110,99,97,116,101,100,10,0,0,110,101,116,112,108,97,121,95,99,108,105,101,110,116,95,115,119,97,112,95,105,110,112,117,116,0,0,0,0,0,0,0,45,110,111,99,100,97,117,100,105,111,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,100,105,114,101,99,116,111,114,121,58,32,34,37,115,34,10,0,0,0,0,37,112,32,100,109,97,32,98,117,102,102,101,114,10,0,0,115,118,99,95,99,108,105,101,110,116,100,97,116,97,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,0,102,97,99,101,95,112,53,0,74,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,110,117,109,95,101,100,105,99,116,115,58,37,51,105,10,0,99,97,112,116,117,114,101,95,112,114,101,118,105,111,117,115,0,0,0,0,0,0,0,0,67,65,76,76,55,0,0,0,114,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,45,118,0,0,0,0,0,0,79,103,114,101,32,67,105,116,97,100,101,108,0,0,0,0,70,97,115,116,32,102,111,114,119,97,114,100,32,116,111,103,103,108,101,0,0,0,0,0,65,85,88,56,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,115,107,105,108,108,0,0,0,37,46,42,115,0,0,0,0,105,110,112,117,116,95,97,120,105,115,95,116,104,114,101,115,104,111,108,100,0,0,0,0,77,79,86,69,84,89,80,69,95,80,85,83,72,32,119,105,116,104,32,97,32,110,111,110,32,98,115,112,32,109,111,100,101,108,0,0,0,0,0,0,37,115,58,32,114,101,97,108,108,111,99,101,100,32,97,32,102,114,101,101,100,32,112,111,105,110,116,101,114,0,0,0,45,110,111,115,111,117,110,100,0,0,0,0,0,0,0,0,50,48,48,0,0,0,0,0,119,101,97,112,111,110,115,47,114,105,99,51,46,119,97,118,0,0,0,0,0,0,0,0,37,53,100,32,115,112,101,101,100,10,0,0,0,0,0,0,115,118,99,95,117,112,100,97,116,101,102,114,97,103,115,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,102,97,99,101,53,0,0,0,112,97,107,0,0,0,0,0,74,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,103,97,109,101,99,102,103,0,116,114,97,110,115,105,116,105,111,110,95,99,111,117,110,116,0,0,0,0,0,0,0,0,67,65,76,76,54,0,0,0,108,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,51,50,48,0,0,0,0,0,56,48,48,0,0,0,0,0,37,115,58,32,37,115,32,110,111,116,32,112,114,101,99,97,99,104,101,101,100,10,0,0,45,99,0,0,0,0,0,0,77,105,115,115,105,110,103,32,82,73,70,70,47,87,65,86,69,32,99,104,117,110,107,115,10,0,0,0,0,0,0,0,101,50,109,50,0,0,0,0,10,83,111,117,110,100,32,73,110,105,116,105,97,108,105,122,97,116,105,111,110,10,0,0,116,111,103,103,108,101,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,99,108,95,115,105,100,101,115,112,101,101,100,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,105,108,101,32,67,82,67,32,100,105,102,102,101,114,115,32,102,114,111,109,32,90,73,80,32,67,82,67,46,32,70,105,108,101,58,32,48,120,37,120,44,32,90,73,80,58,32,48,120,37,120,46,10,0,0,0,0,0,0,73,69,78,68,0,0,0,0,115,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,103,108,85,110,109,97,112,66,117,102,102,101,114,79,69,83,0,0,0,0,0,0,0,0,65,85,88,55,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,83,76,32,115,116,111,99,107,32,112,114,111,103,114,97,109,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,46,10,0,0,0,0,45,45,62,32,99,108,105,101,110,116,32,116,111,32,115,101,114,118,101,114,32,107,101,101,112,97,108,105,118,101,10,0,110,117,109,95,115,108,97,115,104,0,0,0,0,0,0,0,83,97,118,101,103,97,109,101,32,105,115,32,118,101,114,115,105,111,110,32,37,105,44,32,110,111,116,32,37,105,10,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,37,117,32,116,101,120,116,117,114,101,115,46,10,0,0,0,0,0,0,37,102,32,37,102,32,37,102,10,0,0,0,0,0,0,0,114,95,100,114,97,119,111,114,100,101,114,0,0,0,0,0,100,101,102,97,117,108,116,0,114,95,99,108,101,97,114,99,111,108,111,114,0,0,0,0,86,73,68,69,79,32,79,80,84,73,79,78,83,0,0,0,114,103,117,105,46,99,103,112,0,0,0,0,0,0,0,0,37,115,58,32,110,111,32,115,117,99,104,32,102,114,97,109,101,32,37,100,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,101,100,32,84,71,65,58,32,40,37,117,120,37,117,32,64,32,37,117,32,98,112,112,41,10,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,45,110,111,108,97,110,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,0,0,0,99,108,95,110,111,108,101,114,112,0,0,0,0,0,0,0,115,118,99,95,117,112,100,97,116,101,110,97,109,101,0,0,68,73,86,0,0,0,0,0,37,53,100,32,115,117,98,109,105,115,115,105,111,110,95,99,104,117,110,107,10,0,0,0,98,103,109,118,111,108,117,109,101,0,0,0,0,0,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,0,0,0,116,114,105,101,100,32,116,111,32,115,112,114,105,110,116,32,116,111,32,97,32,110,111,110,45,99,108,105,101,110,116,10,0,0,0,0,0,0,0,0,102,97,99,101,95,112,52,0,77,111,117,115,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,111,108,118,101,32,110,101,120,116,32,116,97,114,103,101,116,115,46,10,0,0,0,0,0,0,0,0,115,99,114,97,116,99,104,49,0,0,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,0,0,0,0,0,0,67,65,76,76,53,0,0,0,108,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,110,121,32,99,104,101,97,116,115,32,105,110,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,85,78,83,69,84,32,65,68,68,82,69,83,83,0,0,0,93,93,62,0,0,0,0,0,37,115,58,32,111,118,101,114,102,108,111,119,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,67,117,114,114,101,110,116,32,118,97,108,117,101,58,32,37,115,10,0,0,37,42,112,32,58,32,37,115,10,0,0,0,0,0,0,0,46,46,0,0,0,0,0,0,45,83,0,0,0,0,0,0,84,104,101,32,73,110,115,116,97,108,108,97,116,105,111,110,0,0,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,65,85,88,54,0,0,0,0,114,0,0,0,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,100,105,114,0,0,0,0,0,0,0,0,45,115,116,100,118,105,100,0,115,118,99,95,108,105,103,104,116,115,116,121,108,101,0,0,37,53,100,32,115,97,109,112,108,101,98,105,116,115,10,0,45,109,108,111,111,107,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,102,97,99,101,52,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,66,79,32,116,101,120,116,117,114,101,115,32,101,120,99,101,101,100,101,100,32,109,97,120,105,109,117,109,32,115,105,122,101,32,111,102,32,71,80,85,32,40,37,117,120,37,117,41,46,32,82,101,115,105,122,105,110,103,32,116,111,32,102,105,116,46,10,0,0,0,0,0,0,0,0,77,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,115,99,114,97,116,99,104,50,0,0,0,0,0,0,0,0,99,97,112,116,117,114,101,0,67,65,76,76,52,0,0,0,108,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,45,115,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,101,50,109,49,0,0,0,0,100,105,116,104,101,114,95,102,105,108,116,101,114,0,0,0,114,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,65,85,88,53,0,0,0,0,76,111,97,100,105,110,103,32,103,97,109,101,32,102,114,111,109,32,37,115,46,46,46,10,0,0,0,0,0,0,0,0,118,105,100,101,111,95,103,112,117,95,115,99,114,101,101,110,115,104,111,116,0,0,0,0,99,104,97,115,101,95,114,105,103,104,116,0,0,0,0,0,32,0,0,0,0,0,0,0,115,118,99,95,115,101,114,118,101,114,105,110,102,111,0,0,37,53,100,32,115,97,109,112,108,101,112,111,115,10,0,0,43,109,108,111,111,107,0,0,102,97,99,101,95,112,51,0,82,101,116,114,111,65,114,99,104,58,32,70,66,79,32,112,97,115,115,32,35,37,100,32,105,115,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,46,10,0,0,0,0,0,74,111,121,112,97,100,32,119,47,32,65,110,97,108,111,103,0,0,0,0,0,0,0,0,115,99,114,97,116,99,104,51,0,0,0,0,0,0,0,0,37,115,95,101,113,117,97,108,0,0,0,0,0,0,0,0,67,65,76,76,51,0,0,0,108,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,100,105,116,104,101,114,95,102,105,108,116,101,114,0,0,0,45,45,109,101,110,117,0,0,90,105,103,103,117,114,97,116,32,86,101,114,116,105,103,111,0,0,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,103,102,120,47,98,111,120,95,109,109,46,108,109,112,0,0,65,85,88,52,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,85,78,83,85,80,80,79,82,84,69,68,32,40,35,37,117,41,46,10,0,0,108,111,97,100,32,60,115,97,118,101,110,97,109,101,62,32,58,32,108,111,97,100,32,97,32,103,97,109,101,10,0,0,118,105,100,101,111,95,103,112,117,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,89,32,98,117,116,116,111,110,32,40,108,101,102,116,41,0,109,111,100,101,108,32,37,115,32,104,97,115,32,110,111,32,116,114,105,97,110,103,108,101,115,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,115,118,99,95,115,101,116,97,110,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,109,111,118,105,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,0,37,53,100,32,115,97,109,112,108,101,115,10,0,0,0,0,45,107,108,111,111,107,0,0,102,97,99,101,51,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,32,101,120,116,101,110,115,105,111,110,32,110,111,116,32,102,111,117,110,100,46,10,0,0,0,0,0,74,111,121,112,97,100,0,0,115,99,114,97,116,99,104,52,0,0,0,0,0,0,0,0,37,115,95,109,97,115,107,0,67,65,76,76,50,0,0,0,116,117,114,98,111,0,0,0,82,101,116,114,111,65,114,99,104,58,32,78,111,32,82,79,77,44,32,115,116,97,114,116,105,110,103,32,100,117,109,109,121,32,99,111,114,101,46,10,0,0,0,0,0,0,0,0,101,49,109,56,0,0,0,0,114,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,65,85,88,51,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,46,10,0,0,0,0,0,100,111,110,101,46,10,0,0,101,120,101,99,32,113,117,97,107,101,46,114,99,10,0,0,118,105,100,101,111,95,112,111,115,116,95,102,105,108,116,101,114,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,66,65,67,75,83,80,65,67,69,0,0,0,0,0,0,0,37,115,32,40,37,105,32,102,105,108,101,115,41,10,0,0,37,115,58,32,116,119,111,32,99,111,110,115,101,99,117,116,105,118,101,32,102,114,101,101,32,98,108,111,99,107,115,0,115,118,99,95,115,116,117,102,102,116,101,120,116,0,0,0,115,116,101,114,101,111,0,0,43,107,108,111,111,107,0,0,82,101,116,114,111,65,114,99,104,58,32,83,104,97,100,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,102,97,99,101,95,112,50,0,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,0,0,0,0,0,0,0,0,78,111,110,101,0,0,0,0,115,97,118,101,100,103,97,109,101,99,102,103,0,0,0,0,37,115,95,105,110,112,117,116,95,115,108,111,116,0,0,0,67,65,76,76,49,0,0,0,114,51,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,82,79,77,58,32,37,115,46,10,0,0,0,0,0,0,84,104,101,32,72,111,117,115,101,32,111,102,32,67,104,116,104,111,110,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,65,85,88,50,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,95,69,83,67,65,80,69,46,10,0,0,0,0,0,0,109,10,0,0,0,0,0,0,61,61,61,61,61,61,61,61,81,117,97,107,101,32,73,110,105,116,105,97,108,105,122,101,100,61,61,61,61,61,61,61,61,61,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,37,115,10,0,116,99,112,47,105,112,58,32,32,37,115,10,0,0,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,99,111,108,111,114,0,0,0,0,0,46,98,114,97,109,0,0,0,67,117,114,114,101,110,116,32,115,101,97,114,99,104,32,112,97,116,104,58,10,0,0,0,37,115,58,32,110,101,120,116,32,98,108,111,99,107,32,100,111,101,115,110,39,116,32,104,97,118,101,32,112,114,111,112,101,114,32,98,97,99,107,32,108,105,110,107,0,0,0,0,115,118,99,95,112,114,105,110,116,0,0,0,0,0,0,0,100,105,116,104,101,114,95,102,105,108,116,101,114,0,0,0,109,111,110,111,0,0,0,0,105,109,112,117,108,115,101,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,118,101,114,115,105,111,110,32,37,117,46,10,0,0,0,0,0,0,0,0,102,97,99,101,50,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,117,112,32,102,114,97,109,101,32,98,117,102,102,101,114,32,111,98,106,101,99,116,115,46,32,77,117,108,116,105,45,112,97,115,115,32,115,104,97,100,105,110,103,32,119,105,108,108,32,110,111,116,32,119,111,114,107,46,10,0,0,68,105,115,97,98,108,101,100,0,0,0,0,0,0,0,0,115,97,118,101,100,49,0,0,37,115,95,119,114,97,109,0,67,65,76,76,48,0,0,0,108,51,0,0,0,0,0,0,114,101,116,114,111,97,114,99,104,0,0,0,0,0,0,0,101,49,109,55,0,0,0,0,114,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,65,85,88,49,0,0,0,0,48,46,48,53,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,83,69,84,95,76,73,66,82,69,84,82,79,95,80,65,84,72,46,10,0,0,0,0,0,0,0,0,37,100,10,0,0,0,0,0,45,72,79,83,84,95,72,85,78,75,76,69,86,69,76,45,0,0,0,0,0,0,0,0,98,97,99,107,116,105,108,101,0,0,0,0,0,0,0,0,45,110,111,99,100,97,117,100,105,111,0,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,104,101,105,103,104,116,0,0,46,97,114,97,109,0,0,0,37,115,58,32,110,111,116,32,101,110,111,117,103,104,32,115,112,97,99,101,32,102,111,114,32,37,115,0,0,0,0,0,37,115,58,32,98,108,111,99,107,32,115,105,122,101,32,100,111,101,115,32,110,111,116,32,116,111,117,99,104,32,116,104,101,32,110,101,120,116,32,98,108,111,99,107,0,0,0,0,115,118,99,95,116,105,109,101,0,0,0,0,0,0,0,0,37,53,100,32,99,104,97,110,110,101,108,115,32,40,37,115,41,10,0,0,0,0,0,0,45,106,117,109,112,0,0,0,35,118,101,114,115,105,111,110,32,37,117,10,0,0,0,0,102,97,99,101,95,112,49,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,0,0,0,78,47,65,32,40,112,111,114,116,32,35,37,117,41,0,0,115,97,118,101,100,50,0,0,37,115,95,115,101,109,97,110,116,105,99,0,0,0,0,0,73,70,78,79,84,0,0,0,114,50,0,0,0,0,0,0,37,115,58,32,98,97,100,32,99,97,99,104,101,32,115,105,122,101,32,37,100,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,84,104,101,32,68,111,111,114,32,84,111,32,67,104,116,104,111,110,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,74,79,89,52,0,0,0,0,100,95,109,105,112,99,97,112,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,70,82,65,77,69,95,84,73,77,69,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,37,102,10,0,0,0,0,0,67,111,117,108,100,110,39,116,32,108,111,97,100,32,103,102,120,47,99,111,108,111,114,109,97,112,46,108,109,112,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,119,105,100,116,104,0,0,0,99,111,111,112,0,0,0,0,115,101,116,116,105,110,103,115,46,99,0,0,0,0,0,0,46,112,114,97,109,0,0,0,37,115,58,32,98,97,100,32,117,115,101,104,117,110,107,0,115,118,99,95,115,111,117,110,100,0,0,0,0,0,0,0,85,115,97,103,101,58,32,115,118,95,112,114,111,116,111,99,111,108,32,91,60,118,101,114,115,105,111,110,62,32,124,32,60,110,97,109,101,62,32,124,32,39,108,105,115,116,39,93,10,0,0,0,0,0,0,0,115,111,117,110,100,32,115,121,115,116,101,109,32,110,111,116,32,115,116,97,114,116,101,100,10,0,0,0,0,0,0,0,43,106,117,109,112,0,0,0,35,118,101,114,115,105,111,110,0,0,0,0,0,0,0,0,102,97,99,101,49,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,35,37,100,0,0,0,0,0,49,0,0,0,0,0,0,0,115,97,118,101,100,51,0,0,103,108,115,108,0,0,0,0,115,97,121,95,116,101,97,109,58,0,0,0,0,0,0,0,73,70,0,0,0,0,0,0,108,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,109,111,118,105,110,103,32,116,101,109,112,111,97,114,121,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,101,49,109,54,0,0,0,0,67,118,97,114,95,83,101,116,58,32,118,97,114,105,97,98,108,101,32,37,115,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,0,0,0,114,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,74,79,89,51,0,0,0,0,110,111,0,0,0,0,0,0,37,115,10,0,0,0,0,0,100,114,105,118,101,114,46,99,0,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,103,102,120,47,99,111,108,111,114,109,97,112,46,108,109,112,0,0,0,0,0,0,0,0,114,119,101,98,97,117,100,105,111,0,0,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,121,0,0,0,0,0,0,0,46,114,116,99,0,0,0,0,37,115,37,99,80,65,75,37,105,46,80,65,75,0,0,0,46,46,0,0,0,0,0,0,37,115,58,32,78,85,76,76,32,108,105,110,107,0,0,0,115,118,99,95,115,101,116,118,105,101,119,0,0,0,0,0,99,104,97,110,103,101,32,119,105,108,108,32,110,111,116,32,116,97,107,101,32,101,102,102,101,99,116,32,117,110,116,105,108,32,116,104,101,32,110,101,120,116,32,108,101,118,101,108,32,108,111,97,100,46,10,0,110,111,115,111,117,110,100,0,45,117,115,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,115,98,95,115,105,103,105,108,52,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,98,105,110,100,32,65,80,73,32,37,115,32,116,111,32,99,111,110,116,101,120,116,32,37,115,46,10,0,0,0,0,0,0,37,46,50,102,0,0,0,0,115,97,118,101,100,52,0,0,103,108,115,108,112,0,0,0,78,79,84,95,70,78,67,0,114,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,65,77,32,119,105,108,108,32,110,111,116,32,98,101,32,115,97,118,101,100,46,10,0,0,0,0,0,71,108,111,111,109,32,75,101,101,112,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,0,74,79,89,50,0,0,0,0,121,101,115,0,0,0,0,0,114,0,0,0,0,0,0,0,37,105,10,0,0,0,0,0,67,111,117,108,100,110,39,116,32,108,111,97,100,32,103,102,120,47,112,97,108,101,116,116,101,46,108,109,112,0,0,0,63,109,111,100,101,108,63,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,120,0,0,0,0,0,0,0,83,79,76,73,68,95,66,83,80,32,119,105,116,104,111,117,116,32,77,79,86,69,84,89,80,69,95,80,85,83,72,0,37,115,58,32,114,101,97,108,108,111,99,101,100,32,97,32,112,111,105,110,116,101,114,32,119,105,116,104,111,117,116,32,90,79,78,69,73,68,0,0,46,115,114,109,0,0,0,0,10,0,0,0,0,0,0,0,99,108,95,114,111,108,108,115,112,101,101,100,0,0,0,0,119,101,97,112,111,110,115,47,114,105,99,50,46,119,97,118,0,0,0,0,0,0,0,0,37,115,58,32,97,99,116,105,118,101,32,108,105,110,107,0,115,118,99,95,118,101,114,115,105,111,110,0,0,0,0,0,115,118,95,112,114,111,116,111,99,111,108,58,32,117,110,107,110,111,119,110,32,112,114,111,116,111,99,111,108,32,118,101,114,115,105,111,110,10,0,0,112,114,101,99,97,99,104,101,0,0,0,0,0,0,0,0,43,117,115,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,105,110,107,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,0,0,0,0,0,115,98,95,115,105,103,105,108,51,0,0,0,0,0,0,0,79,112,101,110,71,76,32,69,83,0,0,0,0,0,0,0,118,48,46,54,50,0,0,0,78,111,32,68,105,115,107,0,37,115,58,32,98,97,100,32,112,111,105,110,116,101,114,0,99,103,112,0,0,0,0,0,78,79,84,95,69,78,84,0,108,0,0,0,0,0,0,0,115,118,95,109,97,120,115,112,101,101,100,0,0,0,0,0,115,118,95,103,114,97,118,105,116,121,0,0,0,0,0,0,37,115,58,32,99,104,97,110,110,101,108,32,61,32,37,105,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,107,105,112,112,105,110,103,32,83,82,65,77,32,108,111,97,100,46,10,0,87,65,86,69,0,0,0,0,101,49,109,53,0,0,0,0,37,115,58,32,83,78,68,68,77,65,95,73,110,105,116,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,0,0,108,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,99,108,95,98,97,99,107,115,112,101,101,100,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,97,110,121,32,82,79,77,83,32,116,104,97,116,32,109,97,116,99,104,101,100,32,118,97,108,105,100,32,101,120,116,101,110,115,105,111,110,115,32,102,111,114,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,73,68,65,84,0,0,0,0,108,111,97,100,32,102,97,105,108,101,100,46,10,0,0,0,103,108,77,97,112,66,117,102,102,101,114,79,69,83,0,0,74,79,89,49,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,99,111,110,116,101,120,116,32,105,115,32,117,115,101,100,44,32,98,117,116,32,115,104,97,100,101,114,32,105,115,32,110,111,116,32,109,111,100,101,114,110,46,32,67,97,110,110,111,116,32,117,115,101,32,105,116,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,68,105,109,101,110,115,105,111,110,115,58,32,37,117,120,37,117,10,0,37,115,58,32,67,76,95,71,101,116,77,101,115,115,97,103,101,32,102,97,105,108,101,100,0,0,0,0,0,0,0,0,110,117,109,95,99,111,108,111,110,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,83,85,80,80,79,82,84,95,78,79,95,71,65,77,69,58,32,37,115,46,10,0,0,0,0,69,82,82,79,82,58,32,99,111,117,108,100,110,39,116,32,111,112,101,110,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,109,117,108,116,105,112,97,115,115,32,115,104,97,100,101,114,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,103,102,120,47,112,97,108,101,116,116,101,46,108,109,112,0,82,101,97,100,105,110,103,32,37,115,46,46,46,10,0,0,49,53,0,0,0,0,0,0,68,73,83,75,32,65,80,80,69,78,68,32,37,115,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,121,0,0,0,0,0,114,103,117,105,46,103,108,115,108,112,0,0,0,0,0,0,37,115,58,32,33,101,45,62,99,111,108,111,114,109,97,112,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,71,65,32,105,109,97,103,101,32,105,115,32,110,111,116,32,117,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,46,10,0,0,0,0,0,0,0,0,37,105,40,37,115,41,37,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,46,46,46,32,67,97,110,110,111,116,32,114,101,99,111,118,101,114,32,115,97,118,101,32,102,105,108,101,46,10,0,0,0,0,0,0,0,112,97,107,102,105,108,101,32,105,115,58,10,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,88,77,76,32,115,104,97,100,101,114,58,32,37,115,10,0,0,0,0,0,0,37,115,58,32,37,105,32,105,115,32,103,114,101,97,116,101,114,32,116,104,97,110,32,102,114,101,101,32,104,117,110,107,0,0,0,0,0,0,0,0,99,108,95,115,104,111,119,110,101,116,0,0,0,0,0,0,115,118,99,95,117,112,100,97,116,101,115,116,97,116,0,0,37,55,100,32,32,37,45,52,115,32,32,37,115,10,0,0,77,85,76,95,86,70,0,0,52,48,57,54,0,0,0,0,45,97,116,116,97,99,107,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,105,110,103,32,71,76,83,76,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,0,0,37,115,58,32,85,110,107,110,111,119,110,32,112,114,111,116,111,99,111,108,32,118,101,114,115,105,111,110,32,40,37,100,41,10,0,0,0,0,0,0,115,98,95,115,105,103,105,108,50,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,46,10,51,50,45,98,105,116,32,112,97,116,104,32,119,105,108,108,32,114,101,113,117,105,114,101,32,99,111,110,118,101,114,115,105,111,110,46,10,0,0,0,109,99,97,99,104,101,0,0,60,82,79,77,32,100,105,114,62,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,0,0,37,115,58,32,98,97,100,32,110,117,109,98,101,114,32,37,105,0,0,0,0,0,0,0,99,103,0,0,0,0,0,0,78,79,84,95,83,0,0,0,120,0,0,0,0,0,0,0,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,32,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,32,45,45,45,45,45,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,103,114,97,98,32,99,104,101,97,116,115,46,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,0,0,60,33,91,67,68,65,84,65,91,0,0,0,0,0,0,0])
.concat([76,79,67,65,76,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,75,101,121,58,32,37,115,10,0,0,0,0,67,97,99,104,101,100,32,109,111,100,101,108,115,58,10,0,114,101,99,111,114,100,32,60,100,101,109,111,110,97,109,101,62,32,91,60,109,97,112,62,32,91,99,100,32,116,114,97,99,107,93,93,10,0,0,0,109,105,115,99,47,116,97,108,107,46,119,97,118,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,10,0,0,0,0,0,0,84,104,101,32,71,114,105,115,108,121,32,71,114,111,116,116,111,0,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,0,77,79,85,83,69,56,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,117,110,107,110,111,119,110,32,99,111,110,116,101,120,116,46,10,0,119,0,0,0,0,0,0,0,37,52,46,49,102,32,109,101,103,97,98,121,116,101,32,104,101,97,112,10,0,0,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,120,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,99,99,101,101,100,101,100,32,105,110,32,115,97,118,105,110,103,32,82,65,77,32,100,97,116,97,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,37,115,37,99,112,97,107,37,105,46,112,97,107,0,0,0,37,56,105,32,116,111,116,97,108,32,98,108,111,99,107,115,10,0,0,0,0,0,0,0,99,101,110,116,101,114,118,105,101,119,0,0,0,0,0,0,115,118,99,95,100,105,115,99,111,110,110,101,99,116,0,0,86,101,114,115,105,111,110,32,32,78,97,109,101,32,32,68,101,115,99,114,105,112,116,105,111,110,10,45,45,45,45,45,45,45,32,32,45,45,45,45,32,32,45,45,45,45,45,45,45,45,45,45,45,10,0,0,98,103,109,98,117,102,102,101,114,0,0,0,0,0,0,0,43,97,116,116,97,99,107,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,115,98,95,115,105,103,105,108,49,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,32,102,111,117,110,100,32,102,111,114,32,71,76,69,83,46,10,0,0,0,0,116,105,109,101,100,101,109,111,0,0,0,0,0,0,0,0,60,100,101,102,97,117,108,116,62,0,0,0,0,0,0,0,112,114,111,102,105,108,101,0,105,109,112,111,114,116,115,0,78,79,84,95,86,0,0,0,97,0,0,0,0,0,0,0,83,101,114,118,101,114,32,32,32,32,32,32,32,32,32,32,77,97,112,32,32,32,32,32,32,32,32,32,32,32,32,32,85,115,101,114,115,10,0,0,61,61,61,32,66,117,105,108,100,32,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,101,49,109,52,0,0,0,0,108,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,77,79,85,83,69,55,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,32,99,111,110,116,101,120,116,44,32,98,117,116,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,79,112,101,110,71,76,69,83,50,46,32,67,97,110,110,111,116,32,117,115,101,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,0,83,97,118,105,110,103,32,103,97,109,101,32,116,111,32,37,115,46,46,46,10,0,0,0,69,120,101,58,32,49,54,58,52,50,58,53,49,32,83,101,112,32,49,53,32,50,48,49,51,10,0,0,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,99,97,108,101,0,0,0,0,0,0,0,0,102,105,110,100,95,97,117,100,105,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,37,89,45,37,109,45,37,100,45,37,72,45,37,77,45,37,83,0,0,0,0,0,0,0,65,100,100,101,100,32,112,97,99,107,102,105,108,101,32,37,115,32,40,37,105,32,102,105,108,101,115,41,10,0,0,0,37,42,115,32,58,37,49,48,105,32,37,45,42,115,32,40,84,79,84,65,76,41,10,0,98,102,0,0,0,0,0,0,115,118,99,95,110,111,112,0,108,105,115,116,0,0,0,0,49,54,0,0,0,0,0,0,48,46,51,0,0,0,0,0,45,115,112,101,101,100,0,0,35,100,101,102,105,110,101,32,70,82,65,71,77,69,78,84,10,0,0,0,0,0,0,0,115,98,95,113,117,97,100,0,66,71,82,65,56,56,56,56,0,0,0,0,0,0,0,0,112,108,97,121,100,101,109,111,0,0,0,0,0,0,0,0,37,46,51,102,0,0,0,0,101,100,105,99,116,99,111,117,110,116,0,0,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,95,99,108,97,115,115,0,0,0,0,0,78,79,84,95,70,0,0,0,114,105,103,104,116,0,0,0,37,45,49,53,46,49,53,115,32,37,45,49,53,46,49,53,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,116,97,108,32,101,114,114,111,114,32,114,101,99,101,105,118,101,100,32,105,110,58,32,34,37,115,34,10,0,0,0,0,0,84,104,101,32,78,101,99,114,111,112,111,108,105,115,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,0,103,102,120,47,98,111,120,95,116,109,46,108,109,112,0,0,77,79,85,83,69,54,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,69,83,50,32,99,111,110,116,101,120,116,46,10,0,0,0,0,0,0,0,46,115,97,118,0,0,0,0,103,102,120,46,119,97,100,0,37,55,57,115,10,0,0,0,37,105,10,0,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,101,110,97,98,108,101,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,97,117,100,105,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,114,0,0,0,0,0,0,0,37,115,47,82,101,116,114,111,65,114,99,104,45,114,101,99,111,118,101,114,121,45,0,0,37,115,37,99,115,37,105,46,115,97,118,0,0,0,0,0,112,97,99,107,102,105,108,101,0,0,0,0,0,0,0,0,37,42,112,32,58,37,49,48,105,32,37,45,42,115,10,0,118,95,99,115,104,105,102,116,0,0,0,0,0,0,0,0,45,45,45,32,85,78,85,83,69,68,32,83,76,79,84,32,45,45,45,0,0,0,0,0,115,118,99,95,98,97,100,0,115,118,95,112,114,111,116,111,99,111,108,32,105,115,32,37,100,32,40,37,115,41,10,32,32,32,32,117,115,101,32,39,115,118,95,112,114,111,116,111,99,111,108,32,108,105,115,116,39,32,116,111,32,108,105,115,116,32,97,118,97,105,108,97,98,108,101,32,112,114,111,116,111,99,111,108,115,10,0,0,109,111,100,101,108,32,37,115,32,104,97,115,32,116,111,111,32,109,97,110,121,32,118,101,114,116,105,99,101,115,0,0,97,109,98,105,101,110,116,95,108,101,118,101,108,0,0,0,43,115,112,101,101,100,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,112,108,97,121,98,97,99,107,46,10,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,46,10,0,115,98,95,115,117,105,116,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,104,97,100,101,114,44,32,102,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,115,116,111,112,0,0,0,0,78,47,65,0,0,0,0,0,101,100,105,99,116,115,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,0,0,0,82,69,84,85,82,78,0,0,108,101,102,116,0,0,0,0,37,45,49,53,46,49,53,115,32,37,45,49,53,46,49,53,115,32,37,50,117,47,37,50,117,10,0,0,0,0,0,0,103,102,120,47,109,97,105,110,109,101,110,117,46,108,109,112,0,0,0,0,0,0,0,0,103,102,120,47,116,116,108,95,109,97,105,110,46,108,109,112,0,0,0,0,0,0,0,0,90,73,80,124,122,105,112,0,101,49,109,51,0,0,0,0,103,102,120,47,115,112,95,109,101,110,117,46,108,109,112,0,108,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,103,102,120,47,116,116,108,95,115,103,108,46,108,109,112,0,77,79,85,83,69,53,0,0,103,102,120,47,112,95,108,111,97,100,46,108,109,112,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,110,111,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,37,115,37,99,37,115,0,0,79,110,108,121,32,37,52,46,49,102,32,109,101,103,115,32,111,102,32,109,101,109,111,114,121,32,114,101,112,111,114,116,101,100,44,32,99,97,110,39,116,32,101,120,101,99,117,116,101,32,103,97,109,101,0,0,103,102,120,47,112,95,115,97,118,101,46,108,109,112,0,0,78,111,32,67,111,109,109,117,110,105,99,97,116,105,111,110,115,32,65,118,97,105,108,97,98,108,101,0,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,105,122,101,0,103,102,120,47,109,101,110,117,100,111,116,37,105,46,108,109,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,97,117,100,105,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,83,80,65,67,69,0,0,0,72,79,77,69,0,0,0,0,103,102,120,47,109,112,95,109,101,110,117,46,108,109,112,0,37,115,32,104,97,115,32,37,105,32,102,105,108,101,115,0,37,42,115,32,58,37,49,48,105,32,82,69,77,65,73,78,73,78,71,10,0,0,0,0,103,97,109,109,97,0,0,0,37,115,58,32,85,110,107,110,111,119,110,32,112,114,111,116,111,99,111,108,32,118,101,114,115,105,111,110,32,40,37,100,41,10,0,0,0,0,0,0,117,110,107,110,111,119,110,0,103,102,120,47,109,101,110,117,112,108,121,114,46,108,109,112,0,0,0,0,0,0,0,0,49,48,48,0,0,0,0,0,45,109,111,118,101,114,105,103,104,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,0,0,115,98,95,105,110,118,117,108,110,0,0,0,0,0,0,0,114,101,99,111,114,100,0,0,37,46,51,102,32,72,122,32,40,37,46,49,102,37,37,32,100,101,118,44,32,37,117,32,115,97,109,112,108,101,115,41,0,0,0,0,0,0,0,0,101,100,105,99,116,0,0,0,37,115,95,119,114,97,112,95,109,111,100,101,0,0,0,0,83,84,79,82,69,80,95,70,78,67,0,0,0,0,0,0,100,111,119,110,0,0,0,0,78,111,32,81,117,97,107,101,32,115,101,114,118,101,114,115,32,102,111,117,110,100,46,10,10,0,0,0,0,0,0,0,103,102,120,47,98,105,103,98,111,120,46,108,109,112,0,0,65,99,99,101,112,116,32,67,104,97,110,103,101,115,0,0,82,101,116,114,111,65,114,99,104,32,58,32,37,115,32,37,115,0,0,0,0,0,0,0,67,97,115,116,108,101,32,111,102,32,116,104,101,32,68,97,109,110,101,100,0,0,0,0,80,97,110,116,115,32,99,111,108,111,114,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,0,83,104,105,114,116,32,99,111,108,111,114,0,0,0,0,0,77,79,85,83,69,52,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,72,87,95,82,69,78,68,69,82,46,10,0,0,0,0,0,0,67,97,110,39,116,32,115,97,118,101,103,97,109,101,32,119,105,116,104,32,97,32,100,101,97,100,32,112,108,97,121,101,114,10,0,0,0,0,0,0,45,109,105,110,109,101,109,111,114,121,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,86,65,82,73,65,66,76,69,32,37,115,58,10,0,0,0,0,48,46,54,50,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,112,97,116,104,0,102,105,110,100,95,118,105,100,101,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,79,77,32,105,115,32,117,115,101,100,44,32,98,117,116,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,116,104,105,115,46,10,0,0,32,32,32,32,32,32,70,105,114,115,116,32,80,101,114,115,111,110,0,0,0,0,0,0,37,115,32,105,115,32,110,111,116,32,97,32,112,97,99,107,102,105,108,101,0,0,0,0,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,10,0,0,0,0,0,0,53,48,48,0,0,0,0,0,37,115,58,32,73,108,108,101,103,105,98,108,101,32,115,101,114,118,101,114,32,109,101,115,115,97,103,101,0,0,0,0,66,74,80,32,112,114,111,116,111,99,111,108,32,40,118,51,41,0,0,0,0,0,0,0,97,109,98,105,101,110,116,95,102,97,100,101,0,0,0,0,43,109,111,118,101,114,105,103,104,116,0,0,0,0,0,0,35,100,101,102,105,110,101,32,86,69,82,84,69,88,10,0,115,98,95,105,110,118,105,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,118,97,108,105,100,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,32,67,111,110,116,105,110,117,105,110,103,32,119,105,116,104,111,117,116,32,115,104,97,100,101,114,115,46,10,0,0,0,0,0,0,0,100,105,115,99,111,110,110,101,99,116,0,0,0,0,0,0,114,95,116,105,109,101,103,114,97,112,104,0,0,0,0,0,37,46,49,102,120,0,0,0,37,115,58,32,112,114,95,102,105,101,108,100,100,101,102,115,91,105,93,46,116,121,112,101,32,38,32,68,69,70,95,83,65,86,69,71,76,79,66,65,76,0,0,0,0,0,0,0,37,115,95,108,105,110,101,97,114,0,0,0,0,0,0,0,83,84,79,82,69,80,95,70,76,68,0,0,0,0,0,0,117,112,0,0,0,0,0,0,61,61,32,101,110,100,32,108,105,115,116,32,61,61,10,10,0,0,0,0,0,0,0,0,99,108,95,119,97,114,110,99,109,100,0,0,0,0,0,0,32,32,32,32,32,32,67,97,109,101,114,97,32,84,121,112,101,0,0,0,0,0,0,0,83,101,116,116,105,110,103,32,114,101,102,114,101,115,104,32,114,97,116,101,32,116,111,58,32,37,46,51,102,32,72,122,46,0,0,0,0,0,0,0,118,48,0,0,0,0,0,0,101,49,109,50,0,0,0,0,108,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,77,79,85,83,69,51,0,0,115,121,115,95,116,105,99,114,97,116,101,0,0,0,0,0,32,32,32,32,32,32,70,114,97,109,101,114,97,116,101,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,68,73,83,75,95,67,79,78,84,82,79,76,95,73,78,84,69,82,70,65,67,69,46,10,0,82,101,108,97,116,105,118,101,32,112,97,116,104,110,97,109,101,115,32,97,114,101,32,110,111,116,32,97,108,108,111,119,101,100,46,10,0,0,0,0,115,101,114,118,101,114,112,114,111,102,105,108,101,58,32,37,50,105,32,99,108,105,101,110,116,115,32,37,50,105,32,109,115,101,99,10,0,0,0,0,32,32,32,32,32,32,67,114,111,115,115,104,97,105,114,0,100,105,115,99,0,0,0,0,32,32,32,32,32,32,83,109,111,111,116,104,32,65,110,105,109,97,116,105,111,110,0,0,118,105,100,101,111,95,97,108,108,111,119,95,114,111,116,97,116,101,0,0,0,0,0,0,32,32,32,32,32,32,76,101,118,101,108,32,111,102,32,68,101,116,97,105,108,0,0,0,67,68,65,117,100,105,111,58,32,116,114,97,99,107,32,37,105,32,105,115,32,110,111,116,32,97,117,100,105,111,10,0,65,118,97,105,108,97,98,108,101,32,118,105,100,101,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,32,105,110,32,34,37,115,34,10,0,0,0,0,0,0,0,0,32,32,32,32,32,32,68,105,116,104,101,114,32,70,105,108,116,101,114,105,110,103,0,0,67,111,117,108,100,110,39,116,32,108,111,97,100,32,112,97,99,107,102,105,108,101,58,32,37,115,0,0,0,0,0,0,118,95,99,101,110,116,101,114,115,112,101,101,100,0,0,0,98,106,112,51,0,0,0,0,98,102,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,86,105,100,101,111,32,79,112,116,105,111,110,115,0,0,115,110,100,95,110,111,101,120,116,114,97,117,112,100,97,116,101,0,0,0,0,0,0,0,45,109,111,118,101,108,101,102,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,118,101,114,116,101,120,32,115,104,97,100,101,114,46,10,0,0,0,115,98,95,107,101,121,50,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,10,0,0,0,0,101,110,116,105,116,105,101,115,0,0,0,0,0,0,0,0,114,95,112,111,108,121,109,111,100,101,108,115,116,97,116,115,0,0,0,0,0,0,0,0,37,117,0,0,0,0,0,0,112,114,111,103,115,46,100,97,116,32,115,116,114,105,110,103,115,32,101,120,116,101,110,100,32,112,97,115,116,32,101,110,100,32,111,102,32,102,105,108,101,10,0,0,0,0,0,0,116,101,120,116,117,114,101,115,0,0,0,0,0,0,0,0,83,84,79,82,69,80,95,69,78,84,0,0,0,0,0,0,115,116,97,114,116,0,0,0,34,108,105,115,116,101,110,34,32,105,115,32,34,37,117,34,10,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,76,111,111,107,115,116,114,97,102,101,0,0,37,115,58,32,98,97,100,32,99,97,99,104,101,32,119,105,100,116,104,32,37,100,0,0,32,32,32,32,32,32,32,32,32,32,32,32,76,111,111,107,115,112,114,105,110,103,0,0,85,110,107,110,111,119,110,0,83,108,105,112,103,97,116,101,32,67,111,109,112,108,101,120,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,73,110,118,101,114,116,32,77,111,117,115,101,0,0,84,117,114,98,111,32,101,110,97,98,108,101,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,65,108,119,97,121,115,32,82,117,110,0,0,77,79,85,83,69,50,0,0,32,32,32,32,32,32,32,32,32,32,83,111,117,110,100,32,86,111,108,117,109,101,0,0,49,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,75,69,89,66,79,65,82,68,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,0,0,46,46,0,0,0,0,0,0,37,115,0,0,0,0,0,0,32,32,32,32,32,32,32,67,68,32,77,117,115,105,99,32,86,111,108,117,109,101,0,0,32,32,32,32,32,32,32,32,32,32,32,77,111,117,115,101,32,83,112,101,101,100,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,101,110,97,98,108,101,0,0,0,0,0,34,37,115,34,32,99,104,97,110,103,101,100,32,116,111,32,34,37,115,34,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,66,114,105,103,104,116,110,101,115,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,118,105,100,101,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,32,32,32,32,32,32,32,32,32,32,32,83,99,114,101,101,110,32,115,105,122,101,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,116,99,104,32,37,115,58,32,69,114,114,111,114,32,35,37,117,10,0,0,0,0,0,112,97,107,0,0,0,0,0,37,42,115,32,58,37,49,48,105,32,116,111,116,97,108,32,104,117,110,107,32,115,105,122,101,10,0,0,0,0,0,0,48,46,49,53,0,0,0,0,66,74,80,32,112,114,111,116,111,99,111,108,32,40,118,50,41,0,0,0,0,0,0,0,104,101,108,112,0,0,0,0,32,32,32,32,32,82,101,115,101,116,32,116,111,32,100,101,102,97,117,108,116,115,0,0,115,110,100,95,115,104,111,119,0,0,0,0,0,0,0,0,43,109,111,118,101,108,101,102,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,71,76,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,115,98,95,107,101,121,49,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,78,111,116,32,108,111,97,100,105,110,103,32,97,110,121,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,114,95,100,115,112,101,101,100,115,0,0,0,0,0,0,0,67,76,95,87,114,105,116,101,84,111,83,101,114,118,101,114,58,32,108,111,115,116,32,115,101,114,118,101,114,32,99,111,110,110,101,99,116,105,111,110,0,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,116,114,117,101,0,0,0,0,112,114,111,103,115,46,100,97,116,32,115,121,115,116,101,109,32,118,97,114,115,32,104,97,118,101,32,98,101,101,110,32,109,111,100,105,102,105,101,100,44,32,112,114,111,103,100,101,102,115,46,104,32,105,115,32,111,117,116,32,111,102,32,100,97,116,101,0,0,0,0,0,59,0,0,0,0,0,0,0,83,84,79,82,69,80,95,83,0,0,0,0,0,0,0,0,115,101,108,101,99,116,0,0,49,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,71,111,32,116,111,32,99,111,110,115,111,108,101,0,0,32,32,32,32,67,117,115,116,111,109,105,122,101,32,99,111,110,116,114,111,108,115,0,0,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,0,0,0,0,0,0,0,101,49,109,49,0,0,0,0,103,102,120,47,112,95,111,112,116,105,111,110,46,108,109,112,0,0,0,0,0,0,0,0,116,117,114,98,111,0,0,0,77,79,85,83,69,49,0,0,82,101,116,114,111,65,114,99,104,58,32,9,82,101,116,114,111,80,97,100,44,32,80,108,97,121,101,114,32,37,117,44,32,66,117,116,116,111,110,32,34,37,115,34,32,61,62,32,34,37,115,34,10,0,0,0,115,97,118,101,32,60,115,97,118,101,110,97,109,101,62,32,58,32,115,97,118,101,32,97,32,103,97,109,101,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,37,115,58,32,111,118,101,114,102,108,111,119,0,0,0,0,67,108,101,97,114,105,110,103,32,109,101,109,111,114,121,10,0,0,0,0,0,0,0,0,69,110,116,101,114,32,116,111,32,99,104,97,110,103,101,44,32,98,97,99,107,115,112,97,99,101,32,116,111,32,99,108,101,97,114,0,0,0,0,0,80,114,101,115,115,32,97,32,107,101,121,32,111,114,32,98,117,116,116,111,110,32,102,111,114,32,116,104,105,115,32,97,99,116,105,111,110,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,0,0,0,0,103,102,120,47,116,116,108,95,99,115,116,109,46,108,109,112,0,0,0,0,0,0,0,0,102,105,110,100,95,105,110,112,117,116,95,100,114,105,118,101,114,40,41,0,0,0,0,0,103,102,120,47,104,101,108,112,37,105,46,108,109,112,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,112,97,116,99,104,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,40,37,115,41,46,10,0,0,0,0,0,0,45,112,97,116,104,0,0,0,46,0,0,0,0,0,0,0,85,115,97,103,101,58,32,104,117,110,107,32,112,114,105,110,116,124,112,114,105,110,116,97,108,108,10,0,0,0,0,0,118,95,99,101,110,116,101,114,109,111,118,101,0,0,0,0,98,106,112,50,0,0,0,0,115,118,99,95,117,112,100,97,116,101,115,116,97,116,58,32,37,105,32,105,115,32,105,110,118,97,108,105,100,0,0,0,32,32,32,102,111,114,32,121,111,117,32,110,101,120,116,32,116,105,109,101,33,32,32,32,0,0,0,0,0,0,0,0,48,46,49,0,0,0,0,0,45,115,116,114,97,102,101,0,50,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,71,76,83,76,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,115,98,95,97,114,109,111,114,51,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,110,32,115,112,101,99,105,102,105,101,100,32,71,76,32,101,114,114,111,114,46,10,0,0,0,114,95,114,101,112,111,114,116,115,117,114,102,111,117,116,0,67,76,95,87,114,105,116,101,84,111,83,101,114,118,101,114,58,32,99,97,110,39,116,32,115,101,110,100,10,0,0,0,80,111,105,110,116,32,102,105,108,116,101,114,105,110,103,0,112,114,111,103,115,46,100,97,116,32,104,97,115,32,119,114,111,110,103,32,118,101,114,115,105,111,110,32,110,117,109,98,101,114,32,40,37,105,32,115,104,111,117,108,100,32,98,101,32,37,105,41,0,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,37,117,0,0,0,0,0,0,0,83,84,79,82,69,80,95,86,0,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,99,111,111,112,0,0,0,0,32,32,116,104,114,111,119,32,97,32,98,108,97,110,107,101,116,45,112,97,114,116,121,32,0,0,0,0,0,0,0,0,32,32,73,102,32,121,111,117,32,113,117,105,116,32,110,111,119,44,32,73,39,108,108,32,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,100,105,115,107,32,37,117,32,111,102,32,37,117,46,0,0,0,0,69,110,116,114,97,110,99,101,0,0,0,0,0,0,0,0,32,32,32,116,111,32,121,111,117,114,32,84,105,110,107,101,114,116,111,121,115,46,32,32,0,0,0,0,0,0,0,0,82,51,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,32,113,117,105,116,46,32,80,114,101,115,115,32,89,32,116,111,32,114,101,116,117,114,110,0,0,0,0,0,0,0,0,69,78,68,0,0,0,0,0,32,104,105,115,32,99,104,105,108,100,114,101,110,32,116,114,121,105,110,103,32,116,111,32,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,73,78,80,85,84,95,68,69,83,67,82,73,80,84,79,82,83,58,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,68,105,100,110,39,116,32,114,101,97,100,32,119,104,111,108,101,32,102,105,108,101,46,10,0,0,0,0,67,97,110,39,116,32,115,97,118,101,32,109,117,108,116,105,112,108,97,121,101,114,32,103,97,109,101,115,46,10,0,0,37,115,58,32,78,69,84,95,83,101,110,100,84,111,65,108,108,32,102,97,105,108,101,100,32,102,111,114,32,37,117,32,99,108,105,101,110,116,115,10,0,0,0,0,0,0,0,0,32,32,85,109,44,32,65,115,109,111,100,101,117,115,32,100,105,115,108,105,107,101,115,32,0,0,0,0,0,0,0,0,115,105,122,101,98,117,102,0,32,32,32,32,32,32,104,97,114,100,32,100,114,105,118,101,33,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,118,105,100,101,111,95,114,101,102,114,101,115,104,95,114,97,116,101,0,0,0,0,0,0,84,114,105,103,103,101,114,32,105,110,32,99,108,105,112,112,105,110,103,32,108,105,115,116,0,0,0,0,0,0,0,0,32,32,83,97,116,97,110,32,97,108,108,32,111,118,101,114,32,121,111,117,114,32,32,32,0,0,0,0,0,0,0,0,9,37,115,10,0,0,0,0,37,115,58,32,102,97,105,108,101,100,32,111,110,32,97,108,108,111,99,97,116,105,111,110,32,111,102,32,37,105,32,98,121,116,101,115,0,0,0,0,32,32,113,117,105,116,44,32,73,32,119,105,108,108,32,115,117,109,109,111,110,32,32,32,0,0,0,0,0,0,0,0,37,115,37,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,112,97,116,99,104,101,100,32,82,79,77,32,46,46,46,10,0,0,0,0,0,45,103,97,109,101,0,0,0,115,99,114,95,111,102,115,122,0,0,0,0,0,0,0,0,119,101,97,112,111,110,115,47,114,105,99,49,46,119,97,118,0,0,0,0,0,0,0,0,112,114,105,110,116,97,108,108,0,0,0,0,0,0,0,0,99,108,95,99,114,111,115,115,121,0,0,0,0,0,0,0,100,117,97,108,45,97,110,97,108,111,103,0,0,0,0,0,66,74,80,32,112,114,111,116,111,99,111,108,32,40,118,49,41,0,0,0,0,0,0,0,82,101,99,101,105,118,101,100,32,115,105,103,110,111,110,32,37,105,32,119,104,101,110,32,97,116,32,37,105,0,0,0,32,32,32,73,102,32,121,111,117,32,112,114,101,115,115,32,89,32,116,111,32,32,32,32,0,0,0,0,0,0,0,0,95,115,110,100,95,109,105,120,97,104,101,97,100,0,0,0,43,115,116,114,97,102,101,0,115,99,114,95,99,101,110,116,101,114,116,105,109,101,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,10,0,0,0,115,98,95,97,114,109,111,114,50,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,79,117,116,32,111,102,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,114,95,114,101,112,111,114,116,101,100,103,101,111,117,116,0,10,0,0,0,0,0,0,0,84,121,114,81,117,97,107,101,0,0,0,0,0,0,0,0,66,105,108,105,110,101,97,114,32,102,105,108,116,101,114,105,110,103,0,0,0,0,0,0,80,114,111,103,114,97,109,115,32,111,99,99,117,112,121,32,37,105,75,46,10,0,0,0,119,114,97,112,95,109,111,100,101,37,117,0,0,0,0,0,83,84,79,82,69,80,95,70,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,48,46,56,0,0,0,0,0,32,32,32,32,97,110,100,32,115,117,99,99,101,115,115,102,117,108,33,32,32,32,32,32,0,0,0,0,0,0,0,0,49,48,48,0,0,0,0,0,37,115,58,32,97,116,116,101,110,117,97,116,105,111,110,32,61,32,37,102,0,0,0,0,32,32,80,114,101,115,115,32,78,32,116,111,32,115,116,97,121,32,112,114,111,117,100,32,0,0,0,0,0,0,0,0,82,101,109,111,118,101,100,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,37,115,58,32,105,110,116,101,114,118,97,108,32,60,61,32,48,0,0,0,0,0,0,0,82,73,70,70,0,0,0,0,115,116,97,114,116,0,0,0,32,32,32,98,105,103,32,108,111,115,101,114,32,105,110,32,108,105,102,101,46,32,32,32,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,114,51,0,0,0,0,0,0,99,108,95,102,111,114,119,97,114,100,115,112,101,101,100,0,82,101,116,114,111,65,114,99,104,58,32,79,70,70,83,69,84,58,32,37,117,44,32,67,83,73,90,69,58,32,37,117,44,32,83,73,90,69,58,32,37,117,46,10,0,0,0,0,73,72,68,82,0,0,0,0,57,48,0,0,0,0,0,0,32,80,114,101,115,115,32,89,32,116,111,32,113,117,105,116,32,108,105,107,101,32,97,32,0,0,0,0,0,0,0,0,103,108,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,0,0,0,72,79,77,69,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,83,116,111,99,107,32,71,76,83,76,32,115,104,97,100,101,114,115,32,119,105,108,108,32,98,101,32,117,115,101,100,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,65,116,116,101,109,112,116,101,100,32,116,111,32,114,101,45,105,110,105,116,105,97,108,105,122,101,32,100,114,105,118,101,114,46,10,0,0,0,0,0,0,0,0,37,115,58,32,100,97,116,97,103,114,97,109,32,119,97,115,110,39,116,32,97,32,110,111,112,0,0,0,0,0,0,0,32,32,32,32,32,32,115,109,97,99,107,101,100,32,111,117,116,46,32,32,32,32,32,32,0,0,0,0,0,0,0,0,97,110,117,109,95,109,105,110,117,115,0,0,0,0,0,0,82,51,0,0,0,0,0,0,67,97,110,39,116,32,115,97,118,101,32,105,110,32,105,110,116,101,114,109,105,115,115,105,111,110,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,67,97,110,110,111,116,32,102,105,110,100,32,115,104,97,100,101,114,32,99,111,114,101,32,102,111,114,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,0,0,0,99,111,117,108,100,110,39,116,32,111,112,101,110,32,37,115,10,0,0,0,0,0,0,0,32,32,32,32,32,80,114,101,115,115,32,89,32,116,111,32,103,101,116,32,32,32,32,32,0,0,0,0,0,0,0,0,32,32,32,102,111,114,32,116,114,121,105,110,103,32,116,111,32,113,117,105,116,33,32,32,0,0,0,0,0,0,0,0,114,95,103,114,97,112,104,104,101,105,103,104,116,0,0,0,67,79,82,69,32,83,69,76,69,67,84,73,79,78,32,37,115,0,0,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,95,97,117,116,111,0,99,103,0,0,0,0,0,0,78,111,32,115,117,99,104,32,102,114,97,109,101,32,37,100,32,37,115,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,32,77,97,110,44,32,73,32,111,117,103,104,116,97,32,115,109,97,99,107,32,121,111,117,0,0,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,105,110,112,117,116,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,37,105,40,63,63,63,41,0,32,32,32,32,32,32,32,32,116,111,32,113,117,105,116,63,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,37,115,32,102,105,108,101,32,105,110,32,34,37,115,34,44,32,97,116,116,101,109,112,116,105,110,103,32,116,111,32,112,97,116,99,104,32,46,46,46,10,0,0,0,0,0,0,37,56,105,32,58,32,37,115,10,0,0,0,0,0,0,0,99,108,95,99,114,111,115,115,120,0,0,0,0,0,0,0,71,111,116,32,115,105,122,101,58,32,37,117,32,120,32,37,117,46,10,0,0,0,0,0,48,0,0,0,0,0,0,0,98,106,112,0,0,0,0,0,77,85,76,95,70,86,0,0,32,32,102,97,99,101,32,111,112,101,110,32,102,111,114,32,116,114,121,105,110,103,32,32,0,0,0,0,0,0,0,0,37,115,58,32,115,118,99,95,117,112,100,97,116,101,99,111,108,111,114,115,32,62,32,77,65,88,95,83,67,79,82,69,66,79,65,82,68,0,0,0,37,115,58,32,111,117,116,32,111,102,32,115,102,120,95,116,0,0,0,0,0,0,0,0,45,108,111,111,107,100,111,119,110,0,0,0,0,0,0,0,66,97,100,32,102,111,118,58,32,37,102,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,0,0,110,111,32,112,114,101,99,97,99,104,101,58,32,37,115,10,0,0,0,0,0,0,0,0,115,98,95,97,114,109,111,114,49,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,111,112,101,114,97,116,105,111,110,46,10,0,0,0,0,50,48,48,0,0,0,0,0,67,76,95,82,101,97,100,70,114,111,109,83,101,114,118,101,114,58,32,108,111,115,116,32,115,101,114,118,101,114,32,99,111,110,110,101,99,116,105,111,110,0,0,0,0,0,0,0,79,70,70,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,111,118,101,114,108,97,121,115,32,118,97,114,105,97,98,108,101,32,110,111,116,32,100,101,102,105,110,101,100,32,105,110,32,99,111,110,102,105,103,46,10,0,0,37,115,58,32,99,111,117,108,100,110,39,116,32,108,111,97,100,32,112,114,111,103,115,46,100,97,116,0,0,0,0,0,102,105,108,116,101,114,95,108,105,110,101,97,114,37,117,0,83,84,79,82,69,95,70,78,67,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,115,97,116,117,114,97,116,101,95,112,99,116,0,0,0,100,101,97,116,104,109,97,116,99,104,0,0,0,0,0,0,115,104,97,50,53,54,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,105,109,97,103,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,32,68,111,32,73,32,110,101,101,100,32,116,111,32,98,117,115,116,32,121,111,117,114,32,0,0,0,0,0,0,0,0,85,78,78,65,77,69,68,0,60,47,37,115,62,0,0,0,108,111,99,97,108,104,111,115,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,68,101,115,99,114,105,112,116,105,111,110,58,32,37,115,10,0,0,0,0,37,115,58,32,99,97,99,104,105,110,103,32,102,97,105,108,101,100,0,0,0,0,0,0,67,111,109,112,108,101,116,101,100,32,100,101,109,111,10,0,32,113,117,105,116,116,101,114,46,32,73,115,32,116,104,105,115,32,116,114,117,101,63,32,0,0,0,0,0,0,0,0,83,101,116,116,105,110,103,32,100,105,115,107,32,37,117,32,111,102,32,37,117,32,105,110,32,116,114,97,121,46,0,0,109,97,112,32,37,115,10,0,32,32,32,116,104,111,117,32,97,114,116,32,97,32,108,111,119,108,121,32,32,32,32,32,0,0,0,0,0,0,0,0,76,51,32,98,117,116,116,111,110,32,40,108,101,102,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,0,32,77,105,108,111,114,100,44,32,109,101,116,104,105,110,107,115,32,116,104,97,116,32,32,0,0,0,0,0,0,0,0,80,71,85,80,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,76,51,0,0,0,0,0,0,78,111,116,32,112,108,97,121,105,110,103,32,97,32,108,111,99,97,108,32,103,97,109,101,46,10,0,0,0,0,0,0,67,108,105,101,110,116,32,37,115,32,114,101,109,111,118,101,100,10,0,0,0,0,0,0,32,32,32,101,118,101,114,121,116,104,105,110,103,32,101,108,115,101,63,32,32,32,32,32,0,0,0,0,0,0,0,0,32,32,116,104,105,115,32,103,97,109,101,32,106,117,115,116,32,108,105,107,101,32,32,32,0,0,0,0,0,0,0,0,97,115,112,101,99,116,95,114,97,116,105,111,95,105,110,100,101,120,0,0,0,0,0,0,32,32,65,114,101,32,121,111,117,32,103,111,110,110,97,32])
.concat([113,117,105,116,32,32,32,32,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,105,110,112,117,116,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,32,118,97,108,105,100,32,82,79,77,32,112,97,116,99,104,46,10,0,0,0,0,0,37,115,37,99,104,105,112,110,111,116,105,99,0,0,0,0,85,115,97,103,101,58,32,99,97,99,104,101,32,112,114,105,110,116,124,102,108,117,115,104,10,0,0,0,0,0,0,0,55,57,0,0,0,0,0,0,120,0,0,0,0,0,0,0,37,115,32,116,114,105,101,100,32,116,111,32,37,115,10,0,70,105,116,122,81,117,97,107,101,32,112,114,111,116,111,99,111,108,0,0,0,0,0,0,74,111,105,110,32,103,97,109,101,32,97,116,58,0,0,0,37,115,58,32,115,118,99,95,117,112,100,97,116,101,102,114,97,103,115,32,62,32,77,65,88,95,83,67,79,82,69,66,79,65,82,68,0,0,0,0,37,115,58,32,110,97,109,101,32,116,111,111,32,108,111,110,103,58,32,37,115,0,0,0,43,108,111,111,107,100,111,119,110,0,0,0,0,0,0,0,49,55,48,0,0,0,0,0,114,117,98,121,0,0,0,0,115,98,95,99,101,108,108,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,114,95,97,108,105,97,115,116,114,97,110,115,98,97,115,101,0,0,0,0,0,0,0,0,37,115,58,37,50,105,32,32,40,37,53,46,49,102,44,37,53,46,49,102,44,37,53,46,49,102,41,32,91,37,53,46,49,102,32,37,53,46,49,102,32,37,53,46,49,102,93,10,0,0,0,0,0,0,0,0,79,78,0,0,0,0,0,0,112,114,111,103,115,46,100,97,116,0,0,0,0,0,0,0,115,104,97,100,101,114,37,117,0,0,0,0,0,0,0,0,83,84,79,82,69,95,70,76,68,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,65,110,97,108,111,103,32,104,105,116,98,111,120,32,116,121,112,101,32,109,117,115,116,32,98,101,32,34,114,97,100,105,97,108,34,46,10,0,0,0,34,109,97,120,112,108,97,121,101,114,115,34,32,115,101,116,32,116,111,32,34,37,117,34,10,0,0,0,0,0,0,0,83,101,97,114,99,104,32,102,111,114,32,108,111,99,97,108,32,103,97,109,101,115,46,46,46,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,37,115,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,32,46,46,46,10,0,0,0,0,0,0,109,97,120,112,108,97,121,101,114,115,32,37,117,10,0,0,78,111,116,32,114,101,99,111,114,100,105,110,103,32,97,32,100,101,109,111,46,10,0,0,108,51,0,0,0,0,0,0,37,115,32,45,32,37,115,0,80,71,68,78,0,0,0,0,84,67,80,47,73,80,0,0,82,50,0,0,0,0,0,0,107,105,108,108,115,58,37,51,105,47,37,51,105,0,0,0,43,109,108,111,111,107,10,0,74,111,105,110,32,71,97,109,101,0,0,0,0,0,0,0,78,101,119,32,71,97,109,101,0,0,0,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,0,32,32,32,115,101,101,32,116,101,99,104,105,110,102,111,46,116,120,116,46,32,32,32,32,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,32,99,111,109,109,97,110,100,32,34,37,115,34,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,32,97,117,100,105,111,32,105,110,112,117,116,32,114,97,116,101,32,116,111,58,32,37,46,50,102,32,72,122,46,10,0,0,0,108,105,110,101,32,112,97,114,97,109,101,116,101,114,115,59,32,112,108,101,97,115,101,32,0,0,0,0,0,0,0,0,73,80,83,0,0,0,0,0,112,114,105,110,116,0,0,0,99,114,111,115,115,104,97,105,114,99,111,108,111,114,0,0,98,97,110,0,0,0,0,0,102,105,116,122,0,0,0,0,32,114,101,113,117,105,114,101,115,32,117,115,105,110,103,32,99,111,109,109,97,110,100,32,0,0,0,0,0,0,0,0,37,115,58,32,115,118,99,95,117,112,100,97,116,101,110,97,109,101,32,62,32,77,65,88,95,83,67,79,82,69,66,79,65,82,68,0,0,0,0,0,37,115,58,32,78,85,76,76,0,0,0,0,0,0,0,0,45,108,111,111,107,117,112,0,49,48,0,0,0,0,0,0,115,98,95,114,111,99,107,101,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,101,110,117,109,46,10,0,49,48,48,0,0,0,0,0,69,77,80,84,89,10,0,0,40,70,73,76,69,41,0,0,37,105,32,101,110,116,105,116,105,101,115,32,105,110,104,105,98,105,116,101,100,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,88,77,76,32,115,104,97,100,101,114,32,46,46,46,10,0,0,0,0,0,83,84,79,82,69,95,69,78,84,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,72,105,116,98,111,120,32,116,121,112,101,32,40,37,115,41,32,105,115,32,105,110,118,97,108,105,100,46,32,85,115,101,32,34,114,97,100,105,97,108,34,32,111,114,32,34,114,101,99,116,34,46,10,0,0,0,109,97,120,112,108,97,121,101,114,115,32,99,97,110,32,110,111,116,32,98,101,32,99,104,97,110,103,101,100,32,119,104,105,108,101,32,97,32,115,101,114,118,101,114,32,105,115,32,114,117,110,110,105,110,103,46,10,0,0,0,0,0,0,0,32,32,77,111,114,101,32,116,104,97,110,32,52,32,112,108,97,121,101,114,115,32,32,32,0,0,0,0,0,0,0,0,99,104,97,115,101,95,117,112,0,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,76,101,118,101,108,0,0,0,0,0,0,0,0,99,108,111,115,101,0,0,0,108,105,115,116,101,110,32,48,10,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,32,69,112,105,115,111,100,101,0,0,0,0,0,0,0,0,82,50,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,103,102,120,47,98,111,120,95,98,108,46,108,109,112,0,0,37,105,32,109,105,110,117,116,101,115,0,0,0,0,0,0,68,69,76,0,0,0,0,0,32,32,32,32,32,32,32,84,105,109,101,32,76,105,109,105,116,0,0,0,0,0,0,0,76,50,0,0,0,0,0,0,72,111,115,116,95,82,101,99,111,110,110,101,99,116,95,102,58,32,99,108,115,46,115,116,97,116,101,32,60,32,99,97,95,99,111,110,110,101,99,116,101,100,0,0,0,0,0,0,67,111,117,108,100,110,39,116,32,119,114,105,116,101,32,99,111,110,102,105,103,46,99,102,103,46,10,0,0,0,0,0,37,105,32,102,114,97,103,115,0,0,0,0,0,0,0,0,118,105,100,101,111,95,99,114,111,112,95,111,118,101,114,115,99,97,110,0,0,0,0,0,66,32,98,117,116,116,111,110,32,40,100,111,119,110,41,0,37,117,58,37,117,32,40,49,58,49,32,80,65,82,41,0,32,32,32,32,32,32,32,70,114,97,103,32,76,105,109,105,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,97,109,101,32,70,80,83,32,62,32,77,111,110,105,116,111,114,32,70,80,83,46,32,67,97,110,110,111,116,32,114,101,108,121,32,111,110,32,86,83,121,110,99,46,10,0,0,0,0,0,0,0,67,97,110,39,116,32,34,37,115,34,44,32,110,111,116,32,99,111,110,110,101,99,116,101,100,10,0,0,0,0,0,0,78,105,103,104,116,109,97,114,101,32,100,105,102,102,105,99,117,108,116,121,0,0,0,0,66,80,83,0,0,0,0,0,37,115,37,99,114,111,103,117,101,0,0,0,0,0,0,0,99,97,99,104,101,0,0,0,99,114,111,115,115,104,97,105,114,0,0,0,0,0,0,0,82,71,66,53,54,53,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,103,105,118,101,0,0,0,0,83,116,97,110,100,97,114,100,32,78,101,116,81,117,97,107,101,32,112,114,111,116,111,99,111,108,0,0,0,0,0,0,72,97,114,100,32,100,105,102,102,105,99,117,108,116,121,0,115,118,99,95,108,105,103,104,116,115,116,121,108,101,32,62,32,77,65,88,95,76,73,71,72,84,83,84,89,76,69,83,0,0,0,0,0,0,0,0,46,119,97,118,0,0,0,0,43,108,111,111,107,117,112,0,49,50,48,0,0,0,0,0,114,98,0,0,0,0,0,0,84,101,120,116,117,114,101,0,115,98,95,110,97,105,108,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,76,111,97,100,101,100,32,37,117,32,112,114,111,103,114,97,109,40,115,41,46,10,0,0,0,114,95,97,108,105,97,115,116,114,97,110,115,97,100,106,0,37,51,105,58,0,0,0,0,78,101,97,114,101,115,116,0,78,111,32,115,112,97,119,110,32,102,117,110,99,116,105,111,110,32,102,111,114,58,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,110,111,114,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,105,110,32,88,77,76,32,102,105,108,101,46,10,0,0,0,0,0,0,83,84,79,82,69,95,83,0,114,101,99,116,0,0,0,0,34,109,97,120,112,108,97,121,101,114,115,34,32,105,115,32,34,37,117,34,10,0,0,0,78,111,114,109,97,108,32,100,105,102,102,105,99,117,108,116,121,0,0,0,0,0,0,0,109,111,100,101,108,32,37,115,32,104,97,115,32,110,111,32,118,101,114,116,105,99,101,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,97,100,106,117,115,116,101,100,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,115,105,122,101,32,116,111,32,37,117,32,77,105,66,10,0,0,0,0,0,69,97,115,121,32,100,105,102,102,105,99,117,108,116,121,0,101,106,101,99,116,0,0,0,100,105,115,99,111,110,110,101,99,116,10,0,0,0,0,0,32,32,32,32,32,32,32,32,32,32,32,32,83,107,105,108,108,0,0,0,0,0,0,0,114,50,0,0,0,0,0,0,79,102,102,0,0,0,0,0,86,111,108,117,109,101,32,105,115,32,37,102,10,0,0,0,73,78,83,0,0,0,0,0,84,104,114,101,101,32,84,101,97,109,32,67,84,70,0,0,82,0,0,0,0,0,0,0,79,110,108,121,32,116,104,101,32,115,101,114,118,101,114,32,109,97,121,32,99,104,97,110,103,101,108,101,118,101,108,10,0,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,79,110,101,32,70,108,97,103,32,67,84,70,0,0,0,0,67,97,112,116,117,114,101,32,116,104,101,32,70,108,97,103,0,0,0,0,0,0,0,0,118,105,100,101,111,95,115,99,97,108,101,95,105,110,116,101,103,101,114,0,0,0,0,0,84,97,103,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,84,105,109,105,110,103,115,32,100,101,118,105,97,116,101,32,116,111,111,32,109,117,99,104,46,32,87,105,108,108,32,110,111,116,32,97,100,106,117,115,116,46,32,40,68,105,115,112,108,97,121,32,61,32,37,46,50,102,32,72,122,44,32,71,97,109,101,32,61,32,37,46,50,102,32,72,122,41,10,0,0,0,0,0,0,37,115,58,32,110,111,32,115,117,99,104,32,99,111,109,109,97,110,100,32,45,32,37,115,0,0,0,0,0,0,0,0,69,83,67,65,80,69,0,0,70,114,105,101,110,100,108,121,32,70,105,114,101,0,0,0,85,80,83,0,0,0,0,0,104,117,110,107,0,0,0,0,118,95,105,100,108,101,115,99,97,108,101,0,0,0,0,0,49,0,0,0,0,0,0,0,112,105,110,103,0,0,0,0,110,113,0,0,0,0,0,0,78,111,32,70,114,105,101,110,100,108,121,32,70,105,114,101,0,0,0,0,0,0,0,0,83,101,114,118,101,114,32,100,105,115,99,111,110,110,101,99,116,101,100,10,0,0,0,0,84,111,116,97,108,32,114,101,115,105,100,101,110,116,58,32,37,105,10,0,0,0,0,0,45,98,97,99,107,0,0,0,51,48,0,0,0,0,0,0,103,108,71,101,116,80,111,105,110,116,101,114,118,0,0,0,37,115,37,115,0,0,0,0,115,98,95,115,104,101,108,108,115,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,105,110,105,116,32,102,97,105,108,101,100,46,10,0,37,115,58,32,78,85,76,76,32,119,111,114,108,100,109,111,100,101,108,0,0,0,0,0,112,108,97,121,100,101,109,111,32,37,115,10,0,0,0,0,76,105,110,101,97,114,0,0,78,111,32,99,108,97,115,115,110,97,109,101,32,102,111,114,58,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,83,84,79,82,69,95,86,0,117,110,105,109,112,108,101,109,101,110,116,101,100,32,98,117,108,105,116,105,110,0,0,0,114,97,100,105,97,108,0,0,108,105,115,116,101,110,32,49,10,0,0,0,0,0,0,0,32,32,32,32,32,32,32,32,84,101,97,109,112,108,97,121,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,109,105,115,99,47,109,101,110,117,51,46,119,97,118,0,0,67,111,111,112,101,114,97,116,105,118,101,0,0,0,0,0,76,50,32,98,117,116,116,111,110,32,40,108,101,102,116,32,115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,0,32,32,32,32,32,32,32,32,71,97,109,101,32,84,121,112,101,0,0,0,0,0,0,0,80,97,117,115,101,100,32,37,115,32,116,114,97,99,107,32,37,117,10,0,0,0,0,0,70,49,50,0,0,0,0,0,37,105,0,0,0,0,0,0,76,0,0,0,0,0,0,0,99,104,97,110,103,101,108,101,118,101,108,32,60,108,101,118,101,108,110,97,109,101,62,32,58,32,99,111,110,116,105,110,117,101,32,103,97,109,101,32,111,110,32,97,32,110,101,119,32,108,101,118,101,108,10,0,37,115,47,99,111,110,102,105,103,46,99,102,103,0,0,0,32,32,32,32,32,32,77,97,120,32,112,108,97,121,101,114,115,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,67,65,78,95,68,85,80,69,58,32,116,114,117,101,10,0,0,119,98,0,0,0,0,0,0,118,101,114,115,105,111,110,58,32,84,121,114,81,117,97,107,101,45,37,115,10,0,0,0,118,105,100,101,111,95,102,111,114,99,101,95,97,115,112,101,99,116,0,0,0,0,0,0,103,102,120,47,113,112,108,97,113,117,101,46,108,109,112,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,117,100,105,111,32,98,97,99,107,101,110,100,32,102,97,105,108,101,100,32,116,111,32,119,114,105,116,101,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,115,111,117,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,109,111,117,110,116,32,111,102,32,116,105,109,101,32,115,112,101,110,116,32,99,108,111,115,101,32,116,111,32,117,110,100,101,114,114,117,110,58,32,37,46,50,102,32,37,37,46,32,67,108,111,115,101,32,116,111,32,98,108,111,99,107,105,110,103,58,32,37,46,50,102,32,37,37,46,10,0,0,0,0,0,0,0,0,37,115,58,32,37,115,32,97,108,114,101,97,100,121,32,100,101,102,105,110,101,100,10,0,78,111,32,81,117,97,107,101,32,115,101,114,118,101,114,115,32,102,111,117,110,100,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,115,99,111,112,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,101,118,101,114,97,108,32,112,97,116,99,104,101,115,32,97,114,101,32,101,120,112,108,105,99,105,116,108,121,32,100,101,102,105,110,101,100,44,32,105,103,110,111,114,105,110,103,32,97,108,108,32,46,46,46,10,0,0,0,45,98,97,115,101,100,105,114,0,0,0,0,0,0,0,0,102,108,117,115,104,0,0,0,118,95,105,112,105,116,99,104,95,108,101,118,101,108,0,0,83,101,97,114,99,104,105,110,103,46,46,46,0,0,0,0,100,105,116,104,101,114,95,102,105,108,116,101,114,0,0,0,107,105,99,107,0,0,0,0,37,100,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,77,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,37,115,58,32,83,101,114,118,101,114,32,114,101,116,117,114,110,101,100,32,117,110,107,110,111,119,110,32,112,114,111,116,111,99,111,108,32,118,101,114,115,105,111,110,32,37,105,0,40,37,50,100,98,41,32,37,54,105,32,58,32,37,115,10,0,0,0,0,0,0,0,0,43,98,97,99,107,0,0,0,103,102,120,47,108,111,97,100,105,110,103,46,108,109,112,0,103,108,71,101,116,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,80,114,101,118,37,117,0,0,105,110,118,97,37,105,95,108,105,103,104,116,110,103,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,10,0,0,37,115,0,0,0,0,0,0,78,111,32,100,101,109,111,115,32,108,105,115,116,101,100,32,119,105,116,104,32,115,116,97,114,116,100,101,109,111,115,10,0,0,0,0,0,0,0,0,37,115,58,32,102,111,117,110,100,32,37,115,32,119,104,101,110,32,101,120,112,101,99,116,105,110,103,32,123,0,0,0,115,99,114,105,112,116,0,0,83,84,79,82,69,95,70,0,37,45,49,53,46,49,53,115,32,37,45,49,53,46,49,53,115,10,0,0,0,0,0,0,98,97,99,107,119,97,114,100,115,32,109,105,110,115,47,109,97,120,115,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,110,101,120,116,95,116,97,114,103,101,116,0,0,0,0,108,105,115,116,101,110,32,48,10,0,0,0,0,0,0,0,80,86,83,67,97,99,104,101,58,32,37,55,100,32,104,105,116,115,32,37,55,100,32,109,105,115,115,101,115,10,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,115,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,37,45,49,53,46,49,53,115,32,37,45,49,53,46,49,53,115,32,37,50,117,47,37,50,117,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,67,108,111,115,101,100,0,0,103,102,120,47,112,95,109,117,108,116,105,46,108,109,112,0,37,117,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,109,111,117,115,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,108,50,0,0,0,0,0,0,109,97,112,32,115,116,97,114,116,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,112,108,97,121,105,110,103,0,70,49,49,0,0,0,0,0,109,97,120,112,108,97,121,101,114,115,32,49,10,0,0,0,104,111,115,116,95,115,112,101,101,100,115,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,115,99,111,110,110,101,99,116,105,110,103,32,100,101,118,105,99,101,32,102,114,111,109,32,112,111,114,116,32,37,117,46,10,0,0,88,32,40,117,112,41,0,0,99,111,110,110,101,99,116,32,108,111,99,97,108,0,0,0,108,111,97,100,32,115,37,105,10,0,0,0,0,0,0,0,45,100,101,118,101,108,111,112,101,114,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,99,111,110,102,105,103,32,102,105,108,101,46,32,85,115,105,110,103,32,115,121,115,116,101,109,32,100,101,102,97,117,108,116,46,10,0,0,0,0,0,99,111,110,99,104,97,114,115,0,0,0,0,0,0,0,0,115,97,118,101,32,115,37,105,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,99,111,110,102,105,103,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,118,105,100,101,111,95,115,109,111,111,116,104,0,0,0,0,99,111,108,111,114,32,37,105,32,37,105,10,0,0,0,0,46,99,102,103,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,97,117,100,105,111,32,98,117,102,102,101,114,32,115,97,116,117,114,97,116,105,111,110,58,32,37,46,50,102,32,37,37,44,32,115,116,97,110,100,97,114,100,32,100,101,118,105,97,116,105,111,110,32,40,112,101,114,99,101,110,116,97,103,101,32,112,111,105,110,116,115,41,58,32,37,46,50,102,32,37,37,46,10,0,0,37,115,58,32,37,115,32,97,108,114,101,97,100,121,32,100,101,102,105,110,101,100,32,97,115,32,97,32,118,97,114,10,0,0,0,0,0,0,0,0,67,68,65,117,100,105,111,58,32,66,97,100,32,116,114,97,99,107,32,110,117,109,98,101,114,32,37,117,46,10,0,0,104,111,115,116,110,97,109,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,82,67,51,50,58,32,48,120,37,120,44,32,83,72,65,50,53,54,58,32,37,115,10,0,0,0,0,0,104,111,109,101,32,105,115,58,10,0,0,0,0,0,0,0,122,111,110,101,0,0,0,0,48,46,49,0,0,0,0,0,110,97,109,101,32,34,37,115,34,10,0,0,0,0,0,0,115,104,111,119,114,97,109,0,112,114,101,115,112,97,119,110,0,0,0,0,0,0,0,0,83,101,114,118,101,114,32,115,112,97,119,110,101,100,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,102,97,115,116,32,117,112,100,97,116,101,0,0,0,0,0,32,0,0,0,0,0,0,0,45,102,111,114,119,97,114,100,0,0,0,0,0,0,0,0,51,48,48,0,0,0,0,0,103,108,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,0,0,0,80,114,101,118,0,0,0,0,105,110,118,97,37,105,95,115,114,108,97,117,110,99,104,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,114,115,105,111,110,58,32,37,115,46,10,0,0,46,46,46,0,0,0,0,0,98,101,103,105,110,0,0,0,48,32,37,115,32,48,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,111,114,116,32,118,97,108,117,101,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,65,68,68,82,69,83,83,0,99,104,97,115,101,95,97,99,116,105,118,101,0,0,0,0,98,114,101,97,107,32,115,116,97,116,101,109,101,110,116,10,0,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,66,97,100,32,118,97,108,117,101,44,32,109,117,115,116,32,98,101,32,98,101,116,119,101,101,110,32,49,32,97,110,100,32,54,53,53,51,52,10,0,109,111,100,95,110,117,109,107,110,111,119,110,32,61,61,32,77,65,88,95,77,79,68,95,75,78,79,87,78,0,0,0,46,120,109,108,0,0,0,0,99,104,97,115,101,95,116,121,112,101,0,0,0,0,0,0,37,105,107,32,115,117,114,102,97,99,101,32,99,97,99,104,101,10,0,0,0,0,0,0,46,105,112,115,0,0,0,0,69,106,101,99,116,101,100,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,99,111,110,110,101,99,116,32,34,37,115,34,10,0,0,0,46,98,112,115,0,0,0,0,82,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,99,114,111,115,115,104,97,105,114,0,0,0,0,0,0,0,46,117,112,115,0,0,0,0,70,49,48,0,0,0,0,0,108,111,111,112,105,110,103,0,114,95,108,101,114,112,109,111,100,101,108,115,0,0,0,0,46,114,116,99,0,0,0,0,100,95,109,105,112,115,99,97,108,101,0,0,0,0,0,0,65,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,100,95,109,105,112,115,99,97,108,101,0,0,0,0,0,0,76,111,111,112,98,97,99,107,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,102,97,109,105,32,84,117,114,98,111,32,83,82,65,77,32,112,97,116,104,115,32,119,105,108,108,32,98,101,32,105,110,102,101,114,114,101,100,32,102,114,111,109,32,116,104,101,105,114,32,114,101,115,112,101,99,116,105,118,101,32,112,97,116,104,115,32,116,111,32,97,118,111,105,100,32,99,111,110,102,108,105,99,116,115,46,10,0,0,0,99,108,105,101,110,116,115,0,100,105,116,104,101,114,95,102,105,108,116,101,114,0,0,0,46,115,116,97,116,101,0,0,118,105,100,101,111,95,116,104,114,101,97,100,101,100,0,0,51,0,0,0,0,0,0,0,114,101,103,105,115,116,101,114,101,100,0,0,0,0,0,0,108,111,111,107,115,116,114,97,102,101,0,0,0,0,0,0,37,115,32,105,115,32,115,101,116,116,97,98,108,101,32,111,110,108,121,32,105,110,32,100,101,118,101,108,111,112,101,114,32,109,111,100,101,46,10,0,46,112,115,114,109,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,115,104,97,100,101,114,32,34,37,115,34,10,0,0,0,37,115,58,32,99,97,108,108,101,100,32,97,102,116,101,114,32,104,111,115,116,95,105,110,105,116,105,97,108,105,122,101,100,0,0,0,0,0,0,0,37,115,58,32,98,97,100,32,110,111,100,101,32,110,117,109,98,101,114,32,40,37,105,41,0,0,0,0,0,0,0,0,114,119,101,98,105,110,112,117,116,0,0,0,0,0,0,0,108,111,111,107,115,112,114,105,110,103,0,0,0,0,0,0,46,115,114,109,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,103,97,109,101,46,10,0,0,0,0,0,0,37,115,0,0,0,0,0,0,37,115,58,32,121,111,117,32,109,117,115,116,32,115,112,101,99,105,102,121,32,97,32,115,105,122,101,32,105,110,32,75,66,32,97,102,116,101,114,32,45,122,111,110,101,0,0,0,118,95,105,114,111,108,108,95,108,101,118,101,108,0,0,0,109,95,112,105,116,99,104,0,49,48,48,0,0,0,0,0,98,101,103,105,110,0,0,0,67,111,117,108,100,110,39,116,32,115,112,97,119,110,32,115,101,114,118,101,114,32,37,115,10,0,0,0,0,0,0,0,9,45,68,47,45,45,100,101,116,97,99,104,58,32,68,101,116,97,99,104,32,82,101,116,114,111,65,114,99,104,32,102,114,111,109,32,116,104,101,32,114,117,110,110,105,110,103,32,99,111,110,115,111,108,101,46,32,78,111,116,32,114,101,108,101,118,97,110,116,32,102,111,114,32,97,108,108,32,112,108,97,116,102,111,114,109,115,46,10,0,0,0,0,0,0,0,69,78,68,32,79,70,32,77,69,83,83,65,71,69,0,0,76,0,0,0,0,0,0,0,43,102,111,114,119,97,114,100,0,0,0,0,0,0,0,0,115,99,114,95,99,111,110,115,112,101,101,100,0,0,0,0,103,108,71,101,116,79,98,106,101,99,116,76,97,98,101,108,0,0,0,0,0,0,0,0,80,97,115,115,37,117,0,0,105,110,118,97,37,105,95,114,108,97,117,110,99,104,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,110,100,111,114,58,32,37,115,44,32,82,101,110,100,101,114,101,114,58,32,37,115,46,10,0,0,0,0,0,72,117,110,107,32,105,115,32,109,105,115,115,97,108,105,103,110,101,100,0,0,0,0,0,40,68,73,82,41,0,0,0,115,112,97,119,110,32,37,115,0,0,0,0,0,0,0,0,102,114,111,110,116,101,110,100,47,109,101,110,117,47,46,46,47,46,46,47,103,102,120,47,46,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,39,37,115,39,32,105,115,32,110,111,116,32,97,32,102,105,101,108,100,10,0,0,0,0,105,109,112,111,114,116,0,0,82,101,116,114,111,65,114,99,104,58,32,91,67,111,110,102,105,103,93,58,32,81,117,101,114,121,105,110,103,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,73,78,68,73,82,69,67,84,0,0,0,0,0,0,0,0,99,108,95,98,97,99,107,115,112,101,101,100,0,0,0,0,37,115,47,113,99,111,110,115,111,108,101,46,108,111,103,0,37,115,58,32,99,104,97,110,110,101,108,32,61,32,37,105,0,0,0,0,0,0,0,0,97,110,97,108,111,103,95,114,105,103,104,116,0,0,0,0,34,112,111,114,116,34,32,105,115,32,34,37,117,34,10,0,37,115,58,32,78,85,76,76,32,110,97,109,101,0,0,0,9,45,88,47,45,45,120,109,108,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,116,111,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,46,0,0,0,0,99,108,95,102,111,114,119,97,114,100,115,112,101,101,100,0,9,45,45,110,111,45,112,97,116,99,104,58,32,68,105,115,97,98,108,101,115,32,97,108,108,32,102,111,114,109,115,32,111,102,32,114,111,109,32,112,97,116,99,104,105,110,103,46,0,0,0,0,0,0,0,0,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,0,0,118,111,108,117,109,101,0,0,109,105,115,99,47,109,101,110,117,49,46,119,97,118,0,0,9,45,45,105,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,73,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,98,103,109,118,111,108,117,109,101,0,0,0,0,0,0,0,9,45,45,98,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,66,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,70,57,0,0,0,0,0,0,67,117,114,114,101,110,116,108,121,32,37,115,32,116,114,97,99,107,32,37,117,10,0,0,115,101,110,115,105,116,105,118,105,116,121,0,0,0,0,0,9,45,85,47,45,45,117,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,85,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,46,10,0,0,0,37,115,58,32,111,118,101,114,102,108,111,119,10,0,0,0,103,97,109,109,97,0,0,0,37,115,58,32,78,85,76,76,32,112,111,105,110,116,101,114,0,0,0,0,0,0,0,0,9,45,118,47,45,45,118,101,114,98,111,115,101,58,32,86,101,114,98,111,115,101,32,108,111,103,103,105,110,103,46,0,79,110,108,121,32,111,110,101,32,111,102,32,45,100,101,100,105,99,97,116,101,100,32,111,114,32,45,108,105,115,116,101,110,32,99,97,110,32,98,101,32,115,112,101,99,105,102,105,101,100,0,0,0,0,0,0,118,105,101,119,115,105,122,101,0,0,0,0,0,0,0,0,37,115,58,32,99,111,117,108,100,110,39,116,32,108,111,97,100,32,37,115,0,0,0,0,9,9,68,111,32,110,111,116,101,32,116,104,97,116,32,110,111,108,111,97,100,45,115,97,118,101,32,105,109,112,108,105,101,115,32,116,104,97,116,32,115,97,118,101,32,102,105,108,101,115,32,119,105,108,108,32,98,101,32,100,101,108,101,116,101,100,32,97,110,100,32,111,118,101,114,119,114,105,116,116,101,110,46,0,0,0,0,0,118,105,100,101,111,95,115,119,97,112,95,105,110,116,101,114,118,97,108,0,0,0,0,0,32,10,9,12,13,11,0,0,99,111,110,95,110,111,116,105,102,121,116,105,109,101,0,0,101,120,101,99,32,100,101,102,97,117,108,116,46,99,102,103,10,0,0,0,0,0,0,0,9,9,123,110,111,44,125,108,111,97,100,45,123,110,111,44,125,115,97,118,101,32,100,101,115,99,114,105,98,101,115,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,108,111,97,100,101,100,44,32,97,110,100,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,115,97,118,101,100,46,0,0,115,104,97,100,101,114,124,99,103,124,99,103,112,124,103,108,115,108,124,103,108,115,108,112,0,0,0,0,0,0,0,0,115,119,105,109,32,100,111,119,110,0,0,0,0,0,0,0,9,45,77,47,45,45,115,114,97,109,45,109,111,100,101,58,32,84,97,107,101,115,32,97,110,32,97,114,103,117,109,101,110,116,32,116,101,108,108,105,110,103,32,104,111,119,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,104,97,110,100,108,101,100,32,105,110,32,116,104,101,32,115,101,115,115,105,111,110,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,0,0,70,105,110,100,70,105,108,101,58,32,99,97,110,39,116,32,102,105,110,100,32,37,115,10,0,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,45,122,111,110,101,0,0,0,48,46,51,0,0,0,0,0,43,109,111,118,101,100,111,119,110,0,0,0,0,0,0,0,118,105,101,119,115,105,122,101,0,0,0,0,0,0,0,0,115,112,97,119,110,0,0,0,109,97,112,115,47,37,115,46,98,115,112,0,0,0,0,0,9,45,82,47,45,45,98,115,118,114,101,99,111,114,100,58,32,83,116,97,114,116,32,114,101,99,111,114,100,105,110,103,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,32,102,114,111,109,32,116,104,101,32,98,101,103,105,110,110,105,110,103,46,0,0,0,37,115,58,32,99,97,110,39,116,32,99,97,99,104,101,32,37,115,10,0,0,0,0,0,37,115,58,32,66,97,100,32,115,101,114,118,101,114,32,109,101,115,115,97,103,101,0,0,45,114,105,103,104,116,0,0,115,104,111,119,114,97,109,0,103,108,79,98,106,101,99,116,76,97,98,101,108,0,0,0,80,97,115,115,80,114,101,118,37,117,0,0,0,0,0,0,105,110,118,97,37,105,95,115,110,97,105,108,103,117,110,0,82,101,116,114,111,65,114,99,104,58,32,68,101,116,101,99,116,105,110,103,32,115,99,114,101,101,110,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,46,10,0,0,115,117,114,102,97,99,101,115,0,0,0,0,0,0,0,0,48,46,57,46,57,46,51,0,99,111,108,111,114,32,37,105,32,37,105,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,108,105,103,104,116,95,108,101,118,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,101,120,116,117,114,101,32,105,109,97,103,101,32,102,97,105,108,101,100,32,116,111,32,108,111,97,100,46,10,0,0,0,0,0,71,84,0,0,0,0,0,0,115,119,105,109,32,117,112,0,37,115,58,32,97,116,116,101,110,117,97,116,105,111,110,32,61,32,37,102,0,0,0,0,97,110,97,108,111,103,95,108,101,102,116,0,0,0,0,0,84,67,80,47,73,80,32,97,100,100,114,101,115,115,32,37,115,10,0,0,0,0,0,0,77,105,115,115,105,110,103,32,102,114,97,109,101,32,37,105,32,111,102,32,37,115,0,0,9,45,80,47,45,45,98,115,118,112,108,97,121,58,32,80,108,97,121,98,97,99,107,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,46,0,0,0,0,0,0,0,43,109,111,118,101,117,112,0,9,45,52,47,45,45,109,117,108,116,105,116,97,112,58,32,67,111,110,110,101,99,116,32,97,32,83,78,69,83,32,109,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,65,112,112,101,110,100,101,100,32,100,105,115,107,58,32,37,115,0,0,0,0,0,0,0,107,101,121,98,111,97,114,100,32,108,111,111,107,0,0,0,109,105,115,99,47,109,101,110,117,50,46,119,97,118,0,0,9,45,74,47,45,45,106,117,115,116,105,102,105,101,114,115,58,32,68,97,105,115,121,32,99,104,97,105,110,32,116,119,111,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,115,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,76,32,98,117,116,116,111,110,32,40,108,101,102,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,0,43,107,108,111,111,107,0,0,9,45,106,47,45,45,106,117,115,116,105,102,105,101,114,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,115,99,114,95,111,102,115,120,0,0,0,0,0,0,0,0,70,56,0,0,0,0,0,0,37,117,32,116,114,97,99,107,115,10,0,0,0,0,0,0,109,111,117,115,101,32,108,111,111,107,0,0,0,0,0,0,9,45,112,47,45,45,115,99,111,112,101,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,83,117,112,101,114,83,99,111,112,101,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,67,117,114,114,101,110,116,108,121,32,111,110,58,32,37,115,32,40,32,37,115,32,41,10,0,0,0,0,0,0,0,0,43,109,108,111,111,107,0,0,9,45,109,47,45,45,109,111,117,115,101,58,32,67,111,110,110,101,99,116,32,97,32,109,111,117,115,101,32,105,110,116,111,32,112,111,114,116,32,111,102,32,116,104,101,32,100,101,118,105,99,101,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,0,0,0,45,108,105,115,116,101,110,0,99,101,110,116,101,114,32,118,105,101,119,0,0,0,0,0,9,45,65,47,45,45,100,117,97,108,97,110,97,108,111,103,58,32,67,111,110,110,101,99,116,32,97,32,68,117,97,108,65,110,97,108,111,103,32,99,111,110,116,114,111,108,108,101,114,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,118,105,100,101,111,95,98,108,97,99,107,95,102,114,97,109,101,95,105,110,115,101,114,116,105,111,110,0,0,0,0,0,98,97,99,107,117,112,32,112,97,115,116,32,48,10,0,0,34,0,0,0,0,0,0,0,109,97,112,108,105,115,116,0,99,101,110,116,101,114,118,105,101,119,0,0,0,0,0,0,9,45,78,47,45,45,110,111,100,101,118,105,99,101,58,32,68,105,115,99,111,110,110,101,99,116,115,32,99,111,110,116,114,111,108,108,101,114,32,100,101,118,105,99,101,32,99,111,110,110,101,99,116,101,100,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,48,82,71,66,49,53,53,53,32,112,105,120])
.concat([101,108,32,102,111,114,109,97,116,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,97,110,100,32,119,105,108,108,32,98,101,32,115,108,111,119,101,114,46,32,70,111,114,32,49,53,47,49,54,45,98,105,116,44,32,82,71,66,53,54,53,32,102,111,114,109,97,116,32,105,115,32,112,114,101,102,101,114,114,101,100,46,10,0,0,0,0,0,0,0,0,99,109,100,0,0,0,0,0,37,115,58,32,102,114,101,101,100,32,97,32,102,114,101,101,100,32,112,111,105,110,116,101,114,0,0,0,0,0,0,0,37,115,58,32,37,115,32,110,111,116,32,102,111,117,110,100,0,0,0,0,0,0,0,0,119,105,122,97,114,100,47,104,105,116,46,119,97,118,0,0,108,111,111,107,32,100,111,119,110,0,0,0,0,0,0,0,9,45,45,115,117,102,97,109,105,66,58,32,80,97,116,104,32,116,111,32,66,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,108,111,97,100,105,110,103,32,115,107,105,112,112,101,100,46,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,119,105,108,108,32,108,111,97,100,32,105,116,32,111,110,32,105,116,115,32,111,119,110,46,10,0,0,0,0,0,0,0,0,115,99,114,95,111,102,115,121,0,0,0,0,0,0,0,0,67,111,117,108,100,110,39,116,32,114,101,111,112,101,110,32,37,115,0,0,0,0,0,0,119,101,97,112,111,110,115,47,116,105,110,107,49,46,119,97,118,0,0,0,0,0,0,0,37,115,58,32,111,117,116,32,111,102,32,109,101,109,111,114,121,0,0,0,0,0,0,0,118,95,105,121,97,119,95,108,101,118,101,108,0,0,0,0,43,108,111,111,107,100,111,119,110,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,112,97,117,115,101,0,0,0,101,100,105,99,116,115,0,0,9,45,45,115,117,102,97,109,105,65,58,32,80,97,116,104,32,116,111,32,65,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,32,76,111,97,100,32,83,117,102,97,109,105,32,98,97,115,101,32,99,97,114,116,32,97,115,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,83,111,117,110,100,32,37,115,32,110,111,116,32,108,111,111,112,101,100,10,0,0,0,0,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,45,10,0,0,0,0,0,43,114,105,103,104,116,0,0,115,104,111,119,116,117,114,116,108,101,0,0,0,0,0,0,103,108,80,111,112,68,101,98,117,103,71,114,111,117,112,0,79,114,105,103,0,0,0,0,105,110,118,97,37,105,95,110,97,105,108,103,117,110,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,10,0,0,0,0,0,0,0,0,69,114,114,111,114,58,32,37,115,10,0,0,0,0,0,0,114,95,109,97,120,115,117,114,102,115,0,0,0,0,0,0,37,115,32,45,32,37,115,32,37,115,0,0,0,0,0,0,46,46,46,0,0,0,0,0,110,97,109,101,32,34,37,115,34,10,0,0,0,0,0,0,108,105,103,104,116,0,0,0,116,101,120,116,117,114,101,0,76,84,0,0,0,0,0,0,108,111,111,107,32,117,112,0,37,115,58,32,118,111,108,117,109,101,32,61,32,37,105,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,79,118,101,114,108,97,121,32,100,101,115,99,32,105,115,32,105,110,118,97,108,105,100,46,32,82,101,113,117,105,114,101,115,32,97,116,32,108,101,97,115,116,32,54,32,116,111,107,101,110,115,46,10,0,0,0,78,101,116,119,111,114,107,32,110,111,116,32,97,118,97,105,108,97,98,108,101,33,0,0,115,118,95,105,100,101,97,108,112,105,116,99,104,115,99,97,108,101,0,0,0,0,0,0,66,97,100,32,97,110,105,109,97,116,105,110,103,32,116,101,120,116,117,114,101,32,37,115,0,0,0,0,0,0,0,0,9,45,66,47,45,45,98,115,120,115,108,111,116,58,32,80,97,116,104,32,116,111,32,66,83,88,32,115,108,111,116,116,101,100,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,115,118,95,115,116,111,112,115,112,101,101,100,0,0,0,0,43,108,111,111,107,117,112,0,37,115,58,32,118,111,108,117,109,101,32,61,32,37,105,0,9,45,98,47,45,45,98,115,120,58,32,80,97,116,104,32,116,111,32,66,83,88,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,82,101,115,101,116,46,0,0,82,95,68,114,97,119,83,112,114,105,116,101,58,32,110,111,32,115,117,99,104,32,102,114,97,109,101,32,37,100,10,0,37,115,32,105,115,32,97,32,115,116,101,114,101,111,32,115,97,109,112,108,101,10,0,0,115,105,100,101,115,116,101,112,0,0,0,0,0,0,0,0,9,45,103,47,45,45,103,97,109,101,98,111,121,58,32,80,97,116,104,32,116,111,32,71,97,109,101,98,111,121,32,82,79,77,46,32,76,111,97,100,32,83,117,112,101,114,71,97,109,101,66,111,121,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,109,101,110,117,95,113,117,105,116,0,0,0,0,0,0,0,108,111,97,100,97,115,56,98,105,116,0,0,0,0,0,0,50,48,48,0,0,0,0,0,108,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,90,73,80,32,101,120,116,114,97,99,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,108,105,110,101,58,32,37,100,46,10,0,0,0,0,0,0,0,0,43,115,116,114,97,102,101,0,102,111,118,0,0,0,0,0,9,9,77,117,108,116,105,112,108,101,32,99,111,110,102,105,103,115,32,97,114,101,32,100,101,108,105,109,105,116,101,100,32,98,121,32,39,44,39,46,0,0,0,0,0,0,0,0,103,108,71,101,116,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,70,55,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,71,76,83,76,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,46,46,46,10,0,0,0,115,116,101,112,32,114,105,103,104,116,0,0,0,0,0,0,105,110,102,111,0,0,0,0,37,115,58,32,114,101,99,101,105,118,101,100,32,97,32,109,101,115,115,97,103,101,0,0,9,45,45,97,112,112,101,110,100,99,111,110,102,105,103,58,32,69,120,116,114,97,32,99,111,110,102,105,103,32,102,105,108,101,115,32,97,114,101,32,108,111,97,100,101,100,32,105,110,44,32,97,110,100,32,116,97,107,101,32,112,114,105,111,114,105,116,121,32,111,118,101,114,32,99,111,110,102,105,103,32,115,101,108,101,99,116,101,100,32,105,110,32,45,99,32,40,111,114,32,100,101,102,97,117,108,116,41,46,0,0,0,110,117,109,95,109,105,110,117,115,0,0,0,0,0,0,0,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,0,83,101,114,118,101,114,32,110,111,116,32,97,99,116,105,118,101,10,0,0,0,0,0,0,103,108,0,0,0,0,0,0,37,115,10,37,115,10,37,115,10,0,0,0,0,0,0,0,43,109,111,118,101,114,105,103,104,116,0,0,0,0,0,0,109,97,112,115,47,37,115,46,112,116,115,0,0,0,0,0,9,45,99,47,45,45,99,111,110,102,105,103,58,32,80,97,116,104,32,102,111,114,32,99,111,110,102,105,103,32,102,105,108,101,46,10,9,9,66,121,32,100,101,102,97,117,108,116,32,108,111,111,107,115,32,102,111,114,32,99,111,110,102,105,103,32,105,110,32,36,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,36,72,79,77,69,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,97,110,100,32,36,72,79,77,69,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,46,0,0,0,0,0,45,100,101,100,105,99,97,116,101,100,0,0,0,0,0,0,115,116,101,112,32,108,101,102,116,0,0,0,0,0,0,0,102,114,97,109,101,114,97,116,101,0,0,0,0,0,0,0,9,45,83,47,45,45,115,97,118,101,115,116,97,116,101,58,32,80,97,116,104,32,116,111,32,117,115,101,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,115,46,32,73,102,32,110,111,116,32,115,101,108,101,99,116,101,100,44,32,42,46,115,116,97,116,101,32,119,105,108,108,32,98,101,32,97,115,115,117,109,101,100,46,0,114,95,115,112,101,101,100,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,46,10,0,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,95,102,114,97,109,101,115,0,0,103,108,115,108,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,73,78,67,32,112,97,114,97,109,115,32,40,37,117,32,112,104,97,115,101,32,98,105,116,115,44,32,37,117,32,116,97,112,115,41,46,10,0,0,0,0,0,0,0,33,33,33,32,35,105,110,99,108,117,100,101,32,100,101,112,116,104,32,101,120,99,101,101,100,101,100,32,102,111,114,32,99,111,110,102,105,103,46,32,77,105,103,104,116,32,98,101,32,97,32,99,121,99,108,101,46,10,0,0,0,0,0,0,99,108,101,97,114,0,0,0,114,95,108,101,114,112,109,111,118,101,0,0,0,0,0,0,43,109,111,118,101,108,101,102,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,80,78,71,93,58,32,85,115,105,110,103,32,82,80,78,71,32,108,111,97,100,101,114,46,10,0,0,9,45,102,47,45,45,102,117,108,108,115,99,114,101,101,110,58,32,83,116,97,114,116,32,82,101,116,114,111,65,114,99,104,32,105,110,32,102,117,108,108,115,99,114,101,101,110,32,114,101,103,97,114,100,108,101,115,115,32,111,102,32,99,111,110,102,105,103,32,115,101,116,116,105,110,103,115,46,0,0,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,0,119,97,105,116,0,0,0,0,114,117,110,0,0,0,0,0,37,115,58,32,110,111,32,102,114,101,101,32,101,100,105,99,116,115,0,0,0,0,0,0,9,45,115,47,45,45,115,97,118,101,58,32,80,97,116,104,32,102,111,114,32,115,97,118,101,32,102,105,108,101,32,40,42,46,115,114,109,41,46,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,101,101,100,32,116,111,32,100,101,102,105,110,101,32,97,116,32,108,101,97,115,116,32,49,32,115,104,97,100,101,114,46,10,0,114,98,0,0,0,0,0,0,37,115,58,32,115,105,122,101,32,37,105,0,0,0,0,0,49,0,0,0,0,0,0,0,43,115,112,101,101,100,0,0,99,114,111,115,115,104,97,105,114,0,0,0,0,0,0,0,107,105,108,108,0,0,0,0,115,107,105,108,108,0,0,0,77,85,76,95,86,0,0,0,95,99,108,95,99,111,108,111,114,0,0,0,0,0,0,0,9,45,45,102,101,97,116,117,114,101,115,58,32,80,114,105,110,116,115,32,97,118,97,105,108,97,98,108,101,32,102,101,97,116,117,114,101,115,32,99,111,109,112,105,108,101,100,32,105,110,116,111,32,82,101,116,114,111,65,114,99,104,46,0,116,111,116,97,108,95,99,104,97,110,110,101,108,115,32,61,61,32,77,65,88,95,67,72,65,78,78,69,76,83,10,0,37,105,32,0,0,0,0,0,45,108,101,102,116,0,0,0,49,0,0,0,0,0,0,0,103,108,80,117,115,104,68,101,98,117,103,71,114,111,117,112,0,0,0,0,0,0,0,0,70,114,97,109,101,68,105,114,101,99,116,105,111,110,0,0,37,115,58,32,69,110,116,105,116,121,32,105,115,32,110,111,116,32,97,32,99,108,105,101,110,116,0,0,0,0,0,0,105,110,118,97,37,105,95,115,115,104,111,116,103,117,110,0,82,101,116,114,111,65,114,99,104,58,32,82,101,99,114,101,97,116,105,110,103,32,70,66,79,32,116,101,120,116,117,114,101,32,35,37,100,58,32,37,117,120,37,117,10,0,0,0,114,95,109,97,120,101,100,103,101,115,0,0,0,0,0,0,71,65,77,69,32,40,37,115,41,32,37,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,71,85,73,93,58,32,79,112,101,110,105,110,103,32,104,105,115,116,111,114,121,58,32,37,115,46,10,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,115,0,0,0,0,0,0,0,0,112,114,101,115,112,97,119,110,0,0,0,0,0,0,0,0,97,110,103,108,101,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,88,77,76,32,115,104,97,100,101,114,32,97,116,116,114,105,98,117,116,101,115,32,100,111,32,110,111,116,32,99,111,109,112,108,121,32,119,105,116,104,32,115,112,101,99,105,102,105,99,97,116,105,111,110,115,46,10,0,0,71,69,0,0,0,0,0,0,116,117,114,110,32,114,105,103,104,116,0,0,0,0,0,0,61,61,61,61,61,61,83,69,82,86,69,82,32,69,82,82,79,82,32,105,110,32,37,115,58,10,37,115,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,111,118,101,114,108,97,121,32,100,101,115,99,46,10,0,0,112,111,114,116,0,0,0,0,99,97,114,116,114,105,100,103,101,0,0,0,0,0,0,0,84,101,120,116,117,114,101,32,37,115,32,105,115,32,110,111,116,32,49,54,32,97,108,105,103,110,101,100,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,9,9,73,102,32,110,111,32,97,114,103,117,109,101,110,116,115,32,97,114,101,32,112,97,115,115,101,100,32,116,111,32,82,101,116,114,111,65,114,99,104,44,32,105,116,32,105,115,32,101,113,117,105,118,97,108,101,110,116,32,116,111,32,117,115,105,110,103,32,45,45,109,101,110,117,32,97,115,32,111,110,108,121,32,97,114,103,117,109,101,110,116,46,0,0,0,104,111,115,116,110,97,109,101,0,0,0,0,0,0,0,0,47,62,0,0,0,0,0,0,76,111,111,112,95,67,111,110,110,101,99,116,58,32,110,111,32,113,115,111,99,107,101,116,32,97,118,97,105,108,97,98,108,101,10,0,0,0,0,0,101,100,103,101,102,114,105,99,116,105,111,110,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,114,101,32,111,112,116,105,111,110,58,10,0,0,0,0,0,0,0,0,37,115,58,32,115,114,99,45,62,110,117,109,108,101,97,102,115,32,40,37,100,41,32,33,61,32,100,115,116,45,62,110,117,109,108,101,97,102,115,32,40,37,100,41,0,0,0,0,43,114,105,103,104,116,0,0,9,45,45,109,101,110,117,58,32,68,111,32,110,111,116,32,114,101,113,117,105,114,101,32,82,79,77,32,111,114,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,116,111,32,98,101,32,108,111,97,100,101,100,44,32,115,116,97,114,116,115,32,100,105,114,101,99,116,108,121,32,105,110,32,109,101,110,117,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,115,101,116,116,105,110,103,32,103,97,109,101,46,10,0,0,0,0,0,116,117,114,110,32,108,101,102,116,0,0,0,0,0,0,0,9,45,104,47,45,45,104,101,108,112,58,32,83,104,111,119,32,116,104,105,115,32,104,101,108,112,32,109,101,115,115,97,103,101,46,0,0,0,0,0,104,101,108,112,0,0,0,0,88,32,98,117,116,116,111,110,32,40,116,111,112,41,0,0,43,108,101,102,116,0,0,0,85,115,97,103,101,58,32,114,101,116,114,111,97,114,99,104,32,91,114,111,109,32,102,105,108,101,93,32,91,111,112,116,105,111,110,115,46,46,46,93,0,0,0,0,0,0,0,0,70,54,0,0,0,0,0,0,115,118,95,102,114,105,99,116,105,111,110,0,0,0,0,0,98,97,99,107,112,101,100,97,108,0,0,0,0,0,0,0,101,106,101,99,116,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,114,111,110,116,101,110,100,32,102,111,114,32,108,105,98,114,101,116,114,111,32,45,45,32,118,48,46,57,46,57,46,51,32,45,45,0,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,0,67,117,114,114,101,110,116,108,121,32,111,110,58,32,37,115,10,0,0,0,0,0,0,0,77,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,43,98,97,99,107,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,37,115,58,32,114,101,99,117,114,115,105,118,101,108,121,32,101,110,116,101,114,101,100,0,71,114,97,98,32,109,111,117,115,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,119,97,108,107,32,102,111,114,119,97,114,100,0,0,0,0,83,99,114,105,112,116,32,115,117,112,112,111,114,116,32,105,110,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,68,105,115,107,32,83,119,97,112,32,78,101,120,116,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,0,105,110,99,108,117,100,101,32,0,0,0,0,0,0,0,0,109,101,115,115,97,103,101,109,111,100,101,50,0,0,0,0,43,102,111,114,119,97,114,100,0,0,0,0,0,0,0,0,80,121,116,104,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,109,111,110,105,116,111,114,32,72,122,58,32,37,46,54,102,32,72,122,46,32,40,37,46,51,102,32,37,37,32,102,114,97,109,101,32,116,105,109,101,32,100,101,118,105,97,116,105,111,110,44,32,98,97,115,101,100,32,111,110,32,37,117,32,108,97,115,116,32,115,97,109,112,108,101,115,41,46,10,0,0,0,0,0,0,97,108,105,97,115,0,0,0,68,105,115,107,32,69,106,101,99,116,32,84,111,103,103,108,101,0,0,0,0,0,0,0,106,117,109,112,32,47,32,115,119,105,109,32,117,112,0,0,80,101,101,114,45,116,111,45,112,101,101,114,32,110,101,116,112,108,97,121,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,46,10,0,0,69,114,114,111,114,32,111,112,101,110,105,110,103,32,37,115,0,0,0,0,0,0,0,0,78,101,120,116,32,79,118,101,114,108,97,121,0,0,0,0,37,115,58,32,97,108,108,114,101,97,100,121,32,97,108,108,111,99,97,116,101,100,0,0,118,95,105,112,105,116,99,104,95,99,121,99,108,101,0,0,43,106,117,109,112,0,0,0,48,46,48,50,0,0,0,0,99,111,108,111,114,0,0,0,100,101,97,116,104,109,97,116,99,104,0,0,0,0,0,0,78,101,116,112,108,97,121,0,97,109,98,105,101,110,99,101,47,119,105,110,100,50,46,119,97,118,0,0,0,0,0,0,43,108,101,102,116,0,0,0,84,111,111,32,109,97,110,121,32,115,116,97,116,105,99,32,101,110,116,105,116,105,101,115,0,0,0,0,0,0,0,0,115,104,111,119,112,97,117,115,101,0,0,0,0,0,0,0,103,108,71,101,116,68,101,98,117,103,77,101,115,115,97,103,101,76,111,103,0,0,0,0,70,114,97,109,101,67,111,117,110,116,0,0,0,0,0,0,105,110,118,97,37,105,95,115,104,111,116,103,117,110,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,105,110,105,116,32,70,66,79,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,86,111,108,117,109,101,32,68,111,119,110,0,0,0,0,0,112,111,105,110,116,102,105,108,101,0,0,0,0,0,0,0,78,111,32,67,111,114,101,0,46,114,101,116,114,111,97,114,99,104,45,103,97,109,101,45,104,105,115,116,111,114,121,46,116,120,116,0,0,0,0,0,67,76,95,83,105,103,110,111,110,82,101,112,108,121,58,32,37,105,10,0,0,0,0,0,97,110,103,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,100,101,114,110,32,71,76,83,76,32,119,97,115,32,99,104,111,115,101,110,32,97,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,119,97,115,32,110,111,116,32,112,114,111,118,105,100,101,100,46,32,84,104,105,115,32,105,115,32,97,110,32,101,114,114,111,114,46,10,0,0,0,0,0,0,76,69,0,0,0,0,0,0,112,114,101,118,32,119,101,97,112,111,110,0,0,0,0,0,80,114,111,103,114,97,109,32,101,114,114,111,114,0,0,0,37,105,32,102,114,97,109,101,115,32,37,53,46,49,102,32,115,101,99,111,110,100,115,32,37,53,46,49,102,32,102,112,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,107,101,121,58,32,37,115,46,10,0,0,0,109,97,120,112,108,97,121,101,114,115,0,0,0,0,0,0,109,105,112,116,101,120,32,62,61,32,108,111,97,100,109,111,100,101,108,45,62,110,117,109,116,101,120,116,117,114,101,115,0,0,0,0,0,0,0,0,84,84,70,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,119,105,116,104,32,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,85,112,0,0,0,0,0,0,0,105,109,112,117,108,115,101,32,49,50,0,0,0,0,0,0,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,37,115,10,0,0,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,115,118,95,112,114,111,116,111,99,111,108,0,0,0,0,0,69,110,97,98,108,101,32,72,111,116,107,101,121,0,0,0,110,101,120,116,32,119,101,97,112,111,110,0,0,0,0,0,37,115,58,32,37,115,32,104,97,115,32,119,114,111,110,103,32,118,101,114,115,105,111,110,32,110,117,109,98,101,114,32,40,37,105,32,115,104,111,117,108,100,32,98,101,32,37,105,41,0,0,0,0,0,0,0,79,110,45,116,104,101,45,102,108,121,32,114,101,99,111,114,100,105,110,103,32,111,102,32,103,97,109,101,112,108,97,121,32,119,105,116,104,32,108,105,98,97,118,99,111,100,101,99,0,0,0,0,0,0,0,0,109,101,110,117,95,118,105,100,101,111,0,0,0,0,0,0,83,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,120,0,0,0,0,0,0,0,60,45,45,32,115,101,114,118,101,114,32,116,111,32,99,108,105,101,110,116,32,107,101,101,112,97,108,105,118,101,10,0,105,109,112,117,108,115,101,32,49,48,0,0,0,0,0,0,70,70,109,112,101,103,0,0,78,101,116,112,108,97,121,32,70,108,105,112,32,80,108,97,121,101,114,115,0,0,0,0,70,53,0,0,0,0,0,0,97,116,116,97,99,107,0,0,114,101,115,117,109,101,0,0,68,121,110,97,109,105,99,32,114,117,110,45,116,105,109,101,32,108,111,97,100,105,110,103,32,111,102,32,108,105,98,114,101,116,114,111,32,108,105,98,114,97,114,121,0,0,0,0,115,111,117,110,100,47,0,0,83,116,97,114,116,0,0,0,109,97,112,32,60,108,101,118,101,108,110,97,109,101,62,58,32,115,116,97,114,116,32,97,32,110,101,119,32,115,101,114,118,101,114,10,0,0,0,0,77,117,116,101,32,65,117,100,105,111,0,0,0,0,0,0,43,97,116,116,97,99,107,0,68,121,110,97,109,105,99,0,37,115,58,32,37,115,0,0,68,83,80,32,67,111,110,102,105,103,0,0,0,0,0,0,98,105,110,100,32,34,37,115,34,32,34,37,115,34,10,0,79,112,101,110,71,76,32,114,101,110,100,101,114,45,116,111,45,116,101,120,116,117,114,101,32,40,109,117,108,116,105,45,112,97,115,115,32,115,104,97,100,101,114,115,41,0,0,0,83,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,118,105,100,101,111,95,118,115,121,110,99,0,0,0,0,0,114,0,0,0,0,0,0,0,109,101,115,115,97,103,101,109,111,100,101,0,0,0,0,0,115,116,111,112,100,101,109,111,10,0,0,0,0,0,0,0,70,66,79,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,111,101,115,32,110,111,116,32,104,97,118,101,32,101,110,111,117,103,104,32,115,97,109,112,108,101,115,32,102,111,114,32,109,111,110,105,116,111,114,32,114,101,102,114,101,115,104,32,114,97,116,101,32,101,115,116,105,109,97,116,105,111,110,46,32,82,101,113,117,105,114,101,115,32,116,111,32,114,117,110,32,102,111,114,32,97,116,32,108,101,97,115,116,32,37,117,32,102,114,97,109,101,115,46,10,0,0,0,101,99,104,111,0,0,0,0,67,104,101,97,116,32,84,111,103,103,108,101,0,0,0,0,116,105,109,101,108,105,109,105,116,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,56,0,0,0,83,68,76,95,105,109,97,103,101,32,105,109,97,103,101,32,108,111,97,100,105,110,103,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,119,98,0,0,0,0,0,0,67,104,101,97,116,32,73,110,100,101,120,32,77,105,110,117,115,0,0,0,0,0,0,0,37,115,58,32,110,111,116,32,97,108,108,111,99,97,116,101,100,0,0,0,0,0,0,0,118,95,105,114,111,108,108,95,99,121,99,108,101,0,0,0,102,114,97,103,108,105,109,105,116,0,0,0,0,0,0,0,99,108,95,98,111,98,0,0,116,101,108,108,0,0,0,0,100,101,109,111,110,47,100,108,97,110,100,50,46,119,97,118,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,55,0,0,0,83,112,97,119,110,83,101,114,118,101,114,58,32,37,115,10,0,0,0,0,0,0,0,0,83,68,76,95,105,109,97,103,101,0,0,0,0,0,0,0,97,109,98,105,101,110,99,101,47,119,97,116,101,114,49,46,119,97,118,0,0,0,0,0,45,109,111,118,101,100,111,119,110,0,0,0,0,0,0,0,37,115,58,32,115,108,111,116,32,62,32,99,108,46,109,97,120,99,108,105,101,110,116,115,0,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,97,108,108,98,97,99,107,0,0,84,101,120,116,117,114,101,83,105,122,101,0,0,0,0,0,105,110,118,50,95,108,105,103,104,116,110,103,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,69,71,76,32,105,109,97,103,101,46,10,0,67,104,101,97,116,32,73,110,100,101,120,32,80,108,117,115,0,0,0,0,0,0,0,0,116,105,109,101,114,101,102,114,101,115,104,0,0,0,0,0,83,89,83,84,69,77,32,68,73,82,32,37,115,0,0,0,109,101,110,117,95,105,110,105,116,40,41,0,0,0,0,0,67,76,95,69,115,116,97,98,108,105,115,104,67,111,110,110,101,99,116,105,111,110,58,32,99,111,110,110,101,99,116,101,100,32,116,111,32,37,115,10,0,0,0,0,0,0,0,0,37,115,58,32,112,97,114,115,101,32,101,114,114,111,114,0,102,114,97,103,109,101,110,116,0,0,0,0,0,0,0,0,78,69,95,70,78,67,0,0,115,107,105,108,108,0,0,0,61,61,61,61,61,61,79,66,74,69,67,84,32,69,82,82,79,82,32,105,110,32,37,115,58,10,37,115,10,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,0,0,0,0,0,0,0,0,116,105,109,101,100,101,109,111,32,60,100,101,109,111,110,97,109,101,62,32,58,32,103,101,116,115,32,100,101,109,111,32,115,112,101,101,100,115,10,0,43,0,0,0,0,0,0,0,108,105,115,116,101,110,0,0,105,110,112,117,116,95,112,108,97,121,101,114,54,0,0,0,37,115,58,32,98,109,111,100,101,108,32,37,115,32,104,97,115,32,115,117,114,102,97,99,101,32,119,105,116,104,32,110,111,32,101,100,103,101,115,0,108,105,98,120,109,108,50,32,88,77,76,32,112,97,114,115,105,110,103,0,0,0,0,0,80,114,101,118,105,111,117,115,32,83,104,97,100,101,114,0,49,48,48,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,53,0,0,0,116,101,97,109,112,108,97,121,0,0,0,0,0,0,0,0,108,105,98,120,109,108,50,0,83,97,118,101,32,115,116,97,116,101,47,109,111,118,105,101,32,115,108,111,116,58,32,37,117,0,0,0,0,0,0,0,78,101,120,116,32,83,104,97,100,101,114,0,0,0,0,0,99,111,111,112,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,52,0,0,0,67,103,32,112,105,120,101,108,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,0,109,101,110,117,95,107,101,121,115,0,0,0,0,0,0,0,82,101,115,101,116,0,0,0,65,32,98,117,116,116,111,110,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,0,118,111,108,117,109,101,0,0,84,104,101,32,82,105,102,116,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,51,0,0,0,67,103,0,0,0,0,0,0,103,102,120,47,98,111,120,95,109,108,46,108,109,112,0,0,70,114,97,109,101,32,65,100,118,97,110,99,101,0,0,0,70,52,0,0,0,0,0,0,68,111,109,105,110,105,111,110,32,111,102,32,68,97,114,107,110,101,115,115,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,50,0,0,0,69,120,116,101,114,110,97,108,32,102,105,108,116,101,114,32,97,110,100,32,112,108,117,103,105,110,32,115,117,112,112,111,114,116,0,0,0,0,0,0,112,97,117,115,101,0,0,0,83,101,108,101,99,116,0,0,37,52,105,32,37,115,10,0,80,97,117,115,101,32,84,111,103,103,108,101,0,0,0,0,84,104,114,101,101,32,107,101,121,115,32,100,111,119,110,32,102,111,114,32,97,32,98,117,116,116,111,110,33,10,0,0,70,111,114,116,114,101,115,115,32,111,102,32,116,104,101,32,68,101,97,100,0,0,0,0,37,115,58,32,110,111,116,32,101,110,111,117,103,104,32,109,101,109,32,102,111,114,32,115,116,97,99,107,33,32,40,37,105,41,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,49,0,0,0,69,120,116,101,114,110,97,108,0,0,0,0,0,0,0,0,37,115,58,32,37,115,10,0,37,115,58,32,98,97,100,32,100,101,110,111,109,105,110,97,116,111,114,32,37,108,102,0,77,111,118,105,101,32,82,101,99,111,114,100,32,84,111,103,103,108,101,0,0,0,0,0,83,99,111,117,114,103,101,32,111,102,32,65,114,109,97,103,111,110,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,111,117,110,100,32,105,110,118,97,108,105,100,32,104,97,116,32,105,110,32,99,111,110,102,105,103,33,10,0,0,0,0,0,0,0,79,112,101,110,65,76,0,0,82,101,119,105,110,100,0,0,118,105,100,101,111,95,100,105,115,97,98,108,101,95,99,111,109,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,116,111,103,103,108,101,99,111,110,115,111,108,101,0,0,0,84,104,101,32,69,100,103,101,32,111,102,32,79,98,108,105,118,105,111,110,0,0,0,0,98,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,80,78,71,32,101,110,99,111,100,101,47,100,101,99,111,100,101,32,97,110,100,32,46,122,105,112,32,101,120,116,114,97,99,116,105,111,110,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,110,105,116,111,114,32,70,80,83,32,101,115,116,105,109,97,116,105,111,110,32,105,115,32,100,105,115,97,98,108,101,100,32,102,111,114,32,116,104,114,101,97,100,101,100,32,118,105,100,101,111,46,10,0,0,0,0,0,0,101,120,101,99,0,0,0,0,83,116,97,116,101,32,83,108,111,116,32,77,105,110,117,115,0,0,0,0,0,0,0,0,104,105,112,100,109,49,0,0,122,108,105,98,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,76,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,97,110,121,32,118,97,108,105,100,32,101,120,116,101,110,115,105,111,110,115,46,32,67,97,110,110,111,116,32,117,110,122,105,112,32,119,105,116,104,111,117,116,32,107,110,111,119,105,110,103,32,116,104,105,115,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,82,79,77,32,116,121,112,101,46,10,0,37,115,47,37,115,0,0,0,83,116,97,116,101,32,83,108,111,116,32,80,108,117,115,0,37,52,46,49,102,32,109,101,103,97,98,121,116,101,32,100,97,116,97,32,99,97,99,104,101,10,0,0,0,0,0,0,50,0,0,0,0,0,0,0,65,114,109,97,103,111,110,39,115,32,76,97,105,114,0,0,48,46,54,50,0,0,0,0,115,97,121,95,116,101,97,109,0,0,0,0,0,0,0,0,109,105,115,99,47,104,50,111,104,105,116,49,46,119,97,118,0,0,0,0,0,0,0,0,114,98,0,0,0,0,0,0,85,78,78,65,77,69,68,0,88,65,117,100,105,111,50,0,83,111,117,110,100,32,115,97,109,112,108,105,110,103,32,114,97,116,101,58,32,37,105,10,0,0,0,0,0,0,0,0,43,109,111,118,101,100,111,119,110,0,0,0,0,0,0,0,105,32,62,61,32,99,108,46,109,97,120,99,108,105,101,110,116,115,0,0,0,0,0,0,115,99,114,95,112,114,105,110,116,115,112,101,101,100,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,73,110,115,101,114,116,0,0,0,0,79,117,116,112,117,116,83,105,122,101,0,0,0,0,0,0,105,110,118,50,95,115,114,108,97,117,110,99,104,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,34,37,115,34,32,102,111,114,32,114,101,99,111,114,100,105,110,103,46,10,0,0,0,0,0,111,110,0,0,0,0,0,0,81,117,105,116,32,75,101,121,0,0,0,0,0,0,0,0,110,111,116,101,120,116,117,114,101,0,0,0,0,0,0,0,79,86,69,82,76,65,89,32,68,73,82,32,37,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,109,101,110,117,46,10,0,0,0,0,0,0,0,0,67,76,95,67,111,110,110,101,99,116,58,32,99,111,110,110,101,99,116,32,102,97,105,108,101,100,0,0,0,0,0,0,39,37,115,39,32,105,115,32,110,111,116,32,97,32,103,108,111,98,97,108,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,104,97,100,101,114,32,115,111,117,114,99,101,32,102,105,108,101,32,119,97,115,32,112,114,111,118,105,100,101,100,44,32,98,117,116,32,102,97,105,108,101,100,32,116,111,32,114,101,97,100,46,10,0,0,0,0,0,0,78,69,95,69,0,0,0,0,104,105,112,101,110,100,0,0,37,115,58,32,98,97,100,32,115,101,97,114,99,104,32,115,116,114,105,110,103,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,100,101,115,99,115,32,102,111,114,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,99,111,100,101,0,0,0,0,115,108,105,115,116,0,0,0,66,97,100,32,115,117,114,102,97,99,101,32,101,120,116,101,110,116,115,0,0,0,0,0,68,105,114,101,99,116,83,111,117,110,100,0,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,84,111,103,103,108,101,0,0,0,0,0,0,0,114,101,119,105,110,100,46,99,0,0,0,0,0,0,0,0,109,111,100,101,108,32,37,115,32,104,97,115,32,97,32,115,107,105,110,32,116,97,108,108,101,114,32,116,104,97,110,32,37,100,0,0,0,0,0,0,84,104,101,32,71,97,117,110,116,108,101,116,0,0,0,0,118,105,101,119,115,105,122,101,0,0,0,0,0,0,0,0,80,117,108,115,101,65,117,100,105,111,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,0,0,0,83,97,118,101,32,83,116,97,116,101,0,0,0,0,0,0,104,105,112,51,109,52,0,0,37,115,95,37,115,95,97,120,105,115,0,0,0,0,0,0,82,111,97,114,65,117,100,105,111,0,0,0,0,0,0,0,109,101,110,117,95,111,112,116,105,111,110,115,0,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,84,101,120,116,117,114,101,50,68,79,69,83,0,0,0,0,76,111,97,100,32,83,116,97,116,101,0,0,0,0,0,0,97,0,0,0,0,0,0,0,76,105,109,98,111,0,0,0,37,115,95,37,115,95,98,116,110,0,0,0,0,0,0,0,82,83,111,117,110,100,0,0,70,97,115,116,32,70,111,114,119,97,114,100,32,72,111,108,100,0,0,0,0,0,0,0,70,51,0,0,0,0,0,0,104,105,112,51,109,51,0,0,105,110,112,117,116,0,0,0,74,97,99,107,0,0,0,0,115,116,111,112,0,0,0,0,89,32,40,108,101,102,116,41,0,0,0,0,0,0,0,0,67,108,105,101,110,116,32,112,105,110,103,32,116,105,109,101,115,58,10,0,0,0,0,0,70,97,115,116,32,70,111,114,119,97,114,100,0,0,0,0,80,97,110,100,101,109,111,110,105,117,109,0,0,0,0,0,37,115,95,37,115,0,0,0,79,83,83,0,0,0,0,0,116,101,109,112,49,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,45,0,0,0,0,0,0,0,0,104,105,112,51,109,50,0,0,110,117,108,0,0,0,0,0,97,117,100,105,111,32,100,114,105,118,101,114,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,43,0,0,0,0,0,0,0,0,118,105,100,101,111,95,109,111,110,105,116,111,114,95,105,110,100,101,120,0,0,0,0,0,40,105,110,99,108,117,100,101,100,41,0,0,0,0,0,0,67,111,110,115,111,108,101,32,105,110,105,116,105,97,108,105,122,101,100,46,10,0,0,0,84,117,114,32,84,111,114,109,101,110,116,0,0,0,0,0,112,97,117,115,101,0,0,0,65,76,83,65,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,115,116,117,102,102,99,109,100,115,0,0,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,45,0,0,0,0,0,0,0,0,69,78,84,69,82,0,0,0,104,105,112,51,109,49,0,0,98,97,99,107,113,117,111,116,101,0,0,0,0,0,0,0,103,108,115,108,0,0,0,0,88,86,105,100,101,111,32,111,117,116,112,117,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,101,120,116,114,97,99,116,32,82,79,77,32,102,114,111,109,32,122,105,112,112,101,100,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,37,115,58,32,111,118,101,114,102,108,111,119,32,40,115,116,114,105,110,103,32,116,114,117,110,99,97,116,101,100,41,10,0,0,0,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,43,0,0,0,0,0,0,0,0,37,115,58,32,102,97,105,108,101,100,32,111,110,32,37,105,32,98,121,116,101,115,10,0,118,95,105,121,97,119,95,99,121,99,108,101,0,0,0,0,84,104,101,32,71,114,101,109,108,105,110,39,115,32,68,111,109,97,105,110,0,0,0,0,101,109,115,99,114,105,112,116,101,110,0,0,0,0,0,0,81,117,97,107,101,32,76,105,98,114,101,116,114,111,32,45,45,32,84,121,114,81,117,97,107,101,32,86,101,114,115,105,111,110,32,37,115,10,0,0,115,97,121,0,0,0,0,0,37,115,58,32,98,97,100,32,109,111,118,101,116,121,112,101,32,37,105,0,0,0,0,0,116,105,108,100,101,0,0,0,104,111,115,116,110,97,109,101,0,0,0,0,0,0,0,0,88,86,105,100,101,111,0,0,115,104,109,98,117,102,0,0,45,109,111,118,101,117,112,0,67,76,95,80,97,114,115,101])
.concat([77,111,100,101,108,58,32,98,97,100,32,109,111,100,110,117,109,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,111,110,116,114,111,108,0,0,0,73,110,112,117,116,83,105,122,101,0,0,0,0,0,0,0,105,110,118,50,95,114,108,97,117,110,99,104,0,0,0,0,111,102,102,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,45,0,114,95,102,117,108,108,98,114,105,103,104,116,0,0,0,0,83,65,86,69,70,73,76,69,32,68,73,82,32,37,115,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,102,97,105,108,101,100,46,10,0,0,0,0,83,101,110,100,105,110,103,32,99,108,99,95,100,105,115,99,111,110,110,101,99,116,10,0,71,76,32,114,97,115,116,101,114,0,0,0,0,0,0,0,37,115,58,32,99,108,111,115,105,110,103,32,98,114,97,99,101,32,119,105,116,104,111,117,116,32,100,97,116,97,0,0,115,114,99,0,0,0,0,0,78,69,95,83,0,0,0,0,104,105,112,50,109,54,0,0,37,115,58,32,66,97,100,32,115,116,114,105,110,103,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,100,101,115,99,115,46,10,0,0,0,0,0,0,80,108,97,121,105,110,103,32,100,101,109,111,32,102,114,111,109,32,37,115,46,10,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,113,115,111,99,107,101,116,0,115,99,114,111,108,108,95,108,111,99,107,0,0,0,0,0,79,112,101,110,86,71,32,111,117,116,112,117,116,32,115,117,112,112,111,114,116,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,43,0,77,111,114,116,117,109,39,115,32,75,101,101,112,0,0,0,112,114,105,110,116,95,115,99,114,101,101,110,0,0,0,0,79,112,101,110,86,71,0,0,83,97,118,101,100,32,115,116,97,116,101,32,116,111,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,45,0,104,105,112,50,109,53,0,0,100,105,118,105,100,101,0,0,110,117,109,95,37,105,0,0,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,0,0,0,0,109,101,110,117,95,115,101,116,117,112,0,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,43,0,82,105,103,104,116,32,68,45,112,97,100,0,0,0,0,0,37,115,58,32,98,114,111,107,101,110,32,99,121,99,108,101,0,0,0,0,0,0,0,0,67,76,95,69,110,116,105,116,121,78,117,109,58,32,37,105,32,105,115,32,97,110,32,105,110,118,97,108,105,100,32,110,117,109,98,101,114,0,0,0,84,104,101,32,67,114,121,112,116,0,0,0,0,0,0,0,109,117,108,116,105,112,108,121,0,0,0,0,0,0,0,0,69,71,76,0,0,0,0,0,37,115,58,32,66,97,100,32,115,112,114,105,116,101,32,116,121,112,101,32,37,100,0,0,84,117,114,98,111,32,69,110,97,98,108,101,0,0,0,0,70,50,0,0,0,0,0,0,104,105,112,50,109,52,0,0,98,97,99,107,115,112,97,99,101,0,0,0,0,0,0,0,75,77,83,47,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,108,111,111,112,0,0,0,0,66,32,40,98,111,116,116,111,109,41,0,0,0,0,0,0,102,108,121,109,111,100,101,32,79,70,70,10,0,0,0,0,82,101,116,114,111,80,97,100,32,82,51,32,66,117,116,116,111,110,0,0,0,0,0,0,84,104,101,32,67,97,116,97,99,111,109,98,115,0,0,0,110,117,109,108,111,99,107,0,75,77,83,0,0,0,0,0,112,97,117,115,97,98,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,51,32,66,117,116,116,111,110,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,114,101,97,116,105,110,103,32,70,66,79,32,37,100,32,64,32,37,117,120,37,117,10,0,0,0,0,0,104,105,112,50,109,51,0,0,99,97,112,115,108,111,99,107,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,79,86,69,82,83,67,65,78,58,32,37,117,10,0,0,0,0,79,112,101,110,71,76,32,100,114,105,118,101,114,0,0,0,104,111,115,116,110,97,109,101,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,82,50,32,66,117,116,116,111,110,0,0,0,0,0,0,118,105,100,101,111,95,119,105,110,100,111,119,101,100,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,37,115,32,61,32,34,37,115,34,32,37,115,10,0,0,0,99,111,110,109,97,105,110,0,84,104,101,32,66,108,97,99,107,32,67,97,116,104,101,100,114,97,108,0,0,0,0,0,112,101,114,105,111,100,0,0,114,0,0,0,0,0,0,0,79,112,101,110,71,76,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,105,110,105,116,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,65,108,105,97,115,32,118,97,108,117,101,32,105,115,32,116,111,111,32,108,111,110,103,10,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,50,32,66,117,116,116,111,110,0,0,0,0,0,0,47,0,0,0,0,0,0,0,104,105,112,50,109,50,0,0,107,101,121,112,97,100,57,0,84,104,114,101,97,100,105,110,103,32,115,117,112,112,111,114,116,0,0,0,0,0,0,0,122,105,112,0,0,0,0,0,112,97,116,104,0,0,0,0,82,101,116,114,111,80,97,100,32,82,32,66,117,116,116,111,110,0,0,0,0,0,0,0,37,115,58,32,111,108,100,32,104,117,110,107,32,110,97,109,101,32,116,114,97,115,104,101,100,10,0,0,0,0,0,0,118,95,107,105,99,107,112,105,116,99,104,0,0,0,0,0,65,110,99,105,101,110,116,32,82,101,97,108,109,115,0,0,82,79,71,85,69,0,0,0,110,111,99,108,105,112,0,0,112,108,97,121,101,114,32,105,115,32,115,116,117,99,107,46,10,0,0,0,0,0,0,0,107,101,121,112,97,100,56,0,114,101,99,111,110,110,101,99,116,10,0,0,0,0,0,0,84,104,114,101,97,100,115,0,115,104,109,0,0,0,0,0,43,109,111,118,101,117,112,0,77,111,100,101,108,32,37,115,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,0,115,104,111,119,95,102,112,115,0,0,0,0,0,0,0,0,103,108,73,115,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,0,0,76,85,84,84,101,120,67,111,111,114,100,0,0,0,0,0,105,110,118,50,95,115,110,97,105,108,103,117,110,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,32,86,83,121,110,99,32,61,62,32,37,115,10,0,0,0,0,0,0,45,112,97,114,116,105,99,108,101,115,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,32,66,117,116,116,111,110,0,0,0,0,0,0,0,114,95,108,111,99,107,102,114,117,115,116,117,109,0,0,0,83,65,86,69,83,84,65,84,69,32,68,73,82,32,37,115,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,37,115,46,10,0,0,0,0,0,48,46,56,0,0,0,0,0,37,115,58,32,69,79,70,32,119,105,116,104,111,117,116,32,99,108,111,115,105,110,103,32,98,114,97,99,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,104,97,118,101,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,105,110,32,97,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,78,69,95,86,0,0,0,0,104,105,112,50,109,49,0,0,37,115,58,32,111,118,101,114,102,108,111,119,32,40,109,97,120,32,61,32,37,100,41,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,110,117,109,98,101,114,32,111,102,32,100,101,115,99,115,32,102,114,111,109,32,99,111,110,102,105,103,32,107,101,121,58,32,37,115,46,10,0,0,0,0,112,108,97,121,32,60,100,101,109,111,110,97,109,101,62,32,58,32,112,108,97,121,115,32,97,32,100,101,109,111,10,0,99,104,101,97,116,0,0,0,45,108,105,115,116,101,110,0,107,101,121,112,97,100,55,0,115,107,121,0,0,0,0,0,83,68,76,32,100,114,105,118,101,114,115,0,0,0,0,0,82,101,116,114,111,80,97,100,32,88,32,66,117,116,116,111,110,0,0,0,0,0,0,0,77,105,108,105,116,97,114,121,32,67,111,109,112,108,101,120,0,0,0,0,0,0,0,0,107,101,121,112,97,100,54,0,83,68,76,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,0,37,102,32,115,101,99,111,110,100,115,32,40,37,102,32,102,112,115,41,10,0,0,0,0,82,101,116,114,111,80,97,100,32,65,32,66,117,116,116,111,110,0,0,0,0,0,0,0,104,105,112,49,109,53,0,0,107,101,121,112,97,100,53,0,9,37,115,58,10,9,9,37,115,58,32,37,115,10,0,0,109,101,110,117,95,109,117,108,116,105,112,108,97,121,101,114,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,114,105,103,104,116,0,0,0,82,101,115,101,97,114,99,104,32,70,97,99,105,108,105,116,121,0,0,0,0,0,0,0,107,101,121,112,97,100,52,0,70,101,97,116,117,114,101,115,58,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,70,49,0,0,0,0,0,0,104,105,112,49,109,52,0,0,107,101,121,112,97,100,51,0,48,0,0,0,0,0,0,0,107,101,121,112,97,100,50,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,88,82,71,66,56,56,56,56,46,10,0,102,108,121,109,111,100,101,32,79,78,10,0,0,0,0,0,112,108,97,121,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,84,104,101,32,76,111,115,116,32,77,105,110,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,45,45,109,101,110,117,32,119,97,115,32,117,115,101,100,44,32,98,117,116,32,82,79,77,32,102,105,108,101,32,119,97,115,32,112,97,115,115,101,100,32,97,115,32,119,101,108,108,46,10,0,107,101,121,112,97,100,49,0,99,111,111,112,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,104,105,112,49,109,51,0,0,37,115,58,32,102,97,105,108,101,100,32,116,111,32,108,111,97,100,32,37,115,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,69,114,114,111,114,32,112,97,114,115,105,110,103,32,97,114,103,117,109,101,110,116,115,46,10,0,0,107,101,121,112,97,100,48,0,82,101,116,114,111,80,97,100,32,83,116,97,114,116,32,66,117,116,116,111,110,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,0,37,115,32,61,32,34,37,115,34,10,0,0,0,0,0,0,45,99,111,110,100,101,98,117,103,0,0,0,0,0,0,0,83,116,111,114,97,103,101,32,70,97,99,105,108,105,116,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,32,105,110,32,45,45,115,114,97,109,45,109,111,100,101,46,10,0,0,112,97,103,101,100,111,119,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,112,104,105,99,115,32,100,114,105,118,101,114,32,100,105,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,97,110,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,112,105,99,107,32,97,32,115,117,105,116,97,98,108,101,32,100,114,105,118,101,114,46,10,0,0,0,65,108,105,97,115,32,110,97,109,101,32,105,115,32,116,111,111,32,108,111,110,103,10,0,82,101,116,114,111,80,97,100,32,83,101,108,101,99,116,32,66,117,116,116,111,110,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,114,101,115,111,108,118,101,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,33,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,104,105,112,49,109,50,0,0,81,117,105,116,32,82,101,116,114,111,65,114,99,104,0,0,108,111,97,100,45,115,97,118,101,0,0,0,0,0,0,0,112,97,103,101,117,112,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,116,111,32,34,37,115,34,46,10,0,104,105,112,110,111,116,105,99,47,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,89,32,66,117,116,116,111,110,0,0,0,0,0,0,0,37,115,58,32,111,108,100,32,115,101,110,116,105,110,97,108,32,116,114,97,115,104,101,100,10,0,0,0,0,0,0,0,118,95,107,105,99,107,114,111,108,108,0,0,0,0,0,0,49,0,0,0,0,0,0,0,72,73,80,78,79,84,73,67,0,0,0,0,0,0,0,0,82,101,115,116,97,114,116,32,82,101,116,114,111,65,114,99,104,0,0,0,0,0,0,0,110,97,109,101,0,0,0,0,84,104,101,32,80,117,109,112,105,110,103,32,83,116,97,116,105,111,110,0,0,0,0,0,85,110,115,116,117,99,107,46,10,0,0,0,0,0,0,0,112,114,111,103,115,47,112,108,97,121,101,114,46,109,100,108,0,0,0,0,0,0,0,0,108,111,97,100,45,110,111,115,97,118,101,0,0,0,0,0,110,117,109,57,0,0,0,0,66,97,100,32,34,37,115,34,32,99,104,117,110,107,32,108,101,110,103,116,104,32,40,37,100,41,32,105,110,32,119,97,118,32,102,105,108,101,32,37,115,10,0,0,0,0,0,0,115,102,120,95,116,0,0,0,67,76,95,83,101,110,100,77,111,118,101,58,32,108,111,115,116,32,115,101,114,118,101,114,32,99,111,110,110,101,99,116,105,111,110,10,0,0,0,0,83,67,82,95,83,99,114,101,101,110,83,104,111,116,95,102,58,32,110,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,10,0,0,0,0,83,101,114,118,101,114,32,115,101,110,116,32,116,111,111,32,109,97,110,121,32,115,111,117,110,100,32,112,114,101,99,97,99,104,101,115,32,40,109,97,120,32,61,32,37,100,41,0,103,108,71,101,110,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,0,0,0,67,111,108,111,114,0,0,0,105,110,118,50,95,110,97,105,108,103,117,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,51,50,45,98,105,116,32,70,66,79,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,49,54,45,98,105,116,46,10,0,0,0,0,82,101,116,114,111,80,97,100,32,66,32,66,117,116,116,111,110,0,0,0,0,0,0,0,114,95,108,111,99,107,112,118,115,0,0,0,0,0,0,0,83,72,65,68,69,82,32,68,73,82,32,37,115,0,0,0,82,101,116,114,111,65,114,99,104,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,115,117,99,99,101,101,100,101,100,46,10,0,0,0,109,95,115,105,100,101,0,0,37,105,32,101,110,116,105,116,105,101,115,10,0,0,0,0,118,101,114,116,101,120,0,0,78,69,95,70,0,0,0,0,104,105,112,49,109,49,0,0,37,115,58,32,80,114,101,99,97,99,104,101,32,99,97,110,32,111,110,108,121,32,98,101,32,100,111,110,101,32,105,110,32,115,112,97,119,110,32,102,117,110,99,116,105,111,110,115,0,0,0,0,0,0,0,0,82,101,115,116,97,114,116,32,71,97,109,101,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,115,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,99,104,101,97,116,32,102,111,114,32,103,97,109,101,58,32,34,37,115,34,10,0,0,37,105,10,0,0,0,0,0,37,115,58,32,121,111,117,32,109,117,115,116,32,115,112,101,99,105,102,121,32,97,32,110,117,109,98,101,114,32,97,102,116,101,114,32,45,112,111,114,116,0,0,0,0,0,0,0,37,115,58,32,98,97,100,32,115,117,114,102,97,99,101,32,110,117,109,98,101,114,0,0,110,111,108,111,97,100,45,115,97,118,101,0,0,0,0,0,110,117,109,56,0,0,0,0,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,0,67,111,109,109,97,110,100,32,72,81,0,0,0,0,0,0,82,101,115,117,109,101,32,71,97,109,101,0,0,0,0,0,37,115,58,32,102,97,105,108,101,100,0,0,0,0,0,0,110,111,108,111,97,100,45,110,111,115,97,118,101,0,0,0,76,111,97,100,101,100,32,115,116,97,116,101,32,102,114,111,109,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,110,117,109,55,0,0,0,0,112,97,114,115,101,95,99,111,110,102,105,103,95,102,105,108,101,40,41,0,0,0,0,0,67,111,114,114,105,100,111,114,115,32,111,102,32,84,105,109,101,0,0,0,0,0,0,0,84,97,107,101,32,83,99,114,101,101,110,115,104,111,116,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,115,99,111,110,110,101,99,116,32,100,101,118,105,99,101,32,102,114,111,109,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,110,117,109,54,0,0,0,0,109,101,110,117,95,115,97,118,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,0,0,0,0,0,0,0,76,101,102,116,32,68,45,112,97,100,0,0,0,0,0,0,114,95,100,114,97,119,111,114,100,101,114,0,0,0,0,0,72,101,108,108,39,115,32,70,111,114,116,114,101,115,115,0,76,111,97,100,32,83,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,109,111,117,115,101,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,110,117,109,53,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,58,32,37,115,46,10,0,0,0,82,83,72,73,70,84,0,0,73,110,116,114,111,100,117,99,116,105,111,110,0,0,0,0,83,97,118,101,32,83,116,97,116,101,0,0,0,0,0,0,112,97,114,115,101,95,105,110,112,117,116,40,41,0,0,0,110,117,109,52,0,0,0,0,84,111,111,32,109,97,110,121,32,101,102,114,97,103,115,33,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,82,71,66,53,54,53,46,10,0,0,0,110,111,99,108,105,112,32,79,70,70,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,46,10,0,0,0,0,0,78,111,32,67,68,32,105,110,32,112,108,97,121,101,114,46,10,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,68,105,118,105,115,105,111,110,32,111,102,32,67,104,97,110,103,101,0,0,0,0,0,0,68,105,115,107,32,79,112,116,105,111,110,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,0,110,117,109,51,0,0,0,0,100,101,97,116,104,109,97,116,99,104,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,99,111,110,102,105,103,32,102,114,111,109,58,32,37,115,46,10,0,0,0,0,99,116,102,49,0,0,0,0,83,101,116,116,105,110,103,115,0,0,0,0,0,0,0,0,104,115,58,102,118,83,58,109,58,112,52,106,74,65,58,103,58,98,58,99,58,66,58,89,58,90,58,85,58,68,78,58,88,58,80,58,82,58,77,58,0,0,0,0,0,0,0,0,110,117,109,50,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,121,0,0,0,0,0,0,35,105,110,99,108,117,100,101,32,34,37,115,34,10,0,0,46,98,115,112,0,0,0,0,83,111,117,114,99,101,32,111,102,32,69,118,105,108,0,0,80,97,116,104,32,79,112,116,105,111,110,115,0,0,0,0,103,108,115,108,112,0,0,0,37,115,32,105,115,32,111,98,115,111,108,101,116,101,46,10,0,0,0,0,0,0,0,0,102,101,97,116,117,114,101,115,0,0,0,0,0,0,0,0,110,117,109,49,0,0,0,0,79,117,116,32,111,102,32,101,100,103,101,115,32,102,111,114,32,98,109,111,100,101,108,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,111,112,101,110,32,118,105,100,101,111,32,100,114,105,118,101,114,32,46,46,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,37,115,32,58,32,37,115,10,0,0,0,0,0,0,0,0,103,108,0,0,0,0,0,0,47,101,116,99,0,0,0,0,110,117,108,108,0,0,0,0,47,112,114,111,99,47,37,117,47,37,115,0,0,0,0,0,114,50,109,56,0,0,0,0,73,110,112,117,116,32,79,112,116,105,111,110,115,0,0,0,100,101,116,97,99,104,0,0,110,117,109,48,0,0,0,0,115,105,110,99,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,114,101,99,111,118,101,114,32,46,46,46,10,0,0,114,111,103,117,101,47,0,0,37,115,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,0,37,115,58,32,116,101,109,112,32,104,117,110,107,32,110,111,116,32,97,99,116,105,118,101,0,0,0,0,0,0,0,0,118,95,107,105,99,107,116,105,109,101,0,0,0,0,0,0,76,97,115,116,32,66,97,115,116,105,111,110,0,0,0,0,114,111,103,117,101,0,0,0,65,117,100,105,111,32,79,112,116,105,111,110,115,0,0,0,102,108,121,0,0,0,0,0,103,114,97,118,105,116,121,0,37,115,58,32,109,111,100,101,108,32,37,115,32,110,111,116,32,112,114,101,99,97,99,104,101,100,0,0,0,0,0,0,120,109,108,0,0,0,0,0,102,49,50,0,0,0,0,0,83,111,117,110,100,32,37,115,32,104,97,115,32,97,32,98,97,100,32,108,111,111,112,32,108,101,110,103,116,104,0,0,108,111,97,100,105,110,103,32,97,108,108,32,115,111,117,110,100,115,32,97,115,32,56,98,105,116,10,0,0,0,0,0,49,46,53,0,0,0,0,0,87,114,111,116,101,32,37,115,10,0,0,0,0,0,0,0,83,101,114,118,101,114,32,115,101,110,116,32,116,111,111,32,109,97,110,121,32,109,111,100,101,108,32,112,114,101,99,97,99,104,101,115,32,40,109,97,120,32,61,32,37,100,41,0,103,108,68,101,108,101,116,101,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,114,95,108,101,114,112,109,111,100,101,108,115,0,0,0,0,86,101,114,116,101,120,67,111,111,114,100,0,0,0,0,0,105,110,118,50,95,115,115,104,111,116,103,117,110,0,0,0,46,116,103,97,0,0,0,0,65,82,77,95,97,114,103,98,56,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,111,107,105,110,103,32,102,111,114,32,99,111,110,102,105,103,32,105,110,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,114,95,110,117,109,101,100,103,101,115,0,0,0,0,0,0,66,82,79,87,83,69,82,32,68,73,82,32,37,115,0,0,49,0,0,0,0,0,0,0,34,37,115,34,10,0,0,0,98,105,116,109,97,112,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,76,101,103,97,99,121,32,115,104,97,100,101,114,115,32,97,114,101,32,100,101,112,114,101,99,97,116,101,100,46,10,0,0,0,0,0,0,0,69,81,95,70,78,67,0,0,114,50,109,55,0,0,0,0,72,79,77,69,0,0,0,0,80,97,114,109,32,48,32,110,111,116,32,97,32,99,108,105,101,110,116,0,0,0,0,0,86,105,100,101,111,32,79,112,116,105,111,110,115,0,0,0,111,118,101,114,108,97,121,37,117,95,102,117,108,108,95,115,99,114,101,101,110,0,0,0,37,115,0,0,0,0,0,0,110,97,109,101,0,0,0,0,45,117,100,112,112,111,114,116,0,0,0,0,0,0,0,0,69,82,82,79,82,58,32,99,111,117,108,100,110,39,116,32,111,112,101,110,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,37,115,58,32,98,97,100,32,99,108,105,112,110,111,100,101,32,99,104,105,108,100,32,110,117,109,98,101,114,0,0,0,110,111,45,112,97,116,99,104,0,0,0,0,0,0,0,0,102,49,49,0,0,0,0,0,37,115,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,66,108,111,111,100,32,83,97,99,114,105,102,105,99,101,0,67,111,114,101,32,79,112,116,105,111,110,115,0,0,0,0,105,112,115,0,0,0,0,0,37,115,0,0,0,0,0,0,102,49,48,0,0,0,0,0,37,115,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,114,50,109,54,0,0,0,0,76,111,97,100,32,71,97,109,101,0,0,0,0,0,0,0,98,112,115,0,0,0,0,0,102,57,0,0,0,0,0,0,109,101,110,117,95,108,111,97,100,0,0,0,0,0,0,0,72,79,77,69,0,0,0,0,108,101,102,116,0,0,0,0,87,105,122,97,114,100,39,115,32,75,101,101,112,0,0,0,76,111,97,100,32,71,97,109,101,32,40,72,105,115,116,111,114,121,41,0,0,0,0,0,117,112,115,0,0,0,0,0,102,56,0,0,0,0,0,0,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,0,76,83,72,73,70,84,0,0,114,50,109,53,0,0,0,0,114,103,117,105,46,99,103,112,0,0,0,0,0,0,0,0,115,114,97,109,45,109,111,100,101,0,0,0,0,0,0,0,102,55,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,48,82,71,66,49,53,53,53,46,10,0,110,111,99,108,105,112,32,79,78,10,0,0,0,0,0,0,99,108,111,115,101,0,0,0,67,117,114,115,101,32,111,102,32,79,115,105,114,105,115,0,48,0,0,0,0,0,0,0,114,103,117,105,46,103,108,115,108,112,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,37,115,10,0,0,98,115,118,114,101,99,111,114,100,0,0,0,0,0,0,0,102,54,0,0,0,0,0,0,49,0,0,0,0,0,0,0,46,98,115,112,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,46,46,46,10,0,114,50,109,52,0,0,0,0,98,115,118,112,108,97,121,0,102,53,0,0,0,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,120,0,0,0,0,0,0,119,0,0,0,0,0,0,0,109,97,112,115,0,0,0,0,109,97,112,115,0,0,0,0,82,51,0,0,0,0,0,0,69,108,101,109,101,110,116,97,108,32,70,117,114,121,32,73,73,0,0,0,0,0,0,0,115,117,102,97,109,105,66,0,102,52,0,0,0,0,0,0,105,110,105,116,95,118,105,100,101,111,95,105,110,112,117,116,40,41,0,0,0,0,0,0,67,117,114,114,101,110,116,32,97,108,105,97,115,32,99,111,109,109,97,110,100,115,58,10,0,0,0,0,0,0,0,0,112,97,116,104,47,97,46,111,117,116,0,0,0,0,0,0,118,105,101,119,112,114,101,118,0,0,0,0,0,0,0,0,76,51,0,0,0,0,0,0,114,50,109,51,0,0,0,0,115,117,102,97,109,105,65,0,102,51,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,83,82,65,77,46,10,0,0,0,0,0,0,45,115,97,102,101,0,0,0,116,101,109,112,0,0,0,0,48,46,53,0,0,0,0,0,118,105,101,119,110,101,120,116,0,0,0,0,0,0,0,0,104,105,112,110,111,116,105,99,0,0,0,0,0,0,0,0,82,50,0,0,0,0,0,0,110,111,116,97,114,103,101,116,0,0,0,0,0,0,0,0,69,108,101,109,101,110,116,97,108,32,70,117,114,121,32,73,0,0,0,0,0,0,0,0,37,115,58,32,33,116,114,97,99,101,46,101,110,116,0,0,105,116,101,109,115,50,0,0,109,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,77,105,115,115,105,110,103,32,100,97,116,97,32,99,104,117,110,107,10,0,0,0,0,0,102,50,0,0,0,0,0,0,49,0,0,0,0,0,0,0,99,108,95,97,110,103,108,101,115,112,101,101,100,107,101,121,0,0,0,0,0,0,0,0,3,3,11,0,0,0,0,0,37,115,58,32,67,111,117,108,100,110,39,116,32,99,114,101,97,116,101,32,97,32,80,67,88,32,102,105,108,101,10,0,85,115,105,110,103,32,112,114,111,116,111,99,111,108,32,37,105,10,0,0,0,0,0,0,103,108,66,105,110,100,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,84,101,120,67,111,111,114,100,0,0,0,0,0,0,0,0,105,110,118,50,95,115,104,111,116,103,117,110,0,0,0,0,79,69,83,95,114,103,98,56,95,114,103,98,97,56,0,0,114,95,110,117,109,115,117,114,102,115,0,0,0,0,0,0,79,86,69,82,76,65,89,32,37,115,0,0,0,0,0,0,73,78,70,79,32,45,32,76,111,97,100,105,110,103,32,37,115,32,46,46,46,0,0,0,109,95,102,111,114,119,97,114,100,0,0,0,0,0,0,0,34,37,115,34,32,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,114,101,112,111,114,116,115,32,97,32,71,76,69,83,50,32,115,116,121,108,101,32,115,104,97,100,101,114,46,10,0,0,69,81,95,69,0,0,0,0,118,105,101,119,102,114,97,109,101,0,0,0,0,0,0,0,37,53,46,49,102,0,0,0,76,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,114,101,99,116,32,34,37,115,34,32,105,110,116,111,32,97,116,32,108,101,97,115,116,32,102,111,117,114,32,116,111,107,101,110,115,46,10,0,0,0,115,99,97,108,101,95,121,37,117,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,45,112,111,114,116,0,0,0,114,50,109,50,0,0,0,0,119,98,0,0,0,0,0,0,37,115,58,32,102,117,110,110,121,32,108,117,109,112,32,115,105,122,101,32,105,110,32,37,115,0,0,0,0,0,0,0,98,115,120,115,108,111,116,0,102,49,0,0,0,0,0,0,118,105,101,119,109,111,100,101,108,0,0,0,0,0,0,0,82,0,0,0,0,0,0,0,115,99,97,108,101,95,120,37,117,0,0,0,0,0,0,0,84,101,109,112,117,115,32,70,117,103,105,116,0,0,0,0,110,111,109,111,110,115,116,101,114,115,0,0,0,0,0,0,98,115,120,0,0,0,0,0,37,115,37,117,0,0,0,0,107,112,95,109,105,110,117,115,0,0,0,0,0,0,0,0,115,116,111,112,100,101,109,111,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,115,99,97,108,101,37,117,0,114,50,109,49,0,0,0,0,115,97,118,101,115,116,97,116,101,0,0,0,0,0,0,0,107,112,95,112,108,117,115,0,109,101,110,117,95,115,105,110,103,108,101,112,108,97,121,101,114,0,0,0,0,0,0,0,68,111,119,110,32,68,45,112,97,100,0,0,0,0,0,0,100,101,109,111,115,0,0,0,83,101,108,101,99,116,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,116,116,114,105,98,117,116,101,46,10,0,0,0,0,0,0,0,0,84,111,109,98,32,111,102,32,116,104,101,32,79,118,101,114,108,111,114,100,0,0,0,0,115,104,97,100,101,114,115,0,100,117,97,108,97,110,97,108,111,103,0,0,0,0,0,0,115,117,98,116,114,97,99,116,0,0,0,0,0,0,0,0,79,117,116,32,88,32,61,32,37,100,32,61,62,32,73,110,32,88,32,61,32,37,100,10,0,0,0,0,0,0,0,0,82,67,84,82,76,0,0,0,115,116,97,114,116,100,101,109,111,115,0,0,0,0,0,0,83,116,97,114,116,0,0,0,115,99,97,108,101,95,116,121,112,101,95,121,37,117,0,0,114,49,109,55,0,0,0,0,106,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,97,100,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,89,83,84,69,77,95,68,73,82,69,67,84,79,82,89,58,32,34,37,115,34,46,10,0,0,0,0,0,114,98,0,0,0,0,0,0,110,111,116,97,114,103,101,116,32,79,78,10,0,0,0,0,105,110,112,117,116,95,100,101,118,105,99,101,95,112,37,117,0,0,0,0,0,0,0,0,32,32,37,117,32,45,62,32,37,117,10,0,0,0,0,0,103,105,118,101,0,0,0,0,89,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,95,120,37,117,0,0,84,101,109,112,108,101,32,111,102,32,80,97,105,110,0,0,106,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,101,115,99,97,112,101,0,0,115,107,105,108,108,0,0,0,105,110,112,117,116,95,100,112,97,100,95,101,109,117,108,97,116,105,111,110,95,112,37,117,0,0,0,0,0,0,0,0,115,97,118,101,0,0,0,0,88,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,37,117,0,0,0,0,114,49,109,54,0,0,0,0,115,99,111,112,101,0,0,0,115,112,97,99,101,0,0,0,99,117,115,116,111,109,95,98,103,109,95,101,110,97,98,108,101,0,0,0,0,0,0,0,118,105,100,101,111,95,121,115,99,97,108,101,0,0,0,0,48,0,0,0,0,0,0,0,37,115,58,32,98,97,100,32,110,111,100,101,32,110,117,109,98,101,114,0,0,0,0,0,108,111,97,100,0,0,0,0,37,115,10,0,0,0,0,0,66,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,112,97,114,115,101,32,115,104,97,100,101,114,32,115,111,117,114,99,101,32,40,37,115,41,46,10,0,0,0,0,0,0,0,0,84,111,119,101,114,115,32,111,102,32,87,114,97,116,104,0,110,111,100,101,118,105,99,101,0,0,0,0,0,0,0,0,97,108,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,112,105,120,101,108,32,99,111,110,118,101,114,116,101,114,46,10,0,0,0,37,115,32,0,0,0,0,0,37,115,58,32,102,114,101,101,100,32,97,32,112,111,105,110,116,101,114,32,119,105,116,104,111,117,116,32,90,79,78,69,73,68,0,0,0,0,0,0,115,99,114,101,101,110,95,111,114,105,101,110,116,97,116,105,111,110,0,0,0,0,0,0,87,97,100,32,102,105,108,101,32,37,115,32,100,111,101,115,110,39,116,32,104,97,118,101,32,87,65,68,50,32,105,100,0,0,0,0,0,0,0,0,109,111,117,115,101,0,0,0,102,105,108,101,0,0,0,0,112,105,110,103,0,0,0,0,65,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,73,110,118,97,108,105,100,32,119,114,97,112,112,105,110,103,32,116,121,112,101,32,37,115,46,32,86,97,108,105,100,32,111,110,101,115,32,97,114,101,58,32,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,32,40,100,101,102,97,117,108,116,41,44,32,99,108,97,109,112,95,116,111,95,101,100,103,101,44,32,114,101,112,101,97,116,32,97,110,100,32,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,100,101,102,97,117,108,116,46,10,0,0,0,114,49,109,53,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,32,82,101,119,105,110,100,105,110,103,32,119,105,108,108,32,98,101,32,100,105,115,97,98,108,101,100,46,10,0,0,99,116,114,108,0,0,0,0,48,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,66,108,111,99,107,105,110,103,32,83,82,65,77,32,111,118,101,114,119,114,105,116,101,46,10,0,0,0,0,80,108,97,121,105,110,103,32,114,101,103,105,115,116,101,114,101,100,32,118,101,114,115,105,111,110,46,10,0,0,0,0,97,117,100,105,111,95,109,117,116,101,0,0,0,0,0,0,104,107,110,105,103,104,116,47,104,105,116,46,119,97,118,0,72,117,110,107,95,72,105,103,104,65,108,108,111,99,58,32,102,97,105,108,101,100,32,111,110,32,37,105,32,98,121,116,101,115,10,0,0,0,0,0,98,101,97,109,32,108,105,115,116,32,111,118,101,114,102,108,111,119,33,10,0,0,0,0,99,108,95,98,111,98,117,112,0,0,0,0,0,0,0,0,107,105,99,107,0,0,0,0,37,115,0,0,0,0,0,0,82,105,103,104,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,112,97,116,104,32,116,111,32,116,101,120,116,117,114,101,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,103,111,100,0,0,0,0,0,67,97,118,101,32,111,102,32,68,101,97,116,104,0,0,0,71,111,116,32,97,32,78,97,78,32,111,114,105,103,105,110,32,111,110,32,37,115,10,0,112,97,99,107,101,116,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,0,97,112,112,101,110,100,99,111,110,102,105,103,0,0,0,0,114,49,109,52,0,0,0,0,100,97,116,97,0,0,0,0,115,104,105,102,116,0,0,0,115,111,117,110,100,105,110,102,111,0,0,0,0,0,0,0,49,53,48,0,0,0,0,0,2,3,7,0,0,0,0,0,37,115,47,37,115,0,0,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,51,68,79,69,83,0,0,0,0,0,0,0,37,99,37,115,10,0,0,0,77,86,80,77,97,116,114,105,120,0,0,0,0,0,0,0,105,110,118,95,108,105,103,104,116,110,103,0,0,0,0,0,100,111,101,115,110,39,116,32,101,120,105,115,116,0,0,0,115,116,97,116,101,95,115,108,111,116,0,0,0,0,0,0,54,48,0,0,0,0,0,0,114,95,97,109,98,105,101,110,116,0,0,0,0,0,0,0,76,79,65,68,32,72,73,83,84,79,82,89,0,0,0,0,37,115,46,122,105,112,0,0,109,95,121,97,119,0,0,0,125,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,117,110,105,102,111,114,109,32,97,110,100,32,97,116,116,114,105,98,32,112,114,101,102,105,120,58,32,37,115,10,0,0,0,69,81,95,83,0,0,0,0,112,114,101,115,112,97,119,110,0,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,76,101,102,116,0,0,0,0,44,32,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,97,100,100,114,101,115,115,32,97,115,115,105,103,110,101,100,32,116,111,32,115,101,109,97,110,116,105,99,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,32,116,111,32,34,37,115,34,46,32,67,104,101,99,107,32,112,101,114,109,105,115,115,105,111,110,115,46,10,0,0,0,0,78,69,84,95,83,101,110,100,77,101,115,115,97,103,101,58])
.concat([32,100,105,115,99,111,110,110,101,99,116,101,100,32,115,111,99,107,101,116,10,0,0,0,63,62,10,0,0,0,0,0,114,101,99,111,114,100,105,110,103,32,116,111,32,37,115,46,10,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,102,97,116,112,118,115,0,0,99,111,110,102,105,103,0,0,74,117,100,103,101,109,101,110,116,32,67,97,108,108,0,0,114,115,104,105,102,116,0,0,52,0,0,0,0,0,0,0,115,111,117,110,100,95,109,111,100,101,0,0,0,0,0,0,98,101,103,105,110,0,0,0,68,111,119,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,46,10,0,68,79,78,69,0,0,0,0,103,97,109,101,98,111,121,0,82,101,116,114,111,65,114,99,104,58,32,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,114,49,109,51,0,0,0,0,42,37,105,0,0,0,0,0,104,111,109,101,0,0,0,0,37,115,58,32,73,110,118,97,108,105,100,32,35,32,111,102,32,102,114,97,109,101,115,58,32,37,100,0,0,0,0,0,67,111,117,108,100,110,39,116,32,108,111,97,100,32,37,115,10,0,0,0,0,0,0,0,99,117,114,114,101,110,116,95,114,101,115,111,108,117,116,105,111,110,95,105,100,0,0,0,115,112,97,119,110,0,0,0,85,112,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,46,10,0,0,118,101,114,98,111,115,101,0,68,114,101,97,100,32,80,111,114,116,97,108,0,0,0,0,101,110,100,0,0,0,0,0,109,101,110,117,95,109,97,105,110,0,0,0,0,0,0,0,48,46,55,0,0,0,0,0,112,97,117,115,101,0,0,0,99,108,95,117,112,115,112,101,101,100,0,0,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,0,0,0,100,111,119,110,0,0,0,0,124,0,0,0,0,0,0,0,91,82,80,78,71,93,58,32,69,114,114,111,114,32,105,110,32,108,105,110,101,32,37,100,46,10,0,0,0,0,0,0,95,99,108,95,110,97,109,101,0,0,0,0,0,0,0,0,68,80,97,100,32,69,109,117,108,97,116,105,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,101,120,116,101,114,110,97,108,32,115,111,117,114,99,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,49,48,48,0,0,0,0,0,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,114,49,109,50,0,0,0,0,100,101,108,0,0,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,79,69,83,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,76,67,84,82,76,0,0,0,103,108,115,108,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,37,115,10,0,0,107,105,108,108,0,0,0,0,115,118,95,97,105,109,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,111,117,108,100,110,39,116,32,105,110,105,116,32,102,111,110,116,32,114,101,110,100,101,114,101,114,46,10,0,0,0,0,0,0,0,68,101,118,105,99,101,32,84,121,112,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,115,97,118,101,0,0,0,0,68,101,118,105,97,110,116,39,115,32,68,111,109,97,105,110,0,0,0,0,0,0,0,0,105,110,115,101,114,116,0,0,97,110,117,109,95,37,105,0,67,76,95,80,97,114,115,101,83,116,97,114,116,83,111,117,110,100,80,97,99,107,101,116,58,32,101,110,116,32,61,32,37,105,0,0,0,0,0,0,37,115,58,32,105,110,102,105,110,105,116,101,32,99,121,99,108,101,0,0,0,0,0,0,37,115,58,32,116,111,111,32,109,97,110,121,32,112,111,105,110,116,115,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,80,69,82,70,79,82,77,65,78,67,69,95,76,69,86,69,76,58,32,37,117,46,10,0,0,0,0,0,0,110,111,116,97,114,103,101,116,32,79,70,70,10,0,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,70,66,79,32,116,97,114,103,101,116,115,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,70,66,79,46,10,0,0,119,0,0,0,0,0,0,0,99,111,108,111,114,0,0,0,114,101,109,97,112,0,0,0,112,97,114,116,105,99,108,101,115,0,0,0,0,0,0,0,68,101,118,105,99,101,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,104,101,108,112,0,0,0,0,114,49,109,49,0,0,0,0,116,97,98,0,0,0,0,0,100,101,118,101,108,111,112,101,114,0,0,0,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,0,0,0,116,101,108,108,0,0,0,0,80,108,97,121,101,114,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,109,101,110,117,0,0,0,0,83,112,108,105,116,32,68,101,99,105,115,105,111,110,0,0,107,112,95,101,110,116,101,114,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,37,115,58,32,66,97,100,32,101,110,116,105,116,121,32,116,121,112,101,32,37,100,0,0,105,110,102,111,95,109,115,103,95,101,110,97,98,108,101,0,37,115,32,34,37,115,34,10,0,0,0,0,0,0,0,0,118,105,100,101,111,95,120,115,99,97,108,101,0,0,0,0,99,103,112,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,118,101,114,108,97,121,32,105,110,116,101,114,102,97,99,101,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,118,105,100,101,111,32,100,114,105,118,101,114,46,10,0,82,101,116,114,111,65,114,99,104,58,32,83,105,110,99,32,114,101,115,97,109,112,108,101,114,32,91,67,93,10,0,0,48,0,0,0,0,0,0,0,115,97,121,95,116,101,97,109,0,0,0,0,0,0,0,0,32,32,0,0,0,0,0,0,46,112,110,103,0,0,0,0,79,118,101,114,108,97,121,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,121,32,97,116,116,114,58,32,37,117,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,114,119,101,98,97,117,100,105,111,0,0,0,0,0,0,0,83,101,112,32,49,53,32,50,48,49,51,0,0,0,0,0,68,101,97,116,104,109,97,116,99,104,32,65,114,101,110,97,0,0,0,0,0,0,0,0,101,110,116,101,114,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,102,117,108,108,115,99,114,101,101,110,10,0,0,101,120,101,99,105,110,103,32,37,115,10,0,0,0,0,0,116,114,105,112,108,101,95,98,117,102,102,101,114,105,110,103,95,101,110,97,98,108,101,0,101,120,101,0,0,0,0,0,115,97,121,0,0,0,0,0,79,118,101,114,108,97,121,32,79,112,97,99,105,116,121,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,120,32,97,116,116,114,58,32,37,117,10,0,48,0,0,0,0,0,0,0,66,117,105,108,116,58,32,37,115,10,0,0,0,0,0,0,70,105,110,97,108,32,76,101,118,101,108,0,0,0,0,0,82,71,85,73,32,109,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,34,115,104,97,100,101,114,115,34,32,112,97,114,97,109,46,10,0,0,0,0,0,0,79,117,116,32,89,32,61,32,37,100,32,61,62,32,73,110,32,89,32,61,32,37,100,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,103,97,109,109,97,95,99,111,114,114,101,99,116,105,111,110,0,0,0,0,0,0,0,0,37,115,58,32,98,97,100,32,109,97,114,107,32,37,105,0,37,115,58,32,98,97,100,32,116,121,112,101,0,0,0,0,48,46,54,0,0,0,0,0,118,101,114,115,105,111,110,0,99,108,95,98,97,99,107,115,112,101,101,100,0,0,0,0,79,118,101,114,108,97,121,32,80,114,101,115,101,116,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,32,97,116,116,114,58,32,37,117,10,0,0,0,115,116,97,116,117,115,0,0,71,111,116,32,97,32,78,97,78,32,118,101,108,111,99,105,116,121,32,111,110,32,37,115,10,0,0,0,0,0,0,0,37,115,58,32,85,110,107,110,111,119,110,32,112,114,111,116,111,99,111,108,32,118,101,114,115,105,111,110,32,40,37,100,41,10,0,0,0,0,0,0,77,85,76,95,70,0,0,0,52,46,50,46,49,32,67,111,109,112,97,116,105,98,108,101,32,67,108,97,110,103,32,51,46,50,32,40,116,97,103,115,47,82,69,76,69,65,83,69,95,51,50,47,102,105,110,97,108,41,0,0,0,0,0,0,84,104,101,32,69,108,100,101,114,32,87,111,114,108,100,0,109,97,114,107,0,0,0,0,109,101,110,117,95,116,111,103,103,108,101,0,0,0,0,0,112,108,97,121,101,114,0,0,115,111,117,110,100,108,105,115,116,0,0,0,0,0,0,0,99,108,95,112,105,116,99,104,115,112,101,101,100,0,0,0,5,5,4,0,0,0,0,0,113,117,97,107,101,48,48,46,112,99,120,0,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,10,10,29,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,30,31,10,10,0,0,0,0,0,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,48,46,57,51,0,0,0,0,105,110,118,95,115,114,108,97,117,110,99,104,0,0,0,0,101,120,105,115,116,115,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,114,95,100,114,97,119,102,108,97,116,0,0,0,0,0,0,77,69,78,85,32,37,115,0,37,117,120,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,99,111,110,102,105,103,32,102,105,108,101,58,32,37,115,46,10,0,0,0,123,10,0,0,0,0,0,0,48,46,48,50,50,0,0,0,112,114,101,102,105,120,0,0,69,81,95,86,0,0,0,0,110,111,99,108,105,112,0,0,39,37,53,46,49,102,32,37,53,46,49,102,32,37,53,46,49,102,39,0,0,0,0,0,83,121,115,116,101,109,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,114,101,99,116,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,37,117,59,0,0,0,0,0,37,115,58,32,100,105,115,99,111,110,110,101,99,116,101,100,32,115,111,99,107,101,116,10,0,0,0,0,0,0,0,0,60,63,120,109,108,0,0,0,46,100,101,109,0,0,0,0,100,97,116,97,98,97,115,101,0,0,0,0,0,0,0,0,42,37,105,0,0,0,0,0,119,98,0,0,0,0,0,0,67,108,97,110,103,47,76,76,86,77,32,40,37,115,41,32,37,117,45,98,105,116,10,0,78,101,116,104,101,114,119,111,114,108,100,0,0,0,0,0,71,114,97,98,32,109,111,117,115,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,51,48,48,0,0,0,0,0,114,0,0,0,0,0,0,0,99,111,109,112,97,116,47,99,111,109,112,97,116,46,99,0,108,111,99,97,108,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,99,111,110,102,105,103,46,32,65,115,115,117,109,105,110,103,32,115,121,115,116,101,109,32,100,105,114,101,99,116,111,114,121,32,105,115,32,115,97,109,101,32,102,111,108,100,101,114,32,97,115,32,103,97,109,101,58,32,34,37,115,34,46,10,0,0,0,0,0,124,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,0,0,0,37,115,58,32,98,97,100,32,109,111,100,101,108,0,0,0,110,97,109,101,0,0,0,0,79,118,101,114,108,97,121,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,10,67,111,109,112,105,108,101,114,58,32,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,73,110,105,116,105,110,103,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,119,105,116,104,32,115,105,122,101,58,32,37,117,32,77,66,10,0,0,0,0,0,0,82,101,97,108,109,32,111,102,32,66,108,97,99,107,32,77,97,103,105,99,0,0,0,0,103,114,97,98,95,109,111,117,115,101,95,116,111,103,103,108,101,0,0,0,0,0,0,0,98,109,112,0,0,0,0,0,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,114,101,99,111,110,110,101,99,116,0,0,0,0,0,0,0,83,97,118,101,102,105,108,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,0,0,110,101,116,95,109,101,115,115,97,103,101,116,105,109,101,111,117,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,97,32,100,105,102,102,101,114,101,110,116,32,118,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,116,104,97,110,32,116,104,105,115,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,68,111,111,109,101,100,32,68,105,109,101,110,115,105,111,110,0,0,0,0,0,0,0,0,68,105,115,107,32,110,101,120,116,0,0,0,0,0,0,0,116,111,103,103,108,101,109,101,110,117,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,85,115,105,110,103,32,82,88,77,76,32,97,115,32,100,114,111,112,32,105,110,32,102,111,114,32,108,105,98,120,109,108,50,46,32,66,101,104,97,118,105,111,114,32,109,105,103,104,116,32,98,101,32,118,101,114,121,32,98,117,103,103,121,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,85,112,32,68,45,112,97,100,0,0,0,0,0,0,0,0,99,111,110,110,101,99,116,0,83,97,118,101,115,116,97,116,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,102,114,97,109,101,32,99,111,117,110,116,32,109,111,100,32,97,116,116,114,58,32,37,117,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,65,80,73,58,32,37,117,10,0,0,0,0,87,101,108,99,111,109,101,32,116,111,32,81,117,97,107,101,0,0,0,0,0,0,0,0,100,105,115,107,95,110,101,120,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,46,115,116,97,116,101,0,0,82,65,76,84,0,0,0,0,85,78,78,65,77,69,68,0,99,104,97,110,103,101,108,101,118,101,108,0,0,0,0,0,83,104,97,100,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,65,80,73,58,32,37,117,10,0,84,104,101,32,68,97,114,107,32,90,111,110,101,0,0,0,68,105,115,107,32,101,106,101,99,116,32,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,72,85,84,68,79,87,78,46,10,0,0,0,103,111,100,109,111,100,101,32,79,78,10,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,109,97,112,0,0,0,0,0,66,114,111,119,115,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,0,0,0,0,0,0,0,114,101,115,101,116,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,108,97,115,116,32,115,116,97,116,101,32,115,108,111,116,58,32,35,37,117,10,0,0,100,109,54,0,0,0,0,0,100,105,115,107,95,101,106,101,99,116,95,116,111,103,103,108,101,0,0,0,0,0,0,0,110,111,101,120,105,116,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,0,114,101,115,116,97,114,116,0,68,101,98,117,103,32,73,110,102,111,32,77,101,115,115,97,103,101,115,0,0,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,0,59,32,0,0,0,0,0,0,65,117,116,111,45,108,111,97,100,105,110,103,32,115,97,118,101,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,32,37,115,46,0,0,0,0,84,104,101,32,67,105,115,116,101,114,110,0,0,0,0,0,79,118,101,114,108,97,121,32,110,101,120,116,0,0,0,0,10,0,0,0,0,0,0,0,114,119,101,98,105,110,112,117,116,0,0,0,0,0,0,0,46,115,114,109,0,0,0,0,34,37,115,34,32,105,115,32,34,37,115,34,10,0,0,0,61,61,61,32,67,111,110,102,105,103,32,101,110,100,32,61,61,61,10,0,0,0,0,0,37,120,0,0,0,0,0,0,102,108,121,0,0,0,0,0,67,111,110,102,105,103,32,83,97,118,101,32,79,110,32,69,120,105,116,0,0,0,0,0,111,117,116,115,99,97,108,101,95,121,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,97,117,116,111,32,115,97,118,101,115,116,97,116,101,32,105,110,58,32,37,115,10,0,100,109,53,0,0,0,0,0,111,118,101,114,108,97,121,95,110,101,120,116,0,0,0,0,115,97,121,32,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,37,117,120,37,117,10,0,0,0,0,0,0,0,99,111,117,108,100,110,39,116,32,101,120,101,99,32,37,115,10,0,0,0,0,0,0,0,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,112,118,115,99,97,99,104,101,0,0,0,0,0,0,0,0,46,37,115,0,0,0,0,0,110,111,116,97,114,103,101,116,0,0,0,0,0,0,0,0,82,101,119,105,110,100,32,71,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,111,117,116,115,99,97,108,101,95,120,0,0,0,0,0,0,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,0,84,104,101,32,66,97,100,32,80,108,97,99,101,0,0,0,86,111,108,117,109,101,32,45,0,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,0,99,109,100,108,105,110,101,0,99,111,110,102,105,103,95,115,97,118,101,95,111,110,95,101,120,105,116,0,0,0,0,0,117,110,107,110,111,119,110,0,112,114,111,103,115,47,98,101,97,109,46,109,100,108,0,0,99,108,95,98,111,98,99,121,99,108,101,0,0,0,0,0,103,111,100,0,0,0,0,0,99,108,95,102,111,114,119,97,114,100,115,112,101,101,100,0,82,101,119,105,110,100,0,0,111,117,116,115,99,97,108,101,0,0,0,0,0,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,32,99,104,97,114,10,0,0,0,0,0,0,0,37,115,58,32,110,111,32,102,114,101,101,32,99,108,105,101,110,116,115,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,10,0,0,0,0,100,109,52,0,0,0,0,0,76,73,83,84,0,0,0,0,118,111,108,117,109,101,95,100,111,119,110,0,0,0,0,0,115,116,111,112,115,111,117,110,100,0,0,0,0,0,0,0,49,52,48,0,0,0,0,0,37,115,32,37,105,10,0,0,116,117,114,116,108,101,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,0,0,0,105,110,118,95,114,108,97,117,110,99,104,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,81,117,101,114,121,105,110,103,32,71,76,32,101,120,116,101,110,115,105,111,110,58,32,37,115,32,61,62,32,37,115,10,0,0,0,0,0,106,111,121,112,97,100,95,97,117,116,111,99,111,110,102,105,103,95,100,105,114,0,0,0,114,95,100,114,97,119,118,105,101,119,109,111,100,101,108,0,83,72,65,68,69,82,32,37,115,0,0,0,0,0,0,0,68,111,110,39,116,32,99,97,114,101,0,0,0,0,0,0,37,115,10,0,0,0,0,0,109,95,112,105,116,99,104,0,71,76,69,83,50,0,0,0,69,81,95,70,0,0,0,0,113,117,105,116,0,0,0,0,37,115,0,0,0,0,0,0,103,102,120,47,102,105,110,97,108,101,46,108,109,112,0,0,78,111,32,111,112,116,105,111,110,115,32,97,118,97,105,108,97,98,108,101,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,115,105,122,101,95,121,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,115,97,118,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,46,10,0,0,0,10,0,0,0,0,0,0,0,45,45,62,0,0,0,0,0,109,97,112,32,37,115,0,0,37,115,58,32,37,100,32,97,108,108,111,99,97,116,101,100,32,102,111,114,32,118,105,115,100,97,116,97,44,32,98,117,116,32,109,111,100,101,108,32,37,115,32,104,97,115,32,37,100,32,108,101,97,102,115,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,0,0,0,0,0,0,0,0,84,104,101,32,65,98,97,110,100,111,110,101,100,32,66,97,115,101,0,0,0,0,0,0,86,111,108,117,109,101,32,43,0,0,0,0,0,0,0,0,116,111,103,103,108,101,99,111,110,115,111,108,101,0,0,0,105,110,112,117,116,95,97,117,116,111,100,101,116,101,99,116,95,101,110,97,98,108,101,0,115,116,97,116,117,115,0,0,103,102,120,47,105,110,116,101,114,46,108,109,112,0,0,0,82,97,116,101,32,67,111,110,116,114,111,108,32,68,101,108,116,97,0,0,0,0,0,0,115,105,122,101,95,120,0,0,105,110,105,116,95,109,111,118,105,101,40,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,101,114,102,111,114,109,32,105,110,105,116,105,97,108,32,115,101,114,105,97,108,105,122,97,116,105,111,110,32,102,111,114,32,114,101,119,105,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,32,71,80,85,32,114,101,110,100,101,114,105,110,103,32,105,115,32,117,115,101,100,32,97,110,100,32,114,101,97,100,95,118,105,101,119,112,111,114,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,117,109,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,0,0,0,0,8,14,1,0,40,9,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,97,0,0,0,0,0,0,90,95,82,101,97,108,108,111,99,0,0,0,0,0,0,0,90,95,77,97,108,108,111,99,0,0,0,0,0,0,0,0,90,95,70,114,101,101,0,0,90,95,67,104,101,99,107,72,101,97,112,0,0,0,0,0,87,114,105,116,101,68,101,115,116,0,0,0,0,0,0,0,87,95,76,111,97,100,87,97,100,70,105,108,101,0,0,0,87,95,71,101,116,76,117,109,112,105,110,102,111,0,0,0,83,95,83,116,97,114,116,117,112,0,0,0,0,0,0,0,83,95,76,111,99,97,108,83,111,117,110,100,0,0,0,0,83,95,70,105,110,100,78,97,109,101,0,0,0,0,0,0,83,90,95,71,101,116,83,112,97,99,101,0,0,0,0,0,83,86,95,87,114,105,116,101,83,111,117,110,100,78,117,109,0,0,0,0,0,0,0,0,83,86,95,87,114,105,116,101,77,111,100,101,108,73,110,100,101,120,0,0,0,0,0,0,83,86,95,84,111,117,99,104,76,105,110,107,115,0,0,0,83,86,95,83,116,97,114,116,83,111,117,110,100,0,0,0,83,86,95,82,101,99,117,114,115,105,118,101,72,117,108,108,67,104,101,99,107,0,0,0,83,86,95,82,101,97,100,67,108,105,101,110,116,77,101,115,115,97,103,101,0,0,0,0,83,86,95,80,104,121,115,105,99,115,95,67,108,105,101,110,116,0,0,0,0,0,0,0,83,86,95,80,104,121,115,105,99,115,0,0,0,0,0,0,83,86,95,77,111,100,101,108,73,110,100,101,120,0,0,0,83,86,95,72,117,108,108,80,111,105,110,116,67,111,110,116,101,110,116,115,0,0,0,0,83,86,95,70,108,121,77,111,118,101,0,0,0,0,0,0,83,86,95,67,114,101,97,116,101,65,114,101,97,78,111,100,101,0,0,0,0,0,0,0,83,86,95,67,104,101,99,107,70,111,114,78,101,119,67,108,105,101,110,116,115,0,0,0,83,84,114,101,101,95,83,116,97,99,107,73,110,105,116,0,83,67,82,95,83,99,114,101,101,110,83,104,111,116,95,102,0,0,0,0,0,0,0,0,82,95,84,101,120,116,117,114,101,65,110,105,109,97,116,105,111,110,0,0,0,0,0,0,82,95,83,116,111,114,101,69,102,114,97,103,115,0,0,0,82,95,83,101,116,117,112,65,110,100,68,114,97,119,83,112,114,105,116,101,0,0,0,0,82,95,82,101,110,100,101,114,86,105,101,119,95,0,0,0,82,95,68,114,97,119,83,112,114,105,116,101,0,0,0,0,82,95,65,108,105,97,115,83,101,116,117,112,83,107,105,110,0,0,0,0,0,0,0,0,82,95,65,108,105,97,115,83,101,116,117,112,70,114,97,109,101,0,0,0,0,0,0,0,82,95,65,108,105,97,115,68,114,97,119,77,111,100,101,108,0,0,0,0,0,0,0,0,80,82,95,76,111,97,100,80,114,111,103,115,0,0,0,0,80,82,95,71,101,116,83,116,114,105,110,103,0,0,0,0,80,82,95,69,120,101,99,117,116,101,80,114,111,103,114,97,109,0,0,0,0,0,0,0,80,82,95,67,104,101,99,107,69,109,112,116,121,83,116,114,105,110,103,0,0,0,0,0,80,70,95,115,111,117,110,100,0,0,0,0,0,0,0,0,80,70,95,115,101,116,115,112,97,119,110,112,97,114,109,115,0,0,0,0,0,0,0,0,80,70,95,112,114,101,99,97,99,104,101,95,115,111,117,110,100,0,0,0,0,0,0,0,80,70,95,112,114,101,99,97,99,104,101,95,109,111,100,101,108,0,0,0,0,0,0,0,80,70,95,87,114,105,116,101,83,111,117,110,100,78,117,109,95,83,116,97,116,105,99,0,80,70,95,86,97,114,83,116,114,105,110,103,0,0,0,0,80,70,95,70,105,110,100,0,78,85,77,95,70,79,82,95,69,68,73,67,84,0,0,0,78,69,84,95,83,101,110,100,77,101,115,115,97,103,101,0,78,69,84,95,73,110,105,116,0,0,0,0,0,0,0,0,78,69,84,95,71,101,116,77,101,115,115,97,103,101,0,0,78,69,84,95,70,114,101,101,81,83,111,99,107,101,116,0,77,111,100,95,80,111,105,110,116,73,110,76,101,97,102,0,77,111,100,95,76,111,97,100,86,101,114,116,101,120,101,115,0,0,0,0,0,0,0,0,77,111,100,95,76,111,97,100,84,101,120,105,110,102,111,0,77,111,100,95,76,111,97,100,83,117,114,102,101,100,103,101,115,0,0,0,0,0,0,0,77,111,100,95,76,111,97,100,83,117,98,109,111,100,101,108,115,0,0,0,0,0,0,0,77,111,100,95,76,111,97,100,83,112,114,105,116,101,77,111,100,101,108,0,0,0,0,0,77,111,100,95,76,111,97,100,83,112,114,105,116,101,71,114,111,117,112,0,0,0,0,0,77,111,100,95,76,111,97,100,80,108,97,110,101,115,0,0,77,111,100,95,76,111,97,100,78,111,100,101,115,95,66,83,80,50,57,0,0,0,0,0,77,111,100,95,76,111,97,100,78,111,100,101,115,95,66,83,80,50,0,0,0,0,0,0,77,111,100,95,76,111,97,100,77,111,100,101,108,0,0,0,77,111,100,95,76,111,97,100,77,97,114,107,115,117,114,102,97,99,101,115,95,66,83,80,50,57,0,0,0,0,0,0,77,111,100,95,76,111,97,100,77,97,114,107,115,117,114,102,97,99,101,115,95,66,83,80,50,0,0,0,0,0,0,0,77,111,100,95,76,111,97,100,76,101,97,102,115,95,66,83,80,50,57,0,0,0,0,0,77,111,100,95,76,111,97,100,76,101,97,102,115,95,66,83,80,50,0,0,0,0,0,0,77,111,100,95,76,111,97,100,70,97,99,101,115,95,66,83,80,50,57,0,0,0,0,0,77,111,100,95,76,111,97,100,70,97,99,101,115,95,66,83,80,50,0,0,0,0,0,0,77,111,100,95,76,111,97,100,69,100,103,101,115,95,66,83,80,50,57,0,0,0,0,0,77,111,100,95,76,111,97,100,69,100,103,101,115,95,66,83,80,50,0,0,0,0,0,0,77,111,100,95,76,111,97,100,67,108,105,112,110,111,100,101,115,95,66,83,80,50,57,0,77,111,100,95,76,111,97,100,67,108,105,112,110,111,100,101,115,95,66,83,80,50,0,0,77,111,100,95,76,111,97,100,66,114,117,115,104,77,111,100,101,108,0,0,0,0,0,0,77,111,100,95,76,111,97,100,65,108,108,83,107,105,110,115,0,0,0,0,0,0,0,0,77,111,100,95,76,111,97,100,65,108,105,97,115,83,107,105,110,71,114,111,117,112,0,0,77,111,100,95,76,111,97,100,65,108,105,97,115,77,111,100,101,108,0,0,0,0,0,0,77,111,100,95,76,111,97,100,65,108,105,97,115,71,114,111,117,112,0,0,0,0,0,0,77,111,100,95,70,105,110,100,78,97,109,101,0,0,0,0,77,111,100,95,69,120,116,114,97,100,97,116,97,0,0,0,77,111,100,95,65,100,100,76,101,97,102,66,105,116,115,0,77,101,109,111,114,121,95,73,110,105,116,0,0,0,0,0,76,111,111,112,95,83,101,110,100,77,101,115,115,97,103,101,0,0,0,0,0,0,0,0,72,117,110,107,95,84,101,109,112,65,108,108,111,99,69,120,116,101,110,100,0,0,0,0,72,117,110,107,95,80,114,105,110,116,0,0,0,0,0,0,72,117,110,107,95,72,105,103,104,65,108,108,111,99,78,97,109,101,0,0,0,0,0,0,72,117,110,107,95,70,114,101,101,84,111,76,111,119,77,97,114,107,0,0,0,0,0,0,72,117,110,107,95,70,114,101,101,84,111,72,105,103,104,77,97,114,107,0,0,0,0,0,72,117,110,107,95,67,104,101,99,107,0,0,0,0,0,0,72,117,110,107,95,65,108,108,111,99,78,97,109,101,0,0,72,111,115,116,95,83,104,117,116,100,111,119,110,83,101,114,118,101,114,0,0,0,0,0,72,111,115,116,95,69,114,114,111,114,0,0,0,0,0,0,72,111,115,116,95,69,110,100,71,97,109,101,0,0,0,0,70,108,111,111,114,68,105,118,77,111,100,0,0,0,0,0,69,68,95,80,97,114,115,101,71,108,111,98,97,108,115,0,69,68,95,80,97,114,115,101,69,100,105,99,116,0,0,0,69,68,95,76,111,97,100,70,114,111,109,70,105,108,101,0,69,68,95,65,108,108,111,99,0,0,0,0,0,0,0,0,69,68,73,67,84,95,78,85,77,0,0,0,0,0,0,0,68,114,97,119,95,84,114,97,110,115,80,105,99,84,114,97,110,115,108,97,116,101,0,0,68,114,97,119,95,84,114,97,110,115,80,105,99,0,0,0,68,114,97,119,95,84,105,108,101,67,108,101,97,114,0,0,68,114,97,119,95,80,105,99,0,0,0,0,0,0,0,0,68,114,97,119,95,67,97,99,104,101,80,105,99,0,0,0,68,95,83,67,65,108,108,111,99,0,0,0,0,0,0,0,68,95,67,104,101,99,107,67,97,99,104,101,71,117,97,114,100,0,0,0,0,0,0,0,67,109,100,95,83,101,116,67,111,109,112,108,101,116,105,111,110,0,0,0,0,0,0,0,67,109,100,95,65,100,100,67,111,109,109,97,110,100,0,0,67,98,117,102,95,73,110,115,101,114,116,84,101,120,116,0,67,98,117,102,95,69,120,101,99,117,116,101,0,0,0,0,67,98,117,102,95,65,100,100,84,101,120,116,0,0,0,0,67,97,99,104,101,95,85,110,108,105,110,107,76,82,85,0,67,97,99,104,101,95,84,114,121,65,108,108,111,99,0,0,67,97,99,104,101,95,77,97,107,101,76,82,85,0,0,0,67,97,99,104,101,95,70,114,101,101,0,0,0,0,0,0,67,97,99,104,101,95,65,108,108,111,99,80,97,100,100,101,100,0,0,0,0,0,0,0,67,79,77,95,76,111,97,100,70,105,108,101,0,0,0,0,67,76,95,82,101,97,100,83,111,117,110,100,78,117,109,95,83,116,97,116,105,99,0,0,67,76,95,82,101,97,100,83,111,117,110,100,78,117,109,0,67,76,95,82,101,97,100,77,111,100,101,108,73,110,100,101,120,0,0,0,0,0,0,0,67,76,95,82,101,97,100,77,111,100,101,108,70,114,97,109,101,0,0,0,0,0,0,0,67,76,95,80,97,114,115,101,84,69,110,116,0,0,0,0,67,76,95,80,97,114,115,101,83,101,114,118,101,114,77,101,115,115,97,103,101,0,0,0,67,76,95,78,101,119,84,114,97,110,115,108,97,116,105,111,110,0,0,0,0,0,0,0,67,76,95,75,101,101,112,97,108,105,118,101,77,101,115,115,97,103,101,0,0,0,0,0,66,79,80,83,95,69,114,114,111,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,47,138,66,145,68,55,113,207,251,192,181,165,219,181,233,91,194,86,57,241,17,241,89,164,130,63,146,213,94,28,171,152,170,7,216,1,91,131,18,190,133,49,36,195,125,12,85,116,93,190,114,254,177,222,128,167,6,220,155,116,241,155,193,193,105,155,228,134,71,190,239,198,157,193,15,204,161,12,36,111,44,233,45,170,132,116,74,220,169,176,92,218,136,249,118,82,81,62,152,109,198,49,168,200,39,3,176,199,127,89,191,243,11,224,198,71,145,167,213,81,99,202,6,103,41,41,20,133,10,183,39,56,33,27,46,252,109,44,77,19,13,56,83,84,115,10,101,187,10,106,118,46,201,194,129,133,44,114,146,161,232,191,162,75,102,26,168,112,139,75,194,163,81,108,199,25,232,146,209,36,6,153,214,133,53,14,244,112,160,106,16,22,193,164,25,8,108,55,30,76,119,72,39,181,188,176,52,179,12,28,57,74,170,216,78,79,202,156,91,243,111,46,104,238,130,143,116,111,99,165,120,20,120,200,132,8,2,199,140,250,255,190,144,235,108,80,164,247,163,249,190,242,120,113,198,103,230,9,106,133,174,103,187,114,243,110,60,58,245,79,165,127,82,14,81,140,104,5,155,171,217,131,31,25,205,224,91,89,1,0,0,0,0,0,0,31,2,0,0,0,0,0,0,32,0,0,0,2,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,0,0,128,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,1,0,0,0,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
, "i8", ALLOC_NONE, Runtime.GLOBAL_BASE)
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}
  function _emscripten_set_canvas_size(width, height) {
      Browser.setCanvasSize(width, height);
    }
  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop) {
      Module['noExitRuntime'] = true;
      Browser.mainLoop.runner = function() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from non-main loop sources
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        if (Module['preMainLoop']) {
          Module['preMainLoop']();
        }
        Runtime.dynCall('v', func);
        if (Module['postMainLoop']) {
          Module['postMainLoop']();
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from the main loop itself
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        Browser.mainLoop.scheduler();
      }
      if (fps && fps > 0) {
        Browser.mainLoop.scheduler = function() {
          setTimeout(Browser.mainLoop.runner, 1000/fps); // doing this each time means that on exception, we stop
        }
      } else {
        Browser.mainLoop.scheduler = function() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        }
      }
      Browser.mainLoop.scheduler();
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:35,EIDRM:36,ECHRNG:37,EL2NSYNC:38,EL3HLT:39,EL3RST:40,ELNRNG:41,EUNATCH:42,ENOCSI:43,EL2HLT:44,EDEADLK:45,ENOLCK:46,EBADE:50,EBADR:51,EXFULL:52,ENOANO:53,EBADRQC:54,EBADSLT:55,EDEADLOCK:56,EBFONT:57,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:74,EDOTDOT:76,EBADMSG:77,ENOTUNIQ:80,EBADFD:81,EREMCHG:82,ELIBACC:83,ELIBBAD:84,ELIBSCN:85,ELIBMAX:86,ELIBEXEC:87,ENOSYS:88,ENOTEMPTY:90,ENAMETOOLONG:91,ELOOP:92,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:106,EPROTOTYPE:107,ENOTSOCK:108,ENOPROTOOPT:109,ESHUTDOWN:110,ECONNREFUSED:111,EADDRINUSE:112,ECONNABORTED:113,ENETUNREACH:114,ENETDOWN:115,ETIMEDOUT:116,EHOSTDOWN:117,EHOSTUNREACH:118,EINPROGRESS:119,EALREADY:120,EDESTADDRREQ:121,EMSGSIZE:122,EPROTONOSUPPORT:123,ESOCKTNOSUPPORT:124,EADDRNOTAVAIL:125,ENETRESET:126,EISCONN:127,ENOTCONN:128,ETOOMANYREFS:129,EUSERS:131,EDQUOT:132,ESTALE:133,ENOTSUP:134,ENOMEDIUM:135,EILSEQ:138,EOVERFLOW:139,ECANCELED:140,ENOTRECOVERABLE:141,EOWNERDEAD:142,ESTRPIPE:143};
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"No message of desired type",36:"Identifier removed",37:"Channel number out of range",38:"Level 2 not synchronized",39:"Level 3 halted",40:"Level 3 reset",41:"Link number out of range",42:"Protocol driver not attached",43:"No CSI structure available",44:"Level 2 halted",45:"Deadlock condition",46:"No record locks available",50:"Invalid exchange",51:"Invalid request descriptor",52:"Exchange full",53:"No anode",54:"Invalid request code",55:"Invalid slot",56:"File locking deadlock error",57:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",74:"Multihop attempted",76:"Cross mount point (not really error)",77:"Trying to read unreadable message",80:"Given log. name not unique",81:"f.d. invalid for this operation",82:"Remote address changed",83:"Can   access a needed shared lib",84:"Accessing a corrupted shared lib",85:".lib section in a.out corrupted",86:"Attempting to link in too many libs",87:"Attempting to exec a shared library",88:"Function not implemented",90:"Directory not empty",91:"File or path name too long",92:"Too many symbolic links",95:"Operation not supported on transport endpoint",96:"Protocol family not supported",104:"Connection reset by peer",105:"No buffer space available",106:"Address family not supported by protocol family",107:"Protocol wrong type for socket",108:"Socket operation on non-socket",109:"Protocol not available",110:"Can't send after socket shutdown",111:"Connection refused",112:"Address already in use",113:"Connection aborted",114:"Network is unreachable",115:"Network interface is not configured",116:"Connection timed out",117:"Host is down",118:"Host is unreachable",119:"Connection already in progress",120:"Socket already connected",121:"Destination address required",122:"Message too long",123:"Unknown protocol",124:"Socket type not supported",125:"Address not available",126:"Connection reset by network",127:"Socket is already connected",128:"Socket is not connected",129:"Too many references",131:"Too many users",132:"Quota exceeded",133:"Stale file handle",134:"Not supported",135:"No medium (in tape drive)",138:"Illegal byte sequence",139:"Value too large for defined data type",140:"Operation canceled",141:"State not recoverable",142:"Previous owner died",143:"Streams pipe error"};
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value
      return value;
    }
  var VFS=undefined;
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path, ext) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var f = PATH.splitPath(path)[2];
        if (ext && f.substr(-1 * ext.length) === ext) {
          f = f.substr(0, f.length - ext.length);
        }
        return f;
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.filter(function(p, index) {
          if (typeof p !== 'string') {
            throw new TypeError('Arguments to path.join must be strings');
          }
          return p;
        }).join('/'));
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            continue;
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  var MEMFS={CONTENT_OWNING:1,CONTENT_FLEXIBLE:2,CONTENT_FIXED:3,ensureFlexible:function (node) {
        if (node.contentMode !== MEMFS.CONTENT_FLEXIBLE) {
          var contents = node.contents;
          node.contents = Array.prototype.slice.call(contents);
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        }
      },mount:function (mount) {
        return MEMFS.create_node(null, '/', 0040000 | 0777, 0);
      },create_node:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            lookup: MEMFS.node_ops.lookup,
            mknod: MEMFS.node_ops.mknod,
            mknod: MEMFS.node_ops.mknod,
            rename: MEMFS.node_ops.rename,
            unlink: MEMFS.node_ops.unlink,
            rmdir: MEMFS.node_ops.rmdir,
            readdir: MEMFS.node_ops.readdir,
            symlink: MEMFS.node_ops.symlink
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek
          };
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek,
            read: MEMFS.stream_ops.read,
            write: MEMFS.stream_ops.write,
            allocate: MEMFS.stream_ops.allocate,
            mmap: MEMFS.stream_ops.mmap
          };
          node.contents = [];
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        } else if (FS.isLink(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            readlink: MEMFS.node_ops.readlink
          };
          node.stream_ops = {};
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = FS.chrdev_stream_ops;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.contents.length;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.ensureFlexible(node);
            var contents = node.contents;
            if (attr.size < contents.length) contents.length = attr.size;
            else while (attr.size > contents.length) contents.push(0);
          }
        },lookup:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.create_node(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.create_node(parent, newname, 0777 | 0120000, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          var node = stream.node;
          node.timestamp = Date.now();
          var contents = node.contents;
          if (length && contents.length === 0 && position === 0 && buffer.subarray) {
            // just replace it with the new data
            assert(buffer.length);
            if (canOwn && buffer.buffer === HEAP8.buffer && offset === 0) {
              node.contents = buffer; // this is a subarray of the heap, and we can own it
              node.contentMode = MEMFS.CONTENT_OWNING;
            } else {
              node.contents = new Uint8Array(buffer.subarray(offset, offset+length));
              node.contentMode = MEMFS.CONTENT_FIXED;
            }
            return length;
          }
          MEMFS.ensureFlexible(node);
          var contents = node.contents;
          while (contents.length < position) contents.push(0);
          for (var i = 0; i < length; i++) {
            contents[position + i] = buffer[offset + i];
          }
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.contents.length;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.ungotten = [];
          stream.position = position;
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.ensureFlexible(stream.node);
          var contents = stream.node.contents;
          var limit = offset + length;
          while (limit > contents.length) contents.push(0);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 0x02) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < contents.length) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);var FS={root:null,nodes:[null],devices:[null],streams:[null],nextInode:1,name_table:null,currentPath:"/",initialized:false,ignorePermissions:true,ErrnoError:function ErrnoError(errno) {
          this.errno = errno;
          for (var key in ERRNO_CODES) {
            if (ERRNO_CODES[key] === errno) {
              this.code = key;
              break;
            }
          }
          this.message = ERRNO_MESSAGES[errno];
        },handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + new Error().stack;
        return ___setErrNo(e.errno);
      },hashName:function (parentid, name) {
        var hash = 0;
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.name_table.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.name_table[hash];
        FS.name_table[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.name_table[hash] === node) {
          FS.name_table[hash] = node.name_next;
        } else {
          var current = FS.name_table[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.name_table[hash]; node; node = node.name_next) {
          if (node.parent.id === parent.id && node.name === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        var node = {
          id: FS.nextInode++,
          name: name,
          mode: mode,
          node_ops: {},
          stream_ops: {},
          rdev: rdev,
          parent: null,
          mount: null
        };
        if (!parent) {
          parent = node;  // root node sets parent to itself
        }
        node.parent = parent;
        node.mount = parent.mount;
        // compatibility
        var readMode = 292 | 73;
        var writeMode = 146;
        // NOTE we must use Object.defineProperties instead of individual calls to
        // Object.defineProperty in order to make closure compiler happy
        Object.defineProperties(node, {
          read: {
            get: function() { return (node.mode & readMode) === readMode; },
            set: function(val) { val ? node.mode |= readMode : node.mode &= ~readMode; }
          },
          write: {
            get: function() { return (node.mode & writeMode) === writeMode; },
            set: function(val) { val ? node.mode |= writeMode : node.mode &= ~writeMode; }
          },
          isFolder: {
            get: function() { return FS.isDir(node.mode); },
          },
          isDevice: {
            get: function() { return FS.isChrdev(node.mode); },
          },
        });
        FS.hashAddNode(node);
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return node.mounted;
      },isFile:function (mode) {
        return (mode & 0170000) === 0100000;
      },isDir:function (mode) {
        return (mode & 0170000) === 0040000;
      },isLink:function (mode) {
        return (mode & 0170000) === 0120000;
      },isChrdev:function (mode) {
        return (mode & 0170000) === 0020000;
      },isBlkdev:function (mode) {
        return (mode & 0170000) === 0060000;
      },isFIFO:function (mode) {
        return (mode & 0170000) === 0010000;
      },isSocket:function (mode) {
        return (mode & 0140000) === 0140000;
      },cwd:function () {
        return FS.currentPath;
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.currentPath, path);
        opts = opts || { recurse_count: 0 };
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
        // start at the root
        var current = FS.root;
        var current_path = '/';
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join(current_path, parts[i]);
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            current = current.mount.root;
          }
          // follow symlinks
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            return path ? PATH.join(node.mount.mountpoint, path) : node.mount.mountpoint;
          }
          path = path ? PATH.join(node.name, path) : node.name;
          node = node.parent;
        }
      },flagModes:{"r":0,"rs":8192,"r+":2,"w":1537,"wx":3585,"xw":3585,"w+":1538,"wx+":3586,"xw+":3586,"a":521,"ax":2569,"xa":2569,"a+":522,"ax+":2570,"xa+":2570},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 3;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 1024)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        return FS.nodePermissions(dir, 'x');
      },mayMknod:function (mode) {
        switch (mode & 0170000) {
          case 0100000:
          case 0020000:
          case 0060000:
          case 0010000:
          case 0140000:
            return 0;
          default:
            return ERRNO_CODES.EINVAL;
        }
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.currentPath) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 3) !== 0 ||  // opening for write
              (flags & 1024)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 1;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        // compatibility
        Object.defineProperties(stream, {
          object: {
            get: function() { return stream.node; },
            set: function(val) { stream.node = val; }
          },
          isRead: {
            get: function() { return (stream.flags & 3) !== 1; }
          },
          isWrite: {
            get: function() { return (stream.flags & 3) !== 0; }
          },
          isAppend: {
            get: function() { return (stream.flags & 8); }
          }
        });
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join(parent, part);
          try {
            FS.mkdir(current, 0777);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(path, mode | 146);
          var stream = FS.open(path, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(path, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
              if (!hasByteServing) chunkSize = datalength;
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp', 0777);
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev', 0777);
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', 0666, FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', 0666, FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', 0666, FS.makedev(6, 0));
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm', 0777);
        FS.mkdir('/dev/shm/tmp', 0777);
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=stdin.fd;
        assert(stdin.fd === 1, 'invalid handle for stdin (' + stdin.fd + ')');
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=stdout.fd;
        assert(stdout.fd === 2, 'invalid handle for stdout (' + stdout.fd + ')');
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=stderr.fd;
        assert(stderr.fd === 3, 'invalid handle for stderr (' + stderr.fd + ')');
      },staticInit:function () {
        FS.name_table = new Array(4096);
        FS.root = FS.createNode(null, '/', 0040000 | 0777, 0);
        FS.mount(MEMFS, {}, '/');
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },mount:function (type, opts, mountpoint) {
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          root: null
        };
        var lookup;
        if (mountpoint) {
          lookup = FS.lookupPath(mountpoint, { follow: false });
        }
        // create a root node for the fs
        var root = type.mount(mount);
        root.mount = mount;
        mount.root = root;
        // assign the mount info to the mountpoint's node
        if (lookup) {
          lookup.node.mount = mount;
          lookup.node.mounted = true;
          // compatibility update FS.root if we mount to /
          if (mountpoint === '/') {
            FS.root = mount.root;
          }
        }
        return root;
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode &= 4095;
        mode |= 0100000;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode &= 511 | 0001000;
        mode |= 0040000;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        mode |= 0020000;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
      },readlink:function (path) {
        var lookup = FS.lookupPath(path, { follow: false });
        var link = lookup.node;
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        path = PATH.normalize(path);
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 0666 : mode;
        if ((flags & 512)) {
          mode = (mode & 4095) | 0100000;
        } else {
          mode = 0;
        }
        var node;
        try {
          var lookup = FS.lookupPath(path, {
            follow: !(flags & 0200000)
          });
          node = lookup.node;
          path = lookup.path;
        } catch (e) {
          // ignore
        }
        // perhaps we need to create the node
        if ((flags & 512)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 2048)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~1024;
        }
        // check permissions
        var err = FS.mayOpen(node, flags);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // do truncation if necessary
        if ((flags & 1024)) {
          FS.truncate(node, 0);
        }
        // register the stream with the filesystem
        var stream = FS.createStream({
          path: path,
          node: node,
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        return stream.stream_ops.llseek(stream, offset, whence);
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        if (stream.flags & 8) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.errnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      }};function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module.print('exit(' + status + ') called');
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }
  var SOCKFS={mount:function (mount) {
        return FS.createNode(null, '/', 0040000 | 0777, 0);
      },nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 0140000, 0);
        node.sock = sock;
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              var url = 'ws://' + addr + ':' + port;
              // the node ws library API is slightly different than the browser's
              var opts = ENVIRONMENT_IS_NODE ? {} : ['binary'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
          var handleOpen = function () {
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
          var handleMessage = function(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
          };
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('error', function() {
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onmessage = function(event) {
              handleMessage(event.data);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (0 /* XXX missing C define POLLRDNORM */ | 1) : 0;
          }
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (0 /* XXX missing C define POLLRDNORM */ | 1);
          }
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 2;
          }
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 1:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODS.EOPNOTSUPP);
          }
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
              // push to queue for accept to pick up
              sock.pending.push(newsock);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
            }
          });
          sock.server.on('closed', function() {
            sock.server = null;
          });
          sock.server.on('error', function() {
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  Module["_strlen"] = _strlen;
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
          // Handle precision.
          var precisionSet = false;
          if (next == 46) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          } else {
            var precision = 6; // Standard default.
          }
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
              // Add sign if needed
              if (flagAlwaysSigned) {
                if (currArg < 0) {
                  prefix = '-' + prefix;
                } else {
                  prefix = '+' + prefix;
                }
              }
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
                // Add sign.
                if (flagAlwaysSigned && currArg >= 0) {
                  argText = '+' + argText;
                }
              }
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }
  function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i32=_memset;
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      var stream = FS.getStream(fildes);
      if (stream) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }
  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    } 
  Module["_saveSetjmp"] = _saveSetjmp;
  Module["_testSetjmp"] = _testSetjmp;var _setjmp=undefined;
  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _rmdir(path) {
      // int rmdir(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rmdir.html
      path = Pointer_stringify(path);
      try {
        FS.rmdir(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _remove(path) {
      // int remove(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/remove.html
      var ret = _unlink(path);
      if (ret == -1) ret = _rmdir(path);
      return ret;
    }
  function _strdup(ptr) {
      var len = _strlen(ptr);
      var newStr = _malloc(len + 1);
      (_memcpy(newStr, ptr, len)|0);
      HEAP8[(((newStr)+(len))|0)]=0;
      return newStr;
    }
  Module["_memcpy"] = _memcpy;var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
        var start = window['performance']['now']();
        while (window['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }
  var ___timespec_struct_layout={__size__:8,tv_sec:0,tv_nsec:4};function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_sec))>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_nsec))>>2)];
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_sec))>>2)]=0
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_nsec))>>2)]=0
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }
  function _strrchr(ptr, chr) {
      var ptr2 = ptr + _strlen(ptr);
      do {
        if (HEAP8[(ptr2)] == chr) return ptr2;
        ptr2--;
      } while (ptr2 >= ptr);
      return 0;
    }
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[(((px)+(i))|0)];
        var y = HEAPU8[(((py)+(i))|0)];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }
  var _llvm_pow_f32=Math.pow;
  function _round(x) {
      return (x < 0) ? -Math.round(-x) : Math.round(x);
    }var _roundf=_round;
  function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }
  function _isspace(chr) {
      return (chr == 32) || (chr >= 9 && chr <= 13);
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
      // Apply sign.
      ret *= multiplier;
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
      if (bits == 64) {
        return ((asm["setTempRet0"]((tempDouble=ret,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)),ret>>>0)|0);
      }
      return ret;
    }function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }
  function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      return _write(stream, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }
  function _llvm_lifetime_start() {}
  function _llvm_lifetime_end() {}
  var _llvm_memset_p0i8_i64=_memset;
  var ___dirent_struct_layout={__size__:1040,d_ino:0,d_name:4,d_off:1028,d_reclen:1032,d_type:1036};function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 1024;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 8;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStream(stream);
      stream.eof = false;
      return 0;
    }
  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStream(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }
  function _rewind(stream) {
      // void rewind(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rewind.html
      _fseek(stream, 0, 0);  // SEEK_SET.
      var streamObj = FS.getStream(stream);
      if (streamObj) streamObj.error = false;
    }
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStream(stream);
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)|0)]=streamObj.ungotten.pop()
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(stream, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return Math.floor(bytesRead / size);
    }
  function _feof(stream) {
      // int feof(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/feof.html
      stream = FS.getStream(stream);
      return Number(stream && stream.eof);
    }
  function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }function _fgets(s, n, stream) {
      // char *fgets(char *restrict s, int n, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgets.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return 0;
      if (streamObj.error || streamObj.eof) return 0;
      var byte_;
      for (var i = 0; i < n - 1 && byte_ != 10; i++) {
        byte_ = _fgetc(stream);
        if (byte_ == -1) {
          if (streamObj.error || (streamObj.eof && i == 0)) return 0;
          else if (streamObj.eof) break;
        }
        HEAP8[(((s)+(i))|0)]=byte_
      }
      HEAP8[(((s)+(i))|0)]=0
      return s;
    }
  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }
  Module["_tolower"] = _tolower; 
  Module["_strncasecmp"] = _strncasecmp; 
  Module["_strcasecmp"] = _strcasecmp;
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'root';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/emscripten';
        ENV['LANG'] = 'en_US.UTF-8';
        ENV['_'] = './this.program';
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        for (var j = 0; j < line.length; j++) {
          HEAP8[(((poolPtr)+(j))|0)]=line.charCodeAt(j);
        }
        HEAP8[(((poolPtr)+(j))|0)]=0;
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }
  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }
  var ___tm_struct_layout={__size__:44,tm_sec:0,tm_min:4,tm_hour:8,tm_mday:12,tm_mon:16,tm_year:20,tm_wday:24,tm_yday:28,tm_isdst:32,tm_gmtoff:36,tm_zone:40};
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
      var date = {
        tm_sec: HEAP32[(((tm)+(___tm_struct_layout.tm_sec))>>2)],
        tm_min: HEAP32[(((tm)+(___tm_struct_layout.tm_min))>>2)],
        tm_hour: HEAP32[(((tm)+(___tm_struct_layout.tm_hour))>>2)],
        tm_mday: HEAP32[(((tm)+(___tm_struct_layout.tm_mday))>>2)],
        tm_mon: HEAP32[(((tm)+(___tm_struct_layout.tm_mon))>>2)],
        tm_year: HEAP32[(((tm)+(___tm_struct_layout.tm_year))>>2)],
        tm_wday: HEAP32[(((tm)+(___tm_struct_layout.tm_wday))>>2)],
        tm_yday: HEAP32[(((tm)+(___tm_struct_layout.tm_yday))>>2)],
        tm_isdst: HEAP32[(((tm)+(___tm_struct_layout.tm_isdst))>>2)]
      };
      var pattern = Pointer_stringify(format);
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S',                 // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
      var leadingSomething = function(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
      var leadingNulls = function(value, digits) {
        return leadingSomething(value, digits, '0');
      };
      var compareByDay = function(date1, date2) {
        var sgn = function(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
      var getFirstWeekStartDate = function(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
      var getWeekBasedYear = function(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls(Math.floor(year/100),2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          return leadingNulls(date.tm_hour < 13 ? date.tm_hour : date.tm_hour-12, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour > 0 && date.tm_hour < 13) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ),
          // or by no characters if no timezone is determinable. 
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich). 
          // If tm_isdst is zero, the standard time offset is used. 
          // If tm_isdst is greater than zero, the daylight savings time offset is used. 
          // If tm_isdst is negative, no characters are returned. 
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%Z': function(date) {
          // Replaced by the timezone name or abbreviation, or by no bytes if no timezone information exists. [ tm_isdst]
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }
  var ___tm_current=allocate(4*26, "i8", ALLOC_STATIC);
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);
  var __tzname=allocate(8, "i32*", ALLOC_STATIC);
  var __daylight=allocate(1, "i32*", ALLOC_STATIC);
  var __timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
      HEAP32[((__timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((__daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset())
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((__tzname)>>2)]=winterNamePtr
      HEAP32[(((__tzname)+(4))>>2)]=summerNamePtr
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var offsets = ___tm_struct_layout;
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getDay()
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=start.getTimezoneOffset() * 60
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=dst
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezone
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }
  function _strtok_r(s, delim, lasts) {
      var skip_leading_delim = 1;
      var spanp;
      var c, sc;
      var tok;
      if (s == 0 && (s = getValue(lasts, 'i8*')) == 0) {
        return 0;
      }
      cont: while (1) {
        c = getValue(s++, 'i8');
        for (spanp = delim; (sc = getValue(spanp++, 'i8')) != 0;) {
          if (c == sc) {
            if (skip_leading_delim) {
              continue cont;
            } else {
              setValue(lasts, s, 'i8*');
              setValue(s - 1, 0, 'i8');
              return s - 1;
            }
          }
        }
        break;
      }
      if (c == 0) {
        setValue(lasts, 0, 'i8*');
        return 0;
      }
      tok = s - 1;
      for (;;) {
        c = getValue(s++, 'i8');
        spanp = delim;
        do {
          if ((sc = getValue(spanp++, 'i8')) == c) {
            if (c == 0) {
              s = 0;
            } else {
              setValue(s - 1, 0, 'i8');
            }
            setValue(lasts, s, 'i8*');
            return tok;
          }
        } while (sc != 0);
      }
      abort('strtok_r error!');
    }
  function _qsort(base, num, size, cmp) {
      if (num == 0 || size == 0) return;
      // forward calls to the JavaScript sort method
      // first, sort the items logically
      var keys = [];
      for (var i = 0; i < num; i++) keys.push(i);
      keys.sort(function(a, b) {
        return Module['dynCall_iii'](cmp, base+a*size, base+b*size);
      });
      // apply the sort
      var temp = _malloc(num*size);
      _memcpy(temp, base, num*size);
      for (var i = 0; i < num; i++) {
        if (keys[i] == i) continue; // already in place
        _memcpy(base+i*size, temp+keys[i]*size, size);
      }
      _free(temp);
    }
  function _opendir(dirname) {
      // DIR *opendir(const char *dirname);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/opendir.html
      // NOTE: Calculating absolute path redundantly since we need to associate it
      //       with the opened stream.
      var path = Pointer_stringify(dirname);
      if (!path) {
        ___setErrNo(ERRNO_CODES.ENOENT);
        return 0;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return 0;
      }
      if (!FS.isDir(node.mode)) {
        ___setErrNo(ERRNO_CODES.ENOTDIR);
        return 0;
      }
      var err = _open(dirname, 0, allocate([0, 0, 0, 0], 'i32', ALLOC_STACK));
      // open returns 0 on failure, not -1
      return err === -1 ? 0 : err;
    }
  function _readdir_r(dirp, entry, result) {
      // int readdir_r(DIR *dirp, struct dirent *entry, struct dirent **result);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        return ___setErrNo(ERRNO_CODES.EBADF);
      }
      var entries;
      try {
        entries = FS.readdir(stream.path);
      } catch (e) {
        return FS.handleFSError(e);
      }
      if (stream.position < 0 || stream.position >= entries.length) {
        HEAP32[((result)>>2)]=0
        return 0;
      }
      var id;
      var type;
      var name = entries[stream.position];
      var offset = stream.position + 1;
      if (!name.indexOf('.')) {
        id = 1;
        type = 4;
      } else {
        var child = FS.lookupNode(stream.node, name);
        id = child.id;
        type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
               FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
               FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
               8;                             // DT_REG, regular file.
      }
      HEAP32[(((entry)+(___dirent_struct_layout.d_ino))>>2)]=id
      HEAP32[(((entry)+(___dirent_struct_layout.d_off))>>2)]=offset
      HEAP32[(((entry)+(___dirent_struct_layout.d_reclen))>>2)]=name.length + 1
      for (var i = 0; i < name.length; i++) {
        HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=name.charCodeAt(i)
      }
      HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=0
      HEAP8[(((entry)+(___dirent_struct_layout.d_type))|0)]=type
      HEAP32[((result)>>2)]=entry
      stream.position++;
      return 0;
    }function _readdir(dirp) {
      // struct dirent *readdir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // TODO Is it supposed to be safe to execute multiple readdirs?
      if (!_readdir.entry) _readdir.entry = _malloc(___dirent_struct_layout.__size__);
      if (!_readdir.result) _readdir.result = _malloc(4);
      var err = _readdir_r(dirp, _readdir.entry, _readdir.result);
      if (err) {
        ___setErrNo(err);
        return 0;
      }
      return HEAP32[((_readdir.result)>>2)];
    }
  function _closedir(dirp) {
      // int closedir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/closedir.html
      return _close(dirp);
    }
  var ___stat_struct_layout={__size__:68,st_dev:0,st_ino:4,st_mode:8,st_nlink:12,st_uid:16,st_gid:20,st_rdev:24,st_size:28,st_atime:32,st_spare1:36,st_mtime:40,st_spare2:44,st_ctime:48,st_spare3:52,st_blksize:56,st_blocks:60,st_spare4:64};function _stat(path, buf, dontResolveLastLink) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/stat.html
      // int stat(const char *path, struct stat *buf);
      // NOTE: dontResolveLastLink is a shortcut for lstat(). It should never be
      //       used in client code.
      path = typeof path !== 'string' ? Pointer_stringify(path) : path;
      try {
        var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
        HEAP32[(((buf)+(___stat_struct_layout.st_dev))>>2)]=stat.dev;
        HEAP32[(((buf)+(___stat_struct_layout.st_ino))>>2)]=stat.ino
        HEAP32[(((buf)+(___stat_struct_layout.st_mode))>>2)]=stat.mode
        HEAP32[(((buf)+(___stat_struct_layout.st_nlink))>>2)]=stat.nlink
        HEAP32[(((buf)+(___stat_struct_layout.st_uid))>>2)]=stat.uid
        HEAP32[(((buf)+(___stat_struct_layout.st_gid))>>2)]=stat.gid
        HEAP32[(((buf)+(___stat_struct_layout.st_rdev))>>2)]=stat.rdev
        HEAP32[(((buf)+(___stat_struct_layout.st_size))>>2)]=stat.size
        HEAP32[(((buf)+(___stat_struct_layout.st_atime))>>2)]=Math.floor(stat.atime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_mtime))>>2)]=Math.floor(stat.mtime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_ctime))>>2)]=Math.floor(stat.ctime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_blksize))>>2)]=4096
        HEAP32[(((buf)+(___stat_struct_layout.st_blocks))>>2)]=stat.blocks
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _realpath(file_name, resolved_name) {
      // char *realpath(const char *restrict file_name, char *restrict resolved_name);
      // http://pubs.opengroup.org/onlinepubs/009604499/functions/realpath.html
      var absolute = FS.analyzePath(Pointer_stringify(file_name));
      if (absolute.error) {
        ___setErrNo(absolute.error);
        return 0;
      } else {
        var size = Math.min(4095, absolute.path.length);  // PATH_MAX - 1.
        for (var i = 0; i < size; i++) {
          HEAP8[(((resolved_name)+(i))|0)]=absolute.path.charCodeAt(i)
        }
        HEAP8[(((resolved_name)+(size))|0)]=0
        return resolved_name;
      }
    }
  function _getgid() {
      // gid_t getgid(void);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/getgid.html
      // We have just one process/group/user, all with ID 0.
      return 0;
    }var _getpid=_getgid;
  function _readlink(path, buf, bufsize) {
      // ssize_t readlink(const char *restrict path, char *restrict buf, size_t bufsize);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/readlink.html
      path = Pointer_stringify(path);
      var str;
      try {
        str = FS.readlink(path);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      str = str.slice(0, Math.max(0, bufsize - 1));
      writeStringToMemory(str, buf, true);
      return str.length;
    }
  var _sqrt=Math.sqrt;
  var _fabs=Math.abs;
  function ___errno_location() {
      return ___errno_state;
    }var ___errno=___errno_location;
  function __parseInt64(str, endptr, base, min, max, unsign) {
      var isNegative = false;
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      if (HEAP8[(str)] == 45) {
        str++;
        isNegative = true;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var ok = false;
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            ok = true; // we saw an initial zero, perhaps the entire thing is just "0"
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      start = str;
      // Get digits.
      var chr;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          str++;
          ok = true;
        }
      }
      if (!ok) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return ((asm["setTempRet0"](0),0)|0);
      }
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      try {
        var numberString = isNegative ? '-'+Pointer_stringify(start, str - start) : Pointer_stringify(start, str - start);
        i64Math.fromString(numberString, finalBase, min, max, unsign);
      } catch(e) {
        ___setErrNo(ERRNO_CODES.ERANGE); // not quite correct
      }
      return ((asm["setTempRet0"](((HEAP32[(((tempDoublePtr)+(4))>>2)])|0)),((HEAP32[((tempDoublePtr)>>2)])|0))|0);
    }function _strtoull(str, endptr, base) {
      return __parseInt64(str, endptr, base, 0, '18446744073709551615', true);  // ULONG_MAX.
    }
  var _getc=_fgetc;
  function _isgraph(chr) {
      return 0x20 < chr && chr < 0x7F;
    }
  function _llvm_bswap_i32(x) {
      return ((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24);
    }
  function _isalpha(chr) {
      return (chr >= 97 && chr <= 122) ||
             (chr >= 65 && chr <= 90);
    }
  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
        // Canvas event setup
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', {
              alpha: false
            });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var x, y;
          if (event.type == 'touchstart' ||
              event.type == 'touchend' ||
              event.type == 'touchmove') {
            var t = event.touches.item(0);
            if (t) {
              x = t.pageX - (window.scrollX + rect.left);
              y = t.pageY - (window.scrollY + rect.top);
            } else {
              return;
            }
          } else {
            x = event.pageX - (window.scrollX + rect.left);
            y = event.pageY - (window.scrollY + rect.top);
          }
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};var RI={temp:null,contexts:[],eventHandler:function (event) {
           var i;
           switch (event.type) {
              case 'mousemove':
                 var x = event['movementX'] || event['mozMovementX'] || event['webkitMovementX'];
                 var y = event['movementY'] || event['mozMovementY'] || event['webkitMovementY'];
                 for (i = 0; i < RI.contexts.length; i++) {
                    var oldX = HEAP32[(((RI.contexts[i].state)+(32))>>2)];
                    var oldY = HEAP32[(((RI.contexts[i].state)+(36))>>2)];
                    x += oldX;
                    y += oldY;
                    HEAP32[(((RI.contexts[i].state)+(32))>>2)]=x;
                    HEAP32[(((RI.contexts[i].state)+(36))>>2)]=y;
                 }
                 break;
              case 'mouseup':
              case 'mousedown':
                 var value;
                 var offset;
                 if (event.button === 0) offset = 40;
                 else if (event.button === 2) offset = 41;
                 else break;
                 if (event.type === 'mouseup') value = 0;
                 else value = 1;
                 for (i = 0; i < RI.contexts.length; i++) {
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 break;
              case 'keyup':
              case 'keydown':
                 var key = event.keyCode;
                 var offset = key >> 3;
                 var bit = 1 << (key & 7);
                 if (offset >= 32) throw 'key code error! bad code: ' + key;
                 for (i = 0; i < RI.contexts.length; i++) {
                    var value = HEAP8[(((RI.contexts[i].state)+(offset))|0)];
                    if (event.type === 'keyup') value &= ~bit;
                    else value |= bit;
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 event.preventDefault();
                 break;
              case 'blur':
              case 'visibilitychange':
                 for (i = 0; i < RI.contexts.length; i++) {
                    _memset(RI.contexts[i].state, 0, 42);
                 }
                 break;
           }
        }};function _RWebInputDestroy(context) {
        if (context === RI.contexts.length) {
           RI.contexts.pop();
           if (RI.contexts.length === 0) {
              document.removeEventListener('keyup', RI.eventHandler, false);
              document.removeEventListener('keydown', RI.eventHandler, false);
              document.removeEventListener('mousemove', RI.eventHandler, false);
              document.removeEventListener('mouseup', RI.eventHandler, false);
              document.removeEventListener('mousedown', RI.eventHandler, false);
              document.removeEventListener('blur', RI.eventHandler, false);
              document.removeEventListener('onvisbilitychange', RI.eventHandler, false);
           }
        }
     }
  function _RWebInputPoll(context) {
        context -= 1;
        var state = RI.contexts[context].state;
        _memcpy(RI.temp, state, 42);
        // reset mouse movements
        HEAP32[(((RI.contexts[context].state)+(32))>>2)]=0;
        HEAP32[(((RI.contexts[context].state)+(36))>>2)]=0;
        return RI.temp;
     }
  function _RWebInputInit(latency) {
        if (RI.contexts.length === 0) {
           document.addEventListener('keyup', RI.eventHandler, false);
           document.addEventListener('keydown', RI.eventHandler, false);
           document.addEventListener('mousemove', RI.eventHandler, false);
           document.addEventListener('mouseup', RI.eventHandler, false);
           document.addEventListener('mousedown', RI.eventHandler, false);
           document.addEventListener('blur', RI.eventHandler, false);
           document.addEventListener('onvisbilitychange', RI.eventHandler, false);
        }
        if (RI.temp === null) RI.temp = _malloc(42);
        var s = _malloc(42);
        _memset(s, 0, 42);
        RI.contexts.push({
           state: s
        });
        return RI.contexts.length;
     }
  function _strstr(ptr1, ptr2) {
      var check = 0, start;
      do {
        if (!check) {
          start = ptr1;
          check = ptr2;
        }
        var curr1 = HEAP8[((ptr1++)|0)];
        var curr2 = HEAP8[((check++)|0)];
        if (curr2 == 0) return start;
        if (curr2 != curr1) {
          // rewind to one character after start, to find ez in eeez
          ptr1 = start + 1;
          check = 0;
        }
      } while (curr1);
      return 0;
    }
  Module["_memmove"] = _memmove;var _llvm_memmove_p0i8_p0i8_i32=_memmove;
  Module["_memcmp"] = _memcmp;
  var RA={BUFFER_SIZE:256,context:null,buffers:[],numBuffers:0,bufIndex:0,bufOffset:0,startTime:0,nonblock:false,currentTimeWorkaround:false,setStartTime:function () {
           if (RA.context.currentTime) {
              RA.startTime = window['performance']['now']() - RA.context.currentTime * 1000;
              var time1 = RA.context.currentTime;
              _usleep(50);
              if (time1 === RA.context.currentTime) {
                 RA.currentTimeWorkaround = true;
                 if (RA.startTime === 0) throw 'startTime is 0';
              }
              Module["resumeMainLoop"]();
           } else window['setTimeout'](RA.setStartTime, 0);
        },getCurrentPerfTime:function () {
           if (!RA.currentTimeWorkaround) return RA.context.currentTime;
           else if (RA.startTime) return (window['performance']['now']() - RA.startTime) / 1000;
           else throw 'getCurrentPerfTime() called before start time set';
        },process:function (queueBuffers) {
           var currentTime = RA.getCurrentPerfTime();
           for (var i = 0; i < RA.bufIndex; i++) {
              if (RA.buffers[i].endTime < currentTime) {
                 var buf = RA.buffers.splice(i, 1);
                 RA.buffers[RA.numBuffers - 1] = buf[0];
                 i--;
                 RA.bufIndex--;
              }
           }
        },fillBuffer:function (buf, samples) {
           var count = 0;
           var leftBuffer = RA.buffers[RA.bufIndex].getChannelData(0);
           var rightBuffer = RA.buffers[RA.bufIndex].getChannelData(1);
           while (samples && RA.bufOffset !== RA.BUFFER_SIZE) {
              leftBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8))>>2)];
              rightBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8 + 4))>>2)];
              RA.bufOffset++;
              count++;
              samples--;
           }
           return count;
        },queueAudio:function () {
           var index = RA.bufIndex;
           var startTime;
           if (RA.bufIndex) startTime = RA.buffers[RA.bufIndex - 1].endTime;
           else startTime = RA.context.currentTime;
           RA.buffers[index].endTime = startTime + RA.buffers[index].duration;
           var bufferSource = RA.context.createBufferSource();
           bufferSource.buffer = RA.buffers[index];
           bufferSource.connect(RA.context.destination);
           bufferSource.start(startTime);
           RA.bufIndex++;
           RA.bufOffset = 0;
        },block:function () {
           do {
              RA.process();
           } while (RA.bufIndex === RA.numBuffers - 1);
        }};function _RWebAudioBufferSize() {
        return RA.numBuffers * RA.BUFFER_SIZE + RA.BUFFER_SIZE;
     }
  function _RWebAudioWriteAvail() {
        RA.process();
        return ((RA.numBuffers - RA.bufIndex) * RA.BUFFER_SIZE - RA.bufOffset) * 8;
     }
  function _RWebAudioFree() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return;
     }
  function _RWebAudioSetNonblockState(state) {
        RA.nonblock = state;
     }
  function _RWebAudioStart() {
        return true;
     }
  function _RWebAudioStop() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return true;
     }
  function _RWebAudioWrite(buf, size) {
        RA.process();
        var samples = size / 8;
        var count = 0;
        while (samples) {
           var fill = RA.fillBuffer(buf, samples);
           samples -= fill;
           count += fill;
           buf += fill * 8;
           if (RA.bufOffset === RA.BUFFER_SIZE) {
              if (RA.bufIndex === RA.numBuffers - 1) {
                 if (RA.nonblock) break;
                 else RA.block();
              }
              RA.queueAudio();
           }
        }
        return count * 8;
     }
  function _RWebAudioInit(latency) {
        var ac = window['AudioContext'] || window['webkitAudioContext'];
        if (!ac) return 0;
        RA.context = new ac();
        RA.numBuffers = ((latency * RA.context.sampleRate) / (1000 * RA.BUFFER_SIZE))|0;
        if (RA.numBuffers < 2) RA.numBuffers = 2;
        for (var i = 0; i < RA.numBuffers; i++) RA.buffers[i] = RA.context.createBuffer(2, RA.BUFFER_SIZE, RA.context.sampleRate);
        RA.nonblock = false;
        RA.startTime = 0;
        // chrome hack to get currentTime running
        RA.context.createGain();
        window['setTimeout'](RA.setStartTime, 0);
        Module["pauseMainLoop"]();
        return 1;
     }
  function _RWebAudioSampleRate() {
        return RA.context.sampleRate;
     }
  var _fabsf=Math.abs;
  var _sin=Math.sin;
  var _ceil=Math.ceil;
  function _emscripten_get_now() {
      if (!_emscripten_get_now.actual) {
        if (ENVIRONMENT_IS_NODE) {
            _emscripten_get_now.actual = function() {
              var t = process['hrtime']();
              return t[0] * 1e3 + t[1] / 1e6;
            }
        } else if (typeof dateNow !== 'undefined') {
          _emscripten_get_now.actual = dateNow;
        } else if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
          _emscripten_get_now.actual = function() { return window['performance']['now'](); };
        } else {
          _emscripten_get_now.actual = Date.now;
        }
      }
      return _emscripten_get_now.actual();
    }
  function _llvm_uadd_with_overflow_i32(x, y) {
      x = x>>>0;
      y = y>>>0;
      return ((asm["setTempRet0"](x+y > 4294967295),(x+y)>>>0)|0);
    }
  var GL={counter:1,buffers:[],programs:[],framebuffers:[],renderbuffers:[],textures:[],uniforms:[],shaders:[],currArrayBuffer:0,currElementArrayBuffer:0,byteSizeByTypeRoot:5120,byteSizeByType:[1,1,2,2,4,4,4,2,3,4,8],uniformTable:{},packAlignment:4,unpackAlignment:4,init:function () {
        Browser.moduleContextCreatedCallbacks.push(GL.initExtensions);
      },getNewId:function (table) {
        var ret = GL.counter++;
        for (var i = table.length; i < ret; i++) {
          table[i] = null;
        }
        return ret;
      },MINI_TEMP_BUFFER_SIZE:16,miniTempBuffer:null,miniTempBufferViews:[0],MAX_TEMP_BUFFER_SIZE:2097152,tempBufferIndexLookup:null,tempVertexBuffers:null,tempIndexBuffers:null,tempQuadIndexBuffer:null,generateTempBuffers:function (quads) {
        GL.tempBufferIndexLookup = new Uint8Array(GL.MAX_TEMP_BUFFER_SIZE+1);
        GL.tempVertexBuffers = [];
        GL.tempIndexBuffers = [];
        var last = -1, curr = -1;
        var size = 1;
        for (var i = 0; i <= GL.MAX_TEMP_BUFFER_SIZE; i++) {
          if (i > size) {
            size <<= 1;
          }
          if (size != last) {
            curr++;
            GL.tempVertexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, GL.tempVertexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, null);
            GL.tempIndexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempIndexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
            last = size;
          }
          GL.tempBufferIndexLookup[i] = curr;
        }
        if (quads) {
          // GL_QUAD indexes can be precalculated
          GL.tempQuadIndexBuffer = Module.ctx.createBuffer();
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempQuadIndexBuffer);
          var numIndexes = GL.MAX_TEMP_BUFFER_SIZE >> 1;
          var quadIndexes = new Uint16Array(numIndexes);
          var i = 0, v = 0;
          while (1) {
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+1;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+3;
            if (i >= numIndexes) break;
            v += 4;
          }
          Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, quadIndexes, Module.ctx.STATIC_DRAW);
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
        }
      },findToken:function (source, token) {
        function isIdentChar(ch) {
          if (ch >= 48 && ch <= 57) // 0-9
            return true;
          if (ch >= 65 && ch <= 90) // A-Z
            return true;
          if (ch >= 97 && ch <= 122) // a-z
            return true;
          return false;
        }
        var i = -1;
        do {
          i = source.indexOf(token, i + 1);
          if (i < 0) {
            break;
          }
          if (i > 0 && isIdentChar(source[i - 1])) {
            continue;
          }
          i += token.length;
          if (i < source.length - 1 && isIdentChar(source[i + 1])) {
            continue;
          }
          return true;
        } while (true);
        return false;
      },getSource:function (shader, count, string, length) {
        var source = '';
        for (var i = 0; i < count; ++i) {
          var frag;
          if (length) {
            var len = HEAP32[(((length)+(i*4))>>2)];
            if (len < 0) {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
            } else {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)], len);
            }
          } else {
            frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
          }
          source += frag;
        }
        // Let's see if we need to enable the standard derivatives extension
        type = Module.ctx.getShaderParameter(GL.shaders[shader], 0x8B4F /* GL_SHADER_TYPE */);
        if (type == 0x8B30 /* GL_FRAGMENT_SHADER */) {
          if (GL.findToken(source, "dFdx") ||
              GL.findToken(source, "dFdy") ||
              GL.findToken(source, "fwidth")) {
            source = "#extension GL_OES_standard_derivatives : enable\n" + source;
            var extension = Module.ctx.getExtension("OES_standard_derivatives");
          }
        }
        return source;
      },computeImageSize:function (width, height, sizePerPixel, alignment) {
        function roundedToNextMultipleOf(x, y) {
          return Math.floor((x + y - 1) / y) * y
        }
        var plainRowSize = width * sizePerPixel;
        var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
        return (height <= 0) ? 0 :
                 ((height - 1) * alignedRowSize + plainRowSize);
      },getTexPixelData:function (type, format, width, height, pixels, internalFormat) {
        var sizePerPixel;
        switch (type) {
          case 0x1401 /* GL_UNSIGNED_BYTE */:
            switch (format) {
              case 0x1906 /* GL_ALPHA */:
              case 0x1909 /* GL_LUMINANCE */:
                sizePerPixel = 1;
                break;
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4;
                break;
              case 0x190A /* GL_LUMINANCE_ALPHA */:
                sizePerPixel = 2;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            break;
          case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
          case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
          case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
            sizePerPixel = 2;
            break;
          case 0x1406 /* GL_FLOAT */:
            assert(GL.floatExt, 'Must have OES_texture_float to use float textures');
            switch (format) {
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3*4;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4*4;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            internalFormat = Module.ctx.RGBA;
            break;
          default:
            throw 'Invalid type (' + type + ')';
        }
        var bytes = GL.computeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
        if (type == 0x1401 /* GL_UNSIGNED_BYTE */) {
          pixels = HEAPU8.subarray((pixels),(pixels+bytes));
        } else if (type == 0x1406 /* GL_FLOAT */) {
          pixels = HEAPF32.subarray((pixels)>>2,(pixels+bytes)>>2);
        } else {
          pixels = HEAPU16.subarray((pixels)>>1,(pixels+bytes)>>1);
        }
        return {
          pixels: pixels,
          internalFormat: internalFormat
        }
      },initExtensions:function () {
        if (GL.initExtensions.done) return;
        GL.initExtensions.done = true;
        if (!Module.useWebGL) return; // an app might link both gl and 2d backends
        GL.miniTempBuffer = new Float32Array(GL.MINI_TEMP_BUFFER_SIZE);
        for (var i = 0; i < GL.MINI_TEMP_BUFFER_SIZE; i++) {
          GL.miniTempBufferViews[i] = GL.miniTempBuffer.subarray(0, i+1);
        }
        GL.maxVertexAttribs = Module.ctx.getParameter(Module.ctx.MAX_VERTEX_ATTRIBS);
        GL.compressionExt = Module.ctx.getExtension('WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('MOZ_WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('WEBKIT_WEBGL_compressed_texture_s3tc');
        GL.anisotropicExt = Module.ctx.getExtension('EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('MOZ_EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('WEBKIT_EXT_texture_filter_anisotropic');
        GL.floatExt = Module.ctx.getExtension('OES_texture_float');
        GL.elementIndexUintExt = Module.ctx.getExtension('OES_element_index_uint');
        GL.standardDerivativesExt = Module.ctx.getExtension('OES_standard_derivatives');
      }};function _glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        Module.ctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }
  function _glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        Module.ctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }
  function _glViewport(x0, x1, x2, x3) { Module.ctx.viewport(x0, x1, x2, x3) }
  function _glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.textures);
        var texture = Module.ctx.createTexture();
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }
  function _glBindTexture(target, texture) {
      Module.ctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }
  function _glTexParameteri(x0, x1, x2) { Module.ctx.texParameteri(x0, x1, x2) }
  function _glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      Module.ctx.pixelStorei(pname, param);
    }
  function _glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, internalFormat);
        pixels = data.pixels;
        internalFormat = data.internalFormat;
      } else {
        pixels = null;
      }
      Module.ctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixels);
    }
  function _glBindFramebuffer(target, framebuffer) {
      Module.ctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
    }
  function _glReadPixels(x, y, width, height, format, type, pixels) {
      assert(type == 0x1401 /* GL_UNSIGNED_BYTE */);
      var sizePerPixel;
      switch (format) {
        case 0x1907 /* GL_RGB */:
          sizePerPixel = 3;
          break;
        case 0x1908 /* GL_RGBA */:
          sizePerPixel = 4;
          break;
        default: throw 'unsupported glReadPixels format';
      }
      var totalSize = width*height*sizePerPixel;
      Module.ctx.readPixels(x, y, width, height, format, type, HEAPU8.subarray(pixels, pixels + totalSize));
    }
  function _glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        Module.ctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }
  function _glGetIntegerv(name_, p) {
      switch(name_) { // Handle a few trivial GLES values
        case 0x8DFA: // GL_SHADER_COMPILER
          HEAP32[((p)>>2)]=1;
          return;
        case 0x8DF9: // GL_NUM_SHADER_BINARY_FORMATS
          HEAP32[((p)>>2)]=0;
          return;
        case 0x86A2: // GL_NUM_COMPRESSED_TEXTURE_FORMATS
          // WebGL doesn't have GL_NUM_COMPRESSED_TEXTURE_FORMATS (it's obsolete since GL_COMPRESSED_TEXTURE_FORMATS returns a JS array that can be queried for length),
          // so implement it ourselves to allow C++ GLES2 code get the length.
          var formats = Module.ctx.getParameter(0x86A3 /*GL_COMPRESSED_TEXTURE_FORMATS*/);
          HEAP32[((p)>>2)]=formats.length;
          return;
      }
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAP8[(p)]=result ? 1 : 0;
          break;
        case "string":
          throw 'Native code calling glGetIntegerv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP32[((p)>>2)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetIntegerv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var id = GL.getNewId(GL.framebuffers);
        var framebuffer = Module.ctx.createFramebuffer();
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }
  function _glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.renderbuffers);
        var renderbuffer = Module.ctx.createRenderbuffer();
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }
  function _glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      Module.ctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }
  function _glBindRenderbuffer(target, renderbuffer) {
      Module.ctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }
  function _glRenderbufferStorage(x0, x1, x2, x3) { Module.ctx.renderbufferStorage(x0, x1, x2, x3) }
  function _glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      Module.ctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }
  function _glCheckFramebufferStatus(x0) { return Module.ctx.checkFramebufferStatus(x0) }
  function _glGetString(name_) {
      switch(name_) {
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x1F02 /* GL_VERSION */:
          return allocate(intArrayFromString(Module.ctx.getParameter(name_)), 'i8', ALLOC_NORMAL);
        case 0x1F03 /* GL_EXTENSIONS */:
          return allocate(intArrayFromString(Module.ctx.getSupportedExtensions().join(' ')), 'i8', ALLOC_NORMAL);
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          return allocate(intArrayFromString('OpenGL ES GLSL 1.00 (WebGL)'), 'i8', ALLOC_NORMAL);
        default:
          throw 'Failure: Invalid glGetString value: ' + name_;
      }
    }
  function _glDisable(x0) { Module.ctx.disable(x0) }
  function _glBlendFunc(x0, x1) { Module.ctx.blendFunc(x0, x1) }
  function _glClearColor(x0, x1, x2, x3) { Module.ctx.clearColor(x0, x1, x2, x3) }
  function _glClear(x0) { Module.ctx.clear(x0) }
  function _glDrawArrays(mode, first, count) {
      Module.ctx.drawArrays(mode, first, count);
    }
  function _glEnable(x0) { Module.ctx.enable(x0) }
  function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, -1);
        pixels = data.pixels;
      } else {
        pixels = null;
      }
      Module.ctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels);
    }
  function _glGetError() { return Module.ctx.getError() }
  var _cosf=Math.cos;
  var _sinf=Math.sin;
  function _glGetFloatv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAPF32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAPF32[((p)>>2)]=result ? 1.0 : 0.0;
          break;
        case "string":
            HEAPF32[((p)>>2)]=0;
        case "object":
          if (result === null) {
            throw 'Native code calling glGetFloatv(' + name_ + ') and it returns null';
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAPF32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetFloatv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGetBooleanv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP8[(p)]=result != 0;
          break;
        case "boolean":
          HEAP8[(p)]=result != 0;
          break;
        case "string":
          throw 'Native code calling glGetBooleanv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP8[(p)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP8[(((p)+(i))|0)]=result[i] != 0;
            }
          } else if (result instanceof WebGLBuffer ||
                     result instanceof WebGLProgram ||
                     result instanceof WebGLFramebuffer ||
                     result instanceof WebGLRenderbuffer ||
                     result instanceof WebGLTexture) {
            HEAP8[(p)]=1; // non-zero ID is always 1!
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
            throw 'Unknown object returned from WebGL getParameter';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data);
    }
  function _glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, data);
    }
  function _glGetTexParameterfv(target, pname, params) {
      HEAPF32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glGetTexParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      Module.ctx.texParameterf(target, pname, param);
    }
  function _glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      Module.ctx.texParameteri(target, pname, param);
    }
  function _glIsTexture(texture) {
      var texture = GL.textures[texture];
      if (!texture) return 0;
      return Module.ctx.isTexture(texture);
    }
  function _glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.buffers);
        var buffer = Module.ctx.createBuffer();
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }
  function _glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
        Module.ctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }
  function _glGetBufferParameteriv(target, value, data) {
      HEAP32[((data)>>2)]=Module.ctx.getBufferParameter(target, value);
    }
  function _glBufferData(target, size, data, usage) {
      switch (usage) { // fix usages, WebGL only has *_DRAW
        case 0x88E1: // GL_STREAM_READ
        case 0x88E2: // GL_STREAM_COPY
          usage = 0x88E0; // GL_STREAM_DRAW
          break;
        case 0x88E5: // GL_STATIC_READ
        case 0x88E6: // GL_STATIC_COPY
          usage = 0x88E4; // GL_STATIC_DRAW
          break;
        case 0x88E9: // GL_DYNAMIC_READ
        case 0x88EA: // GL_DYNAMIC_COPY
          usage = 0x88E8; // GL_DYNAMIC_DRAW
          break;
      }
      Module.ctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
    }
  function _glBufferSubData(target, offset, size, data) {
      Module.ctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }
  function _glIsBuffer(buffer) {
      var b = GL.buffers[buffer];
      if (!b) return 0;
      return Module.ctx.isBuffer(b);
    }
  function _glGetRenderbufferParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.ctx.getRenderbufferParameter(target, pname);
    }
  function _glIsRenderbuffer(renderbuffer) {
      var rb = GL.renderbuffers[renderbuffer];
      if (!rb) return 0;
      return Module.ctx.isRenderbuffer(rb);
    }
  function _glGetUniformfv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformiv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
      var ptable = GL.uniformTable[program];
      if (!ptable) ptable = GL.uniformTable[program] = {};
      var id = ptable[name];
      if (id) return id;
      var loc = Module.ctx.getUniformLocation(GL.programs[program], name);
      if (!loc) return -1;
      id = GL.getNewId(GL.uniforms);
      GL.uniforms[id] = loc;
      ptable[name] = id;
      return id;
    }
  function _glGetVertexAttribfv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribiv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribPointerv(index, pname, pointer) {
      HEAP32[((pointer)>>2)]=Module.ctx.getVertexAttribOffset(index, pname);
    }
  function _glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveUniform(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glUniform1f(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1f(location, v0);
    }
  function _glUniform2f(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2f(location, v0, v1);
    }
  function _glUniform3f(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3f(location, v0, v1, v2);
    }
  function _glUniform4f(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4f(location, v0, v1, v2, v3);
    }
  function _glUniform1i(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1i(location, v0);
    }
  function _glUniform2i(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2i(location, v0, v1);
    }
  function _glUniform3i(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3i(location, v0, v1, v2);
    }
  function _glUniform4i(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4i(location, v0, v1, v2, v3);
    }
  function _glUniform1iv(location, count, value) {
      location = GL.uniforms[location];
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform1iv(location, value);
    }
  function _glUniform2iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 2;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform2iv(location, value);
    }
  function _glUniform3iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 3;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform3iv(location, value);
    }
  function _glUniform4iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 4;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform4iv(location, value);
    }
  function _glUniform1fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[0];
        view[0] = HEAPF32[((value)>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      Module.ctx.uniform1fv(location, view);
    }
  function _glUniform2fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[1];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      Module.ctx.uniform2fv(location, view);
    }
  function _glUniform3fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[2];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      Module.ctx.uniform3fv(location, view);
    }
  function _glUniform4fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[3];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
        view[3] = HEAPF32[(((value)+(12))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniform4fv(location, view);
    }
  function _glUniformMatrix2fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[3];
        for (var i = 0; i < 4; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniformMatrix2fv(location, transpose, view);
    }
  function _glUniformMatrix3fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[8];
        for (var i = 0; i < 9; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      Module.ctx.uniformMatrix3fv(location, transpose, view);
    }
  function _glUniformMatrix4fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[15];
        for (var i = 0; i < 16; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      Module.ctx.uniformMatrix4fv(location, transpose, view);
    }
  function _glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
      if (target == Module.ctx.ARRAY_BUFFER) {
        GL.currArrayBuffer = buffer;
      } else if (target == Module.ctx.ELEMENT_ARRAY_BUFFER) {
        GL.currElementArrayBuffer = buffer;
      }
      Module.ctx.bindBuffer(target, bufferObj);
    }
  function _glVertexAttrib1fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+4)>>2);
      Module.ctx.vertexAttrib1fv(index, v);
    }
  function _glVertexAttrib2fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+8)>>2);
      Module.ctx.vertexAttrib2fv(index, v);
    }
  function _glVertexAttrib3fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+12)>>2);
      Module.ctx.vertexAttrib3fv(index, v);
    }
  function _glVertexAttrib4fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+16)>>2);
      Module.ctx.vertexAttrib4fv(index, v);
    }
  function _glGetAttribLocation(program, name) {
      program = GL.programs[program];
      name = Pointer_stringify(name);
      return Module.ctx.getAttribLocation(program, name);
    }
  function _glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveAttrib(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = Module.ctx.createShader(shaderType);
      return id;
    }
  function _glDeleteShader(shader) {
      Module.ctx.deleteShader(GL.shaders[shader]);
      GL.shaders[shader] = null;
    }
  function _glGetAttachedShaders(program, maxCount, count, shaders) {
      var result = Module.ctx.getAttachedShaders(GL.programs[program]);
      var len = result.length;
      if (len > maxCount) {
        len = maxCount;
      }
      HEAP32[((count)>>2)]=len;
      for (var i = 0; i < len; ++i) {
        var id = GL.shaders.indexOf(result[i]);
        assert(id !== -1, 'shader not bound to local id');
        HEAP32[(((shaders)+(i*4))>>2)]=id;
      }
    }
  function _glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
      Module.ctx.shaderSource(GL.shaders[shader], source);
    }
  function _glGetShaderSource(shader, bufSize, length, source) {
      var result = Module.ctx.getShaderSource(GL.shaders[shader]);
      result = result.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(result, source);
      if (length) {
        HEAP32[((length)>>2)]=result.length;
      }
    }
  function _glCompileShader(shader) {
      Module.ctx.compileShader(GL.shaders[shader]);
    }
  function _glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = Module.ctx.getShaderInfoLog(GL.shaders[shader]);
      // Work around a bug in Chromium which causes getShaderInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glGetShaderiv(shader, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getShaderInfoLog(GL.shaders[shader]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }
  function _glGetProgramiv(program, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getProgramInfoLog(GL.programs[program]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getProgramParameter(GL.programs[program], pname);
      }
    }
  function _glIsShader(shader) {
      var s = GL.shaders[shader];
      if (!s) return 0;
      return Module.ctx.isShader(s);
    }
  function _glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = Module.ctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }
  function _glDeleteProgram(program) {
      var program = GL.programs[program];
      Module.ctx.deleteProgram(program);
      program.name = 0;
      GL.programs[program] = null;
      GL.uniformTable[program] = null;
    }
  function _glAttachShader(program, shader) {
      Module.ctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glDetachShader(program, shader) {
      Module.ctx.detachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
      var result = Module.ctx.getShaderPrecisionFormat(shaderType, precisionType);
      HEAP32[((range)>>2)]=result.rangeMin;
      HEAP32[(((range)+(4))>>2)]=result.rangeMax;
      HEAP32[((precision)>>2)]=result.precision;
    }
  function _glLinkProgram(program) {
      Module.ctx.linkProgram(GL.programs[program]);
      GL.uniformTable[program] = {}; // uniforms no longer keep the same names after linking
    }
  function _glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = Module.ctx.getProgramInfoLog(GL.programs[program]);
      // Work around a bug in Chromium which causes getProgramInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glUseProgram(program) {
      Module.ctx.useProgram(program ? GL.programs[program] : null);
    }
  function _glValidateProgram(program) {
      Module.ctx.validateProgram(GL.programs[program]);
    }
  function _glIsProgram(program) {
      var program = GL.programs[program];
      if (!program) return 0;
      return Module.ctx.isProgram(program);
    }
  function _glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      Module.ctx.bindAttribLocation(GL.programs[program], index, name);
    }
  function _glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = Module.ctx.getFramebufferAttachmentParameter(target, attachment, pname);
      HEAP32[((params)>>2)]=params;
    }
  function _glIsFramebuffer(framebuffer) {
      var fb = GL.framebuffers[framebuffer];
      if (!fb) return 0;
      return Module.ctx.isFramebuffer(fb);
    }
  function _glVertexPointer(){ throw 'Legacy GL function (glVertexPointer) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glGenVertexArrays(){ throw 'Legacy GL function (glGenVertexArrays) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glMatrixMode(){ throw 'Legacy GL function (glMatrixMode) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glBegin(){ throw 'Legacy GL function (glBegin) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glLoadIdentity(){ throw 'Legacy GL function (glLoadIdentity) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _gluPerspective(fov, aspect, near, far) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix[GL.immediate.currentMatrix] =
        GL.immediate.matrix.lib.mat4.perspective(fov, aspect, near, far,
                                                 GL.immediate.matrix[GL.immediate.currentMatrix]);
    }
  function _gluLookAt(ex, ey, ez, cx, cy, cz, ux, uy, uz) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix.lib.mat4.lookAt(GL.immediate.matrix[GL.immediate.currentMatrix], [ex, ey, ez],
          [cx, cy, cz], [ux, uy, uz]);
    }
  function _gluProject(objX, objY, objZ, model, proj, view, winX, winY, winZ) {
      // The algorithm for this functions comes from Mesa
      var inVec = new Float32Array(4);
      var outVec = new Float32Array(4);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((model)>>3,(model+128)>>3),
          [objX, objY, objZ, 1.0], outVec);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          outVec, inVec);
      if (inVec[3] == 0.0) {
        return 0 /* GL_FALSE */;
      }
      inVec[0] /= inVec[3];
      inVec[1] /= inVec[3];
      inVec[2] /= inVec[3];
      // Map x, y and z to range 0-1 */
      inVec[0] = inVec[0] * 0.5 + 0.5;
      inVec[1] = inVec[1] * 0.5 + 0.5;
      inVec[2] = inVec[2] * 0.5 + 0.5;
      // Map x, y to viewport
      inVec[0] = inVec[0] * HEAP32[(((view)+(8))>>2)] + HEAP32[((view)>>2)];
      inVec[1] = inVec[1] * HEAP32[(((view)+(12))>>2)] + HEAP32[(((view)+(4))>>2)];
      HEAPF64[((winX)>>3)]=inVec[0];
      HEAPF64[((winY)>>3)]=inVec[1];
      HEAPF64[((winZ)>>3)]=inVec[2];
      return 1 /* GL_TRUE */;
    }
  function _gluUnProject(winX, winY, winZ, model, proj, view, objX, objY, objZ) {
      var result = GL.immediate.matrix.lib.mat4.unproject([winX, winY, winZ],
          HEAPF64.subarray((model)>>3,(model+128)>>3),
          HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          HEAP32.subarray((view)>>2,(view+16)>>2));
      if (result === null) {
        return 0 /* GL_FALSE */;
      }
      HEAPF64[((objX)>>3)]=result[0];
      HEAPF64[((objY)>>3)]=result[1];
      HEAPF64[((objZ)>>3)]=result[2];
      return 1 /* GL_TRUE */;
    }
  function _gluOrtho2D(left, right, bottom, top) {
      _glOrtho(left, right, bottom, top, -1, 1);
    }
  function _glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      Module.ctx.vertexAttribPointer(index, size, type, normalized, stride, ptr);
    }
  function _glEnableVertexAttribArray(index) {
      Module.ctx.enableVertexAttribArray(index);
    }
  function _glDisableVertexAttribArray(index) {
      Module.ctx.disableVertexAttribArray(index);
    }
  function _glDrawElements(mode, count, type, indices) {
      Module.ctx.drawElements(mode, count, type, indices);
    }
  function _glFinish() { Module.ctx.finish() }
  function _glFlush() { Module.ctx.flush() }
  function _glClearDepth(x0) { Module.ctx.clearDepth(x0) }
  function _glClearDepthf(x0) { Module.ctx.clearDepth(x0) }
  function _glDepthFunc(x0) { Module.ctx.depthFunc(x0) }
  function _glFrontFace(x0) { Module.ctx.frontFace(x0) }
  function _glCullFace(x0) { Module.ctx.cullFace(x0) }
  function _glLineWidth(x0) { Module.ctx.lineWidth(x0) }
  function _glClearStencil(x0) { Module.ctx.clearStencil(x0) }
  function _glDepthMask(x0) { Module.ctx.depthMask(x0) }
  function _glStencilMask(x0) { Module.ctx.stencilMask(x0) }
  function _glGenerateMipmap(x0) { Module.ctx.generateMipmap(x0) }
  function _glActiveTexture(x0) { Module.ctx.activeTexture(x0) }
  function _glBlendEquation(x0) { Module.ctx.blendEquation(x0) }
  function _glSampleCoverage(x0) { Module.ctx.sampleCoverage(x0) }
  function _glIsEnabled(x0) { return Module.ctx.isEnabled(x0) }
  function _glBlendEquationSeparate(x0, x1) { Module.ctx.blendEquationSeparate(x0, x1) }
  function _glDepthRange(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glDepthRangef(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glStencilMaskSeparate(x0, x1) { Module.ctx.stencilMaskSeparate(x0, x1) }
  function _glHint(x0, x1) { Module.ctx.hint(x0, x1) }
  function _glPolygonOffset(x0, x1) { Module.ctx.polygonOffset(x0, x1) }
  function _glVertexAttrib1f(x0, x1) { Module.ctx.vertexAttrib1f(x0, x1) }
  function _glTexParameterf(x0, x1, x2) { Module.ctx.texParameterf(x0, x1, x2) }
  function _glVertexAttrib2f(x0, x1, x2) { Module.ctx.vertexAttrib2f(x0, x1, x2) }
  function _glStencilFunc(x0, x1, x2) { Module.ctx.stencilFunc(x0, x1, x2) }
  function _glStencilOp(x0, x1, x2) { Module.ctx.stencilOp(x0, x1, x2) }
  function _glScissor(x0, x1, x2, x3) { Module.ctx.scissor(x0, x1, x2, x3) }
  function _glVertexAttrib3f(x0, x1, x2, x3) { Module.ctx.vertexAttrib3f(x0, x1, x2, x3) }
  function _glColorMask(x0, x1, x2, x3) { Module.ctx.colorMask(x0, x1, x2, x3) }
  function _glBlendFuncSeparate(x0, x1, x2, x3) { Module.ctx.blendFuncSeparate(x0, x1, x2, x3) }
  function _glBlendColor(x0, x1, x2, x3) { Module.ctx.blendColor(x0, x1, x2, x3) }
  function _glStencilFuncSeparate(x0, x1, x2, x3) { Module.ctx.stencilFuncSeparate(x0, x1, x2, x3) }
  function _glStencilOpSeparate(x0, x1, x2, x3) { Module.ctx.stencilOpSeparate(x0, x1, x2, x3) }
  function _glVertexAttrib4f(x0, x1, x2, x3, x4) { Module.ctx.vertexAttrib4f(x0, x1, x2, x3, x4) }
  function _glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }
  function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }function _emscripten_procAddressTable(name) {
  switch(name) {
  case "glPixelStorei": return 118; break;
  case "glGetString": return 70; break;
  case "glGetIntegerv": return 50; break;
  case "glGetFloatv": return 64; break;
  case "glGetBooleanv": return 82; break;
  case "glGenTextures": return 48; break;
  case "glDeleteTextures": return 88; break;
  case "glCompressedTexImage2D": return 2; break;
  case "glCompressedTexSubImage2D": return 4; break;
  case "glTexImage2D": return 8; break;
  case "glTexSubImage2D": return 6; break;
  case "glReadPixels": return 6; break;
  case "glBindTexture": return 62; break;
  case "glGetTexParameterfv": return 80; break;
  case "glGetTexParameteriv": return 12; break;
  case "glTexParameterfv": return 50; break;
  case "glTexParameteriv": return 2; break;
  case "glIsTexture": return 88; break;
  case "glGenBuffers": return 38; break;
  case "glDeleteBuffers": return 26; break;
  case "glGetBufferParameteriv": return 82; break;
  case "glBufferData": return 38; break;
  case "glBufferSubData": return 18; break;
  case "glIsBuffer": return 58; break;
  case "glGenRenderbuffers": return 116; break;
  case "glDeleteRenderbuffers": return 98; break;
  case "glBindRenderbuffer": return 86; break;
  case "glGetRenderbufferParameteriv": return 56; break;
  case "glIsRenderbuffer": return 96; break;
  case "glGetUniformfv": return 52; break;
  case "glGetUniformiv": return 28; break;
  case "glGetUniformLocation": return 26; break;
  case "glGetVertexAttribfv": return 46; break;
  case "glGetVertexAttribiv": return 48; break;
  case "glGetVertexAttribPointerv": return 16; break;
  case "glGetActiveUniform": return 4; break;
  case "glUniform1f": return 4; break;
  case "glUniform2f": return 2; break;
  case "glUniform3f": return 2; break;
  case "glUniform4f": return 6; break;
  case "glUniform1i": return 110; break;
  case "glUniform2i": return 8; break;
  case "glUniform3i": return 22; break;
  case "glUniform4i": return 10; break;
  case "glUniform1iv": return 18; break;
  case "glUniform2iv": return 26; break;
  case "glUniform3iv": return 22; break;
  case "glUniform4iv": return 40; break;
  case "glUniform1fv": return 24; break;
  case "glUniform2fv": return 44; break;
  case "glUniform3fv": return 84; break;
  case "glUniform4fv": return 34; break;
  case "glUniformMatrix2fv": return 2; break;
  case "glUniformMatrix3fv": return 14; break;
  case "glUniformMatrix4fv": return 4; break;
  case "glBindBuffer": return 32; break;
  case "glVertexAttrib1fv": return 66; break;
  case "glVertexAttrib2fv": return 84; break;
  case "glVertexAttrib3fv": return 112; break;
  case "glVertexAttrib4fv": return 24; break;
  case "glGetAttribLocation": return 76; break;
  case "glGetActiveAttrib": return 2; break;
  case "glCreateShader": return 56; break;
  case "glDeleteShader": return 126; break;
  case "glGetAttachedShaders": return 40; break;
  case "glShaderSource": return 32; break;
  case "glGetShaderSource": return 56; break;
  case "glCompileShader": return 124; break;
  case "glGetShaderInfoLog": return 48; break;
  case "glGetShaderiv": return 32; break;
  case "glGetProgramiv": return 30; break;
  case "glIsShader": return 60; break;
  case "glCreateProgram": return 28; break;
  case "glDeleteProgram": return 74; break;
  case "glAttachShader": return 18; break;
  case "glDetachShader": return 100; break;
  case "glLinkProgram": return 38; break;
  case "glGetProgramInfoLog": return 54; break;
  case "glUseProgram": return 46; break;
  case "glValidateProgram": return 86; break;
  case "glIsProgram": return 94; break;
  case "glBindAttribLocation": return 38; break;
  case "glBindFramebuffer": return 52; break;
  case "glGenFramebuffers": return 54; break;
  case "glDeleteFramebuffers": return 56; break;
  case "glFramebufferRenderbuffer": return 6; break;
  case "glFramebufferTexture2D": return 8; break;
  case "glGetFramebufferAttachmentParameteriv": return 36; break;
  case "glIsFramebuffer": return 52; break;
  case "glVertexAttribPointer": return 14; break;
  case "glEnableVertexAttribArray": return 30; break;
  case "glDisableVertexAttribArray": return 4; break;
  case "glDrawArrays": return 14; break;
  case "glDrawElements": return 16; break;
  case "glGetError": return 10; break;
  case "glFinish": return 80; break;
  case "glFlush": return 502; break;
  case "glClearDepth": return 40; break;
  case "glClearDepthf": return 92; break;
  case "glDepthFunc": return 114; break;
  case "glEnable": return 42; break;
  case "glDisable": return 72; break;
  case "glFrontFace": return 64; break;
  case "glCullFace": return 22; break;
  case "glClear": return 98; break;
  case "glLineWidth": return 108; break;
  case "glClearStencil": return 2; break;
  case "glDepthMask": return 12; break;
  case "glStencilMask": return 132; break;
  case "glCheckFramebufferStatus": return 36; break;
  case "glGenerateMipmap": return 50; break;
  case "glActiveTexture": return 28; break;
  case "glBlendEquation": return 76; break;
  case "glSampleCoverage": return 94; break;
  case "glIsEnabled": return 76; break;
  case "glBlendFunc": return 74; break;
  case "glBlendEquationSeparate": return 28; break;
  case "glDepthRange": return 106; break;
  case "glDepthRangef": return 68; break;
  case "glStencilMaskSeparate": return 16; break;
  case "glHint": return 44; break;
  case "glPolygonOffset": return 34; break;
  case "glVertexAttrib1f": return 30; break;
  case "glTexParameteri": return 64; break;
  case "glTexParameterf": return 66; break;
  case "glVertexAttrib2f": return 36; break;
  case "glStencilFunc": return 42; break;
  case "glStencilOp": return 72; break;
  case "glViewport": return 30; break;
  case "glClearColor": return 10; break;
  case "glScissor": return 26; break;
  case "glVertexAttrib3f": return 52; break;
  case "glColorMask": return 42; break;
  case "glRenderbufferStorage": return 50; break;
  case "glBlendFuncSeparate": return 24; break;
  case "glBlendColor": return 44; break;
  case "glStencilFuncSeparate": return 28; break;
  case "glStencilOpSeparate": return 20; break;
  case "glVertexAttrib4f": return 2; break;
  case "glCopyTexImage2D": return 6; break;
  case "glCopyTexSubImage2D": return 4; break;
  }
  return 0;
  }function _emscripten_GetProcAddress(name) {
    name = name.replace('EXT', '').replace('ARB', '');
    switch(name) { // misc renamings
      case 'glCreateProgramObject': name = 'glCreateProgram'; break;
      case 'glUseProgramObject': name = 'glUseProgram'; break;
      case 'glCreateShaderObject': name = 'glCreateShader'; break;
      case 'glAttachObject': name = 'glAttachShader'; break;
      case 'glDetachObject': name = 'glDetachShader'; break;
    }
    var ret = _emscripten_procAddressTable(name);
    if (!ret) Module.printErr('WARNING: getProcAddress failed for ' + name);
    return ret;
  }function _eglGetProcAddress(name_) {
      return _emscripten_GetProcAddress(Pointer_stringify(name_));
    }
  function _emscripten_get_canvas_size(width, height, isFullscreen) {
      var canvas = Module['canvas'];
      HEAP32[((width)>>2)]=canvas.width;
      HEAP32[((height)>>2)]=canvas.height;
      HEAP32[((isFullscreen)>>2)]=Browser.isFullScreen ? 1 : 0;
    }
  var EGL={eglErrorCode:12288,setErrorCode:function (code) {
        EGL.eglErrorCode = code;
      },chooseConfig:function (display, attribList, config, config_size, numConfigs) { 
        if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
          EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
          return 0;
        }
        // TODO: read attribList.
        if ((!config || !config_size) && !numConfigs) {
          EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
          return 0;
        }
        if (numConfigs) {
          HEAP32[((numConfigs)>>2)]=1; // Total number of supported configs: 1.
        }
        if (config && config_size > 0) {
          HEAP32[((config)>>2)]=62002; 
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      }};function _eglBindAPI(api) {
      if (api == 0x30A0 /* EGL_OPENGL_ES_API */) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } else { // if (api == 0x30A1 /* EGL_OPENVG_API */ || api == 0x30A2 /* EGL_OPENGL_API */) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
    }
  function _eglMakeCurrent(display, draw, read, context) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      //\todo An EGL_NOT_INITIALIZED error is generated if EGL is not initialized for dpy. 
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      if (read != 62006 || draw != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _glutDestroyWindow(name) {
      Module.ctx = Browser.destroyContext(Module['canvas'], true, true);
      return 1;
    }function _eglDestroyContext(display, context) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglDestroySurface(display, surface) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0; 
      }
      if (surface != 62006 /* Magic ID for the only EGLSurface supported by Emscripten */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 1;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglTerminate(display) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      // TODO: Tear down EGL here. Currently a no-op since we don't need to actually do anything here for the browser.
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglGetDisplay(nativeDisplayType) {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      // Note: As a 'conformant' implementation of EGL, we would prefer to init here only if the user
      //       calls this function with EGL_DEFAULT_DISPLAY. Other display IDs would be preferred to be unsupported
      //       and EGL_NO_DISPLAY returned. Uncomment the following code lines to do this.
      // Instead, an alternative route has been preferred, namely that the Emscripten EGL implementation
      // "emulates" X11, and eglGetDisplay is expected to accept/receive a pointer to an X11 Display object.
      // Therefore, be lax and allow anything to be passed in, and return the magic handle to our default EGLDisplay object.
  //    if (nativeDisplayType == 0 /* EGL_DEFAULT_DISPLAY */) {
          return 62000; // Magic ID for Emscripten 'default display'
  //    }
  //    else
  //      return 0; // EGL_NO_DISPLAY
    }
  function _eglInitialize(display, majorVersion, minorVersion) {
      if (display == 62000 /* Magic ID for Emscripten 'default display' */) {
        if (majorVersion) {
          HEAP32[((majorVersion)>>2)]=1; // Advertise EGL Major version: '1'
        }
        if (minorVersion) {
          HEAP32[((minorVersion)>>2)]=4; // Advertise EGL Minor version: '4'
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } 
      else {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
    }
  function _eglChooseConfig(display, attrib_list, configs, config_size, numConfigs) { 
      return EGL.chooseConfig(display, attrib_list, configs, config_size, numConfigs);
    }
  function _glutCreateWindow(name) {
      Module.ctx = Browser.createContext(Module['canvas'], true, true);
      return Module.ctx ? 1 /* a new GLUT window ID for the created context */ : 0 /* failure */;
    }function _eglCreateContext(display, config, hmm, contextAttribs) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      EGL.windowID = _glutCreateWindow();
      if (EGL.windowID != 0) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 62004; // Magic ID for Emscripten EGLContext
      } else {
        EGL.setErrorCode(0x3009 /* EGL_BAD_MATCH */); // By the EGL 1.4 spec, an implementation that does not support GLES2 (WebGL in this case), this error code is set.
        return 0; /* EGL_NO_CONTEXT */
      }
    }
  function _eglCreateWindowSurface(display, config, win, attrib_list) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (config != 62002 /* Magic ID for the only EGLConfig supported by Emscripten */) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0;
      }
      // TODO: Examine attrib_list! Parameters that can be present there are:
      // - EGL_RENDER_BUFFER (must be EGL_BACK_BUFFER)
      // - EGL_VG_COLORSPACE (can't be set)
      // - EGL_VG_ALPHA_FORMAT (can't be set)
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 62006; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglQuerySurface(display, surface, attribute, value) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (surface != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      if (!value) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      switch(attribute) {
      case 0x3028: // EGL_CONFIG_ID
        HEAP32[((value)>>2)]=62002;
          return 1;
      case 0x3058: // EGL_LARGEST_PBUFFER
        // Odd EGL API: If surface is not a pbuffer surface, 'value' should not be written to. It's not specified as an error, so true should(?) be returned.
        // Existing Android implementation seems to do so at least.
        return 1;
      case 0x3057: // EGL_WIDTH
        HEAP32[((value)>>2)]=Module.canvas.width;
        return 1;
      case 0x3056: // EGL_HEIGHT
        HEAP32[((value)>>2)]=Module.canvas.height;
        return 1;
      case 0x3090: // EGL_HORIZONTAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3091: // EGL_VERTICAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3092: // EGL_PIXEL_ASPECT_RATIO
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3086: // EGL_RENDER_BUFFER
        // The main surface is bound to the visible canvas window - it's always backbuffered. 
        // Alternative to EGL_BACK_BUFFER would be EGL_SINGLE_BUFFER.
        HEAP32[((value)>>2)]=0x3084; 
        return 1;
      case 0x3099: // EGL_MULTISAMPLE_RESOLVE
        HEAP32[((value)>>2)]=0x309A; 
        return 1;
      case 0x3093: // EGL_SWAP_BEHAVIOR
        // The two possibilities are EGL_BUFFER_PRESERVED and EGL_BUFFER_DESTROYED. Slightly unsure which is the
        // case for browser environment, but advertise the 'weaker' behavior to be sure.
        HEAP32[((value)>>2)]=0x3095;
        return 1;
      case 0x3080: // EGL_TEXTURE_FORMAT
      case 0x3081: // EGL_TEXTURE_TARGET
      case 0x3082: // EGL_MIPMAP_TEXTURE
      case 0x3083: // EGL_MIPMAP_LEVEL
        // This is a window surface, not a pbuffer surface. Spec:
        // "Querying EGL_TEXTURE_FORMAT, EGL_TEXTURE_TARGET, EGL_MIPMAP_TEXTURE, or EGL_MIPMAP_LEVEL for a non-pbuffer surface is not an error, but value is not modified."
        // So pass-through.
        return 1;
      default:
        EGL.setErrorCode(0x3004 /* EGL_BAD_ATTRIBUTE */);
        return 0;
      }
    }
  function _atoi(ptr) {
      return _strtol(ptr, null, 10);
    }
  Module["_strncpy"] = _strncpy;
  var _atan=Math.atan;
  function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }
  Module["_strcpy"] = _strcpy;
  function _rand() {
      return Math.floor(Math.random()*0x80000000);
    }
  var _atan2=Math.atan2;
  var _sqrtf=Math.sqrt;
  function _vsnprintf(s, n, format, va_arg) {
      return _snprintf(s, n, format, HEAP32[((va_arg)>>2)]);
    }
  var _llvm_va_start=undefined;
  function _llvm_va_end() {}
  var _floorf=Math.floor;
  Module["_strcat"] = _strcat;
  function _llvm_bswap_i16(x) {
      return ((x&0xff)<<8) | ((x>>8)&0xff);
    }
  function _memchr(ptr, chr, num) {
      chr = unSign(chr);
      for (var i = 0; i < num; i++) {
        if (HEAP8[(ptr)] == chr) return ptr;
        ptr++;
      }
      return 0;
    }
  var _ceilf=Math.ceil;
  function __isFloat(text) {
      return !!(/^[+-]?[0-9]*\.?[0-9]+([eE][+-]?[0-9]+)?$/.exec(text));
    }function __scanString(format, get, unget, varargs) {
      if (!__scanString.whiteSpace) {
        __scanString.whiteSpace = {};
        __scanString.whiteSpace[32] = 1;
        __scanString.whiteSpace[9] = 1;
        __scanString.whiteSpace[10] = 1;
        __scanString.whiteSpace[11] = 1;
        __scanString.whiteSpace[12] = 1;
        __scanString.whiteSpace[13] = 1;
        __scanString.whiteSpace[' '] = 1;
        __scanString.whiteSpace['\t'] = 1;
        __scanString.whiteSpace['\n'] = 1;
        __scanString.whiteSpace['\v'] = 1;
        __scanString.whiteSpace['\f'] = 1;
        __scanString.whiteSpace['\r'] = 1;
      }
      // Supports %x, %4x, %d.%d, %lld, %s, %f, %lf.
      // TODO: Support all format specifiers.
      format = Pointer_stringify(format);
      var soFar = 0;
      if (format.indexOf('%n') >= 0) {
        // need to track soFar
        var _get = get;
        get = function() {
          soFar++;
          return _get();
        }
        var _unget = unget;
        unget = function() {
          soFar--;
          return _unget();
        }
      }
      var formatIndex = 0;
      var argsi = 0;
      var fields = 0;
      var argIndex = 0;
      var next;
      mainLoop:
      for (var formatIndex = 0; formatIndex < format.length;) {
        if (format[formatIndex] === '%' && format[formatIndex+1] == 'n') {
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          HEAP32[((argPtr)>>2)]=soFar;
          formatIndex += 2;
          continue;
        }
        if (format[formatIndex] === '%') {
          var nextC = format.indexOf('c', formatIndex+1);
          if (nextC > 0) {
            var maxx = 1;
            if (nextC > formatIndex+1) {
              var sub = format.substring(formatIndex+1, nextC)
              maxx = parseInt(sub);
              if (maxx != sub) maxx = 0;
            }
            if (maxx) {
              var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
              argIndex += Runtime.getAlignSize('void*', null, true);
              fields++;
              for (var i = 0; i < maxx; i++) {
                next = get();
                HEAP8[((argPtr++)|0)]=next;
              }
              formatIndex += nextC - formatIndex + 1;
              continue;
            }
          }
        }
        // remove whitespace
        while (1) {
          next = get();
          if (next == 0) return fields;
          if (!(next in __scanString.whiteSpace)) break;
        }
        unget();
        if (format[formatIndex] === '%') {
          formatIndex++;
          var suppressAssignment = false;
          if (format[formatIndex] == '*') {
            suppressAssignment = true;
            formatIndex++;
          }
          var maxSpecifierStart = formatIndex;
          while (format[formatIndex].charCodeAt(0) >= 48 &&
                 format[formatIndex].charCodeAt(0) <= 57) {
            formatIndex++;
          }
          var max_;
          if (formatIndex != maxSpecifierStart) {
            max_ = parseInt(format.slice(maxSpecifierStart, formatIndex), 10);
          }
          var long_ = false;
          var half = false;
          var longLong = false;
          if (format[formatIndex] == 'l') {
            long_ = true;
            formatIndex++;
            if (format[formatIndex] == 'l') {
              longLong = true;
              formatIndex++;
            }
          } else if (format[formatIndex] == 'h') {
            half = true;
            formatIndex++;
          }
          var type = format[formatIndex];
          formatIndex++;
          var curr = 0;
          var buffer = [];
          // Read characters according to the format. floats are trickier, they may be in an unfloat state in the middle, then be a valid float later
          if (type == 'f' || type == 'e' || type == 'g' ||
              type == 'F' || type == 'E' || type == 'G') {
            var last = 0;
            next = get();
            while (next > 0) {
              buffer.push(String.fromCharCode(next));
              if (__isFloat(buffer.join(''))) {
                last = buffer.length;
              }
              next = get();
            }
            for (var i = 0; i < buffer.length - last + 1; i++) {
              unget();
            }
            buffer.length = last;
          } else {
            next = get();
            var first = true;
            while ((curr < max_ || isNaN(max_)) && next > 0) {
              if (!(next in __scanString.whiteSpace) && // stop on whitespace
                  (type == 's' ||
                   ((type === 'd' || type == 'u' || type == 'i') && ((next >= 48 && next <= 57) ||
                                                                     (first && next == 45))) ||
                   ((type === 'x' || type === 'X') && (next >= 48 && next <= 57 ||
                                     next >= 97 && next <= 102 ||
                                     next >= 65 && next <= 70))) &&
                  (formatIndex >= format.length || next !== format[formatIndex].charCodeAt(0))) { // Stop when we read something that is coming up
                buffer.push(String.fromCharCode(next));
                next = get();
                curr++;
                first = false;
              } else {
                break;
              }
            }
            unget();
          }
          if (buffer.length === 0) return 0;  // Failure.
          if (suppressAssignment) continue;
          var text = buffer.join('');
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          switch (type) {
            case 'd': case 'u': case 'i':
              if (half) {
                HEAP16[((argPtr)>>1)]=parseInt(text, 10);
              } else if (longLong) {
                (tempI64 = [parseInt(text, 10)>>>0,(tempDouble=parseInt(text, 10),(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)],HEAP32[((argPtr)>>2)]=tempI64[0],HEAP32[(((argPtr)+(4))>>2)]=tempI64[1]);
              } else {
                HEAP32[((argPtr)>>2)]=parseInt(text, 10);
              }
              break;
            case 'X':
            case 'x':
              HEAP32[((argPtr)>>2)]=parseInt(text, 16)
              break;
            case 'F':
            case 'f':
            case 'E':
            case 'e':
            case 'G':
            case 'g':
            case 'E':
              // fallthrough intended
              if (long_) {
                HEAPF64[((argPtr)>>3)]=parseFloat(text)
              } else {
                HEAPF32[((argPtr)>>2)]=parseFloat(text)
              }
              break;
            case 's':
              var array = intArrayFromString(text);
              for (var j = 0; j < array.length; j++) {
                HEAP8[(((argPtr)+(j))|0)]=array[j]
              }
              break;
          }
          fields++;
        } else if (format[formatIndex] in __scanString.whiteSpace) {
          next = get();
          while (next in __scanString.whiteSpace) {
            if (next <= 0) break mainLoop;  // End of input.
            next = get();
          }
          unget(next);
          formatIndex++;
        } else {
          // Not a specifier.
          next = get();
          if (format[formatIndex].charCodeAt(0) !== next) {
            unget(next);
            break mainLoop;
          }
          formatIndex++;
        }
      }
      return fields;
    }
  function _ungetc(c, stream) {
      // int ungetc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ungetc.html
      stream = FS.getStream(stream);
      if (!stream) {
        return -1;
      }
      if (c === -1) {
        // do nothing for EOF character
        return c;
      }
      c = unSign(c & 0xFF);
      stream.ungotten.push(c);
      stream.eof = false;
      return c;
    }function _fscanf(stream, format, varargs) {
      // int fscanf(FILE *restrict stream, const char *restrict format, ... );
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/scanf.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) {
        return -1;
      }
      var buffer = [];
      var get = function() {
        var c = _fgetc(stream);
        buffer.push(c);
        return c;
      };
      var unget = function() {
        _ungetc(buffer.pop(), stream);
      };
      return __scanString(format, get, unget, varargs);
    }
  function _strncat(pdest, psrc, num) {
      var len = _strlen(pdest);
      var i = 0;
      while(1) {
        HEAP8[((pdest+len+i)|0)]=HEAP8[((psrc+i)|0)];
        if (HEAP8[(((pdest)+(len+i))|0)] == 0) break;
        i ++;
        if (i == num) {
          HEAP8[(((pdest)+(len+i))|0)]=0
          break;
        }
      }
      return pdest;
    }
  var _cos=Math.cos;
  var _floor=Math.floor;
  function _abort() {
      Module['abort']();
    }
  var _tan=Math.tan;
  var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_STATIC); 
  Module["_llvm_cttz_i32"] = _llvm_cttz_i32;
  function _mknod(path, mode, dev) {
      // int mknod(const char *path, mode_t mode, dev_t dev);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/mknod.html
      path = Pointer_stringify(path);
      // we don't want this in the JS API as the JS API
      // uses mknod to create all nodes.
      var err = FS.mayMknod(mode);
      if (err) {
        ___setErrNo(err);
        return -1;
      }
      try {
        FS.mknod(path, mode, dev);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _mkdir(path, mode) {
      // int mkdir(const char *path, mode_t mode);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/mkdir.html
      path = Pointer_stringify(path);
      try {
        FS.mkdir(path, mode, 0);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _gettimeofday(ptr) {
      // %struct.timeval = type { i32, i32 }
      var now = Date.now();
      HEAP32[((ptr)>>2)]=Math.floor(now/1000); // seconds
      HEAP32[(((ptr)+(4))>>2)]=Math.floor((now-1000*Math.floor(now/1000))*1000); // microseconds
      return 0;
    }
  var ___strtok_state=0;function _strtok(s, delim) {
      return _strtok_r(s, delim, ___strtok_state);
    }
  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
        case 10: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
___buildEnvironment(ENV);
Module["requestFullScreen"] = function(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function() { Browser.getUserMedia() }
GL.init()
___strtok_state = Runtime.staticAlloc(4);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
staticSealed = true; // seal the static portion of memory
STACK_MAX = STACK_BASE + 5242880;
DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
assert(DYNAMIC_BASE < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY
 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
var Math_min = Math.min;
function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vif(index,a1,a2) {
  try {
    Module["dynCall_vif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viffff(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viffff"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_if(index,a1) {
  try {
    return Module["dynCall_if"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiif(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiif"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viff(index,a1,a2,a3) {
  try {
    Module["dynCall_viff"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vifff(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_vifff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_fii(index,a1,a2) {
  try {
    return Module["dynCall_fii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiif(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iif(index,a1,a2) {
  try {
    return Module["dynCall_iif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ff(index,a1) {
  try {
    return Module["dynCall_ff"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_i(index) {
  try {
    return Module["dynCall_i"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env._stdout|0;var p=env._stderr|0;var q=+env.NaN;var r=+env.Infinity;var s=0;var t=0;var u=0;var v=0;var w=0,x=0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0.0;var F=0;var G=0;var H=0;var I=0;var J=0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=global.Math.floor;var Q=global.Math.abs;var R=global.Math.sqrt;var S=global.Math.pow;var T=global.Math.cos;var U=global.Math.sin;var V=global.Math.tan;var W=global.Math.acos;var X=global.Math.asin;var Y=global.Math.atan;var Z=global.Math.atan2;var _=global.Math.exp;var $=global.Math.log;var aa=global.Math.ceil;var ab=global.Math.imul;var ac=env.abort;var ad=env.assert;var ae=env.asmPrintInt;var af=env.asmPrintFloat;var ag=env.min;var ah=env.invoke_iiiiiiii;var ai=env.invoke_vif;var aj=env.invoke_viiiii;var ak=env.invoke_vi;var al=env.invoke_vii;var am=env.invoke_iiiiiii;var an=env.invoke_ii;var ao=env.invoke_viiiiiiiiiii;var ap=env.invoke_viffff;var aq=env.invoke_if;var ar=env.invoke_iiiiii;var as=env.invoke_iiii;var at=env.invoke_viiiiif;var au=env.invoke_viff;var av=env.invoke_vifff;var aw=env.invoke_fii;var ax=env.invoke_iiif;var ay=env.invoke_viiiiiiii;var az=env.invoke_iif;var aA=env.invoke_viiiiiii;var aB=env.invoke_ff;var aC=env.invoke_viiiiiiiii;var aD=env.invoke_iii;var aE=env.invoke_viiiiii;var aF=env.invoke_i;var aG=env.invoke_iiiii;var aH=env.invoke_viii;var aI=env.invoke_v;var aJ=env.invoke_viiii;var aK=env._llvm_lifetime_end;var aL=env._lseek;var aM=env._RWebInputDestroy;var aN=env._RWebAudioStop;var aO=env._glClearColor;var aP=env._sysconf;var aQ=env._rand;var aR=env.__scanString;var aS=env._fclose;var aT=env._RWebAudioInit;var aU=env._glGetVertexAttribPointerv;var aV=env._glGetRenderbufferParameteriv;var aW=env._eglDestroySurface;var aX=env._strtoul;var aY=env._strtoull;var aZ=env._glBindTexture;var a_=env._fflush;var a$=env._glGetUniformiv;var a0=env._fabsf;var a1=env._strtol;var a2=env._fputc;var a3=env._glGetString;var a4=env._strtok;var a5=env._fwrite;var a6=env._gluUnProject;var a7=env._send;var a8=env._fputs;var a9=env._glLineWidth;var ba=env._glUniform2fv;var bb=env._emscripten_get_now;var bc=env._eglCreateContext;var bd=env._glBindAttribLocation;var be=env._glCompileShader;var bf=env._isspace;var bg=env._localtime;var bh=env._glDeleteTextures;var bi=env._eglBindAPI;var bj=env._glCompressedTexImage2D;var bk=env._glStencilFuncSeparate;var bl=env._read;var bm=env._RWebAudioBufferSize;var bn=env._glDeleteShader;var bo=env._RWebInputInit;var bp=env._glClearDepthf;var bq=env._glUniform4iv;var br=env._glGetTexParameteriv;var bs=env._glClearStencil;var bt=env._glLoadIdentity;var bu=env._glUniform1fv;var bv=env._glIsShader;var bw=env._strstr;var bx=env._glSampleCoverage;var by=env._fsync;var bz=env._glGenTextures;var bA=env._glDepthFunc;var bB=env._remove;var bC=env._glCompressedTexSubImage2D;var bD=env._ceilf;var bE=env._glUniform1f;var bF=env._opendir;var bG=env._mkdir;var bH=env._glGetTexParameterfv;var bI=env._RWebAudioWrite;var bJ=env._glStencilMaskSeparate;var bK=env._glCreateShader;var bL=env._round;var bM=env._glUniform1i;var bN=env._strncmp;var bO=env._cosf;var bP=env._glDeleteRenderbuffers;var bQ=env._glLinkProgram;var bR=env._snprintf;var bS=env._glUniform2i;var bT=env._fgetc;var bU=env._glStencilFunc;var bV=env._vsnprintf;var bW=env._glShaderSource;var bX=env._readdir;var bY=env._glVertexAttribPointer;var bZ=env._glHint;var b_=env._mknod;var b$=env._glBindBuffer;var b0=env._glVertexPointer;var b1=env._fgets;var b2=env._close;var b3=env._getgid;var b4=env._glGetAttachedShaders;var b5=env._glBindFramebuffer;var b6=env._glIsFramebuffer;var b7=env._strchr;var b8=env._llvm_bswap_i16;var b9=env._glUniform4fv;var ca=env._abort;var cb=env.___setErrNo;var cc=env._glDeleteFramebuffers;var cd=env._eglTerminate;var ce=env._glGetVertexAttribfv;var cf=env._glIsBuffer;var cg=env._emscripten_GetProcAddress;var ch=env._eglGetProcAddress;var ci=env._ftell;var cj=env._glDeleteProgram;var ck=env._exit;var cl=env._sprintf;var cm=env._glRenderbufferStorage;var cn=env._strrchr;var co=env._glAttachShader;var cp=env._RWebInputPoll;var cq=env._glUniform3i;var cr=env._glIsProgram;var cs=env._glCheckFramebufferStatus;var ct=env.__isLeapYear;var cu=env._gluProject;var cv=env._llvm_uadd_with_overflow_i32;var cw=env._localtime_r;var cx=env._glUniform3f;var cy=env._glGetBufferParameteriv;var cz=env._glFlush;var cA=env._glBlendEquationSeparate;var cB=env._emscripten_get_canvas_size;var cC=env._glCopyTexImage2D;var cD=env._glDrawElements;var cE=env._glColorMask;var cF=env._sinf;var cG=env._gluLookAt;var cH=env._eglInitialize;var cI=env._recv;var cJ=env.__parseInt64;var cK=env._glVertexAttrib1fv;var cL=env._glUniform2iv;var cM=env._cos;var cN=env._putchar;var cO=env._glUniform1iv;var cP=env._glActiveTexture;var cQ=env._glMatrixMode;var cR=env._glBlendEquation;var cS=env._strcmp;var cT=env._glVertexAttrib1f;var cU=env._RWebAudioWriteAvail;var cV=env._glGenerateMipmap;var cW=env._memchr;var cX=env._glDetachShader;var cY=env._glGetShaderiv;var cZ=env.__exit;var c_=env._strftime;var c$=env._glVertexAttrib3f;var c0=env._glGenRenderbuffers;var c1=env._tzset;var c2=env._RWebAudioSampleRate;var c3=env._floorf;var c4=env._glGetShaderPrecisionFormat;var c5=env._glVertexAttrib4fv;var c6=env._glDepthMask;var c7=env._glDisableVertexAttribArray;var c8=env._glBegin;var c9=env._printf;var da=env._glBindRenderbuffer;var db=env._pread;var dc=env._fopen;var dd=env._open;var de=env._glDrawArrays;var df=env._usleep;var dg=env._llvm_pow_f32;var dh=env.__arraySum;var di=env._glCopyTexSubImage2D;var dj=env._sqrtf;var dk=env._glDisable;var dl=env._puts;var dm=env._glUniform4i;var dn=env._nanosleep;var dp=env._glClear;var dq=env._qsort;var dr=env._glUniform2f;var ds=env._eglDestroyContext;var dt=env._isalpha;var du=env._glEnableVertexAttribArray;var dv=env._rmdir;var dw=env._glUniform3fv;var dx=env._glStencilOp;var dy=env._strdup;var dz=env._glDepthRange;var dA=env._glUniform4f;var dB=env._glFramebufferTexture2D;var dC=env._glUniformMatrix2fv;var dD=env._glGenVertexArrays;var dE=env._eglMakeCurrent;var dF=env._glUniformMatrix3fv;var dG=env._glutCreateWindow;var dH=env._glBufferData;var dI=env._glBlendColor;var dJ=env._glGetUniformLocation;var dK=env._glIsEnabled;var dL=env.__formatString;var dM=env._getenv;var dN=env._glGetError;var dO=env._gettimeofday;var dP=env._glGetVertexAttribiv;var dQ=env._glTexParameteriv;var dR=env._glGetProgramiv;var dS=env._glVertexAttrib3fv;var dT=env._glGetFloatv;var dU=env._glBufferSubData;var dV=env._glUniform3iv;var dW=env._glReadPixels;var dX=env._glGenFramebuffers;var dY=env._glFramebufferRenderbuffer;var dZ=env._emscripten_procAddressTable;var d_=env._fscanf;var d$=env._ceil;var d0=env.___errno_location;var d1=env._glGetIntegerv;var d2=env._RWebAudioFree;var d3=env._llvm_lifetime_start;var d4=env._glIsRenderbuffer;var d5=env._llvm_bswap_i32;var d6=env._sbrk;var d7=env.__parseInt;var d8=env._ungetc;var d9=env._RWebAudioSetNonblockState;var ea=env._glVertexAttrib2fv;var eb=env._glGetFramebufferAttachmentParameteriv;var ec=env._glUseProgram;var ed=env._glTexImage2D;var ee=env._glGetProgramInfoLog;var ef=env._glTexSubImage2D;var eg=env._glStencilMask;var eh=env._fread;var ei=env._glStencilOpSeparate;var ej=env._strtok_r;var ek=env._glGetShaderInfoLog;var el=env._glIsTexture;var em=env._eglCreateWindowSurface;var en=env._fprintf;var eo=env._glGetShaderSource;var ep=env._gluPerspective;var eq=env._eglChooseConfig;var er=env._tan;var es=env.___buildEnvironment;var et=env._feof;var eu=env.__addDays;var ev=env._strncat;var ew=env._glScissor;var ex=env._glEnable;var ey=env._glBlendFuncSeparate;var ez=env._floor;var eA=env.__reallyNegative;var eB=env._glGetActiveAttrib;var eC=env._fseek;var eD=env._sqrt;var eE=env._glTexParameterfv;var eF=env._write;var eG=env._glGenBuffers;var eH=env._glFinish;var eI=env._glGetAttribLocation;var eJ=env._glVertexAttrib4f;var eK=env._rewind;var eL=env._sin;var eM=env._glBlendFunc;var eN=env._glCreateProgram;var eO=env._realpath;var eP=env._stat;var eQ=env._longjmp;var eR=env._atan;var eS=env._glViewport;var eT=env._emscripten_set_main_loop;var eU=env._time;var eV=env._glVertexAttrib2f;var eW=env._closedir;var eX=env._isgraph;var eY=env._readlink;var eZ=env._glGetUniformfv;var e_=env._llvm_va_end;var e$=env._unlink;var e0=env._gluOrtho2D;var e1=env._glUniformMatrix4fv;var e2=env._glClearDepth;var e3=env._glGetActiveUniform;var e4=env._glutDestroyWindow;var e5=env._pwrite;var e6=env.__isFloat;var e7=env._fabs;var e8=env._glTexParameterf;var e9=env._RWebAudioStart;var fa=env._glTexParameteri;var fb=env._glFrontFace;var fc=env._glCullFace;var fd=env._glDepthRangef;var fe=env._glDeleteBuffers;var ff=env._eglGetDisplay;var fg=env._emscripten_set_canvas_size;var fh=env._atan2;var fi=env._atoi;var fj=env._glGetBooleanv;var fk=env._eglQuerySurface;var fl=env._glPixelStorei;var fm=env._readdir_r;var fn=env._glValidateProgram;var fo=env._glPolygonOffset;
// EMSCRIPTEN_START_FUNCS
function nt(a){a=a|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0.0,Q=0.0,R=0.0,S=0.0,T=0,U=0;d=i;if((c[353150]|0)==3){c[353704]=4;ni()}if((a&1|0)==0){e=a}else{e=(nL()|0)<<8|a}do{if((c[644543]|0)==666){if((e&32768|0)==0){f=e}else{f=(nL()|0)<<16|e}if((f&8388608|0)==0){j=f;break}j=(nL()|0)<<24|f}else{j=e}}while(0);if((j&16384|0)==0){k=nL()|0}else{k=nM()|0}e=c[644472]|0;do{if((e|0)<=(k|0)){if((k|0)>2047){qa(92856,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l;m=c[644472]|0}else{m=e}if((m|0)>(k|0)){break}f=c[29377]|0;a=m;do{c[1960896+(a*264|0)>>2]=f;a=a+1|0;}while((a|0)<=(k|0));c[644472]=a}}while(0);m=1960752+(k*264|0)|0;e=1960808+(k*264|0)|0;f=+h[e>>3]!=+h[321193]|0;h[e>>3]=+h[321192];do{if((j&1024|0)==0){n=c[1960784+(k*264|0)>>2]|0}else{e=c[644543]|0;if((e|0)==15){o=nL()|0}else if((e|0)==1e4|(e|0)==10001|(e|0)==10002){o=nM()|0}else if((e|0)==666){o=nL()|0}else{qa(64120,(l=i,i=i+16|0,c[l>>2]=111776,c[l+8>>2]=e,l)|0);i=l;o=0}e=c[644543]|0;if((e|0)==1e4|(e|0)==10001|(e|0)==10002|(e|0)==666){p=1024}else if((e|0)==15){p=256}else{p=0}if((o|0)<(p|0)){n=o;break}qa(92160,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l;n=o}}while(0);if((j&64|0)==0){o=c[1960788+(k*264|0)>>2]|0;c[1960892+(k*264|0)>>2]=o;q=o}else{o=nL()|0;c[1960892+(k*264|0)>>2]=o;q=o}o=1960942+(k*264|0)|0;p=b[o>>1]|0;e=1960892+(k*264|0)|0;if((p<<16>>16|0)!=(q|0)){b[1960940+(k*264|0)>>1]=p;p=1960948+(k*264|0)|0;g[1960944+(k*264|0)>>2]=+g[p>>2];b[o>>1]=q&65535;g[p>>2]=+h[321194]}if((j&2048|0)==0){r=c[1960792+(k*264|0)>>2]|0}else{r=nL()|0}if((r|0)==0){c[1960896+(k*264|0)>>2]=c[29377]}else{if((r|0)>(c[644468]|0)){w1(90424,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l}c[1960896+(k*264|0)>>2]=(c[644542]|0)+((r-1|0)*16428|0)+42}if((j&4096|0)==0){c[1960900+(k*264|0)>>2]=c[1960796+(k*264|0)>>2]}else{c[1960900+(k*264|0)>>2]=nL()|0}if((j&8192|0)==0){c[1960916+(k*264|0)>>2]=c[1960800+(k*264|0)>>2]}else{c[1960916+(k*264|0)>>2]=nL()|0}r=1960816+(k*264|0)|0;l=1960828+(k*264|0)|0;g[l>>2]=+g[r>>2];p=1960820+(k*264|0)|0;q=1960832+(k*264|0)|0;g[q>>2]=+g[p>>2];o=1960824+(k*264|0)|0;s=1960836+(k*264|0)|0;g[s>>2]=+g[o>>2];t=1960840+(k*264|0)|0;u=1960852+(k*264|0)|0;g[u>>2]=+g[t>>2];v=1960844+(k*264|0)|0;w=1960856+(k*264|0)|0;g[w>>2]=+g[v>>2];x=1960848+(k*264|0)|0;y=1960860+(k*264|0)|0;g[y>>2]=+g[x>>2];if((j&2|0)==0){z=+g[1960760+(k*264|0)>>2]}else{z=+nQ()}g[r>>2]=z;if((j&256|0)==0){A=+g[1960772+(k*264|0)>>2]}else{A=+nR()}g[t>>2]=A;if((j&4|0)==0){B=+g[1960764+(k*264|0)>>2]}else{B=+nQ()}g[p>>2]=B;if((j&16|0)==0){C=+g[1960776+(k*264|0)>>2]}else{C=+nR()}g[v>>2]=C;if((j&8|0)==0){D=+g[1960768+(k*264|0)>>2]}else{D=+nQ()}g[o>>2]=D;if((j&512|0)==0){E=+g[1960780+(k*264|0)>>2]}else{E=+nR()}g[x>>2]=E;do{if((c[644543]|0)==666){if((j&65536|0)!=0){nL()|0}if((j&131072|0)!=0){F=c[e>>2]&255;c[e>>2]=(nL()|0)<<8|F}if((j&262144|0)==0){G=n}else{G=(nL()|0)<<8|n&255}if((j&524288|0)==0){H=G;break}nL()|0;H=G}else{H=n}}while(0);n=c[2569572+(H<<2)>>2]|0;H=1960888+(k*264|0)|0;do{if((n|0)==(c[H>>2]|0)){I=f}else{c[H>>2]=n;if((n|0)==0){I=1;break}if((c[n+76>>2]|0)==1){g[1960904+(k*264|0)>>2]=+((aQ()|0)&32767|0)/32767.0;I=f;break}else{g[1960904+(k*264|0)>>2]=0.0;I=f;break}}}while(0);f=1960964+(k*264|0)|0;if((q6(r,f)|0)==0){n=1960980+(k*264|0)|0;E=+g[n>>2];if(E!=0.0){g[1960952+(k*264|0)>>2]=+g[f>>2];H=1960968+(k*264|0)|0;g[1960956+(k*264|0)>>2]=+g[H>>2];G=1960972+(k*264|0)|0;g[1960960+(k*264|0)>>2]=+g[G>>2];g[1960976+(k*264|0)>>2]=E;J=+g[r>>2];K=+g[p>>2];L=+g[o>>2];M=+h[321192];N=H;O=G}else{E=+g[r>>2];g[1960952+(k*264|0)>>2]=E;D=+g[p>>2];g[1960956+(k*264|0)>>2]=D;C=+g[o>>2];g[1960960+(k*264|0)>>2]=C;B=+h[321192];g[1960976+(k*264|0)>>2]=B;J=E;K=D;L=C;M=B;N=1960968+(k*264|0)|0;O=1960972+(k*264|0)|0}g[f>>2]=J;g[N>>2]=K;g[O>>2]=L;g[n>>2]=M}n=1960996+(k*264|0)|0;if((q6(t,n)|0)==0){O=1961012+(k*264|0)|0;M=+g[O>>2];if(M!=0.0){g[1960984+(k*264|0)>>2]=+g[n>>2];N=1961e3+(k*264|0)|0;g[1960988+(k*264|0)>>2]=+g[N>>2];f=1961004+(k*264|0)|0;g[1960992+(k*264|0)>>2]=+g[f>>2];g[1961008+(k*264|0)>>2]=M;P=+g[t>>2];Q=+g[v>>2];R=+g[x>>2];S=+h[321192];T=N;U=f}else{M=+g[t>>2];g[1960984+(k*264|0)>>2]=M;L=+g[v>>2];g[1960988+(k*264|0)>>2]=L;K=+g[x>>2];g[1960992+(k*264|0)>>2]=K;J=+h[321192];g[1961008+(k*264|0)>>2]=J;P=M;Q=L;R=K;S=J;T=1961e3+(k*264|0)|0;U=1961004+(k*264|0)|0}g[n>>2]=P;g[T>>2]=Q;g[U>>2]=R;g[O>>2]=S}if((j&32|0)!=0){c[m>>2]=1}if((I|0)==0){i=d;return}S=+g[r>>2];g[l>>2]=S;R=+g[p>>2];g[q>>2]=R;Q=+g[o>>2];g[s>>2]=Q;g[1960864+(k*264|0)>>2]=S;g[1960868+(k*264|0)>>2]=R;g[1960872+(k*264|0)>>2]=Q;Q=+g[t>>2];g[u>>2]=Q;R=+g[v>>2];g[w>>2]=R;S=+g[x>>2];g[y>>2]=S;g[1960876+(k*264|0)>>2]=Q;g[1960880+(k*264|0)>>2]=R;g[1960884+(k*264|0)>>2]=S;c[m>>2]=1;i=d;return}function nu(){var a=0,b=0,d=0,e=0,f=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0,s=0,t=0;a=i;b=nM()|0;d=b&65535;if((b&32768|0)==0){e=d}else{e=(nL()|0)<<16|d}if((e&8388608|0)==0){f=e}else{f=(nL()|0)<<24|e}if((f&1|0)==0){j=22.0}else{j=+(nK()|0)}g[642376]=j;if((f&2|0)==0){k=0.0}else{k=+(nK()|0)}g[642369]=k;g[642360]=+g[642357];g[642361]=+g[642358];g[642362]=+g[642359];if((f&4|0)==0){l=0.0}else{l=+(nK()|0)}g[642366]=l;if((f&32|0)==0){m=0.0}else{m=+((nK()|0)<<4|0)}g[642357]=m;if((f&8|0)==0){n=0.0}else{n=+(nK()|0)}g[642367]=n;if((f&64|0)==0){o=0.0}else{o=+((nK()|0)<<4|0)}g[642358]=o;if((f&16|0)==0){p=0.0}else{p=+(nK()|0)}g[642368]=p;if((f&128|0)==0){q=0.0}else{q=+((nK()|0)<<4|0)}g[642359]=q;e=nN()|0;if((c[642266]|0)!=(e|0)){u_();d=0;do{b=1<<d;do{if((b&e|0)!=0){if((c[642266]&b|0)!=0){break}g[2569132+(d<<2)>>2]=+h[321194]}}while(0);d=d+1|0;}while((d|0)<32);c[642266]=e}c[642379]=f>>>10&1;c[642380]=f>>>11&1;if((f&4096|0)==0){r=0}else{r=nL()|0}c[642256]=r;if((f&8192|0)==0){s=0}else{s=nL()|0}if((c[642255]|0)!=(s|0)){c[642255]=s;u_()}do{if((f&16384|0)==0){t=0}else{s=c[644543]|0;if((s|0)==666){t=nL()|0;break}else if((s|0)==15){t=nL()|0;break}else if((s|0)==1e4|(s|0)==10001|(s|0)==10002){t=nM()|0;break}else{qa(64120,(r=i,i=i+16|0,c[r>>2]=111776,c[r+8>>2]=s,r)|0);i=r;t=0;break}}}while(0);if((c[642253]|0)!=(t|0)){c[642253]=t;u_()}t=nM()|0;if((c[642251]|0)!=(t|0)){c[642251]=t;u_()}t=nL()|0;if((c[642254]|0)!=(t|0)){c[642254]=t;u_()}t=nL()|0;if((c[642257]|0)!=(t|0)){c[642257]=t;u_()}t=nL()|0;if((c[642258]|0)!=(t|0)){c[642258]=t;u_()}t=nL()|0;if((c[642259]|0)!=(t|0)){c[642259]=t;u_()}t=nL()|0;if((c[642260]|0)!=(t|0)){c[642260]=t;u_()}t=nL()|0;r=c[642261]|0;do{if((c[836]|0)==0){s=1<<t;if((r|0)==(s|0)){break}c[642261]=s;u_()}else{if((r|0)==(t|0)){break}c[642261]=t;u_()}}while(0);if((f&65536|0)!=0){t=(nL()|0)<<8;c[642253]=c[642253]|t}if((f&131072|0)!=0){t=(nL()|0)<<8;c[642255]=c[642255]|t}if((f&262144|0)!=0){t=(nL()|0)<<8;c[642254]=c[642254]|t}if((f&524288|0)!=0){t=(nL()|0)<<8;c[642257]=c[642257]|t}if((f&1048576|0)!=0){t=(nL()|0)<<8;c[642258]=c[642258]|t}if((f&2097152|0)!=0){t=(nL()|0)<<8;c[642259]=c[642259]|t}if((f&4194304|0)!=0){t=(nL()|0)<<8;c[642260]=c[642260]|t}if((f&16777216|0)!=0){t=(nL()|0)<<8;c[642256]=c[642256]|t}if((f&33554432|0)==0){i=a;return}nL()|0;i=a;return}function nv(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;if((c[644468]|0)<(b|0)){w1(88608,(e=i,i=i+8|0,c[e>>2]=111864,e)|0);i=e}e=(c[644542]|0)+(b*16428|0)+42|0;f=c[29377]|0;yJ(e|0,f|0,16384)|0;g=c[644542]|0;h=a[g+(b*16428|0)+40|0]|0;j=h&255;k=a[g+(b*16428|0)+41|0]|0;b=k&255;g=k<<24>>24>-1;k=b+15|0;l=j+15|0;if(h<<24>>24>-1){h=0;m=e;n=f;while(1){o=m+16|0;p=n+j|0;yJ(o|0,p|0,16)|0;if(g){p=m+96|0;o=n+b|0;yJ(p|0,o|0,16)|0}else{a[m+96|0]=a[n+k|0]|0;a[m+97|0]=a[n+(b+14)|0]|0;a[m+98|0]=a[n+(b+13)|0]|0;a[m+99|0]=a[n+(b+12)|0]|0;a[m+100|0]=a[n+(b+11)|0]|0;a[m+101|0]=a[n+(b+10)|0]|0;a[m+102|0]=a[n+(b+9)|0]|0;a[m+103|0]=a[n+(b+8)|0]|0;a[m+104|0]=a[n+(b+7)|0]|0;a[m+105|0]=a[n+(b+6)|0]|0;a[m+106|0]=a[n+(b+5)|0]|0;a[m+107|0]=a[n+(b+4)|0]|0;a[m+108|0]=a[n+(b+3)|0]|0;a[m+109|0]=a[n+(b+2)|0]|0;a[m+110|0]=a[n+(b+1)|0]|0;a[m+111|0]=a[n+b|0]|0}o=h+1|0;if((o|0)<64){h=o;m=m+256|0;n=n+256|0}else{break}}i=d;return}else{if(g){g=0;n=e;m=f;while(1){a[n+16|0]=a[m+l|0]|0;a[n+17|0]=a[m+(j+14)|0]|0;a[n+18|0]=a[m+(j+13)|0]|0;a[n+19|0]=a[m+(j+12)|0]|0;a[n+20|0]=a[m+(j+11)|0]|0;a[n+21|0]=a[m+(j+10)|0]|0;a[n+22|0]=a[m+(j+9)|0]|0;a[n+23|0]=a[m+(j+8)|0]|0;a[n+24|0]=a[m+(j+7)|0]|0;a[n+25|0]=a[m+(j+6)|0]|0;a[n+26|0]=a[m+(j+5)|0]|0;a[n+27|0]=a[m+(j+4)|0]|0;a[n+28|0]=a[m+(j+3)|0]|0;a[n+29|0]=a[m+(j+2)|0]|0;a[n+30|0]=a[m+(j+1)|0]|0;a[n+31|0]=a[m+j|0]|0;h=n+96|0;o=m+b|0;yJ(h|0,o|0,16)|0;o=g+1|0;if((o|0)<64){g=o;n=n+256|0;m=m+256|0}else{break}}i=d;return}else{m=0;n=e;e=f;while(1){a[n+16|0]=a[e+l|0]|0;a[n+17|0]=a[e+(j+14)|0]|0;a[n+18|0]=a[e+(j+13)|0]|0;a[n+19|0]=a[e+(j+12)|0]|0;a[n+20|0]=a[e+(j+11)|0]|0;a[n+21|0]=a[e+(j+10)|0]|0;a[n+22|0]=a[e+(j+9)|0]|0;a[n+23|0]=a[e+(j+8)|0]|0;a[n+24|0]=a[e+(j+7)|0]|0;a[n+25|0]=a[e+(j+6)|0]|0;a[n+26|0]=a[e+(j+5)|0]|0;a[n+27|0]=a[e+(j+4)|0]|0;a[n+28|0]=a[e+(j+3)|0]|0;a[n+29|0]=a[e+(j+2)|0]|0;a[n+30|0]=a[e+(j+1)|0]|0;a[n+31|0]=a[e+j|0]|0;a[n+96|0]=a[e+k|0]|0;a[n+97|0]=a[e+(b+14)|0]|0;a[n+98|0]=a[e+(b+13)|0]|0;a[n+99|0]=a[e+(b+12)|0]|0;a[n+100|0]=a[e+(b+11)|0]|0;a[n+101|0]=a[e+(b+10)|0]|0;a[n+102|0]=a[e+(b+9)|0]|0;a[n+103|0]=a[e+(b+8)|0]|0;a[n+104|0]=a[e+(b+7)|0]|0;a[n+105|0]=a[e+(b+6)|0]|0;a[n+106|0]=a[e+(b+5)|0]|0;a[n+107|0]=a[e+(b+4)|0]|0;a[n+108|0]=a[e+(b+3)|0]|0;a[n+109|0]=a[e+(b+2)|0]|0;a[n+110|0]=a[e+(b+1)|0]|0;a[n+111|0]=a[e+b|0]|0;f=m+1|0;if((f|0)<64){m=f;n=n+256|0;e=e+256|0}else{break}}i=d;return}}}function nw(a){a=a|0;var d=0,e=0,f=0,j=0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0;d=i;e=c[644473]|0;if((e|0)>1023){qa(86848,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;j=c[644473]|0}else{j=e}f=1686e3+(e*264|0)|0;c[644473]=j+1;nx(f,a);c[1686136+(e*264|0)>>2]=c[2569572+(c[1686032+(e*264|0)>>2]<<2)>>2];a=c[1686036+(e*264|0)>>2]|0;c[1686140+(e*264|0)>>2]=a;c[1686144+(e*264|0)>>2]=c[29377];c[1686148+(e*264|0)>>2]=c[1686044+(e*264|0)>>2];c[1686164+(e*264|0)>>2]=c[1686048+(e*264|0)>>2];j=a&65535;b[1686190+(e*264|0)>>1]=j;b[1686188+(e*264|0)>>1]=j;k=+h[321194];g[1686196+(e*264|0)>>2]=k;g[1686192+(e*264|0)>>2]=k;g[1686224+(e*264|0)>>2]=k;g[1686228+(e*264|0)>>2]=k;k=+g[1686008+(e*264|0)>>2];g[1686200+(e*264|0)>>2]=k;l=+g[1686012+(e*264|0)>>2];g[1686204+(e*264|0)>>2]=l;m=+g[1686016+(e*264|0)>>2];g[1686208+(e*264|0)>>2]=m;g[1686212+(e*264|0)>>2]=k;g[1686216+(e*264|0)>>2]=l;g[1686220+(e*264|0)>>2]=m;n=+g[1686020+(e*264|0)>>2];g[1686232+(e*264|0)>>2]=n;o=+g[1686024+(e*264|0)>>2];g[1686236+(e*264|0)>>2]=o;p=+g[1686028+(e*264|0)>>2];g[1686240+(e*264|0)>>2]=p;g[1686244+(e*264|0)>>2]=n;g[1686248+(e*264|0)>>2]=o;g[1686252+(e*264|0)>>2]=p;g[1686112+(e*264|0)>>2]=k;g[1686116+(e*264|0)>>2]=l;g[1686120+(e*264|0)>>2]=m;g[1686124+(e*264|0)>>2]=n;g[1686128+(e*264|0)>>2]=o;g[1686132+(e*264|0)>>2]=p;uh(f);i=d;return}function nx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,j=0;d=i;e=c[644543]|0;do{if((e|0)==666){if((b&1|0)==0){f=nL()|0;break}else{f=nM()|0;break}}else if((e|0)==15){f=nL()|0}else if((e|0)==1e4|(e|0)==10001|(e|0)==10002){f=nM()|0}else{qa(64120,(h=i,i=i+16|0,c[h>>2]=111776,c[h+8>>2]=e,h)|0);i=h;f=0}}while(0);c[a+32>>2]=f;f=c[644543]|0;do{if((f|0)==15|(f|0)==1e4|(f|0)==10001|(f|0)==10002){j=nL()|0}else if((f|0)==666){if((b&2|0)==0){j=nL()|0;break}else{j=nM()|0;break}}else{qa(64120,(h=i,i=i+16|0,c[h>>2]=111800,c[h+8>>2]=f,h)|0);i=h;j=0}}while(0);c[a+36>>2]=j;c[a+40>>2]=nL()|0;c[a+44>>2]=nL()|0;g[a+8>>2]=+nQ();g[a+20>>2]=+nR();g[a+12>>2]=+nQ();g[a+24>>2]=+nR();g[a+16>>2]=+nQ();g[a+28>>2]=+nR();if((c[644543]|0)!=666){i=d;return}if((b&4|0)==0){i=d;return}nL()|0;i=d;return}function ny(){var b=0,d=0,e=0.0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+16|0;d=b|0;e=+g[5460];do{if(e==1.0){oW(84928,(f=i,i=i+8|0,c[f>>2]=c[169348],f)|0);i=f}else{if(e!=2.0){break}oW(82504,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f}}while(0);c[642379]=0;nJ();j=d|0;k=d+4|0;l=d+8|0;L11157:while(1){if((c[169380]|0)!=0){qa(80520,(f=i,i=i+8|0,c[f>>2]=111840,f)|0);i=f}d=nL()|0;if((d|0)==-1){break}m=+g[5460]==2.0;if((d&128|0)!=0){if(m){oW(42952,(f=i,i=i+16|0,c[f>>2]=(c[169378]|0)-1,c[f+8>>2]=77472,f)|0);i=f}nt(d&127);continue}if(m){m=c[2008+(d<<2)>>2]|0;oW(42952,(f=i,i=i+16|0,c[f>>2]=(c[169378]|0)-1,c[f+8>>2]=m,f)|0);i=f}switch(d|0){case 20:{nw(0);continue L11157;break};case 43:{nw(nL()|0);continue L11157;break};case 8:{break};case 26:{vc(nP()|0);continue L11157;break};case 1:{continue L11157;break};case 29:{g[j>>2]=+nQ();g[k>>2]=+nQ();g[l>>2]=+nQ();d=c[644543]|0;if((d|0)==15|(d|0)==1e4|(d|0)==10002|(d|0)==666){n=nL()|0}else if((d|0)==10001){n=nM()|0}else{qa(64120,(f=i,i=i+16|0,c[f>>2]=111736,c[f+8>>2]=d,f)|0);i=f;n=0}d=nL()|0;m=nL()|0;vL(c[2573668+(n<<2)>>2]|0,j,+(d|0),+(m|0));continue L11157;break};case 27:{c[642265]=(c[642265]|0)+1;continue L11157;break};case 41:{nL()|0;nL()|0;nL()|0;nL()|0;nM()|0;continue L11157;break};case 18:{uD();continue L11157;break};case 22:{m=nM()|0;d=c[644472]|0;do{if((d|0)<=(m|0)){if((m|0)>2047){qa(92856,(f=i,i=i+8|0,c[f>>2]=m,f)|0);i=f;o=c[644472]|0}else{o=d}if((o|0)>(m|0)){break}p=c[29377]|0;q=o;do{c[1960896+(q*264|0)>>2]=p;q=q+1|0;}while((q|0)<=(m|0));c[644472]=q}}while(0);nx(1960752+(m*264|0)|0,0);continue L11157;break};case 15:{nu();continue L11157;break};case 32:{c[644540]=nL()|0;c[644541]=nL()|0;d=c[353699]|0;if((c[353696]|c[353697]|0)!=0&(d|0)!=-1){m_(d&255,1);continue L11157}else{m_(c[644540]&255,1);continue L11157}break};case 30:{c[642381]=1;c[642382]=~~+h[321194];c[29385]=1;continue L11157;break};case 31:{c[642381]=2;c[642382]=~~+h[321194];c[29385]=1;vc(nP()|0);continue L11157;break};case 37:{nP()|0;continue L11157;break};case 40:{oy(65856,1);continue L11157;break};case 6:{nq();continue L11157;break};case 44:{g[j>>2]=+nQ();g[k>>2]=+nQ();g[l>>2]=+nQ();d=nM()|0;p=nL()|0;r=nL()|0;vL(c[2573668+(d<<2)>>2]|0,j,+(p|0),+(r|0));continue L11157;break};case 28:{c[642264]=(c[642264]|0)+1;continue L11157;break};case 3:{r=nL()|0;if(r>>>0>31){w1(67816,(f=i,i=i+8|0,c[f>>2]=r,f)|0);i=f}c[2569004+(r<<2)>>2]=nN()|0;continue L11157;break};case 42:{r=nM()|0;p=nL()|0;d=c[644472]|0;do{if((d|0)<=(r|0)){if((r|0)>2047){qa(92856,(f=i,i=i+8|0,c[f>>2]=r,f)|0);i=f;s=c[644472]|0}else{s=d}if((s|0)>(r|0)){break}t=c[29377]|0;u=s;do{c[1960896+(u*264|0)>>2]=t;u=u+1|0;}while((u|0)<=(r|0));c[644472]=u}}while(0);nx(1960752+(r*264|0)|0,p);continue L11157;break};case 34:{c[642381]=3;c[642382]=~~+h[321194];c[29385]=1;vc(nP()|0);continue L11157;break};case 33:{oy(66848,1);continue L11157;break};case 11:{ns();c[29385]=1;continue L11157;break};case 2:{p9(74800,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;break};case 14:{u_();d=nL()|0;if((d|0)>=(c[644468]|0)){qa(71936,(f=i,i=i+8|0,c[f>>2]=111840,f)|0);i=f}m=nM()|0;c[(c[644542]|0)+(d*16428|0)+36>>2]=m;continue L11157;break};case 16:{m=nM()|0;vB(m>>3,m&7);continue L11157;break};case 13:{u_();m=nL()|0;if((m|0)>=(c[644468]|0)){qa(72832,(f=i,i=i+8|0,c[f>>2]=111840,f)|0);i=f}d=nP()|0;bR((c[644542]|0)+(m*16428|0)|0,32,108272,(f=i,i=i+8|0,c[f>>2]=d,f)|0)|0;i=f;continue L11157;break};case 9:{d=nP()|0;ov(108272,(f=i,i=i+8|0,c[f>>2]=d,f)|0);i=f;continue L11157;break};case 23:{nG();continue L11157;break};case 24:{d=nL()|0;c[642378]=d;if((d|0)==0){mZ();continue L11157}else{mY();continue L11157}break};case 10:{g[642354]=+nR();g[642355]=+nR();g[642356]=+nR();continue L11157;break};case 19:{xM();continue L11157;break};case 12:{d=nL()|0;if((d|0)>63){w1(73888,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f}m=nP()|0;t=1956404+(d*68|0)|0;bR(t|0,64,108272,(f=i,i=i+8|0,c[f>>2]=m,f)|0)|0;i=f;c[1956400+(d*68|0)>>2]=yF(t|0)|0;continue L11157;break};case 7:{h[321193]=+h[321192];h[321192]=+nO();continue L11157;break};case 25:{t=nL()|0;d=c[353704]|0;if((t|0)<=(d|0)){qa(69064,(f=i,i=i+16|0,c[f>>2]=t,c[f+8>>2]=d,f)|0);i=f}c[353704]=t;ni();continue L11157;break};case 4:{t=nN()|0;if(!((t|0)==15|(t|0)==666|(t|0)==1e4|(t|0)==10001|(t|0)==10002)){qa(76024,(f=i,i=i+16|0,c[f>>2]=111840,c[f+8>>2]=t,f)|0);i=f}c[644543]=t;continue L11157;break};case 5:{c[644467]=nM()|0;continue L11157;break};case 17:{u_();t=nL()|0;if((t|0)>=(c[644468]|0)){qa(70632,(f=i,i=i+8|0,c[f>>2]=111840,f)|0);i=f}d=nL()|0;a[(c[644542]|0)+(t*16428|0)+40|0]=d>>>4&15;a[(c[644542]|0)+(t*16428|0)+41|0]=d&15;nv(t);continue L11157;break};default:{qa(64920,(f=i,i=i+8|0,c[f>>2]=111840,f)|0);i=f;continue L11157}}t=nP()|0;oW(108272,(f=i,i=i+8|0,c[f>>2]=t,f)|0);i=f}if(+g[5460]!=2.0){i=b;return}oW(42952,(f=i,i=i+16|0,c[f>>2]=(c[169378]|0)-1,c[f+8>>2]=78728,f)|0);i=f;i=b;return}function nz(){c[489084]=vE(82088)|0;c[489096]=vE(101640)|0;c[489086]=vE(82288)|0;c[489092]=vE(68968)|0;c[489090]=vE(59600)|0;c[489088]=vE(53824)|0;c[489094]=vE(49840)|0;return}function nA(){yG(2568112|0,0|0,864|0);return}function nB(a){a=a|0;c[a+4>>2]=a;c[a>>2]=a;return}function nC(a){a=a|0;var b=0,d=0;b=a|0;d=a+4|0;c[c[d>>2]>>2]=c[b>>2];c[(c[b>>2]|0)+4>>2]=c[d>>2];return}function nD(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+4|0;c[d>>2]=b;e=c[b>>2]|0;c[a>>2]=e;c[e+4>>2]=a;c[c[d>>2]>>2]=a;return}function nE(b){b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=(a[b]|0)==45;d=c?b+1|0:b;b=c?-1:1;c=a[d]|0;L11275:do{if((c<<24>>24|0)==39){e=a[d+1|0]|0}else if((c<<24>>24|0)==48){f=a[d+1|0]|0;if(!((f<<24>>24|0)==120|(f<<24>>24|0)==88)){g=d;h=-48;i=48;j=8541;break}f=0;k=d+2|0;while(1){l=k+1|0;m=a[k]|0;n=m<<24>>24;do{if((m-48&255)<10){o=(f<<4)-48|0}else{if((m-97&255)<6){o=(f<<4)-87|0;break}if((m-65&255)>=6){e=f;break L11275}o=(f<<4)-55|0}}while(0);f=o+n|0;k=l}}else{if((c-48&255)>9){e=0}else{g=d;h=-48;i=c;j=8541}}}while(0);L11290:do{if((j|0)==8541){while(1){j=0;c=g+1|0;d=h+(i<<24>>24)|0;o=a[c]|0;if((o-48&255)>9){e=d;break L11290}g=c;h=(d*10|0)-48|0;i=o;j=8541}}}while(0);return ab(e,b)|0}function nF(b){b=b|0;var c=0,d=0,e=0,f=0.0,g=0,h=0,i=0.0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0;c=(a[b]|0)==45;d=c?b+1|0:b;b=c?-1:1;c=a[d]|0;if((c<<24>>24|0)==48){e=8545}else if((c<<24>>24|0)==39){f=+(ab(a[d+1|0]|0,b)|0);return+f}else{g=0;h=-1;i=0.0;j=d}do{if((e|0)==8545){c=a[d+1|0]|0;if(!((c<<24>>24|0)==120|(c<<24>>24|0)==88)){g=0;h=-1;i=0.0;j=d;break}k=0.0;c=d+2|0;while(1){l=c+1|0;m=a[c]|0;if((m-48&255)<10){k=k*16.0+ +(m<<24>>24|0)+-48.0;c=l;continue}if((m-97&255)<6){k=k*16.0+ +(m<<24>>24|0)+-97.0+10.0;c=l;continue}if((m-65&255)>=6){break}k=k*16.0+ +(m<<24>>24|0)+-65.0+10.0;c=l}f=+(b|0)*k;return+f}}while(0);while(1){n=h;d=j;while(1){o=d+1|0;p=a[d]|0;if(p<<24>>24==46){n=g;d=o}else{break}}if((p-48&255)>9){break}g=g+1|0;h=n;i=i*10.0+ +(p<<24>>24|0)+-48.0;j=o}if((n|0)==-1){f=+(b|0)*i;return+f}if((g|0)>(n|0)){k=i;o=g;while(1){q=k/10.0;g=o-1|0;if((g|0)>(n|0)){k=q;o=g}else{r=q;break}}}else{r=i}f=+(b|0)*r;return+f}function nG(){var a=0,b=0,d=0,e=0,f=0,j=0;a=i;i=i+16|0;b=a|0;switch(nL()|0){case 1:{d=b|0;g[d>>2]=+nQ();g[b+4>>2]=+nQ();g[b+8>>2]=+nQ();uE(d,117584,0,20);if(((aQ()|0)%5|0|0)!=0){vJ(-1,0,c[489086]|0,d,1.0,1.0);i=a;return}e=(aQ()|0)&3;if((e|0)==1){vJ(-1,0,c[489092]|0,d,1.0,1.0);i=a;return}else if((e|0)==2){vJ(-1,0,c[489090]|0,d,1.0,1.0);i=a;return}else{vJ(-1,0,c[489088]|0,d,1.0,1.0);i=a;return}break};case 9:{nH(rG(37936,1)|0);i=a;return};case 7:{d=b|0;g[d>>2]=+nQ();g[b+4>>2]=+nQ();g[b+8>>2]=+nQ();uE(d,117584,20,30);vJ(-1,0,c[489084]|0,d,1.0,1.0);i=a;return};case 2:{d=b|0;g[d>>2]=+nQ();g[b+4>>2]=+nQ();g[b+8>>2]=+nQ();uE(d,117584,0,20);i=a;return};case 3:{d=b|0;g[d>>2]=+nQ();e=b+4|0;g[e>>2]=+nQ();f=b+8|0;g[f>>2]=+nQ();uF(d);j=nl(0)|0;g[j+4>>2]=+g[d>>2];g[j+8>>2]=+g[e>>2];g[j+12>>2]=+g[f>>2];g[j+16>>2]=350.0;g[j+20>>2]=+h[321194]+.5;g[j+24>>2]=300.0;vJ(-1,0,c[489094]|0,d,1.0,1.0);i=a;return};case 12:{d=b|0;g[d>>2]=+nQ();j=b+4|0;g[j>>2]=+nQ();f=b+8|0;g[f>>2]=+nQ();uG(d,nL()|0,nL()|0);e=nl(0)|0;g[e+4>>2]=+g[d>>2];g[e+8>>2]=+g[j>>2];g[e+12>>2]=+g[f>>2];g[e+16>>2]=350.0;g[e+20>>2]=+h[321194]+.5;g[e+24>>2]=300.0;vJ(-1,0,c[489094]|0,d,1.0,1.0);i=a;return};case 8:{d=b|0;g[d>>2]=+nQ();g[b+4>>2]=+nQ();g[b+8>>2]=+nQ();uE(d,117584,226,20);vJ(-1,0,c[489096]|0,d,1.0,1.0);i=a;return};case 6:{nH(rG(41576,1)|0);i=a;return};case 0:{d=b|0;g[d>>2]=+nQ();g[b+4>>2]=+nQ();g[b+8>>2]=+nQ();uE(d,117584,0,10);if(((aQ()|0)%5|0|0)!=0){vJ(-1,0,c[489086]|0,d,1.0,1.0);i=a;return}e=(aQ()|0)&3;if((e|0)==2){vJ(-1,0,c[489090]|0,d,1.0,1.0);i=a;return}else if((e|0)==1){vJ(-1,0,c[489092]|0,d,1.0,1.0);i=a;return}else{vJ(-1,0,c[489088]|0,d,1.0,1.0);i=a;return}break};case 10:{d=b|0;g[d>>2]=+nQ();g[b+4>>2]=+nQ();g[b+8>>2]=+nQ();uI(d);i=a;return};case 11:{d=b|0;g[d>>2]=+nQ();g[b+4>>2]=+nQ();g[b+8>>2]=+nQ();uJ(d);i=a;return};case 4:{d=b|0;g[d>>2]=+nQ();g[b+4>>2]=+nQ();g[b+8>>2]=+nQ();uH(d);vJ(-1,0,c[489094]|0,d,1.0,1.0);i=a;return};case 5:{nH(rG(45752,1)|0);i=a;return};case 13:{nH(rG(107992,1)|0);i=a;return};default:{w1(104648,(d=i,i=i+8|0,c[d>>2]=111824,d)|0);i=d;i=a;return}}}function nH(a){a=a|0;var b=0,d=0,e=0.0,f=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;d=nM()|0;e=+nQ();f=+nQ();j=+nQ();k=+nQ();l=+nQ();m=+nQ();do{if((c[642028]|0)==(d|0)){n=2568112;o=2568112}else{if((c[642037]|0)==(d|0)){n=2568148;o=2568148;break}if((c[642046]|0)==(d|0)){n=2568184;o=2568184;break}if((c[642055]|0)==(d|0)){n=2568220;o=2568220;break}if((c[642064]|0)==(d|0)){n=2568256;o=2568256;break}if((c[642073]|0)==(d|0)){n=2568292;o=2568292;break}if((c[642082]|0)==(d|0)){n=2568328;o=2568328;break}if((c[642091]|0)==(d|0)){n=2568364;o=2568364;break}if((c[642100]|0)==(d|0)){n=2568400;o=2568400;break}if((c[642109]|0)==(d|0)){n=2568436;o=2568436;break}if((c[642118]|0)==(d|0)){n=2568472;o=2568472;break}if((c[642127]|0)==(d|0)){n=2568508;o=2568508;break}if((c[642136]|0)==(d|0)){n=2568544;o=2568544;break}if((c[642145]|0)==(d|0)){n=2568580;o=2568580;break}if((c[642154]|0)==(d|0)){n=2568616;o=2568616;break}if((c[642163]|0)==(d|0)){n=2568652;o=2568652;break}if((c[642172]|0)==(d|0)){n=2568688;o=2568688;break}if((c[642181]|0)==(d|0)){n=2568724;o=2568724;break}if((c[642190]|0)==(d|0)){n=2568760;o=2568760;break}if((c[642199]|0)==(d|0)){n=2568796;o=2568796;break}if((c[642208]|0)==(d|0)){n=2568832;o=2568832;break}if((c[642217]|0)==(d|0)){n=2568868;o=2568868;break}if((c[642226]|0)==(d|0)){n=2568904;o=2568904;break}if((c[642235]|0)==(d|0)){n=2568940;o=2568940;break}p=+h[321194];q=2568112;r=0;while(1){s=q+4|0;t=q+8|0;if((c[s>>2]|0)==0){u=8622;break}if(+g[t>>2]<p){u=8622;break}v=r+1|0;if((v|0)<24){q=q+36|0;r=v}else{u=8624;break}}if((u|0)==8622){c[q>>2]=d;c[s>>2]=a;g[t>>2]=+h[321194]+.2;g[q+12>>2]=e;g[q+16>>2]=f;g[q+20>>2]=j;g[q+24>>2]=k;g[q+28>>2]=l;g[q+32>>2]=m;i=b;return}else if((u|0)==8624){oW(101696,(r=i,i=i+1|0,i=i+7>>3<<3,c[r>>2]=0,r)|0);i=r;i=b;return}}}while(0);c[o>>2]=d;c[n+4>>2]=a;g[n+8>>2]=+h[321194]+.2;g[n+12>>2]=e;g[n+16>>2]=f;g[n+20>>2]=j;g[n+24>>2]=k;g[n+28>>2]=l;g[n+32>>2]=m;i=b;return}function nI(){var a=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0.0,t=0,u=0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0,D=0,E=0,F=0;a=i;i=i+32|0;d=a|0;e=a+16|0;f=d|0;j=d+4|0;k=d+8|0;d=e|0;l=e+4|0;m=e+8|0;e=2568112;n=0;L11419:while(1){o=e+4|0;do{if((c[o>>2]|0)!=0){if(+g[e+8>>2]<+h[321194]){break}p=c[e>>2]|0;if((p|0)==(c[644467]|0)){q=+g[1960864+(p*264|0)>>2];g[e+12>>2]=q;p=e+16|0;g[p>>2]=+g[1960868+((c[644467]|0)*264|0)>>2];r=e+20|0;g[r>>2]=+g[1960872+((c[644467]|0)*264|0)>>2];s=q;t=p;u=r}else{s=+g[e+12>>2];t=e+16|0;u=e+20|0}r=e+12|0;q=+g[e+24>>2]-s;g[f>>2]=q;v=+g[e+28>>2]- +g[t>>2];g[j>>2]=v;w=+g[e+32>>2]- +g[u>>2];g[k>>2]=w;do{if(v==0.0&q==0.0){x=w>0.0?90.0:270.0;y=0.0}else{z=+(~~(+Z(+v,+q)*180.0/3.141592653589793)|0);if(z<0.0){A=z+360.0}else{A=z}z=+(~~(+Z(+w,+(+R(+(q*q+v*v))))*180.0/3.141592653589793)|0);if(z>=0.0){x=z;y=A;break}x=z+360.0;y=A}}while(0);g[d>>2]=+g[r>>2];g[l>>2]=+g[t>>2];g[m>>2]=+g[u>>2];v=+q1(f);if(v>0.0){B=v}else{break}do{p=c[489098]|0;if((p|0)==1024){C=8669;break L11419}c[489098]=p+1;yG(1415664+(p*264|0)|0,0,264);c[1415808+(p*264|0)>>2]=c[29377];D=1415776+(p*264|0)|0;g[D>>2]=+g[d>>2];E=1415780+(p*264|0)|0;g[E>>2]=+g[l>>2];F=1415784+(p*264|0)|0;g[F>>2]=+g[m>>2];c[1415800+(p*264|0)>>2]=c[o>>2];g[1415788+(p*264|0)>>2]=x;g[1415792+(p*264|0)>>2]=y;g[1415796+(p*264|0)>>2]=+((aQ()|0)%360|0|0);q7(d,30.0,f,d);B=B+-30.0;c[1415804+(p*264|0)>>2]=0;b[1415854+(p*264|0)>>1]=0;b[1415852+(p*264|0)>>1]=0;v=+h[321194];g[1415860+(p*264|0)>>2]=v;g[1415856+(p*264|0)>>2]=v;q=+g[D>>2];g[1415876+(p*264|0)>>2]=q;w=+g[E>>2];g[1415880+(p*264|0)>>2]=w;z=+g[F>>2];g[1415884+(p*264|0)>>2]=z;g[1415864+(p*264|0)>>2]=q;g[1415868+(p*264|0)>>2]=w;g[1415872+(p*264|0)>>2]=z;g[1415892+(p*264|0)>>2]=v;g[1415888+(p*264|0)>>2]=v;}while(B>0.0)}}while(0);o=n+1|0;if((o|0)<24){e=e+36|0;n=o}else{C=8670;break}}if((C|0)==8670){i=a;return}else if((C|0)==8669){i=a;return}}function nJ(){c[169378]=0;c[169380]=0;return}function nK(){var b=0,d=0,e=0,f=0;b=c[169378]|0;d=b+1|0;if((d|0)>(c[169348]|0)){c[169380]=1;e=-1;return e|0}else{f=a[(c[169346]|0)+b|0]|0;c[169378]=d;e=f;return e|0}return 0}function nL(){var a=0,b=0,e=0,f=0;a=c[169378]|0;b=a+1|0;if((b|0)>(c[169348]|0)){c[169380]=1;e=-1;return e|0}else{f=d[(c[169346]|0)+a|0]|0;c[169378]=b;e=f;return e|0}return 0}function nM(){var a=0,b=0,e=0,f=0,g=0;a=c[169378]|0;b=a+2|0;if((b|0)>(c[169348]|0)){c[169380]=1;e=-1;return e|0}else{f=c[169346]|0;g=((d[f+(a+1)|0]|0)<<8|(d[f+a|0]|0))<<16>>16;c[169378]=b;e=g;return e|0}return 0}function nN(){var a=0,b=0,e=0,f=0,g=0;a=c[169378]|0;b=a+4|0;if((b|0)>(c[169348]|0)){c[169380]=1;e=-1;return e|0}else{f=c[169346]|0;g=(d[f+(a+1)|0]|0)<<8|(d[f+a|0]|0)|(d[f+(a+2)|0]|0)<<16|(d[f+(a+3)|0]|0)<<24;c[169378]=b;e=g;return e|0}return 0}function nO(){var a=0,b=0,e=0;a=c[169378]|0;b=c[169346]|0;e=(d[b+(a+1)|0]|0)<<8|(d[b+a|0]|0)|(d[b+(a+2)|0]|0)<<16|(d[b+(a+3)|0]|0)<<24;c[169378]=a+4;return+(c[k>>2]=e,+g[k>>2])}function nP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[667372]|0)+1|0;c[667372]=b;d=b&3;b=2669496+(d<<11)|0;e=c[169348]|0;f=0;g=c[169378]|0;while(1){h=g+1|0;if((h|0)>(e|0)){i=8699;break}j=a[(c[169346]|0)+g|0]|0;k=j<<24>>24;c[169378]=h;if((k|0)==(-1|0)|(k|0)==0){l=f;break}k=f+1|0;a[2669496+(d<<11)+f|0]=j;if((k|0)<2047){f=k;g=h}else{l=k;break}}if((i|0)==8699){c[169380]=1;l=f}a[2669496+(d<<11)+l|0]=0;return b|0}function nQ(){var a=0,b=0,e=0.0,f=0,g=0;a=c[169378]|0;b=a+2|0;if((b|0)>(c[169348]|0)){c[169380]=1;e=-.125;return+e}else{f=c[169346]|0;g=(d[f+(a+1)|0]|0)<<8|(d[f+a|0]|0);c[169378]=b;e=+(g<<16>>16|0)*.125;return+e}return 0.0}function nR(){var b=0,d=0,e=0.0,f=0;b=c[169378]|0;d=b+1|0;if((d|0)>(c[169348]|0)){c[169380]=1;e=-1.40625;return+e}else{f=a[(c[169346]|0)+b|0]|0;c[169378]=d;e=+(f<<24>>24|0)*1.40625;return+e}return 0.0}function nS(){var a=0,b=0,e=0.0,f=0,g=0;a=c[169378]|0;b=a+2|0;if((b|0)>(c[169348]|0)){c[169380]=1;e=-.0054931640625;return+e}else{f=c[169346]|0;g=(d[f+(a+1)|0]|0)<<8|(d[f+a|0]|0);c[169378]=b;e=+(g<<16>>16|0)*.0054931640625;return+e}return 0.0}function nT(a){a=a|0;c[a+16>>2]=0;c[a+4>>2]=0;return}function nU(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=b+16|0;h=c[f>>2]|0;j=h+1|0;k=b+12|0;l=c[k>>2]|0;if((j|0)<=(l|0)){m=h;n=b+8|0;o=c[n>>2]|0;p=o+m|0;q=m+1|0;c[f>>2]=q;r=d&255;a[p]=r;i=e;return}if((c[b>>2]|0)==0){w1(51920,(s=i,i=i+24|0,c[s>>2]=109632,c[s+8>>2]=j,c[s+16>>2]=l,s)|0);i=s;t=c[k>>2]|0}else{t=l}if((t|0)<1){w1(51600,(s=i,i=i+16|0,c[s>>2]=109632,c[s+8>>2]=1,s)|0);i=s}if(+g[5052]!=0.0){wD(51288,(s=i,i=i+8|0,c[s>>2]=109632,s)|0);i=s}c[f>>2]=0;c[b+4>>2]=1;m=0;n=b+8|0;o=c[n>>2]|0;p=o+m|0;q=m+1|0;c[f>>2]=q;r=d&255;a[p]=r;i=e;return}function nV(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=b+16|0;h=c[f>>2]|0;j=h+1|0;k=b+12|0;l=c[k>>2]|0;if((j|0)<=(l|0)){m=h;n=b+8|0;o=c[n>>2]|0;p=o+m|0;q=m+1|0;c[f>>2]=q;r=d&255;a[p]=r;i=e;return}if((c[b>>2]|0)==0){w1(51920,(s=i,i=i+24|0,c[s>>2]=109632,c[s+8>>2]=j,c[s+16>>2]=l,s)|0);i=s;t=c[k>>2]|0}else{t=l}if((t|0)<1){w1(51600,(s=i,i=i+16|0,c[s>>2]=109632,c[s+8>>2]=1,s)|0);i=s}if(+g[5052]!=0.0){wD(51288,(s=i,i=i+8|0,c[s>>2]=109632,s)|0);i=s}c[f>>2]=0;c[b+4>>2]=1;m=0;n=b+8|0;o=c[n>>2]|0;p=o+m|0;q=m+1|0;c[f>>2]=q;r=d&255;a[p]=r;i=e;return}function nW(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=b+16|0;h=c[f>>2]|0;j=h+2|0;k=b+12|0;l=c[k>>2]|0;if((j|0)>(l|0)){if((c[b>>2]|0)==0){w1(51920,(m=i,i=i+24|0,c[m>>2]=109632,c[m+8>>2]=j,c[m+16>>2]=l,m)|0);i=m;n=c[k>>2]|0}else{n=l}if((n|0)<2){w1(51600,(m=i,i=i+16|0,c[m>>2]=109632,c[m+8>>2]=2,m)|0);i=m}if(+g[5052]!=0.0){wD(51288,(m=i,i=i+8|0,c[m>>2]=109632,m)|0);i=m}c[f>>2]=0;c[b+4>>2]=1;o=0}else{o=h}h=c[b+8>>2]|0;c[f>>2]=o+2;a[h+o|0]=d&255;a[h+(o+1)|0]=d>>>8&255;i=e;return}function nX(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=b+16|0;h=c[f>>2]|0;j=h+4|0;k=b+12|0;l=c[k>>2]|0;if((j|0)>(l|0)){if((c[b>>2]|0)==0){w1(51920,(m=i,i=i+24|0,c[m>>2]=109632,c[m+8>>2]=j,c[m+16>>2]=l,m)|0);i=m;n=c[k>>2]|0}else{n=l}if((n|0)<4){w1(51600,(m=i,i=i+16|0,c[m>>2]=109632,c[m+8>>2]=4,m)|0);i=m}if(+g[5052]!=0.0){wD(51288,(m=i,i=i+8|0,c[m>>2]=109632,m)|0);i=m}c[f>>2]=0;c[b+4>>2]=1;o=0}else{o=h}h=c[b+8>>2]|0;c[f>>2]=o+4;a[h+o|0]=d&255;a[h+(o+1)|0]=d>>>8&255;a[h+(o+2)|0]=d>>>16&255;a[h+(o+3)|0]=d>>>24&255;i=e;return}function nY(b,d){b=b|0;d=+d;var e=0,f=0,h=0,j=0,l=0,m=0,n=0,o=0,p=0;e=i;f=b+16|0;h=c[f>>2]|0;j=h+4|0;l=b+12|0;m=c[l>>2]|0;if((j|0)>(m|0)){if((c[b>>2]|0)==0){w1(51920,(n=i,i=i+24|0,c[n>>2]=109632,c[n+8>>2]=j,c[n+16>>2]=m,n)|0);i=n;o=c[l>>2]|0}else{o=m}if((o|0)<4){w1(51600,(n=i,i=i+16|0,c[n>>2]=109632,c[n+8>>2]=4,n)|0);i=n}if(+g[5052]!=0.0){wD(51288,(n=i,i=i+8|0,c[n>>2]=109632,n)|0);i=n}c[f>>2]=0;c[b+4>>2]=1;p=0}else{p=h}h=(c[b+8>>2]|0)+p|0;c[f>>2]=p+4;p=h;g[k>>2]=d;a[p]=a[k]|0;a[p+1|0]=a[k+1|0]|0;a[p+2|0]=a[k+2|0]|0;a[p+3|0]=a[k+3|0]|0;i=e;return}function nZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;f=a+16|0;h=c[f>>2]|0;j=h+d|0;k=a+12|0;l=c[k>>2]|0;if((j|0)<=(l|0)){m=h;n=a+8|0;o=c[n>>2]|0;p=o+m|0;q=m+d|0;c[f>>2]=q;yJ(p|0,b|0,d)|0;i=e;return}if((c[a>>2]|0)==0){w1(51920,(r=i,i=i+24|0,c[r>>2]=109632,c[r+8>>2]=j,c[r+16>>2]=l,r)|0);i=r;s=c[k>>2]|0}else{s=l}if((s|0)<(d|0)){w1(51600,(r=i,i=i+16|0,c[r>>2]=109632,c[r+8>>2]=d,r)|0);i=r}if(+g[5052]!=0.0){wD(51288,(r=i,i=i+8|0,c[r>>2]=109632,r)|0);i=r}c[f>>2]=0;c[a+4>>2]=1;m=0;n=a+8|0;o=c[n>>2]|0;p=o+m|0;q=m+d|0;c[f>>2]=q;yJ(p|0,b|0,d)|0;i=e;return}function n_(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;if((d|0)==0){f=b+16|0;h=c[f>>2]|0;j=h+1|0;k=b+12|0;l=c[k>>2]|0;if((j|0)>(l|0)){if((c[b>>2]|0)==0){w1(51920,(m=i,i=i+24|0,c[m>>2]=109632,c[m+8>>2]=j,c[m+16>>2]=l,m)|0);i=m;n=c[k>>2]|0}else{n=l}if((n|0)<1){w1(51600,(m=i,i=i+16|0,c[m>>2]=109632,c[m+8>>2]=1,m)|0);i=m}if(+g[5052]!=0.0){wD(51288,(m=i,i=i+8|0,c[m>>2]=109632,m)|0);i=m}c[f>>2]=0;c[b+4>>2]=1;o=0}else{o=h}h=(c[b+8>>2]|0)+o|0;c[f>>2]=o+1;a[h]=0;i=e;return}else{h=(yF(d|0)|0)+1|0;o=b+16|0;f=c[o>>2]|0;n=f+h|0;l=b+12|0;k=c[l>>2]|0;if((n|0)>(k|0)){if((c[b>>2]|0)==0){w1(51920,(m=i,i=i+24|0,c[m>>2]=109632,c[m+8>>2]=n,c[m+16>>2]=k,m)|0);i=m;p=c[l>>2]|0}else{p=k}if((p|0)<(h|0)){w1(51600,(m=i,i=i+16|0,c[m>>2]=109632,c[m+8>>2]=h,m)|0);i=m}if(+g[5052]!=0.0){wD(51288,(m=i,i=i+8|0,c[m>>2]=109632,m)|0);i=m}c[o>>2]=0;c[b+4>>2]=1;q=0}else{q=f}f=(c[b+8>>2]|0)+q|0;c[o>>2]=q+h;yJ(f|0,d|0,h)|0;i=e;return}}function n$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=a+12|0;h=a+16|0;j=c[h>>2]|0;k=(bV((c[a+8>>2]|0)+j|0,(c[f>>2]|0)-j|0,b|0,d|0)|0)+1|0;d=c[h>>2]|0;b=d+k|0;j=c[f>>2]|0;if((b|0)<=(j|0)){l=d;m=l+k|0;c[h>>2]=m;i=e;return}if((c[a>>2]|0)==0){w1(51920,(n=i,i=i+24|0,c[n>>2]=109632,c[n+8>>2]=b,c[n+16>>2]=j,n)|0);i=n;o=c[f>>2]|0}else{o=j}if((o|0)<(k|0)){w1(51600,(n=i,i=i+16|0,c[n>>2]=109632,c[n+8>>2]=k,n)|0);i=n}if(+g[5052]!=0.0){wD(51288,(n=i,i=i+8|0,c[n>>2]=109632,n)|0);i=n}c[h>>2]=0;c[a+4>>2]=1;l=0;m=l+k|0;c[h>>2]=m;i=e;return}function n0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;n$(a,b,f|0);i=e;return}function n1(a,b){a=a|0;b=+b;nW(a,~~(b*8.0));return}function n2(b,d){b=b|0;d=+d;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;f=~~+P(+(d*256.0/360.0+.5));h=b+16|0;j=c[h>>2]|0;k=j+1|0;l=b+12|0;m=c[l>>2]|0;if((k|0)<=(m|0)){n=j;o=b+8|0;p=c[o>>2]|0;q=p+n|0;r=n+1|0;c[h>>2]=r;s=f&255;a[q]=s;i=e;return}if((c[b>>2]|0)==0){w1(51920,(t=i,i=i+24|0,c[t>>2]=109632,c[t+8>>2]=k,c[t+16>>2]=m,t)|0);i=t;u=c[l>>2]|0}else{u=m}if((u|0)<1){w1(51600,(t=i,i=i+16|0,c[t>>2]=109632,c[t+8>>2]=1,t)|0);i=t}if(+g[5052]!=0.0){wD(51288,(t=i,i=i+8|0,c[t>>2]=109632,t)|0);i=t}c[h>>2]=0;c[b+4>>2]=1;n=0;o=b+8|0;p=c[o>>2]|0;q=p+n|0;r=n+1|0;c[h>>2]=r;s=f&255;a[q]=s;i=e;return}function n3(a,b){a=a|0;b=+b;nW(a,~~+P(+(b*65536.0/360.0+.5))&65535);return}function n4(a,b){a=a|0;b=b|0;var d=0;d=(b|0)<256?256:b;c[a+8>>2]=x1(d,68656)|0;c[a+12>>2]=d;c[a+16>>2]=0;return}function n5(b){b=b|0;var c=0,d=0;c=b;d=b;while(1){b=a[d]|0;if((b<<24>>24|0)==0){break}else if((b<<24>>24|0)==47){b=d+1|0;c=b;d=b;continue}else{c=c;d=d+1|0;continue}}return c|0}function n6(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;f=yF(d|0)|0;h=b+16|0;j=c[h>>2]|0;do{if((j|0)!=0){k=b+8|0;l=c[k>>2]|0;if((a[l+(j-1)|0]|0)!=0){break}m=j+f|0;n=b+12|0;o=c[n>>2]|0;if((m|0)>(o|0)){if((c[b>>2]|0)==0){w1(51920,(p=i,i=i+24|0,c[p>>2]=109632,c[p+8>>2]=m,c[p+16>>2]=o,p)|0);i=p;q=c[n>>2]|0}else{q=o}if((q|0)<(f|0)){w1(51600,(p=i,i=i+16|0,c[p>>2]=109632,c[p+8>>2]=f,p)|0);i=p}if(+g[5052]!=0.0){wD(51288,(p=i,i=i+8|0,c[p>>2]=109632,p)|0);i=p}c[h>>2]=0;c[b+4>>2]=1;r=0;s=c[k>>2]|0}else{r=j;s=l}c[h>>2]=r+f;l=s+(r-1)|0;k=f+1|0;yJ(l|0,d|0,k)|0;i=e;return}}while(0);r=f+1|0;f=j+r|0;s=b+12|0;q=c[s>>2]|0;if((f|0)>(q|0)){if((c[b>>2]|0)==0){w1(51920,(p=i,i=i+24|0,c[p>>2]=109632,c[p+8>>2]=f,c[p+16>>2]=q,p)|0);i=p;t=c[s>>2]|0}else{t=q}if((t|0)<(r|0)){w1(51600,(p=i,i=i+16|0,c[p>>2]=109632,c[p+8>>2]=r,p)|0);i=p}if(+g[5052]!=0.0){wD(51288,(p=i,i=i+8|0,c[p>>2]=109632,p)|0);i=p}c[h>>2]=0;c[b+4>>2]=1;u=0}else{u=j}j=(c[b+8>>2]|0)+u|0;c[h>>2]=u+r;yJ(j|0,d|0,r)|0;i=e;return}function n7(b){b=b|0;var c=0,d=0;c=b;L11678:while(1){b=c;while(1){d=a[b]|0;if((d<<24>>24|0)==47){break}else if((d<<24>>24|0)==0){break L11678}b=b+1|0}c=b+1|0}d=cn(c|0,46)|0;if((d|0)==0){return}if((a[d]|0)==0){return}a[d]=0;return}function n8(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=b;L11693:while(1){b=g;while(1){h=a[b]|0;if((h<<24>>24|0)==0){break L11693}else if((h<<24>>24|0)==47){break}b=b+1|0}g=b+1|0}h=cn(g|0,46)|0;if((h|0)==0){j=yF(g|0)|0}else{j=h-g|0}h=(j|0)<2;bR(d|0,e|0,53696|0,(e=i,i=i+16|0,c[e>>2]=h?7:j,c[e+8>>2]=h?59464:g,e)|0)|0;i=e;i=f;return}function n9(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;d=b+((yF(b|0)|0)-1)|0;while(1){e=a[d]|0;if(e<<24>>24==47|(d|0)==(b|0)){break}if(e<<24>>24==46){f=8885;break}else{d=d-1|0}}if((f|0)==8885){return}yR(b|0,c|0)|0;return}function oa(b){b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[1410640]=0;if((b|0)==0){c=0;return c|0}else{d=b}L11715:while(1){b=a[d]|0;e=b<<24>>24;if(b<<24>>24<33){if(b<<24>>24==0){c=0;f=8906;break}d=d+1|0;continue}if((b<<24>>24|0)==34){f=8894;break}else if((b<<24>>24|0)!=47){g=b;f=8898;break}if((a[d+1|0]|0)==47){h=d;i=47}else{g=47;f=8898;break}while(1){if((i<<24>>24|0)==0|(i<<24>>24|0)==10){d=h;continue L11715}b=h+1|0;h=b;i=a[b]|0}}if((f|0)==8894){i=0;h=d+1|0;while(1){j=h+1|0;b=a[h]|0;if((b<<24>>24|0)==34|(b<<24>>24|0)==0){break}a[1410640+i|0]=b;i=i+1|0;h=j}a[1410640+i|0]=0;c=j;return c|0}else if((f|0)==8906){return c|0}else if((f|0)==8898){if((cW(3632,e|0,7)|0)==0){k=0;l=g;m=d}else{a[1410640]=g;a[1410641]=0;c=d+1|0;return c|0}do{a[1410640+k|0]=l;m=m+1|0;k=k+1|0;l=a[m]|0;}while((cW(3632,l<<24>>24|0,7)|0)==0&l<<24>>24>32);a[1410640+k|0]=0;c=m;return c|0}return 0}function ob(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[353050]|0;if(b>>>0<=1){d=0;return d|0}e=c[353048]|0;f=1;while(1){g=c[e+(f<<2)>>2]|0;if((g|0)!=0){if((cS(a|0,g|0)|0)==0){d=f;h=8916;break}}g=f+1|0;if(g>>>0<b>>>0){f=g}else{d=0;h=8914;break}}if((h|0)==8916){return d|0}else if((h|0)==8914){return d|0}return 0}function oc(){var d=0,e=0,f=0,g=0,h=0;d=i;i=i+264|0;e=d|0;f=d+8|0;od(49736,e)|0;a[3336]=1;g=c[e>>2]|0;if((g|0)==0){oW(45648,(h=i,i=i+1|0,i=i+7>>3<<3,c[h>>2]=0,h)|0);i=h;if(!(a[21472]|0)){i=d;return}w1(41424,(h=i,i=i+1|0,i=i+7>>3<<3,c[h>>2]=0,h)|0);i=h;i=d;return}eh(f|0,1,256,g|0)|0;aS(g|0)|0;g=0;do{e=b[14384+(g<<1)>>1]|0;if(e<<16>>16!=(b8(b[f+(g<<1)>>1]|0)|0)<<16>>16){w1(37808,(h=i,i=i+1|0,i=i+7>>3<<3,c[h>>2]=0,h)|0);i=h}g=g+1|0;}while((g|0)<128);o9(107952,1411808);o9(78232,104600);a[3336]=0;oW(101592,(h=i,i=i+1|0,i=i+7>>3<<3,c[h>>2]=0,h)|0);i=h;i=d;return}function od(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+128|0;c[350572]=0;f=c[352916]|0;L11769:do{if((f|0)!=0){g=e|0;h=f;L11771:while(1){j=c[h+128>>2]|0;L11773:do{if((j|0)==0){if(a[3336]|0){if((b7(b|0,47)|0)!=0){break}if((b7(b|0,92)|0)!=0){break}}k=h|0;bR(g|0,128,90224,(l=i,i=i+16|0,c[l>>2]=k,c[l+8>>2]=b,l)|0)|0;i=l;if((wX(g)|0)!=-1){m=8942;break L11771}}else{k=c[j+128>>2]|0;n=j+132|0;o=0;while(1){if((o|0)>=(k|0)){break L11773}if((cS((c[n>>2]|0)+(o*72|0)|0,b|0)|0)==0){break L11771}else{o=o+1|0}}}}while(0);h=c[h+132>>2]|0;if((h|0)==0){break L11769}}if((m|0)==8942){h=dc(g|0,84736)|0;c[d>>2]=h;k=ci(h|0)|0;eC(h|0,0,2)|0;p=ci(h|0)|0;eC(h|0,k|0,0)|0;c[352950]=p;q=p;i=e;return q|0}p=j|0;k=dc(p|0,84736)|0;c[d>>2]=k;if((k|0)==0){w1(82264,(l=i,i=i+8|0,c[l>>2]=p,l)|0);i=l;r=c[d>>2]|0}else{r=k}eC(r|0,c[(c[n>>2]|0)+(o*72|0)+64>>2]|0,0)|0;k=c[(c[n>>2]|0)+(o*72|0)+68>>2]|0;c[352950]=k;c[350572]=1;q=k;i=e;return q|0}}while(0);wD(80312,(l=i,i=i+8|0,c[l>>2]=b,l)|0);i=l;c[d>>2]=0;c[352950]=-1;q=-1;i=e;return q|0}function oe(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;L11795:do{if((b|0)>0){e=0;f=0;while(1){if((f|0)>=255){g=f;break L11795}h=d+(e<<2)|0;i=0;j=f;while(1){k=a[(c[h>>2]|0)+i|0]|0;if(k<<24>>24==0){break}l=j+1|0;a[1411808+j|0]=k;if((l|0)<255){i=i+1|0;j=l}else{g=l;break L11795}}i=j+1|0;a[1411808+j|0]=32;h=e+1|0;if((h|0)<50&(h|0)<(b|0)){e=h;f=i}else{g=i;break}}}else{g=0}}while(0);a[1411808+g|0]=0;c[353050]=0;do{if((b|0)==0){m=0}else{g=0;f=0;while(1){e=d+(g<<2)|0;c[1098304+(g<<2)>>2]=c[e>>2];n=(cS(99456,c[e>>2]|0)|0)==0?1:f;o=g+1|0;c[353050]=o;if(o>>>0<50&o>>>0<b>>>0){g=o;f=n}else{break}}if((n|0)==0){m=o;break}f=1098304+(o<<2)|0;c[f>>2]=c[1286];c[f+4>>2]=c[1287];c[f+8>>2]=c[1288];c[f+12>>2]=c[1289];c[f+16>>2]=c[1290];c[f+20>>2]=c[1291];c[f+24>>2]=c[1292];f=g+8|0;c[353050]=f;m=f}}while(0);c[1098304+(m<<2)>>2]=56136;c[353048]=1098304;if((bw(1243216,97808)|0)!=0){c[155622]=1;c[836]=0}if((bw(1243216,95504)|0)==0){return}c[278834]=1;c[836]=0;return}function of(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+640|0;e=d|0;a[183488]=1;a[183489]=0;c[660128]=(b[91744]|0)!=1;pb(9168);pb(21480);oE(93608,514);f=d+128|0;g=d+384|0;bR(f|0,256,78504,(h=i,i=i+8|0,c[h>>2]=1242960,h)|0)|0;i=h;wD(77328,(h=i,i=i+1|0,i=i+7>>3<<3,c[h>>2]=0,h)|0);i=h;wD(f,(h=i,i=i+1|0,i=i+7>>3<<3,c[h>>2]=0,h)|0);i=h;j=c[353050]|0;L11818:do{if(j>>>0>1){k=c[353048]|0;l=1;while(1){m=c[k+(l<<2)>>2]|0;if((m|0)!=0){if((cS(75888,m|0)|0)==0){break}}m=l+1|0;if(m>>>0<j>>>0){l=m}else{n=8974;break L11818}}if((l|0)==0){n=8974;break}if(l>>>0>=(j-1|0)>>>0){n=8974;break}yQ(1412064,c[k+(l+1<<2)>>2]|0)|0}else{n=8974}}while(0);if((n|0)==8974){j=c[278802]|0;yQ(1412064,j|0)|0}oo(f);do{if((bw(1243216,97808)|0)==0){if((bw(1243216,95504)|0)==0){break}bR(g|0,256,71816,(h=i,i=i+16|0,c[h>>2]=f,c[h+8>>2]=47,h)|0)|0;i=h;oo(g)}else{bR(g|0,256,73760,(h=i,i=i+16|0,c[h>>2]=f,c[h+8>>2]=47,h)|0)|0;i=h;oo(g)}}while(0);g=c[353050]|0;L11836:do{if(g>>>0>1){j=c[353048]|0;m=1;while(1){o=c[j+(m<<2)>>2]|0;if((o|0)!=0){if((cS(68944,o|0)|0)==0){break}}o=m+1|0;if(o>>>0<g>>>0){m=o}else{break L11836}}if((m|0)==0){break}if(m>>>0>=(g-1|0)>>>0){break}a[21472]=1;oh(78504,(h=i,i=i+8|0,c[h>>2]=c[j+(m+1<<2)>>2],h)|0)|0;i=h;oo(f)}}while(0);f=e|0;L11847:do{if((a[1411672]|0)!=0){yP(f|0,1411672,128)|0;a[e+127|0]=0;g=e+1|0;while(1){l=a[g]|0;if((l<<24>>24|0)==47){a[g]=0;wY(f);a[g]=47}else if((l<<24>>24|0)==0){break L11847}g=g+1|0}}}while(0);wY(1411672);f=c[353050]|0;if(f>>>0<=1){oc();i=d;return}e=c[353048]|0;g=1;while(1){m=c[e+(g<<2)>>2]|0;if((m|0)!=0){if((cS(67744,m|0)|0)==0){break}}m=g+1|0;if(m>>>0<f>>>0){g=m}else{n=9026;break}}if((n|0)==9026){oc();i=d;return}if((g|0)==0){oc();i=d;return}a[21472]=1;c[352916]=0;m=g+1|0;if(m>>>0>=f>>>0){oc();i=d;return}f=c[e+(m<<2)>>2]|0;if((f|0)==0){oc();i=d;return}else{p=m;q=f}while(1){f=a[q]|0;if((f<<24>>24|0)==43|(f<<24>>24|0)==45){n=9023;break}f=x2(136)|0;m=(c[353048]|0)+(p<<2)|0;e=c[m>>2]|0;g=e;L11877:while(1){j=g;while(1){l=a[j]|0;if((l<<24>>24|0)==47){break}else if((l<<24>>24|0)==0){break L11877}j=j+1|0}g=j+1|0}l=f;k=cn(g|0,46)|0;if((k|0)==0){r=2659296;s=e}else{o=a[k+1|0]|0;do{if(o<<24>>24==0){t=0}else{a[2677688]=o;u=a[k+2|0]|0;if(u<<24>>24==0){t=1;break}a[2677689]=u;u=a[k+3|0]|0;if(u<<24>>24==0){t=2;break}a[2677690]=u;u=a[k+4|0]|0;if(u<<24>>24==0){t=3;break}a[2677691]=u;u=a[k+5|0]|0;if(u<<24>>24==0){t=4;break}a[2677692]=u;u=a[k+6|0]|0;if(u<<24>>24==0){t=5;break}a[2677693]=u;u=a[k+7|0]|0;if(u<<24>>24==0){t=6;break}a[2677694]=u;t=7}}while(0);a[2677688+t|0]=0;r=2677688;s=c[m>>2]|0}do{if((cS(r|0,66776)|0)==0){k=ot(s)|0;c[f+128>>2]=k;if((k|0)!=0){break}w1(65800,(h=i,i=i+8|0,c[h>>2]=c[(c[353048]|0)+(p<<2)>>2],h)|0);i=h}else{yQ(f|0,s|0)|0}}while(0);c[f+132>>2]=c[352916];c[352916]=l;m=p+1|0;if(m>>>0>=(c[353050]|0)>>>0){n=9024;break}k=c[(c[353048]|0)+(m<<2)>>2]|0;if((k|0)==0){n=9030;break}else{p=m;q=k}}if((n|0)==9024){oc();i=d;return}else if((n|0)==9030){oc();i=d;return}else if((n|0)==9023){oc();i=d;return}}function og(){var a=0,b=0,d=0,e=0,f=0;a=i;oW(57440,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;d=c[352916]|0;if((d|0)==0){i=a;return}else{e=d}do{d=c[e+128>>2]|0;if((d|0)==0){oW(56560,(b=i,i=i+8|0,c[b>>2]=e,b)|0);i=b}else{f=c[d+128>>2]|0;oW(56984,(b=i,i=i+16|0,c[b>>2]=d,c[b+8>>2]=f,b)|0);i=b}e=c[e+132>>2]|0;}while((e|0)!=0);i=a;return}function oh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+16|0;e=d|0;f=(c[667372]|0)+1|0;c[667372]=f;g=2669496+((f&3)<<11)|0;f=e;c[f>>2]=b;c[f+4>>2]=0;if((bV(g|0,2048,a|0,e|0)|0)<=2047){i=d;return g|0}oX(91896,(e=i,i=i+8|0,c[e>>2]=109472,e)|0);i=e;i=d;return g|0}function oi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+128|0;f=e|0;bR(f|0,128,90224,(g=i,i=i+16|0,c[g>>2]=1411672,c[g+8>>2]=a,g)|0)|0;i=g;h=dc(f|0,88384)|0;do{if((h|0)==0){wY(1411672);j=dc(f|0,88384)|0;if((j|0)!=0){k=j;break}w1(86688,(g=i,i=i+8|0,c[g>>2]=a,g)|0);i=g;k=0}else{k=h}}while(0);a5(b|0,1,d|0,k|0)|0;aS(k|0)|0;i=e;return}function oj(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+128|0;j=h|0;k=c[352916]|0;if((k|0)==0){i=h;return}l=j|0;m=j+127|0;j=(e|0)!=0;n=(f|0)!=0;o=n^1;p=(g|0)==0|o;g=(d|0)!=0;q=g^1;r=j^1;s=k;do{k=c[s+128>>2]|0;L11932:do{if((k|0)==0){t=s|0;bR(l|0,128,90224,(u=i,i=i+16|0,c[u>>2]=t,c[u+8>>2]=d,u)|0)|0;i=u;a[m]=0;u=bF(l|0)|0;if((u|0)==0){break}if(j){v=yF(e|0)|0}else{v=0}if(n){w=yF(f|0)|0}else{w=0}t=bX(u|0)|0;if((t|0)!=0){x=p?0:w;y=t;do{t=y+4|0;if(j){if((yL(t|0,e|0,v|0)|0)==0){z=9090}}else{z=9090}do{if((z|0)==9090){z=0;if(n){A=cn(t|0,46)|0;if((A|0)==0){break}B=(a[f]|0)==46?A:A+1|0;if((B|0)==0){break}if((yM(B|0,f|0)|0)!=0){break}}B=(yF(t|0)|0)-x|0;A=xZ(B+1|0)|0;if((A|0)==0){break}yP(A|0,t|0,B|0)|0;a[A+B|0]=0;vo(b,A,1)|0;xY(A)}}while(0);y=bX(u|0)|0;}while((y|0)!=0)}eW(u|0)|0}else{if(g){C=yF(d|0)|0}else{C=0}if(j){D=yF(e|0)|0}else{D=0}if(n){E=yF(f|0)|0}else{E=0}y=k+128|0;if((c[y>>2]|0)<=0){break}x=k+132|0;t=(D|0)==0|r;A=(E|0)==0|o;B=p?0:E;F=C+1|0;if((C|0)==0|q){G=0;while(1){H=(c[x>>2]|0)+(G*72|0)|0;do{if((b7(H|0,47)|0)==0){if(!t){if((yL(H|0,e|0,D|0)|0)!=0){break}}if(!A){I=cn(H|0,46)|0;if((I|0)==0){break}J=(a[f]|0)==46?I:I+1|0;if((J|0)==0){break}if((yM(J|0,f|0)|0)!=0){break}}J=(yF(H|0)|0)-B|0;I=xZ(J+1|0)|0;if((I|0)==0){break}yP(I|0,H|0,J|0)|0;a[I+J|0]=0;vo(b,I,1)|0;xY(I)}}while(0);G=G+1|0;if((G|0)>=(c[y>>2]|0)){break L11932}}}else{K=0}do{G=c[x>>2]|0;do{if((yL(G+(K*72|0)|0,d|0,C|0)|0)==0){if((a[G+(K*72|0)+C|0]|0)!=47){break}u=G+(K*72|0)+F|0;if((b7(u|0,47)|0)!=0){break}if(!t){if((yL(u|0,e|0,D|0)|0)!=0){break}}if(!A){H=cn(u|0,46)|0;if((H|0)==0){break}I=(a[f]|0)==46?H:H+1|0;if((I|0)==0){break}if((yM(I|0,f|0)|0)!=0){break}}I=(yF(u|0)|0)-B|0;H=xZ(I+1|0)|0;if((H|0)==0){break}yP(H|0,u|0,I|0)|0;a[H+I|0]=0;vo(b,H,1)|0;xY(H)}}while(0);K=K+1|0;}while((K|0)<(c[y>>2]|0))}}while(0);s=c[s+132>>2]|0;}while((s|0)!=0);i=h;return}function ok(a){a=a|0;return ol(a,1,0)|0}function ol(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+40|0;g=f|0;h=f+8|0;j=od(b,g)|0;c[352950]=j;if((c[g>>2]|0)==0){k=0;i=f;return k|0}if((e|0)==0){l=b}else{c[e>>2]=j;l=b}L12008:while(1){e=l;while(1){m=a[e]|0;if((m<<24>>24|0)==0){break L12008}else if((m<<24>>24|0)==47){break}e=e+1|0}l=e+1|0}m=h|0;h=cn(l|0,46)|0;if((h|0)==0){n=yF(l|0)|0}else{n=h-l|0}h=(n|0)<2;bR(m|0,32,53696,(o=i,i=i+16|0,c[o>>2]=h?7:n,c[o+8>>2]=h?59464:l,o)|0)|0;i=o;L12019:do{switch(d|0){case 2:{p=x7(j+1|0)|0;q=9122;break};case 1:{p=x1(j+1|0,m)|0;q=9122;break};case 4:{l=j+1|0;if((l|0)>(c[274520]|0)){p=x7(l)|0;q=9122;break L12019}else{p=c[274542]|0;q=9122;break L12019}break};case 3:{p=yd(c[274540]|0,j+1|0,m)|0;q=9122;break};case 0:{p=xZ(j+1|0)|0;q=9122;break};default:{w1(58536,(o=i,i=i+8|0,c[o>>2]=111720,o)|0);i=o;q=9123}}}while(0);if((q|0)==9122){if((p|0)==0){q=9123}else{r=p}}if((q|0)==9123){w1(57968,(o=i,i=i+16|0,c[o>>2]=111720,c[o+8>>2]=b,o)|0);i=o;r=0}a[r+j|0]=0;pX();eh(r|0,1,j|0,c[g>>2]|0)|0;aS(c[g>>2]|0)|0;pY();k=r;i=f;return k|0}function om(a,b){a=a|0;b=b|0;c[274540]=b;ol(a,3,0)|0;return}function on(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[274542]=b;c[274520]=d;return ol(a,4,e)|0}function oo(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+128|0;if((a|0)==0){i=b;return}d=oh(78504,(e=i,i=i+8|0,c[e>>2]=a,e)|0)|0;i=e;yQ(1411672,d|0)|0;d=x2(136)|0;yQ(d|0,1411672)|0;c[d+132>>2]=c[352916];c[352916]=d;d=b|0;a=0;while(1){bR(d|0,128,61824,(e=i,i=i+24|0,c[e>>2]=1411672,c[e+8>>2]=47,c[e+16>>2]=a,e)|0)|0;i=e;wD(60800,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e;wD(d,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e;wD(59576,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e;f=ot(d)|0;if((f|0)==0){bR(d|0,128,59040,(e=i,i=i+24|0,c[e>>2]=1411672,c[e+8>>2]=47,c[e+16>>2]=a,e)|0)|0;i=e;g=ot(d)|0;if((g|0)==0){break}else{h=g}}else{h=f}f=x2(136)|0;c[f+128>>2]=h;c[f+132>>2]=c[352916];c[352916]=f;a=a+1|0}i=b;return}function op(){a[21560]=1;return}function oq(){return c[353142]|0}function or(){var a=0;a=c[353140]|0;return((a|0)==0?2659288:a)|0}function os(a){a=a|0;var b=0;if((c[353142]|0)<=(a|0)){b=2659288;return b|0}b=c[1412240+(a<<2)>>2]|0;return b|0}function ot(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+131088|0;e=d|0;f=d+16|0;g=dc(b|0,84736)|0;if((g|0)==0){h=0;i=d;return h|0}j=ci(g|0)|0;eC(g|0,0,2)|0;k=ci(g|0)|0;eC(g|0,j|0,0)|0;if((k|0)==-1){h=0;i=d;return h|0}k=e|0;eh(k|0,1,12,g|0)|0;do{if((a[k]|0)==80){if((a[e+1|0]|0)!=65){l=9152;break}if((a[e+2|0]|0)!=67){l=9152;break}if((a[e+3|0]|0)!=75){l=9152}}else{l=9152}}while(0);if((l|0)==9152){w1(64856,(m=i,i=i+8|0,c[m>>2]=b,m)|0);i=m}l=c[e+8>>2]|0;k=l>>>6;if(l>>>0>131135){w1(64072,(m=i,i=i+16|0,c[m>>2]=b,c[m+8>>2]=k,m)|0);i=m}if((k|0)!=339){a[21472]=1}j=x1(k*72|0,63152)|0;eC(g|0,c[e+4>>2]|0,0)|0;e=f|0;eh(e|0,1,l|0,g|0)|0;if((oI(e,l)|0)<<16>>16!=-32555){a[21472]=1}if((k|0)!=0){l=0;do{yQ(j+(l*72|0)|0,f+(l<<6)|0)|0;c[j+(l*72|0)+64>>2]=c[f+(l<<6)+56>>2];c[j+(l*72|0)+68>>2]=c[f+(l<<6)+60>>2];l=l+1|0;}while((l|0)<(k|0))}l=x2(136)|0;yQ(l|0,b|0)|0;c[l+128>>2]=k;c[l+132>>2]=j;oW(62584,(m=i,i=i+16|0,c[m>>2]=b,c[m+8>>2]=k,m)|0);i=m;wD(62584,(m=i,i=i+16|0,c[m>>2]=b,c[m+8>>2]=k,m)|0);i=m;h=l;i=d;return h|0}function ou(){n4(1412208,8192);return}function ov(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+16|0;e=d|0;f=c[353056]|0;g=(c[353054]|0)+f|0;h=(c[353055]|0)-f|0;f=e;c[f>>2]=b;c[f+4>>2]=0;f=bV(g|0,h|0,a|0,e|0)|0;e=(c[353056]|0)+f|0;if((e|0)<(c[353055]|0)){c[353056]=e;i=d;return}else{oW(79696,(e=i,i=i+8|0,c[e>>2]=111616,e)|0);i=e;i=d;return}}function ow(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=yF(b|0)|0;f=c[353056]|0;if((f|0)==0){ov(58960,(g=i,i=i+8|0,c[g>>2]=b,g)|0);i=g;i=d;return}h=e+1|0;if((h+f|0)>(c[353055]|0)){w1(67496,(g=i,i=i+8|0,c[g>>2]=111584,g)|0);i=g;j=c[353056]|0}else{j=f}f=c[353054]|0;yN(f+h|0,f|0,j|0);j=c[353054]|0;yJ(j|0,b|0,e)|0;a[(c[353054]|0)+e|0]=10;c[353056]=h+(c[353056]|0);i=d;return}function ox(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+1024|0;d=b|0;e=d|0;do{f=c[353056]|0;if((f|0)==0){g=9195;break}h=c[353054]|0;j=(f|0)<1024?f:1024;k=0;l=0;while(1){if((l|0)>=(j|0)){break}m=a[h+l|0]|0;n=(m<<24>>24==34)+k|0;if((n&1|0)==0&m<<24>>24==59){break}if(m<<24>>24==10){break}else{k=n;l=l+1|0}}if((l|0)==1024){oW(53152,(k=i,i=i+8|0,c[k>>2]=111600,k)|0);i=k;o=1023;p=c[353056]|0}else{o=l;p=f}yJ(e|0,h|0,o)|0;a[d+o|0]=0;if((o|0)==(p|0)){c[353056]=0}else{k=o+1|0;j=p-k|0;c[353056]=j;yN(h|0,h+k|0,j|0)}oy(e,1);}while(!(a[21560]|0));if((g|0)==9195){i=b;return}a[21560]=0;i=b;return}function oy(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0;e=i;c[353058]=d;oJ(b);if((c[353142]|0)==0){i=e;return}b=vr(21568,c[353060]|0)|0;do{if((b|0)!=0){d=b-20+8|0;if((d|0)==0){break}f=c[d+4>>2]|0;if((f|0)==0){i=e;return}fQ[f&1023]();i=e;return}}while(0);b=vr(21536,c[353060]|0)|0;do{if((b|0)!=0){f=b-40+4|0;if((f|0)==0){break}d=c[f+32>>2]|0;f=yF(d|0)|0;h=c[353056]|0;if((h|0)==0){ov(58960,(j=i,i=i+8|0,c[j>>2]=d,j)|0);i=j;i=e;return}k=f+1|0;if((k+h|0)>(c[353055]|0)){w1(67496,(j=i,i=i+8|0,c[j>>2]=111584,j)|0);i=j;l=c[353056]|0}else{l=h}h=c[353054]|0;yN(h+k|0,h|0,l|0);h=c[353054]|0;yJ(h|0,d|0,f)|0;a[(c[353054]|0)+f|0]=10;c[353056]=(c[353056]|0)+k;i=e;return}}while(0);if((pc()|0)!=0){i=e;return}if(!(+g[5418]!=0.0|+g[5052]!=0.0)){i=e;return}oW(72648,(j=i,i=i+8|0,c[j>>2]=(c[353142]|0)>0?c[353060]|0:2659288,j)|0);i=j;i=e;return}function oz(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;if((c[353142]|0)!=1){oW(49400,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=b;return}e=c[353050]|0;if(e>>>0<=1){i=b;return}f=c[353048]|0;g=0;h=1;while(1){j=c[f+(h<<2)>>2]|0;if((j|0)==0){k=g}else{k=g+1+(yF(j|0)|0)|0}j=h+1|0;if(j>>>0<e>>>0){g=k;h=j}else{break}}if((k|0)==0){i=b;return}h=k+1|0;g=xZ(h)|0;a[g]=0;e=c[353050]|0;if(e>>>0>1){f=1;j=e;while(1){e=c[(c[353048]|0)+(f<<2)>>2]|0;do{if((e|0)==0){l=j}else{yR(g|0,e|0)|0;m=c[353050]|0;if((f|0)==(m-1|0)){l=m;break}m=g+(yF(g|0)|0)|0;x=32;a[m]=x&255;x=x>>8;a[m+1|0]=x&255;l=c[353050]|0}}while(0);e=f+1|0;if(e>>>0<l>>>0){f=e;j=l}else{break}}}l=xZ(h)|0;a[l]=0;h=k-1|0;do{if((h|0)>0){k=0;do{if((a[g+k|0]|0)==43){j=k+1|0;f=j;while(1){n=g+f|0;o=a[n]|0;if((o<<24>>24|0)==43|(o<<24>>24|0)==45|(o<<24>>24|0)==0){break}f=f+1|0}a[n]=0;yR(l|0,g+j|0)|0;e=l+(yF(l|0)|0)|0;x=10;a[e]=x&255;x=x>>8;a[e+1|0]=x&255;a[n]=o;p=f-1|0}else{p=k}k=p+1|0;}while((k|0)<(h|0));if((a[l]|0)==0){break}k=yF(l|0)|0;e=c[353056]|0;if((e|0)==0){ov(58960,(d=i,i=i+8|0,c[d>>2]=l,d)|0);i=d;break}m=k+1|0;if((m+e|0)>(c[353055]|0)){w1(67496,(d=i,i=i+8|0,c[d>>2]=111584,d)|0);i=d;q=c[353056]|0}else{q=e}e=c[353054]|0;yN(e+m|0,e|0,q|0);e=c[353054]|0;yJ(e|0,l|0,k)|0;a[(c[353054]|0)+k|0]=10;c[353056]=(c[353056]|0)+m}}while(0);xY(g);xY(l);i=b;return}function oA(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0;b=i;if((c[353142]|0)!=2){oW(37528,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=b;return}e=x_()|0;f=ok((c[353142]|0)>1?c[353061]|0:2659288)|0;if((f|0)==0){oW(107712,(d=i,i=i+8|0,c[d>>2]=(c[353142]|0)>1?c[353061]|0:2659288,d)|0);i=d;i=b;return}if(+g[5418]!=0.0|+g[5052]!=0.0){oW(104304,(d=i,i=i+8|0,c[d>>2]=(c[353142]|0)>1?c[353061]|0:2659288,d)|0);i=d}h=yF(f|0)|0;j=c[353056]|0;if((j|0)==0){ov(58960,(d=i,i=i+8|0,c[d>>2]=f,d)|0);i=d}else{k=h+1|0;if((k+j|0)>(c[353055]|0)){w1(67496,(d=i,i=i+8|0,c[d>>2]=111584,d)|0);i=d;l=c[353056]|0}else{l=j}j=c[353054]|0;yN(j+k|0,j|0,l|0);l=c[353054]|0;yJ(l|0,f|0,h)|0;a[(c[353054]|0)+h|0]=10;c[353056]=(c[353056]|0)+k}x3(e);i=b;return}function oB(){var a=0,b=0,d=0;a=i;if((c[353142]|0)>1){b=1;do{oW(101144,(d=i,i=i+8|0,c[d>>2]=c[1412240+(b<<2)>>2],d)|0);i=d;b=b+1|0;}while((b|0)<(c[353142]|0))}oW(41112,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}function oC(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+1032|0;d=b|0;e=b+1024|0;f=c[353142]|0;if((f|0)==1){oW(99312,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;vs(21536,e);if((vu(21536,e)|0)==0){i=b;return}do{h=(c[e>>2]|0)-40+4|0;j=c[h+32>>2]|0;oW(97656,(g=i,i=i+16|0,c[g>>2]=h,c[g+8>>2]=j,g)|0);i=g;vm(e);}while((vu(21536,e)|0)!=0);i=b;return}e=(f|0)>1?c[353061]|0:2659288;if((yF(e|0)|0)>>>0>31){oW(95288,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}f=vr(21536,e)|0;do{if((f|0)==0){k=9280}else{j=f-40+4|0;if((j|0)==0){k=9280;break}xY(c[j+32>>2]|0);l=j}}while(0);if((k|0)==9280){k=xZ(56)|0;f=k;yQ(k|0,e|0)|0;e=k+36|0;j=e;c[e>>2]=k;vn(21536,j)|0;l=f}f=d|0;a[f]=0;j=c[353142]|0;L12239:do{if((j|0)>2){k=j-1|0;e=2;h=1;m=j;while(1){n=(m|0)>(e|0);if(n){o=c[1412240+(e<<2)>>2]|0}else{o=2659288}p=(e|0)!=(k|0);q=(p&1)+h+(yF(o|0)|0)|0;if(q>>>0>1023){break}if(n){r=c[1412240+(e<<2)>>2]|0}else{r=2659288}yR(f|0,r|0)|0;if(p){p=d+(yF(f|0)|0)|0;x=32;a[p]=x&255;x=x>>8;a[p+1|0]=x&255}p=e+1|0;if((p|0)>=(j|0)){break L12239}e=p;h=q;m=c[353142]|0}oW(93496,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;a[f]=0}}while(0);g=d+(yF(f|0)|0)|0;x=10;a[g]=x&255;x=x>>8;a[g+1|0]=x&255;g=xZ((yF(f|0)|0)+1|0)|0;yQ(g|0,f|0)|0;c[l+32>>2]=g;i=b;return}function oD(){oE(91728,440);oE(90016,204);oE(88264,370);oE(86568,530);oE(84568,298);oE(82024,428);return}function oE(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;if((c[278808]|0)!=0){w1(78344,(f=i,i=i+8|0,c[f>>2]=111568,f)|0);i=f}if((a[o8(b)|0]|0)!=0){oW(77152,(f=i,i=i+16|0,c[f>>2]=111568,c[f+8>>2]=b,f)|0);i=f;i=e;return}g=vr(21568,b)|0;if((g|0)==0|(g-20+8|0)==0){g=x2(32)|0;c[g>>2]=b;c[g+4>>2]=d;c[g+8>>2]=0;d=g+12|0;g=d;c[d>>2]=b;vn(21568,g)|0;i=e;return}else{oW(75712,(f=i,i=i+16|0,c[f>>2]=111568,c[f+8>>2]=b,f)|0);i=f;i=e;return}}function oF(){var a=0,b=0,d=0,e=0;a=i;if((c[353150]|0)>>>0<2){oW(73696,(b=i,i=i+8|0,c[b>>2]=(c[353142]|0)>0?c[353060]|0:2659288,b)|0);i=b;i=a;return}if((c[353697]|0)!=0){i=a;return}nV(1414824,4);b=c[353142]|0;d=(b|0)>0?c[353060]|0:2659288;if((yM(d|0,82024)|0)==0){e=b}else{n6(1414824,d);n6(1414824,45192);e=c[353142]|0}if((e|0)>1){e=c[353140]|0;n6(1414824,(e|0)==0?2659288:e);i=a;return}else{n6(1414824,41112);i=a;return}}function oG(){c[278172]=2;c[644592]=0;return}function oH(){c[278172]=2;c[644592]=1;return}function oI(a,c){a=a|0;c=c|0;var e=0,f=0,g=0,h=0;if((c|0)==0){e=-1;return e|0}else{f=-1;g=a;h=c}while(1){c=h-1|0;a=b[20744+(((d[g]|0)^(f&65535)>>>8)<<1)>>1]^f<<8;if((c|0)==0){e=a;break}else{f=a;g=g+1|0;h=c}}return e|0}function oJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;if((c[353142]|0)>0){d=0;do{xY(c[1412240+(d<<2)>>2]|0);d=d+1|0;}while((d|0)<(c[353142]|0))}c[353142]=0;c[353140]=0;d=b;b=0;while(1){e=a[d]|0;if(e<<24>>24<33){if((e<<24>>24|0)==10|(e<<24>>24|0)==0){f=9346;break}d=d+1|0;b=b;continue}if((e<<24>>24|0)==10|(e<<24>>24|0)==0){f=9345;break}if((b|0)==1){c[353140]=d}e=oa(d)|0;if((e|0)==0){f=9344;break}g=c[353142]|0;if((g|0)>=80){d=e;b=g;continue}g=xZ((yF(1410640)|0)+1|0)|0;yQ(g|0,1410640)|0;h=c[353142]|0;c[1412240+(h<<2)>>2]=g;g=h+1|0;c[353142]=g;d=e;b=g}if((f|0)==9345){return}else if((f|0)==9346){return}else if((f|0)==9344){return}}function oK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=vr(21568,a)|0;do{if((e|0)!=0){f=e-20+8|0;if((f|0)==0){break}c[f+8>>2]=b;i=d;return}}while(0);w1(74664,(b=i,i=i+16|0,c[b>>2]=111544,c[b+8>>2]=a,b)|0);i=b;i=d;return}function oL(a){a=a|0;var b=0,c=0;b=vr(21568,a)|0;if((b|0)==0){c=0;return c|0}c=(b-20+8|0)!=0|0;return c|0}function oM(a){a=a|0;var b=0,c=0;b=vr(21536,a)|0;if((b|0)==0){c=0;return c|0}c=(b-40+4|0)!=0|0;return c|0}function oN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=vr(21568,a)|0;do{if((d|0)==0){e=0}else{a=d-20+8|0;if((a|0)==0){e=0;break}f=c[a+8>>2]|0;if((f|0)==0){e=0;break}e=fv[f&127](b)|0}}while(0);return e|0}function oO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=vr(21568,a)|0;do{if((d|0)==0){e=0}else{a=d-20+8|0;if((a|0)==0){e=0;break}f=c[a+8>>2]|0;if((f|0)==0){e=0;break}a=fv[f&127](b)|0;if((a|0)==0){e=0;break}f=vp(a,b)|0;xY(a);e=f}}while(0);return e|0}function oP(a){a=a|0;var b=0,d=0;b=xZ(20)|0;d=b;c[b>>2]=0;c[b+4>>2]=0;c[b+8>>2]=-1;c[b+16>>2]=0;vl();vv(d,21568,a);vv(d,21536,a);vv(d,20544,a);return d|0}function oQ(a){a=a|0;var b=0,d=0,e=0;b=xZ(20)|0;d=b;c[b>>2]=0;c[b+4>>2]=0;c[b+8>>2]=-1;c[b+16>>2]=0;vl();vv(d,21568,a);vv(d,21536,a);vv(d,20544,a);e=vp(d,a)|0;xY(b);return e|0}function oR(){qT();do{if((c[278172]|0)==1){if((c[352656]|0)!=0){break}c[278172]=0;qT()}else{c[278172]=1}}while(0);yG(1410560,0,16);return}function oS(){yG(1410560|0,0|0,16|0);return}function oT(){yG(c[352648]|0,32,16384);return}function oU(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+16384|0;d=b|0;e=(c[29381]>>3)-2|0;f=c[352652]|0;if((e|0)==(f|0)){i=b;return}if((e|0)<1){c[352652]=38;c[352638]=431;yG(c[352648]|0,32,16384)}else{c[352652]=e;g=c[352638]|0;h=16384/(e|0)|0;c[352638]=h;j=(h|0)<(g|0)?h:g;h=(e|0)<(f|0)?e:f;e=c[352648]|0;yJ(d|0,e|0,16384)|0;yG(e|0,32,16384);if((j|0)>0&(h|0)>0){e=0;k=0;while(1){l=k+g|0;m=k-1|0;n=0;do{o=a[d+((ab((l+(c[352649]|0)|0)%(g|0)|0,f)|0)+n)|0]|0;p=(ab(m+(c[352638]|0)|0,c[352652]|0)|0)+n|0;a[(c[352648]|0)+p|0]=o;n=n+1|0;}while((n|0)<(h|0));n=e+1|0;m=~e;if((n|0)<(j|0)){e=n;k=m}else{break}}}yG(1410560,0,16)}k=(c[352638]|0)-1|0;c[352649]=k;c[352651]=k;i=b;return}function oV(b){b=b|0;var d=0,e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a[b]|0;do{if((d-1&255)<2){e=b+1|0;f=a[e]|0;if(f<<24>>24!=1){i=128;j=e;k=f;break}vP(61536);i=128;j=e;k=a[e]|0}else{i=0;j=b;k=d}}while(0);if(k<<24>>24==0){return}else{l=j;m=k}do{k=m<<24>>24;j=c[352652]|0;d=0;while(1){if((d|0)>=(j|0)){break}if((a[l+d|0]|0)<33){break}else{d=d+1|0}}do{if((d|0)!=(j|0)){b=(c[352658]|0)+8|0;if(((c[b>>2]|0)+d|0)<=(j|0)){break}c[b>>2]=0}}while(0);l=l+1|0;if(a[112384]|0){j=(c[352658]|0)+4|0;c[j>>2]=(c[j>>2]|0)-1;a[112384]=0}j=c[352658]|0;d=j+8|0;do{if((c[d>>2]|0)==0){c[d>>2]=0;b=c[352658]|0;e=b+12|0;f=c[e>>2]|0;n=c[b+4>>2]|0;if((f|0)==(n|0)){c[e>>2]=f+1;f=c[352658]|0;o=f;p=c[f+4>>2]|0}else{o=b;p=n}c[o+4>>2]=p+1;n=c[352658]|0;b=c[352652]|0;f=ab(b,(c[n+4>>2]|0)%(c[352638]|0)|0)|0;yG((c[n>>2]|0)+f|0,32,b|0);b=c[352658]|0;f=c[b+4>>2]|0;if((f|0)<=-1){q=b;break}g[1410560+(((f|0)%4|0)<<2)>>2]=+h[1153];q=b}else{q=j}}while(0);do{if((k|0)==10){c[q+8>>2]=0}else if((k|0)==13){c[q+8>>2]=0;a[112384]=1}else{j=(k|i|c[352644])&255;d=ab(c[352652]|0,(c[q+4>>2]|0)%(c[352638]|0)|0)|0;a[(c[q>>2]|0)+(d+(c[q+8>>2]|0))|0]=j;j=(c[352658]|0)+8|0;c[j>>2]=(c[j>>2]|0)+1;j=(c[352658]|0)+8|0;if((c[j>>2]|0)<(c[352652]|0)){break}c[j>>2]=0}}while(0);m=a[l]|0;}while(m<<24>>24!=0);return}function oW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+4112|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;g=e+16|0;bV(g|0,4096,b|0,f|0)|0;wD(98480,(f=i,i=i+8|0,c[f>>2]=g,f)|0);i=f;if((c[350718]|0)!=0){b=oh(79088,(f=i,i=i+8|0,c[f>>2]=1411672,f)|0)|0;i=f;wE(b,98480,(f=i,i=i+8|0,c[f>>2]=g,f)|0);i=f}if((c[352654]|0)==0|(c[353150]|0)==0){i=e;return}oV(g);f=b7(g|0,10)|0;if((c[353150]|0)==4|(f|0)==0|(c[155168]|0)!=0|a[112376]){i=e;return}a[112376]=1;vd();a[112376]=0;i=e;return}function oX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0;d=i;i=i+4112|0;e=d|0;f=d+16|0;h=f|0;if(+g[5052]!=0.0){j=e|0;k=e;c[k>>2]=b;c[k+4>>2]=0;k=f;bV(k|0,4096,a|0,j|0)|0;oW(98480,(l=i,i=i+8|0,c[l>>2]=f,l)|0);i=l;i=d;return}if((c[350718]|0)==0){i=d;return}c[h>>2]=1430406468;c[h+4>>2]=2112071;h=e;c[h>>2]=b;c[h+4>>2]=0;bV(f+7|0,4089,a|0,e|0)|0;e=oh(79088,(l=i,i=i+8|0,c[l>>2]=1411672,l)|0)|0;i=l;wE(e,98480,(l=i,i=i+8|0,c[l>>2]=f,l)|0);i=l;i=d;return}function oY(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0;if(!((c[278172]|0)==1|(c[352656]|0)!=0)){return}b=c[350594]|0;d=c[278168]|0;a[1104480+(b<<8)+d|0]=(~~(+h[1153]*4.0)&1|10)&255;e=d+1|0;f=c[352652]|0;if((e|0)<(f|0)){g=d+2|0;yG(1104480+(b<<8)+e|0,32,((f|0)>(g|0)?f:g)-1-d|0)}if((d|0)<(f|0)){i=1104480+(b<<8)|0}else{i=1-f+d+(1104480+(b<<8))|0}g=(c[352636]|0)-22|0;if((f|0)>0){f=0;while(1){e=f+1|0;pF(e<<3,g,a[i+f|0]|0);if((e|0)<(c[352652]|0)){f=e}else{break}}j=c[278168]|0;k=c[350594]|0}else{j=d;k=b}a[1104480+(k<<8)+j|0]=0;return}function oZ(){var b=0,d=0,e=0,f=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[352658]|0;d=0;e=(c[b+4>>2]|0)-3|0;f=b;while(1){do{if((e|0)<0){i=d;j=f}else{k=+g[1410560+(((e|0)%4|0)<<2)>>2];if(k==0.0){i=d;j=f;break}if(+h[1153]-k>+g[5358]){i=d;j=f;break}b=c[f>>2]|0;l=c[352652]|0;m=ab(l,(e|0)%(c[352638]|0)|0)|0;c[353912]=0;c[155170]=1;if((l|0)>0){l=0;while(1){n=l+1|0;pF(n<<3,d,a[b+(l+m)|0]|0);if((n|0)<(c[352652]|0)){l=n}else{break}}o=c[352658]|0}else{o=f}i=d+8|0;j=o}}while(0);l=e+1|0;if((l|0)>(c[j+4>>2]|0)){break}else{d=i;e=l;f=j}}if((c[278172]|0)==2){c[353912]=0;c[155170]=1;if((c[644592]|0)==0){pP(8,i,52920);p=6}else{pP(8,i,58776);p=11}j=c[644594]|0;f=(c[29381]>>3)+~p|0;if((j|0)>(f|0)){q=2578384+(j-f)|0}else{q=2578384}f=a[q]|0;j=p<<3;if(f<<24>>24==0){r=j}else{e=0;d=f;f=j;while(1){pF(f,i,d<<24>>24);j=e+1|0;o=a[q+j|0]|0;l=j+p<<3;if(o<<24>>24==0){r=l;break}else{e=j;d=o;f=l}}}pF(r,i,~~(+h[1153]*4.0)&1|10);s=i+8|0}else{s=i}if((s|0)<=(c[352646]|0)){return}c[352646]=s;return}function o_(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((b|0)<1){return}pV(b);c[352636]=b;d=b-22>>3;e=b-30|0;f=c[352658]|0;g=c[f+12>>2]|0;if((g|0)==(c[f+4>>2]|0)){h=d;i=e;j=f;k=g}else{if((c[352652]|0)>0){l=0;do{pF(l<<3|8,e,94);l=l+4|0;}while((l|0)<(c[352652]|0));l=c[352658]|0;m=l;n=c[l+12>>2]|0}else{m=f;n=g}h=d-1|0;i=b-38|0;j=m;k=n}L12486:do{if(!((h|0)<1|(k|0)<0)){n=i;m=1;b=k;d=j;while(1){g=c[352638]|0;if(((c[d+4>>2]|0)-b|0)>=(g|0)){break L12486}f=c[d>>2]|0;l=c[352652]|0;e=ab(l,(b|0)%(g|0)|0)|0;if((l|0)>0){l=0;while(1){g=l+1|0;pF(g<<3,n,a[f+(l+e)|0]|0);if((g|0)<(c[352652]|0)){l=g}else{break}}}l=b-1|0;if((m|0)>=(h|0)|(l|0)<0){break L12486}n=n-8|0;m=m+1|0;b=l;d=c[352658]|0}}}while(0);oY();return}function o$(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;g=xZ((c[352652]|0)+1|0)|0;h=(c[352652]|0)/(e+2|0)|0;j=(((d>>>0)%(h>>>0)|0|0)!=0)+((d>>>0)/(h>>>0)|0)|0;do{if(j>>>0<5){k=(((d|0)%5|0|0)!=0)+((d|0)/5|0)|0;l=(((d>>>0)%(k>>>0)|0|0)!=0)+((d>>>0)/(k>>>0)|0)|0;if((l|0)!=0){m=k;n=l;break}xY(g);i=f;return}else{m=h;n=j}}while(0);j=m-1|0;if((m|0)==0){h=0;do{a[g]=0;oW(100968,(o=i,i=i+8|0,c[o>>2]=g,o)|0);i=o;h=h+1|0;}while(h>>>0<n>>>0);xY(g);i=f;return}else{p=0}do{a[g]=0;h=0;do{l=(ab(h,n)|0)+p|0;if(l>>>0>=d>>>0){break}k=c[b+(l<<2)>>2]|0;l=yF(k|0)|0;yR(g|0,k|0)|0;if(h>>>0<j>>>0){k=g+(yF(g|0)|0)|0;if(l>>>0<e>>>0){q=l;l=k;while(1){r=l;x=32;a[r]=x&255;x=x>>8;a[r+1|0]=x&255;r=q+1|0;s=g+(yF(g|0)|0)|0;if(r>>>0<e>>>0){q=r;l=s}else{t=s;break}}}else{t=k}a[t]=a[104080]|0;a[t+1|0]=a[104081|0]|0;a[t+2|0]=a[104082|0]|0}h=h+1|0;}while(h>>>0<m>>>0);oW(100968,(o=i,i=i+8|0,c[o>>2]=g,o)|0);i=o;p=p+1|0;}while(p>>>0<n>>>0);xY(g);i=f;return}function o0(a){a=a|0;var b=0,d=0;b=a|0;d=yx(c[b>>2]<<2)|0;c[155104]=d;if((d|0)==0){return}c[155106]=0;o1(c[a+12>>2]|0);o$(c[155104]|0,c[b>>2]|0,c[a+4>>2]|0);yz(c[155104]|0);return}function o1(a){a=a|0;var b=0,d=0;if((a|0)==0){return}else{b=a}do{o1(c[b+12>>2]|0);a=c[b-16+12>>2]|0;d=c[155106]|0;c[155106]=d+1;c[(c[155104]|0)+(d<<2)>>2]=a;b=c[b+8>>2]|0;}while((b|0)!=0);return}function o2(){var a=0,b=0,d=0,e=0,f=0;a=i;i=i+24|0;b=a|0;d=b|0;c[d>>2]=0;e=b+4|0;c[e>>2]=0;c[b+8>>2]=-1;c[b+16>>2]=0;if((oq()|0)==2){f=os(1)|0}else{f=0}vl();oj(b,99224,f,97464,1);f=yx(c[d>>2]<<2)|0;c[155104]=f;if((f|0)==0){i=a;return}c[155106]=0;o1(c[b+12>>2]|0);o$(c[155104]|0,c[d>>2]|0,c[e>>2]|0);yz(c[155104]|0);i=a;return}function o3(){var a=0,b=0;a=i;c[350718]=ob(95072)|0;c[352648]=x1(16384,93376)|0;c[352658]=1410592;c[352652]=-1;oU();oW(91608,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;pb(21416);oE(89848,464);oE(88104,170);oE(86424,70);oE(84392,406);oE(81792,2);c[352654]=1;i=a;return}function o4(a){a=a|0;var b=0,c=0;b=vr(20544,a)|0;if((b|0)==0){c=0}else{c=b-40+12|0}return c|0}function o5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=vr(20544,a)|0;do{if((d|0)==0){e=0}else{a=d-40+12|0;if((a|0)==0){e=0;break}f=c[a+48>>2]|0;if((f|0)==0){e=0;break}e=fv[f&127](b)|0}}while(0);return e|0}function o6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=vr(20544,a)|0;do{if((d|0)==0){e=0}else{a=d-40+12|0;if((a|0)==0){e=0;break}f=c[a+48>>2]|0;if((f|0)==0){e=0;break}a=fv[f&127](b)|0;if((a|0)==0){e=0;break}f=vp(a,b)|0;xY(a);e=f}}while(0);return e|0}function o7(a){a=a|0;var b=0,d=0.0;b=vr(20544,a)|0;do{if((b|0)==0){d=0.0}else{a=b-40+12|0;if((a|0)==0){d=0.0;break}d=+nF(c[a+4>>2]|0)}}while(0);return+d}function o8(a){a=a|0;var b=0,d=0;b=vr(20544,a)|0;do{if((b|0)==0){d=2659352}else{a=b-40+12|0;if((a|0)==0){d=2659352;break}d=c[a+4>>2]|0}}while(0);return d|0}function o9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0.0;d=i;e=b;b=a;while(1){a=vr(20544,b)|0;if((a|0)==0){f=9549;break}h=a-40+12|0;a=h;if((h|0)==0){f=9549;break}j=c[h+24>>2]|0;if((j&2|0)!=0){f=9551;break}k=h+4|0;l=c[k>>2]|0;m=(cS(l|0,e|0)|0)!=0;if(m){if(!((j&1|0)==0|+g[5052]!=0.0)){f=9554;break}}xY(l);l=xZ((yF(e|0)|0)+1|0)|0;yQ(l|0,e|0)|0;c[k>>2]=l;j=h+16|0;g[j>>2]=+nF(l);do{if((c[h+12>>2]|0)!=0){if(!(m&(c[46140]|0)!=0)){break}l=c[k>>2]|0;p3(66528,(n=i,i=i+16|0,c[n>>2]=c[h>>2],c[n+8>>2]=l,n)|0);i=n}}while(0);do{if(m){k=c[h+20>>2]|0;if((k|0)==0){break}fs[k&255](a)}}while(0);o=+g[j>>2];do{if(o!=0.0){if((cS(c[h>>2]|0,c[5062]|0)|0)!=0){p=o;break}o9(58504,52816);p=+g[j>>2]}else{p=o}}while(0);if(p==0.0){f=9569;break}if((cS(c[h>>2]|0,c[5340]|0)|0)==0){e=52816;b=49064}else{f=9570;break}}if((f|0)==9554){oW(78264,(n=i,i=i+8|0,c[n>>2]=b,n)|0);i=n;i=d;return}else if((f|0)==9549){oW(58864,(n=i,i=i+8|0,c[n>>2]=b,n)|0);i=n;i=d;return}else if((f|0)==9551){oW(97512,(n=i,i=i+8|0,c[n>>2]=b,n)|0);i=n;i=d;return}else if((f|0)==9569){i=d;return}else if((f|0)==9570){i=d;return}}function pa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=i;i=i+32|0;d=c|0;bR(d|0,32,44824,(e=i,i=i+8|0,h[e>>3]=b,e)|0)|0;i=e;o9(a,d);i=c;return}function pb(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0.0;d=i;i=i+512|0;e=d|0;f=b|0;h=vr(20544,c[f>>2]|0)|0;do{if((h|0)==0){j=c[f>>2]|0}else{k=c[f>>2]|0;if((h-40+12|0)==0){j=k;break}oW(40680,(l=i,i=i+8|0,c[l>>2]=k,l)|0);i=l;i=d;return}}while(0);h=(oL(j)|0)==0;j=c[f>>2]|0;if(h){h=b+28|0;c[h>>2]=j;vn(20544,h)|0;h=e|0;k=b+4|0;b=c[k>>2]|0;yP(h|0,b|0,511)|0;a[e+511|0]=0;c[k>>2]=xZ(1)|0;m=+g[5052];g[5052]=1.0;o9(c[f>>2]|0,h);g[5052]=m;i=d;return}else{oW(37240,(l=i,i=i+8|0,c[l>>2]=j,l)|0);i=l;i=d;return}}function pc(){var a=0,b=0,d=0,e=0,f=0,g=0;a=i;b=vr(20544,os(0)|0)|0;if((b|0)==0){d=0;i=a;return d|0}e=b-40+12|0;if((e|0)==0){d=0;i=a;return d|0}if((oq()|0)!=1){b=c[e>>2]|0;o9(b,os(1)|0);d=1;i=a;return d|0}b=c[e>>2]|0;if((c[e+24>>2]&2|0)==0){f=c[e+4>>2]|0;oW(107512,(g=i,i=i+16|0,c[g>>2]=b,c[g+8>>2]=f,g)|0);i=g;d=1;i=a;return d|0}else{oW(97512,(g=i,i=i+8|0,c[g>>2]=b,g)|0);i=g;d=1;i=a;return d|0}return 0}function pd(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=b|0;vs(20544,d);if((vu(20544,d)|0)==0){i=b;return}do{e=(c[d>>2]|0)-40+12|0;if((c[e+8>>2]|0)!=0){f=c[e>>2]|0;g=c[e+4>>2]|0;en(a|0,103912,(e=i,i=i+16|0,c[e>>2]=f,c[e+8>>2]=g,e)|0)|0;i=e}vm(d);}while((vu(20544,d)|0)!=0);i=b;return}function pe(){return}function pf(){return}function pg(){var a=0,b=0.0;a=(c[157498]|0)==0;c[350744]=a?c[29376]|0:c[157256]|0;c[155126]=a?c[29380]|0:320;c[351962]=0;c[352258]=c[155438];a=~~+g[5126];c[351994]=a;do{if((a|0)>3){c[351994]=3}else{if((a|0)>=0){break}c[351994]=0}}while(0);b=+g[5112];g[351958]=b;g[351959]=b*.4000000059604645;g[351960]=b*.20000000298023224;return}function ph(d){d=d|0;var e=0.0,f=0.0,h=0.0,i=0.0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=+g[d>>2]- +g[157424];f=+g[d+4>>2]- +g[157425];h=+g[d+8>>2]- +g[157426];i=e*+g[157386]+f*+g[157387]+h*+g[157388];if(i<8.0){return}j=1.0/i;k=~~(+g[20]+j*(f*+g[157383]+e*+g[157382]+h*+g[157384])+.5);l=~~(+g[10]-j*(f*+g[157379]+e*+g[157378]+h*+g[157380])+.5);if((l|0)>(c[350742]|0)|(k|0)>(c[350740]|0)|(l|0)<(c[350736]|0)|(k|0)<(c[350738]|0)){return}m=c[351966]|0;n=c[350722]|0;o=m+((ab(n,l)|0)+k<<1)|0;m=(c[350744]|0)+((c[1403032+(l<<2)>>2]|0)+k)|0;k=~~(j*32768.0);l=k>>c[351978];p=c[351980]|0;if((l|0)<(p|0)){q=p}else{p=c[351982]|0;q=(l|0)>(p|0)?p:l}if((q|0)==1){l=k&65535;p=d+12|0;r=1<<c[350732];s=o;t=m;u=n;while(1){if((b[s>>1]|0)>(k|0)){v=u}else{b[s>>1]=l;a[t]=~~+g[p>>2];v=c[350722]|0}n=r-1|0;if((n|0)==0){break}else{r=n;s=s+(v<<1)|0;t=t+(c[155126]|0)|0;u=v}}return}else if((q|0)==2){v=2<<c[350732];if((v|0)==0){return}u=k&65535;t=d+12|0;s=v;v=o;r=m;while(1){if((b[v>>1]|0)<=(k|0)){b[v>>1]=u;a[r]=~~+g[t>>2]}p=v+2|0;if((b[p>>1]|0)<=(k|0)){b[p>>1]=u;a[r+1|0]=~~+g[t>>2]}p=s-1|0;if((p|0)==0){break}else{s=p;v=v+(c[350722]<<1)|0;r=r+(c[155126]|0)|0}}return}else if((q|0)==3){r=k&65535;v=d+12|0;s=3<<c[350732];t=o;u=m;while(1){if((b[t>>1]|0)<=(k|0)){b[t>>1]=r;a[u]=~~+g[v>>2]}p=t+2|0;if((b[p>>1]|0)<=(k|0)){b[p>>1]=r;a[u+1|0]=~~+g[v>>2]}p=t+4|0;if((b[p>>1]|0)<=(k|0)){b[p>>1]=r;a[u+2|0]=~~+g[v>>2]}p=s-1|0;if((p|0)==0){break}else{s=p;t=t+(c[350722]<<1)|0;u=u+(c[155126]|0)|0}}return}else if((q|0)==4){u=4<<c[350732];if((u|0)==0){return}t=k&65535;s=d+12|0;v=u;u=o;r=m;while(1){if((b[u>>1]|0)<=(k|0)){b[u>>1]=t;a[r]=~~+g[s>>2]}p=u+2|0;if((b[p>>1]|0)<=(k|0)){b[p>>1]=t;a[r+1|0]=~~+g[s>>2]}p=u+4|0;if((b[p>>1]|0)<=(k|0)){b[p>>1]=t;a[r+2|0]=~~+g[s>>2]}p=u+6|0;if((b[p>>1]|0)<=(k|0)){b[p>>1]=t;a[r+3|0]=~~+g[s>>2]}p=v-1|0;if((p|0)==0){break}else{v=p;u=u+(c[350722]<<1)|0;r=r+(c[155126]|0)|0}}return}else{r=q<<c[350732];if((r|0)==0){return}u=k&65535;v=d+12|0;if((q|0)>0){w=r;x=o;y=m}else{return}while(1){m=0;do{o=x+(m<<1)|0;if((b[o>>1]|0)<=(k|0)){b[o>>1]=u;a[y+m|0]=~~+g[v>>2]}m=m+1|0;}while((m|0)<(q|0));m=w-1|0;if((m|0)==0){break}else{w=m;x=x+(c[350722]<<1)|0;y=y+(c[155126]|0)|0}}return}}function pi(){var b=0,d=0,e=0.0,f=0.0,h=0.0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0,N=0,O=0;b=i;i=i+16|0;d=b|0;uu(677560,183448);e=+g[45862];f=+g[45863];h=+g[45864];j=c[139454]|0;k=j+64|0;if(k>>>0>=(c[139456]|0)>>>0){i=b;return}l=d|0;m=d+4|0;n=d+8|0;d=j;j=628760;o=k;L90:while(1){k=d;p=o;L92:while(1){q=k+72|0;do{if((c[q>>2]|0)!=0){c[157494]=(c[157494]|0)+1;g[5078]=+g[k+112>>2];g[5076]=+g[k+116>>2];g[5080]=+g[k+108>>2];r=c[k+88>>2]|0;if((r&4|0)!=0){if((c[157310]|0)==0){uO()}pA(c[q>>2]|0);py(c[q>>2]|0);break}if((r&64|0)==0){break L92}g[5078]=0.0;g[5076]=0.0;g[5080]=-.8999999761581421;s=~~+g[2826];t=s&255;u=s<<24|t|t<<16|t<<8;t=c[q>>2]|0;if((t|0)==0){v=0}else{w=s&255;s=t;do{t=c[350744]|0;x=ab(c[s+4>>2]|0,c[155126]|0)|0;y=c[s>>2]|0;z=(c[s+8>>2]|0)+y|0;A=z-1|0;a[t+(x+y)|0]=w;B=y+1|0;do{if((A-y|0)<8){if((B|0)>(A|0)){break}else{C=B}do{a[t+(C+x)|0]=w;C=C+1|0;}while((C|0)<=(A|0))}else{if((B&3|0)==0){D=B}else{E=B;while(1){a[t+(E+x)|0]=w;F=E+1|0;if((F&3|0)==0){D=F;break}else{E=F}}}E=z-5|0;if((D|0)>(E|0)){G=D}else{F=D;while(1){c[t+(F+x)>>2]=u;H=F+4|0;if((H|0)>(E|0)){G=H;break}else{F=H}}}if((G|0)>(A|0)){break}else{I=G}do{a[t+(I+x)|0]=w;I=I+1|0;}while((I|0)<=(A|0))}}while(0);s=c[s+12>>2]|0;}while((s|0)!=0);v=c[q>>2]|0}py(v)}}while(0);s=p+64|0;if(s>>>0<(c[139456]|0)>>>0){k=p;p=s}else{J=102;break L90}}do{if((r&16|0)==0){s=k+104|0;if((c[s>>2]|0)==0){K=j}else{w=c[k+96>>2]|0;g[l>>2]=+g[157424]- +g[w+112>>2];g[m>>2]=+g[157425]- +g[w+116>>2];g[n>>2]=+g[157426]- +g[w+120>>2];uu(l,183448);t$(w);K=w}w=c[k+92>>2]|0;u=w;L=+g[k+100>>2]*+g[1200]*+g[(c[w+72>>2]|0)+32>>2];do{if(+g[351958]>L){if(+g[351959]<=L){M=1;break}M=+g[351960]>L?3:2}else{M=0}}while(0);w=c[351994]|0;A=(M|0)<(w|0)?w:M;c[220088]=A;w=pL(K,u,A)|0;c[651324]=w+48;c[651320]=c[w+32>>2];pj(u);pz(c[q>>2]|0);py(c[q>>2]|0);if((c[s>>2]|0)==0){N=K;break}g[45862]=e;g[45863]=f;g[45864]=h;g[29332]=+g[660142];g[29333]=+g[660143];g[29334]=+g[660144];g[29324]=+g[660134];g[29325]=+g[660135];g[29326]=+g[660136];g[29328]=+g[660138];g[29329]=+g[660139];g[29330]=+g[660140];g[169390]=+g[660146];g[169391]=+g[660147];g[169392]=+g[660148];uy();N=628760}else{w=c[k+92>>2]|0;c[220088]=0;A=c[(c[w+72>>2]|0)+36>>2]|0;c[651324]=A+(c[A+44>>2]|0);c[651320]=64;A=k+104|0;if((c[A>>2]|0)==0){O=j}else{x=c[k+96>>2]|0;g[l>>2]=+g[157424]- +g[x+112>>2];g[m>>2]=+g[157425]- +g[x+116>>2];g[n>>2]=+g[157426]- +g[x+120>>2];uu(l,183448);t$(x);O=x}pj(w);px(c[q>>2]|0);py(c[q>>2]|0);if((c[A>>2]|0)==0){N=O;break}g[45862]=e;g[45863]=f;g[45864]=h;g[29332]=+g[660142];g[29333]=+g[660143];g[29334]=+g[660144];g[29324]=+g[660134];g[29325]=+g[660135];g[29326]=+g[660136];g[29328]=+g[660138];g[29329]=+g[660139];g[29330]=+g[660140];g[169390]=+g[660146];g[169391]=+g[660147];g[169392]=+g[660148];uy();N=628760}}while(0);k=p+64|0;if(k>>>0<(c[139456]|0)>>>0){d=p;j=N;o=k}else{J=100;break}}if((J|0)==100){i=b;return}else if((J|0)==102){i=b;return}}function pj(a){a=a|0;var b=0,d=0,f=0,h=0,j=0.0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0,r=0.0,s=0,t=0.0,u=0,v=0.0;b=i;i=i+48|0;d=b|0;f=b+16|0;h=b+32|0;j=1.0/+(1<<c[220088]|0);k=a+72|0;l=f|0;uu(c[k>>2]|0,l);m=h|0;uu((c[k>>2]|0)+16|0,m);n=j*+g[16];o=+g[l>>2]*n;g[5104]=o;p=n*+g[m>>2];g[5084]=p;n=j*+g[6];q=f+4|0;r=n*(-0.0- +g[q>>2]);g[5102]=r;s=h+4|0;t=n*(-0.0- +g[s>>2]);g[5082]=t;u=f+8|0;n=+g[20];v=+g[10];g[5106]=j*+g[u>>2]-n*o-v*r;f=h+8|0;g[5086]=j*+g[f>>2]-n*p-v*t;h=d|0;q9(183448,j,h);t=j*65536.0;j=+g[h>>2];v=+g[d+4>>2];p=+g[d+8>>2];d=c[220088]|0;c[155602]=~~(t*+g[(c[k>>2]|0)+12>>2]+ +(~~((j*+g[l>>2]+v*+g[q>>2]+p*+g[u>>2])*65536.0+.5)-((e[a+64>>1]|0)<<16>>d)|0));c[45870]=~~(t*+g[(c[k>>2]|0)+28>>2]+ +(~~((j*+g[m>>2]+v*+g[s>>2]+p*+g[f>>2])*65536.0+.5)-((e[a+66>>1]|0)<<16>>d)|0));c[660132]=((e[a+68>>1]|0)<<16>>d)-1;c[660130]=((e[a+70>>1]|0)<<16>>d)-1;i=b;return}function pk(){c[157312]=1;pb(20352);pb(20488);pb(20432);pb(20136);c[2602]=1;c[2604]=1;g[3336]=1.0;return}function pl(){xd();return}function pm(){xe();return}function pn(){var a=0,b=0.0,d=0.0,e=0,f=0,h=0,i=0;a=(c[157498]|0)==0?c[29380]|0:320;b=+g[18];g[1200]=b;d=+g[8];if(d>b){g[1200]=d}e=c[29381]|0;c[350724]=e<<1;c[350722]=e;f=c[157326]|0;c[351980]=(f|0)<320?1:(f|0)/320|0;d=+(f|0);f=~~(d/80.0+.5);c[351982]=f;c[351978]=8-~~(d/320.0+.5);if((f|0)<1){c[351982]=1;h=1}else{h=f}f=+g[3702]>1.4|0;c[350732]=f;c[350738]=c[157324];c[350736]=c[157325];c[350740]=(c[157334]|0)-h;c[350742]=(c[157335]|0)-(h<<f);f=c[29382]|0;if((f|0)<=0){return}h=c[351966]|0;i=0;do{c[1403032+(i<<2)>>2]=ab(i,a)|0;c[112416+(i<<2)>>2]=h+((ab(e,i)|0)<<1);i=i+1|0;}while((i|0)<(f|0));return}function po(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((f|0)>0){g=1;h=e}else{return}while(1){e=h|0;i=c[e>>2]|0;do{if((i|0)<(c[157334]|0)){j=h+4|0;k=c[j>>2]|0;if((k|0)>=(c[157335]|0)){break}l=c[h+20>>2]>>16;m=(c[112416+(k<<2)>>2]|0)+(i<<1)|0;if((l|0)<(b[m>>1]|0)){break}b[m>>1]=l&65535;a[(c[350744]|0)+((c[e>>2]|0)+(c[1403032+(c[j>>2]<<2)>>2]|0))|0]=a[(c[664796]|0)+(c[h+16>>2]&65280|d[(c[615408+(c[h+12>>2]>>16<<2)>>2]|0)+(c[h+8>>2]>>16)|0])|0]|0}}while(0);if((g|0)>=(f|0)){break}g=g+1|0;h=h+32|0}return}function pp(){var a=0,b=0,d=0,e=0;a=c[157523]|0;b=c[157522]|0;if((a|0)==(c[153850]|0)&(b|0)==(c[154332]|0)){return}c[153850]=a;c[154332]=b;d=0;e=b;while(1){c[615408+(d<<2)>>2]=e;b=d+1|0;if((b|0)<480){d=b;e=e+a|0}else{break}}return}function pq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a=c[351990]|0;d=c[351984]|0;while(1){c[d>>2]=a;c[(c[351984]|0)+4>>2]=c[351970];c[(c[351984]|0)+8>>2]=c[352262];c[(c[351984]|0)+12>>2]=c[351976];c[(c[351984]|0)+16>>2]=c[350756];c[(c[351984]|0)+20>>2]=c[350750];c[(c[351984]|0)+24>>2]=c[352256];c[(c[351984]|0)+28>>2]=c[350730];e=(c[351984]|0)+32|0;c[351984]=e;f=(c[350576]|0)+(c[350578]|0)|0;c[350576]=f;if((f|0)>-1){g=(c[351990]|0)+(c[351986]|0)|0;c[351990]=g;c[351970]=(c[351970]|0)+(c[351964]<<1);c[352262]=(c[352262]|0)+(c[352260]|0);h=c[351976]|0;i=(c[350756]|0)+(c[350752]|0)|0;j=(i>>16)+(c[351972]|0)|0;c[351976]=h+j;c[350756]=i&65535;i=(c[350750]|0)+(c[350746]|0)|0;c[350750]=i;if((i&65536|0)!=0){c[351976]=h+(j+(c[157523]|0));c[350750]=i&65535}c[352256]=(c[352256]|0)+(c[352252]|0);c[350730]=(c[350730]|0)+(c[350726]|0);c[350576]=f-(c[350580]|0);k=g}else{g=(c[351990]|0)+(c[351988]|0)|0;c[351990]=g;c[351970]=(c[351970]|0)+(c[351968]<<1);c[352262]=(c[352262]|0)+(c[29412]|0);f=c[351976]|0;i=(c[350756]|0)+(c[350754]|0)|0;j=(i>>16)+(c[351974]|0)|0;c[351976]=f+j;c[350756]=i&65535;i=(c[350750]|0)+(c[350748]|0)|0;c[350750]=i;if((i&65536|0)!=0){c[351976]=f+(j+(c[157523]|0));c[350750]=i&65535}c[352256]=(c[352256]|0)+(c[352254]|0);c[350730]=(c[350730]|0)+(c[350728]|0);k=g}g=b-1|0;if((g|0)==0){break}else{b=g;a=k;d=e}}return}function pr(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=e;while(1){e=c[352262]|0;g=c[f+8>>2]|0;h=(c[350576]|0)+(c[350578]|0)|0;c[350576]=h;if((h|0)>-1){c[352262]=e+(c[352260]|0);c[350576]=h-(c[350580]|0)}else{c[352262]=e+(c[29412]|0)}if((e|0)!=(g|0)){h=c[f+4>>2]|0;i=c[f+28>>2]|0;j=c[f+24>>2]|0;k=c[f+20>>2]|0;l=c[f+16>>2]|0;m=c[f+12>>2]|0;n=c[f>>2]|0;o=e-g|0;while(1){g=i>>16;if((g|0)>=(b[h>>1]|0)){a[n]=a[(c[664796]|0)+(d[m]|j&65280)|0]|0;b[h>>1]=g&65535}g=(c[664802]|0)+l|0;e=(g>>16)+(c[664800]|0)|0;p=(c[664798]|0)+k|0;if((p&65536|0)==0){q=p;r=e}else{q=p&65535;r=(c[157523]|0)+e|0}e=o-1|0;if((e|0)==0){break}else{h=h+2|0;i=(c[157188]|0)+i|0;j=(c[157448]|0)+j|0;k=q;l=g&65535;m=m+r|0;n=n+1|0;o=e}}}if((c[f+40>>2]|0)==-999999){break}f=f+32|0}return}function ps(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=i;i=i+38496|0;c[664804]=a+31&-32;b=c[157526]|0;if((c[157528]|0)!=0){d=c[157525]|0;e=c[157527]|0;if((e|0)>0){f=0}else{i=a;return}do{g=c[d+(f<<4)+4>>2]|0;h=c[d+(f<<4)+8>>2]|0;j=c[d+(f<<4)+12>>2]|0;k=c[b+(g<<5)+4>>2]|0;l=b+(g<<5)|0;m=c[l>>2]|0;n=b+(j<<5)|0;o=ab(m-(c[n>>2]|0)|0,k-(c[b+(h<<5)+4>>2]|0)|0)|0;p=b+(h<<5)|0;do{if((o-(ab(k-(c[b+(j<<5)+4>>2]|0)|0,m-(c[p>>2]|0)|0)|0)|0)<=-1){c[351992]=(c[664796]|0)+(c[b+(g<<5)+16>>2]&65280);if((c[d+(f<<4)>>2]|0)!=0){pv(l,p,n);break}q=b+(g<<5)+8|0;r=c[q>>2]|0;s=b+(h<<5)+8|0;t=c[s>>2]|0;u=b+(j<<5)+8|0;v=c[u>>2]|0;if((c[b+(g<<5)+24>>2]&32|0)!=0){c[q>>2]=(c[157529]|0)+r}if((c[b+(h<<5)+24>>2]&32|0)!=0){c[s>>2]=(c[s>>2]|0)+(c[157529]|0)}if((c[b+(j<<5)+24>>2]&32|0)!=0){c[u>>2]=(c[u>>2]|0)+(c[157529]|0)}pv(l,p,n);c[q>>2]=r;c[s>>2]=t;c[u>>2]=v}}while(0);f=f+1|0;}while((f|0)<(e|0));i=a;return}e=c[157527]|0;if((e|0)<=0){i=a;return}f=0;d=c[157525]|0;while(1){n=c[d+4>>2]|0;p=c[d+8>>2]|0;l=c[d+12>>2]|0;j=b+(n<<5)+4|0;h=c[j>>2]|0;g=b+(p<<5)+4|0;m=b+(n<<5)|0;k=c[m>>2]|0;o=b+(l<<5)|0;v=ab(k-(c[o>>2]|0)|0,h-(c[g>>2]|0)|0)|0;u=b+(p<<5)|0;t=b+(l<<5)+4|0;s=v-(ab(h-(c[t>>2]|0)|0,k-(c[u>>2]|0)|0)|0)|0;c[350734]=s;if((s|0)<=-1){c[157414]=c[m>>2];m=c[j>>2]|0;c[157415]=m;j=c[b+(n<<5)+8>>2]|0;c[157416]=j;c[157417]=c[b+(n<<5)+12>>2];c[157418]=c[b+(n<<5)+16>>2];c[157419]=c[b+(n<<5)+20>>2];c[157408]=c[u>>2];u=c[g>>2]|0;c[157409]=u;g=c[b+(p<<5)+8>>2]|0;c[157410]=g;c[157411]=c[b+(p<<5)+12>>2];c[157412]=c[b+(p<<5)+16>>2];c[157413]=c[b+(p<<5)+20>>2];c[157402]=c[o>>2];o=c[t>>2]|0;c[157403]=o;t=c[b+(l<<5)+8>>2]|0;c[157404]=t;c[157405]=c[b+(l<<5)+12>>2];c[157406]=c[b+(l<<5)+16>>2];c[157407]=c[b+(l<<5)+20>>2];do{if((c[d>>2]|0)==0){if((c[b+(n<<5)+24>>2]&32|0)!=0){c[157416]=(c[157529]|0)+j}if((c[b+(p<<5)+24>>2]&32|0)!=0){c[157410]=(c[157529]|0)+g}if((c[b+(l<<5)+24>>2]&32|0)==0){break}c[157404]=(c[157529]|0)+t}}while(0);do{if((m|0)<(u|0)){w=0;x=185}else{if((m|0)!=(u|0)){w=1;x=185;break}if((m|0)<(o|0)){c[158768]=19680;break}else{c[158768]=19788;break}}}while(0);do{if((x|0)==185){x=0;if((m|0)==(o|0)){if((w|0)==0){c[158768]=19932;break}else{c[158768]=19896;break}}if((u|0)!=(o|0)){t=(m|0)>(o|0)?w|2:w;c[158768]=19608+(((u|0)>(o|0)?t|4:t)*36|0);break}if((w|0)==0){c[158768]=20004;break}else{c[158768]=19968;break}}}while(0);pu()}o=f+1|0;if((o|0)<(e|0)){f=o;d=d+16|0}else{break}}i=a;return}function pt(a){a=a|0;var b=0,d=0.0,e=0,f=0.0,g=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0;b=c[157402]|0;d=+((c[157414]|0)-b|0);e=c[157403]|0;f=+((c[157415]|0)-e|0);g=+((c[157408]|0)-b|0);h=+((c[157409]|0)-e|0);i=1.0/+(c[350734]|0);j=-0.0-i;e=c[157406]|0;k=+((c[157418]|0)-e|0);l=+((c[157412]|0)-e|0);c[157448]=~~+aa(+(i*(f*l-h*k)));c[157446]=~~+aa(+((d*l-g*k)*j));e=c[157404]|0;k=+((c[157416]|0)-e|0);l=+((c[157410]|0)-e|0);e=~~(i*(f*l-h*k));c[157288]=e;c[157286]=~~((d*l-g*k)*j);b=c[157405]|0;k=+((c[157417]|0)-b|0);l=+((c[157411]|0)-b|0);b=~~(i*(f*l-h*k));c[157282]=b;c[157280]=~~((d*l-g*k)*j);m=c[157407]|0;k=+((c[157419]|0)-m|0);l=+((c[157413]|0)-m|0);c[157188]=~~(i*(f*l-h*k));c[157186]=~~((d*l-g*k)*j);c[664802]=e&65535;c[664798]=b&65535;c[664800]=(ab(b>>16,a)|0)+(e>>16);return}function pu(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=c[158768]|0;b=c[a+8>>2]|0;d=c[a+24>>2]|0;e=c[a+12>>2]|0;f=c[a+28>>2]|0;a=e+4|0;g=b+4|0;h=(c[a>>2]|0)-(c[g>>2]|0)|0;i=f+4|0;j=d+4|0;k=(c[i>>2]|0)-(c[j>>2]|0)|0;pt(c[157523]|0);l=c[b>>2]|0;m=c[g>>2]|0;n=c[e>>2]|0;o=c[a>>2]|0;c[350576]=-1;p=n-l|0;l=o-m|0;do{if((p+15|0)>>>0<32){if((l+15|0)>>>0>=32){q=205;break}m=l+495+(p<<5)|0;o=c[27896+(m<<3)>>2]|0;c[29412]=o;c[350578]=c[27900+(m<<3)>>2];r=o}else{q=205}}while(0);if((q|0)==205){re(+(p|0),+(l|0),117648,1402312);r=c[29412]|0}c[350580]=l;c[351984]=c[664804];l=c[g>>2]|0;c[29306]=l;c[352262]=(c[b>>2]|0)-(c[d>>2]|0);g=c[157522]|0;p=b+8|0;o=c[p>>2]>>16;m=b+12|0;n=c[157523]|0;c[351976]=g+((ab(c[m>>2]>>16,n)|0)+o);c[350756]=c[p>>2]&65535;c[350750]=c[m>>2]&65535;m=c[350722]|0;p=r+m|0;c[351968]=p;c[351964]=p+1;c[352256]=c[b+16>>2];c[350730]=c[b+20>>2];p=c[155126]|0;o=r+p|0;c[351988]=o;c[351986]=o+1;o=c[350744]|0;g=ab(p,l)|0;c[351990]=o+(g+(c[b>>2]|0));g=c[351966]|0;o=ab(m,l)|0;c[351970]=g+(o+(c[b>>2]|0)<<1);b=(c[157448]|0)+(r>>31)|0;o=r+1|0;c[352260]=o;g=c[157286]|0;l=c[157288]|0;m=(ab(l,r)|0)+g|0;p=c[157280]|0;s=c[157282]|0;t=(ab(s,r)|0)+p|0;c[351974]=(ab(t>>16,n)|0)+(m>>16);c[350754]=m&65535;c[350748]=t&65535;t=c[157446]|0;m=t+(ab(r,b)|0)|0;c[352254]=m;t=c[157186]|0;u=c[157188]|0;v=(ab(r,u)|0)+t|0;c[350728]=v;t=(ab(o,l)|0)+g|0;g=(ab(s,o)|0)+p|0;c[351972]=(ab(g>>16,n)|0)+(t>>16);c[350752]=t&65535;c[350746]=g&65535;c[352252]=m+b;c[350726]=u+v;pq(h);h=c[158768]|0;if((c[h+4>>2]|0)==2){v=c[h+16>>2]|0;h=c[e>>2]|0;u=c[a>>2]|0;b=c[v>>2]|0;m=v+4|0;v=c[m>>2]|0;c[350576]=-1;g=b-h|0;h=v-u|0;do{if((g+15|0)>>>0<32){if((h+15|0)>>>0>=32){q=210;break}u=h+495+(g<<5)|0;v=c[27896+(u<<3)>>2]|0;c[29412]=v;c[350578]=c[27900+(u<<3)>>2];w=v}else{q=210}}while(0);if((q|0)==210){re(+(g|0),+(h|0),117648,1402312);w=c[29412]|0}c[350580]=h;h=c[a>>2]|0;a=(c[m>>2]|0)-h|0;c[29306]=h;c[352262]=(c[e>>2]|0)-(c[d>>2]|0);m=c[157522]|0;g=c[e+8>>2]>>16;v=c[157523]|0;c[351976]=m+((ab(c[e+12>>2]>>16,v)|0)+g);c[350756]=0;c[350750]=0;c[352256]=c[e+16>>2];c[350730]=c[e+20>>2];g=c[155126]|0;m=w+g|0;c[351988]=m;c[351986]=m+1;m=c[350744]|0;u=ab(g,h)|0;c[351990]=m+(u+(c[e>>2]|0));u=c[350722]|0;m=w+u|0;c[351968]=m;c[351964]=m+1;m=c[351966]|0;g=ab(u,h)|0;c[351970]=m+(g+(c[e>>2]|0)<<1);e=(c[157448]|0)+(w>>31)|0;g=w+1|0;c[352260]=g;m=c[157286]|0;h=c[157288]|0;u=(ab(h,w)|0)+m|0;b=c[157280]|0;t=c[157282]|0;n=(ab(t,w)|0)+b|0;c[351974]=(ab(n>>16,v)|0)+(u>>16);c[350754]=u&65535;c[350748]=n&65535;n=c[157446]|0;u=n+(ab(w,e)|0)|0;c[352254]=u;n=c[157186]|0;p=c[157188]|0;o=(ab(w,p)|0)+n|0;c[350728]=o;n=(ab(g,h)|0)+m|0;m=(ab(t,g)|0)+b|0;c[351972]=(ab(m>>16,v)|0)+(n>>16);c[350752]=n&65535;c[350746]=m&65535;c[352252]=u+e;c[350726]=p+o;pq(a)}a=c[664804]|0;c[351984]=a;o=c[d>>2]|0;p=c[j>>2]|0;j=c[f>>2]|0;e=c[i>>2]|0;c[350576]=-1;u=j-o|0;o=e-p|0;do{if((u+15|0)>>>0<32){if((o+15|0)>>>0>=32){q=215;break}p=o+495+(u<<5)|0;e=c[27896+(p<<3)>>2]|0;c[29412]=e;c[350578]=c[27900+(p<<3)>>2];x=e;y=a}else{q=215}}while(0);if((q|0)==215){re(+(u|0),+(o|0),117648,1402312);x=c[29412]|0;y=c[664804]|0}c[350580]=o;c[352262]=0;c[352260]=x+1;x=y+(k<<5)+8|0;y=c[x>>2]|0;c[x>>2]=-999999;pr(c[664804]|0);if((c[(c[158768]|0)+20>>2]|0)!=2){return}x=c[664804]|0;o=x+(k<<5)|0;c[x+(k<<5)+8>>2]=y;c[352262]=(c[f>>2]|0)-(c[d>>2]|0);d=c[(c[158768]|0)+32>>2]|0;y=(c[d+4>>2]|0)-(c[i>>2]|0)|0;i=c[f>>2]|0;f=c[d>>2]|0;c[350576]=-1;d=f-i|0;do{if((d+15|0)>>>0<32){if((y+15|0)>>>0>=32){q=220;break}i=y+495+(d<<5)|0;f=c[27896+(i<<3)>>2]|0;c[29412]=f;c[350578]=c[27900+(i<<3)>>2];z=f}else{q=220}}while(0);if((q|0)==220){re(+(d|0),+(y|0),117648,1402312);z=c[29412]|0}c[350580]=y;c[352260]=z+1;c[(c[664804]|0)+(y+k<<5)+8>>2]=-999999;pr(o);return}function pv(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;i=i+24|0;j=h|0;k=c[f>>2]|0;l=c[e>>2]|0;do{if((k+1-l|0)>>>0>2){m=e;n=f;o=g}else{p=c[f+4>>2]|0;q=c[e+4>>2]|0;if((p+1-q|0)>>>0>2){m=e;n=f;o=g;break}r=c[g>>2]|0;if((1-k+r|0)>>>0>2){m=f;n=g;o=e;break}s=c[g+4>>2]|0;if((1-p+s|0)>>>0>2){m=f;n=g;o=e;break}if((l+1-r|0)>>>0>2){m=g;n=e;o=f;break}if((q+1-s|0)>>>0>2){m=g;n=e;o=f;break}i=h;return}}while(0);f=c[m>>2]|0;e=c[n>>2]|0;g=e+f>>1;l=j|0;c[l>>2]=g;k=c[m+4>>2]|0;s=c[n+4>>2]|0;q=s+k>>1;c[j+4>>2]=q;r=(c[n+8>>2]|0)+(c[m+8>>2]|0)|0;c[j+8>>2]=r>>1;p=(c[n+12>>2]|0)+(c[m+12>>2]|0)|0;c[j+12>>2]=p>>1;t=(c[n+20>>2]|0)+(c[m+20>>2]|0)|0;c[j+20>>2]=t>>1;do{if((s|0)<=(k|0)){if((s|0)==(k|0)&(e|0)<(f|0)){break}j=t>>17;u=(c[112416+(q<<2)>>2]|0)+(g<<1)|0;if((j|0)<(b[u>>1]|0)){break}b[u>>1]=j&65535;a[(c[350744]|0)+(g+(c[1403032+(q<<2)>>2]|0))|0]=a[(c[351992]|0)+(d[(c[615408+(p>>17<<2)>>2]|0)+(r>>17)|0]|0)|0]|0}}while(0);pv(o,m,l);pv(o,l,n);i=h;return}function pw(){var b=0,d=0,e=0.0,f=0,g=0.0,i=0.0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=c[157326]|0;d=c[157327]|0;e=+(b|0);f=c[155150]|0;g=e/+(f|0);i=+(d|0);j=c[155151]|0;k=i/+(j|0);l=yx((j<<2)+24|0)|0;m=l;n=j+6|0;if((n|0)>0){o=c[350744]|0;p=c[157325]|0;q=c[155126]|0;r=+(d+6|0);d=0;do{c[m+(d<<2)>>2]=o+(ab(~~(i*k*+(d|0)/r)+p|0,q)|0);d=d+1|0;}while((d|0)<(n|0))}n=yx((f<<2)+24|0)|0;d=n;q=f+6|0;if((q|0)>0){p=c[157324]|0;r=+(b+6|0);b=0;do{c[d+(b<<2)>>2]=~~(e*g*+(b|0)/r)+p;b=b+1|0;}while((b|0)<(q|0))}q=~~(+h[321194]*20.0)&127;if((j|0)<=0){yz(l);yz(n);return}b=c[29380]|0;p=c[155148]|0;o=(ab(b,c[155149]|0)|0)+p|0;p=(c[29376]|0)+o|0;o=0;s=f;f=b;b=j;while(1){j=c[1112712+((o&127)+q<<2)>>2]|0;if((s|0)>0){t=0;do{a[p+t|0]=a[(c[m+((c[1112712+((t&124)+q<<2)>>2]|0)+o<<2)>>2]|0)+(c[d+(t+j<<2)>>2]|0)|0]|0;u=t|1;a[p+u|0]=a[(c[m+((c[1112712+((u&125)+q<<2)>>2]|0)+o<<2)>>2]|0)+(c[d+(u+j<<2)>>2]|0)|0]|0;u=t|2;a[p+u|0]=a[(c[m+((c[1112712+((u&126)+q<<2)>>2]|0)+o<<2)>>2]|0)+(c[d+(u+j<<2)>>2]|0)|0]|0;u=t|3;a[p+u|0]=a[(c[m+((c[1112712+((u&127)+q<<2)>>2]|0)+o<<2)>>2]|0)+(c[d+(u+j<<2)>>2]|0)|0]|0;t=t+4|0;v=c[155150]|0;}while((t|0)<(v|0));w=v;x=c[29380]|0;y=c[155151]|0}else{w=s;x=f;y=b}t=o+1|0;if((t|0)<(y|0)){p=p+x|0;o=t;s=w;f=x;b=y}else{break}}yz(l);yz(n);return}function px(b){b=b|0;var d=0.0,e=0.0,f=0.0,i=0.0,j=0.0,k=0.0,l=0,m=0.0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0,v=0,w=0.0,x=0.0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0.0,I=0.0,J=0,K=0;c[157264]=619392+((~~(+h[321194]*20.0)&127)<<2);c[157270]=0;c[157266]=0;c[157278]=c[651324];d=+g[5104];e=d*16.0;f=+g[5084];i=f*16.0;j=+g[5078];k=j*16.0;l=b;m=d;d=f;f=j;while(1){b=c[350744]|0;n=l+4|0;o=ab(c[n>>2]|0,c[155126]|0)|0;p=l|0;c[157276]=b+(o+(c[p>>2]|0));o=c[l+8>>2]|0;j=+(c[p>>2]|0);q=+(c[n>>2]|0);r=+g[5106]+q*+g[5102]+j*m;s=+g[5086]+q*+g[5082]+j*d;t=+g[5080]+q*+g[5076]+j*f;j=65536.0/t;n=~~(r*j)+(c[155602]|0)|0;c[157274]=n;p=c[660132]|0;do{if((n|0)>(p|0)){c[157274]=p;u=p}else{if((n|0)>=0){u=n;break}c[157274]=0;u=0}}while(0);n=(c[45870]|0)+~~(s*j)|0;c[157268]=n;p=c[660130]|0;do{if((n|0)>(p|0)){c[157268]=p;v=o;w=r;x=s;y=t;z=u;A=p}else{if((n|0)>=0){v=o;w=r;x=s;y=t;z=u;A=n;break}c[157268]=0;v=o;w=r;x=s;y=t;z=u;A=0}}while(0);while(1){o=(v|0)<16?v:16;c[157272]=o;n=v-o|0;do{if((v|0)==(o|0)){p=v-1|0;t=+(p|0);s=w+t*+g[5104];r=x+t*+g[5084];j=y+t*+g[5078];t=65536.0/j;b=~~(s*t)+(c[155602]|0)|0;B=c[660132]|0;if((b|0)>(B|0)){C=B}else{C=(b|0)<16?16:b}b=(c[45870]|0)+~~(r*t)|0;B=c[660130]|0;if((b|0)>(B|0)){D=B}else{D=(b|0)<16?16:b}if((v|0)<=1){E=C;F=D;G=s;H=r;I=j;break}c[157270]=(C-z|0)/(p|0)|0;c[157266]=(D-A|0)/(p|0)|0;E=C;F=D;G=s;H=r;I=j}else{j=e+w;r=i+x;s=k+y;t=65536.0/s;p=~~(j*t)+(c[155602]|0)|0;b=c[660132]|0;if((p|0)>(b|0)){J=b}else{J=(p|0)<16?16:p}p=(c[45870]|0)+~~(r*t)|0;b=c[660130]|0;if((p|0)>(b|0)){K=b}else{K=(p|0)<16?16:p}c[157270]=J-z>>4;c[157266]=K-A>>4;E=J;F=K;G=j;H=r;I=s}}while(0);o=z&8388607;c[157274]=o;p=A&8388607;c[157268]=p;b=o;o=p;do{p=c[157264]|0;B=a[(c[157278]|0)+(((c[p+((b>>>16&127)<<2)>>2]|0)+o|0)>>>16<<6&4032|((c[p+((o>>>16&127)<<2)>>2]|0)+b|0)>>>16&63)|0]|0;p=c[157276]|0;c[157276]=p+1;a[p]=B;b=(c[157274]|0)+(c[157270]|0)|0;c[157274]=b;o=(c[157268]|0)+(c[157266]|0)|0;c[157268]=o;B=(c[157272]|0)-1|0;c[157272]=B;}while((B|0)>0);c[157274]=E;c[157268]=F;if((n|0)>0){v=n;w=G;x=H;y=I;z=E;A=F}else{break}}o=c[l+12>>2]|0;if((o|0)==0){break}l=o;m=+g[5104];d=+g[5084];f=+g[5078]}return}function py(a){a=a|0;var d=0.0,e=0,f=0,h=0,i=0.0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=+g[5078];e=~~(d*32768.0*65536.0);f=e<<1;h=a;i=d;while(1){a=c[351966]|0;j=c[h+4>>2]|0;k=ab(j,c[350722]|0)|0;l=c[h>>2]|0;m=k+l|0;k=a+(m<<1)|0;n=c[h+8>>2]|0;o=~~((+g[5080]+ +(j|0)*+g[5076]+ +(l|0)*i)*32768.0*65536.0);if((k&2|0)==0){p=n;q=o;r=k}else{b[k>>1]=o>>>16&65535;p=n-1|0;q=o+e|0;r=a+(m+1<<1)|0}m=p>>1;a=q>>>16&65535;if((m|0)>0){o=m<<1;n=ab(f,m)|0;k=m;m=q;l=r;while(1){j=m+e|0;c[l>>2]=j&-65536|m>>16;s=k-1|0;if((s|0)>0){k=s;m=j+e|0;l=l+4|0}else{break}}t=(q+n|0)>>>16&65535;u=r+(o<<1)|0}else{t=a;u=r}if((p&1|0)!=0){b[u>>1]=t}l=c[h+12>>2]|0;if((l|0)==0){break}h=l;i=+g[5078]}return}function pz(b){b=b|0;var d=0,e=0.0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0.0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0.0,I=0.0,J=0,K=0,L=0,M=0,N=0,O=0,P=0.0,Q=0.0,R=0.0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0;d=c[651324]|0;e=+g[5104];f=e*16.0;h=+g[5084];i=h*16.0;j=+g[5078];k=j*16.0;l=b;b=0;m=0;n=e;e=h;h=j;while(1){o=c[350744]|0;p=l+4|0;q=c[p>>2]|0;r=ab(q,c[155126]|0)|0;s=l|0;t=c[s>>2]|0;u=o+(r+t)|0;r=c[l+8>>2]|0;j=+(t|0);v=+(q|0);w=+g[5106]+v*+g[5102]+j*n;x=+g[5086]+v*+g[5082]+j*e;y=+g[5080]+v*+g[5076]+j*h;j=65536.0/y;q=~~(w*j)+(c[155602]|0)|0;t=c[660132]|0;if((q|0)>(t|0)){z=t}else{z=(q|0)<0?0:q}q=(c[45870]|0)+~~(x*j)|0;t=c[660130]|0;if((q|0)>(t|0)){A=r;B=u;C=z;D=t;E=b;F=m;G=w;H=x;I=y}else{A=r;B=u;C=z;D=(q|0)<0?0:q;E=b;F=m;G=w;H=x;I=y}while(1){q=(A|0)<16?A:16;u=A-q|0;do{if((A|0)==(q|0)){r=A-1|0;y=+(r|0);x=G+y*+g[5104];w=H+y*+g[5084];j=I+y*+g[5078];y=65536.0/j;t=~~(x*y)+(c[155602]|0)|0;o=c[660132]|0;if((t|0)>(o|0)){J=o}else{J=(t|0)<16?16:t}t=(c[45870]|0)+~~(w*y)|0;o=c[660130]|0;if((t|0)>(o|0)){K=o}else{K=(t|0)<16?16:t}if((A|0)<=1){L=J;M=K;N=E;O=F;P=x;Q=w;R=j;break}L=J;M=K;N=(J-C|0)/(r|0)|0;O=(K-D|0)/(r|0)|0;P=x;Q=w;R=j}else{j=f+G;w=i+H;x=k+I;y=65536.0/x;r=~~(j*y)+(c[155602]|0)|0;t=c[660132]|0;if((r|0)>(t|0)){S=t}else{S=(r|0)>16?r:16}r=(c[45870]|0)+~~(w*y)|0;t=c[660130]|0;if((r|0)>(t|0)){T=t}else{T=(r|0)<16?16:r}L=S;M=T;N=S-C>>4;O=T-D>>4;P=j;Q=w;R=x}}while(0);r=o4(56320)|0;L431:do{if((r|0)==0){U=311}else{if(+g[r+16>>2]==0.0){U=311;break}t=(c[s>>2]|0)+q&1;o=c[p>>2]&1;V=c[20104+(t<<4)+(o<<3)>>2]|0;W=c[20104+(t<<4)+(o<<3)+4>>2]|0;X=t^1;t=c[20104+(X<<4)+(o<<3)>>2]|0;Y=c[20104+(X<<4)+(o<<3)+4>>2]|0;o=V+C>>16;X=W+D>>16;Z=(o|0)!=0?o-1|0:0;o=(X|0)!=0?X-1|0:0;X=t+C>>16;_=Y+D>>16;$=(X|0)!=0?X-1|0:0;X=(_|0)!=0?_-1|0:0;_=B+q|0;switch(q|0){case 16:{a[B]=a[d+((ab(c[651320]|0,o)|0)+Z)|0]|0;aa=N+C|0;ac=O+D|0;ad=t+aa>>16;ae=Y+ac>>16;af=(ae|0)!=0?ae-1|0:0;ag=(ad|0)!=0?ad-1|0:0;ah=aa;ai=ac;U=315;break};case 15:{af=X;ag=$;ah=C;ai=D;U=315;break};case 14:{aj=o;ak=Z;al=C;am=D;U=316;break};case 13:{an=X;ao=$;ap=C;aq=D;U=317;break};case 5:{ar=X;as=$;at=C;au=D;U=325;break};case 4:{av=o;aw=Z;ax=C;ay=D;U=326;break};case 9:{az=X;aA=$;aB=C;aC=D;U=321;break};case 8:{aD=o;aE=Z;aF=C;aG=D;U=322;break};case 7:{aH=X;aI=$;aJ=C;aK=D;U=323;break};case 6:{aL=o;aM=Z;aN=C;aO=D;U=324;break};case 3:{aP=X;aQ=$;aR=C;aS=D;U=327;break};case 2:{aT=o;aU=Z;aV=C;aW=D;U=328;break};case 1:{aX=X;aY=$;break};case 12:{aZ=o;a_=Z;a$=C;a0=D;U=318;break};case 11:{a1=X;a2=$;a3=C;a4=D;U=319;break};case 10:{a5=o;a6=Z;a7=C;a8=D;U=320;break};default:{a9=_;break L431}}if((U|0)==315){U=0;a[B+(q-15)|0]=a[d+((ab(c[651320]|0,af)|0)+ag)|0]|0;Z=ah+N|0;o=ai+O|0;$=Z+V>>16;X=o+W>>16;aj=(X|0)!=0?X-1|0:0;ak=($|0)!=0?$-1|0:0;al=Z;am=o;U=316}if((U|0)==316){U=0;a[B+(q-14)|0]=a[d+((ab(c[651320]|0,aj)|0)+ak)|0]|0;o=al+N|0;Z=am+O|0;$=o+t>>16;X=Z+Y>>16;an=(X|0)!=0?X-1|0:0;ao=($|0)!=0?$-1|0:0;ap=o;aq=Z;U=317}if((U|0)==317){U=0;a[B+(q-13)|0]=a[d+((ab(c[651320]|0,an)|0)+ao)|0]|0;Z=ap+N|0;o=aq+O|0;$=Z+V>>16;X=o+W>>16;aZ=(X|0)!=0?X-1|0:0;a_=($|0)!=0?$-1|0:0;a$=Z;a0=o;U=318}if((U|0)==318){U=0;a[B+(q-12)|0]=a[d+((ab(c[651320]|0,aZ)|0)+a_)|0]|0;o=a$+N|0;Z=a0+O|0;$=o+t>>16;X=Z+Y>>16;a1=(X|0)!=0?X-1|0:0;a2=($|0)!=0?$-1|0:0;a3=o;a4=Z;U=319}if((U|0)==319){U=0;a[B+(q-11)|0]=a[d+((ab(c[651320]|0,a1)|0)+a2)|0]|0;Z=a3+N|0;o=a4+O|0;$=Z+V>>16;X=o+W>>16;a5=(X|0)!=0?X-1|0:0;a6=($|0)!=0?$-1|0:0;a7=Z;a8=o;U=320}if((U|0)==320){U=0;a[B+(q-10)|0]=a[d+((ab(c[651320]|0,a5)|0)+a6)|0]|0;o=a7+N|0;Z=a8+O|0;$=o+t>>16;X=Z+Y>>16;az=(X|0)!=0?X-1|0:0;aA=($|0)!=0?$-1|0:0;aB=o;aC=Z;U=321}if((U|0)==321){U=0;a[B+(q-9)|0]=a[d+((ab(c[651320]|0,az)|0)+aA)|0]|0;Z=aB+N|0;o=aC+O|0;$=Z+V>>16;X=o+W>>16;aD=(X|0)!=0?X-1|0:0;aE=($|0)!=0?$-1|0:0;aF=Z;aG=o;U=322}if((U|0)==322){U=0;a[B+(q-8)|0]=a[d+((ab(c[651320]|0,aD)|0)+aE)|0]|0;o=aF+N|0;Z=aG+O|0;$=o+t>>16;X=Z+Y>>16;aH=(X|0)!=0?X-1|0:0;aI=($|0)!=0?$-1|0:0;aJ=o;aK=Z;U=323}if((U|0)==323){U=0;a[B+(q-7)|0]=a[d+((ab(c[651320]|0,aH)|0)+aI)|0]|0;Z=aJ+N|0;o=aK+O|0;$=Z+V>>16;X=o+W>>16;aL=(X|0)!=0?X-1|0:0;aM=($|0)!=0?$-1|0:0;aN=Z;aO=o;U=324}if((U|0)==324){U=0;a[B+(q-6)|0]=a[d+((ab(c[651320]|0,aL)|0)+aM)|0]|0;o=aN+N|0;Z=aO+O|0;$=o+t>>16;X=Z+Y>>16;ar=(X|0)!=0?X-1|0:0;as=($|0)!=0?$-1|0:0;at=o;au=Z;U=325}if((U|0)==325){U=0;a[B+(q-5)|0]=a[d+((ab(c[651320]|0,ar)|0)+as)|0]|0;Z=at+N|0;o=au+O|0;$=Z+V>>16;X=o+W>>16;av=(X|0)!=0?X-1|0:0;aw=($|0)!=0?$-1|0:0;ax=Z;ay=o;U=326}if((U|0)==326){U=0;a[B+(q-4)|0]=a[d+((ab(c[651320]|0,av)|0)+aw)|0]|0;o=ax+N|0;Z=ay+O|0;$=o+t>>16;X=Z+Y>>16;aP=(X|0)!=0?X-1|0:0;aQ=($|0)!=0?$-1|0:0;aR=o;aS=Z;U=327}if((U|0)==327){U=0;a[B+(q-3)|0]=a[d+((ab(c[651320]|0,aP)|0)+aQ)|0]|0;Z=aR+N|0;o=aS+O|0;$=Z+V>>16;V=o+W>>16;aT=(V|0)!=0?V-1|0:0;aU=($|0)!=0?$-1|0:0;aV=Z;aW=o;U=328}if((U|0)==328){U=0;a[B+(q-2)|0]=a[d+((ab(c[651320]|0,aT)|0)+aU)|0]|0;o=t+N+aV>>16;t=Y+O+aW>>16;aX=(t|0)!=0?t-1|0:0;aY=(o|0)!=0?o-1|0:0}a[B+(q-1)|0]=a[d+((ab(c[651320]|0,aX)|0)+aY)|0]|0;a9=_}}while(0);if((U|0)==311){U=0;r=~A;_=(r|0)>-17?r:-17;r=_+1|0;o=((r|0)>-1?r:-1)-_|0;_=q;r=B;t=C;Y=D;while(1){a[r]=a[d+((ab(c[651320]|0,Y>>16)|0)+(t>>16))|0]|0;Z=_-1|0;if((Z|0)>0){_=Z;r=r+1|0;t=t+N|0;Y=Y+O|0}else{break}}a9=B+o|0}if((u|0)>0){A=u;B=a9;C=L;D=M;E=N;F=O;G=P;H=Q;I=R}else{break}}p=c[l+12>>2]|0;if((p|0)==0){break}l=p;b=N;m=O;n=+g[5104];e=+g[5084];h=+g[5078]}return}function pA(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+16|0;e=d|0;f=e|0;h=e+4|0;j=e+8|0;e=b;b=0;k=0;l=0;m=0;while(1){n=c[350744]|0;o=c[e+4>>2]|0;p=ab(o,c[155126]|0)|0;q=c[e>>2]|0;r=c[e+8>>2]|0;s=c[157326]|0;t=c[157327]|0;u=+(((s|0)<(t|0)?t:s)|0);v=+(q-(c[29381]>>1)|0)*8192.0/u;w=+((c[29382]>>1)-o|0)*8192.0/u;g[f>>2]=+g[29332]*4096.0+v*+g[29328]+w*+g[29324];g[h>>2]=+g[29333]*4096.0+v*+g[29329]+w*+g[29325];g[j>>2]=(+g[29334]*4096.0+v*+g[29330]+w*+g[29326])*3.0;+q1(f);w=+g[888]*+g[892];s=b;t=k;x=n+(p+q)|0;p=r;r=q;q=l;n=m;y=~~((w+ +g[h>>2]*378.0)*65536.0);z=~~((w+ +g[f>>2]*378.0)*65536.0);while(1){A=(p|0)<32?p:32;B=p-A|0;do{if((p|0)==(A|0)){C=~~+(p-1|0);if((C|0)<=0){D=s;E=t;F=r;G=q;H=n;break}I=C+r|0;J=c[157326]|0;K=c[157327]|0;w=+(((J|0)<(K|0)?K:J)|0);v=+(I-(c[29381]>>1)|0)*8192.0/w;u=+((c[29382]>>1)-o|0)*8192.0/w;g[f>>2]=+g[29332]*4096.0+v*+g[29328]+u*+g[29324];g[h>>2]=+g[29333]*4096.0+v*+g[29329]+u*+g[29325];g[j>>2]=(+g[29334]*4096.0+v*+g[29330]+u*+g[29326])*3.0;+q1(f);u=+g[888]*+g[892];J=~~((u+ +g[f>>2]*378.0)*65536.0);K=~~((u+ +g[h>>2]*378.0)*65536.0);D=(K-y|0)/(C|0)|0;E=(J-z|0)/(C|0)|0;F=I;G=K;H=J}else{J=A+r|0;K=c[157326]|0;I=c[157327]|0;u=+(((K|0)<(I|0)?I:K)|0);v=+(J-(c[29381]>>1)|0)*8192.0/u;w=+((c[29382]>>1)-o|0)*8192.0/u;g[f>>2]=+g[29332]*4096.0+v*+g[29328]+w*+g[29324];g[h>>2]=+g[29333]*4096.0+v*+g[29329]+w*+g[29325];g[j>>2]=(+g[29334]*4096.0+v*+g[29330]+w*+g[29326])*3.0;+q1(f);w=+g[888]*+g[892];K=~~((w+ +g[f>>2]*378.0)*65536.0);I=~~((w+ +g[h>>2]*378.0)*65536.0);D=I-y>>5;E=K-z>>5;F=J;G=I;H=K}}while(0);K=~p;I=(K|0)>-33?K:-33;K=I+1|0;J=((K|0)>-1?K:-1)-I|0;I=x;K=A;C=y;L=z;while(1){a[I]=a[(c[157308]|0)+(C>>>8&32512|L>>>16&127)|0]|0;M=K-1|0;if((M|0)>0){I=I+1|0;K=M;C=D+C|0;L=E+L|0}else{break}}if((B|0)>0){s=D;t=E;x=x+J|0;p=B;r=F;q=G;n=H;y=G;z=H}else{break}}z=c[e+12>>2]|0;if((z|0)==0){break}else{e=z;b=D;k=E;l=G;m=H}}i=d;return}function pB(d){d=d|0;var e=0,f=0.0,h=0.0,i=0.0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0.0,y=0.0,z=0.0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0.0,U=0.0,V=0.0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0;e=c[651324]|0;f=+g[5104]*8.0;h=+g[5084]*8.0;i=+g[5078];j=i*8.0;k=~~(i*32768.0*65536.0);l=d;d=0;m=0;while(1){n=c[350744]|0;o=l+4|0;p=c[o>>2]|0;q=ab(p,c[155126]|0)|0;r=l|0;s=c[r>>2]|0;t=n+(q+s)|0;q=c[351966]|0;n=q+((ab(c[350722]|0,p)|0)+s<<1)|0;q=c[l+8>>2]|0;if((q|0)<1){u=d;v=m}else{i=+(s|0);w=+(p|0);x=+g[5106]+w*+g[5102]+i*+g[5104];y=+g[5086]+w*+g[5082]+i*+g[5084];z=+g[5080]+w*+g[5076]+i*+g[5078];i=65536.0/z;p=~~(z*32768.0*65536.0);s=~~(x*i)+(c[155602]|0)|0;A=c[660132]|0;if((s|0)>(A|0)){B=A}else{B=(s|0)<0?0:s}s=(c[45870]|0)+~~(y*i)|0;A=c[660130]|0;if((s|0)>(A|0)){C=q;D=p;E=t;F=n;G=B;H=A;I=d;J=m;K=z;L=y;M=x}else{C=q;D=p;E=t;F=n;G=B;H=(s|0)<0?0:s;I=d;J=m;K=z;L=y;M=x}while(1){s=(C|0)<8?C:8;n=C-s|0;do{if((C|0)==(s|0)){t=C-1|0;x=+(t|0);y=M+x*+g[5104];z=L+x*+g[5084];i=K+x*+g[5078];x=65536.0/i;p=~~(y*x)+(c[155602]|0)|0;q=c[660132]|0;if((p|0)>(q|0)){N=q}else{N=(p|0)<8?8:p}p=(c[45870]|0)+~~(z*x)|0;q=c[660130]|0;if((p|0)>(q|0)){O=q}else{O=(p|0)<8?8:p}if((C|0)<=1){P=N;Q=O;R=I;S=J;T=i;U=z;V=y;break}P=N;Q=O;R=(N-G|0)/(t|0)|0;S=(O-H|0)/(t|0)|0;T=i;U=z;V=y}else{y=f+M;z=h+L;i=j+K;x=65536.0/i;t=~~(y*x)+(c[155602]|0)|0;p=c[660132]|0;if((t|0)>(p|0)){W=p}else{W=(t|0)<8?8:t}t=(c[45870]|0)+~~(z*x)|0;p=c[660130]|0;if((t|0)>(p|0)){X=p}else{X=(t|0)<8?8:t}P=W;Q=X;R=W-G>>3;S=X-H>>3;T=i;U=z;V=y}}while(0);t=o4(56024)|0;L518:do{if((t|0)==0){Y=366}else{if(+g[t+16>>2]==0.0){Y=366;break}p=~C;q=(p|0)>-9?p:-9;p=q+1|0;A=((p|0)>-1?p:-1)-q|0;q=s;p=D;Z=E;_=F;$=G;aa=H;while(1){ac=(c[r>>2]|0)+q&1;ad=c[o>>2]&1;ae=(c[20104+(ac<<4)+(ad<<3)>>2]|0)+$>>16;af=(c[20104+(ac<<4)+(ad<<3)+4>>2]|0)+aa>>16;ad=a[e+((ab((af|0)!=0?af-1|0:0,c[651320]|0)|0)+((ae|0)!=0?ae-1|0:0))|0]|0;do{if(ad<<24>>24!=-1){ae=p>>16;if((b[_>>1]|0)>(ae|0)){break}b[_>>1]=ae&65535;a[Z]=ad}}while(0);ad=q-1|0;if((ad|0)<=0){ag=A;break L518}q=ad;p=p+k|0;Z=Z+1|0;_=_+2|0;$=$+R|0;aa=aa+S|0}}}while(0);L528:do{if((Y|0)==366){Y=0;t=~C;aa=(t|0)>-9?t:-9;t=aa+1|0;$=((t|0)>-1?t:-1)-aa|0;aa=s;t=D;_=E;Z=F;p=G;q=H;while(1){A=a[e+((ab(c[651320]|0,q>>16)|0)+(p>>16))|0]|0;do{if(A<<24>>24!=-1){ad=t>>16;if((b[Z>>1]|0)>(ad|0)){break}b[Z>>1]=ad&65535;a[_]=A}}while(0);A=aa-1|0;if((A|0)<=0){ag=$;break L528}aa=A;t=t+k|0;_=_+1|0;Z=Z+2|0;p=p+R|0;q=q+S|0}}}while(0);s=D+(ab(k,ag)|0)|0;if((n|0)>0){C=n;D=s;E=E+ag|0;F=F+(ag<<1)|0;G=P;H=Q;I=R;J=S;K=T;L=U;M=V}else{u=R;v=S;break}}}if((c[l+20>>2]|0)==-128){break}l=l+12|0;d=u;m=v}return}function pC(){var a=0,b=0,d=0,e=0,f=0,h=0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[145620]|0;b=c[220090]|0;d=c[157290]|0;e=(b|0)==0?d:b;b=c[270774]|0;f=(b|0)==0?d:b;b=c[157291]|0;h=e;i=+aa(+(+g[b+(e*20|0)+4>>2]));e=a;a=d;d=b;while(1){b=h-1|0;j=+g[d+(b*20|0)+4>>2];k=+aa(+j);do{if(i<k){l=+g[d+(h*20|0)>>2];m=+g[d+(h*20|0)+4>>2];n=(+g[d+(b*20|0)>>2]-l)/(j-m);o=~~(n*65536.0);p=~~i;q=~~k;if((p|0)>=(q|0)){r=e;s=a;break}t=q-p|0;u=e;v=p;p=~~((l+n*(i-m))*65536.0)+65535|0;while(1){c[u>>2]=p>>16;c[u+4>>2]=v;w=v+1|0;if((w|0)<(q|0)){u=u+12|0;v=w;p=p+o|0}else{break}}r=e+(t*12|0)|0;s=c[157290]|0}else{r=e;s=a}}while(0);o=(b|0)==0?s:b;if((o|0)==(f|0)){break}h=o;i=k;e=r;a=s;d=c[157291]|0}return}function pD(){var a=0,b=0,d=0,e=0.0,f=0.0,h=0.0,i=0.0,j=0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=c[145620]|0;b=c[220090]|0;d=c[157291]|0;e=+g[d+(b*20|0)+4>>2];f=+g[157342];h=e<f?f:e;e=+g[157346];i=h>e?e:h;j=b;h=i;b=a;k=+aa(+i);a=d;i=f;f=e;while(1){d=j+1|0;e=+g[a+(d*20|0)+4>>2];l=e<i?i:e;e=l>f?f:l;l=+aa(+e);do{if(k<l){m=+g[a+(j*20|0)>>2];n=+g[157341];o=m<n?n:m;m=+g[157345];p=o>m?m:o;o=+g[a+(d*20|0)>>2];q=o<n?n:o;o=((q>m?m:q)-p)/(e-h);r=~~(o*65536.0);s=~~k;t=~~l;if((s|0)>=(t|0)){u=b;break}v=t-s|0;w=b;x=s;s=~~((p+(k-h)*o)*65536.0)+65535|0;while(1){c[w+8>>2]=(s>>16)-(c[w>>2]|0);y=x+1|0;if((y|0)<(t|0)){w=w+12|0;x=y;s=s+r|0}else{break}}u=b+(v*12|0)|0}else{u=b}}while(0);r=(d|0)==(c[157290]|0)?0:d;if((r|0)==(c[270774]|0)){break}j=r;h=e;b=u;k=l;a=c[157291]|0;i=+g[157342];f=+g[157346]}c[u+8>>2]=-128;return}function pE(){var a=0,b=0;a=c[155440]|0;if((a|0)==0){return}else{b=a}do{a=c[b+4>>2]|0;if((a|0)!=0){c[a>>2]=0}b=c[b>>2]|0;}while((b|0)!=0);b=c[155440]|0;c[155438]=b;c[b>>2]=0;c[(c[155440]|0)+4>>2]=0;c[(c[155440]|0)+28>>2]=c[155436];return}function pF(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)<-7){return}if(((c[29382]|0)-8|0)<(d|0)|(b|0)<0){return}if(((c[29381]|0)-8|0)<(b|0)){return}f=c[350712]|0;g=e>>>4<<10&15360|e<<3&120;do{if((d|0)<0){e=d+8|0;if((e|0)!=0){h=g-(d<<7)|0;i=e;j=0;break}return}else{h=g;i=8;j=d}}while(0);d=(ab(c[29387]|0,j)|0)+b|0;b=(c[29386]|0)+d|0;d=f+h|0;h=i;while(1){i=h-1|0;f=a[d]|0;if(f<<24>>24!=0){a[b]=f}f=a[d+1|0]|0;if(f<<24>>24!=0){a[b+1|0]=f}f=a[d+2|0]|0;if(f<<24>>24!=0){a[b+2|0]=f}f=a[d+3|0]|0;if(f<<24>>24!=0){a[b+3|0]=f}f=a[d+4|0]|0;if(f<<24>>24!=0){a[b+4|0]=f}f=a[d+5|0]|0;if(f<<24>>24!=0){a[b+5|0]=f}f=a[d+6|0]|0;if(f<<24>>24!=0){a[b+6|0]=f}f=a[d+7|0]|0;if(f<<24>>24!=0){a[b+7|0]=f}if((i|0)==0){break}else{b=b+(c[29387]|0)|0;d=d+128|0;h=i}}return}function pG(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0,q=0.0,r=0.0,s=0,t=0.0,u=0.0,v=0.0;a=i;i=i+64|0;b=a|0;d=a+16|0;e=a+32|0;f=a+48|0;h=b|0;uu(629196,h);j=d|0;uu(629184,j);k=e|0;uu(629172,k);q8(k);l=1.0/(-0.0-(+g[169390]*+g[157299]+ +g[169391]*+g[157300]+ +g[169392]*+g[157301]));m=+g[16];n=+g[j>>2]*m;g[5104]=n;o=m*+g[k>>2];g[5084]=o;p=d+4|0;q=+g[6];r=q*(-0.0- +g[p>>2]);g[5102]=r;s=e+4|0;t=q*(-0.0- +g[s>>2]);g[5082]=t;u=l*+g[h>>2]*m;g[5078]=u;m=l*q*(-0.0- +g[b+4>>2]);g[5076]=m;h=d+8|0;q=+g[20];v=+g[10];g[5106]=+g[h>>2]-q*n-v*r;d=e+8|0;g[5086]=+g[d>>2]-q*o-v*t;g[5080]=l*+g[b+8>>2]-q*u-v*m;b=f|0;uu(677560,b);m=+g[b>>2];v=+g[f+4>>2];u=+g[f+8>>2];f=c[651320]|0;c[155602]=~~((m*+g[j>>2]+v*+g[p>>2]+u*+g[h>>2])*65536.0+.5)-(-(f>>>1)<<16);h=c[145624]|0;c[45870]=~~((m*+g[k>>2]+v*+g[s>>2]+u*+g[d>>2])*65536.0+.5)-(-(h>>>1)<<16);c[660132]=(f<<16)-1;c[660130]=(h<<16)-1;i=a;return}function pH(){var a=0,b=0,d=0,e=0.0,f=0.0,h=0,j=0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0;a=i;i=i+14416|0;c[145620]=a;b=c[157290]|0;if((b|0)>0){d=0;e=3.4028234663852886e+38;f=-3.4028234663852886e+38;h=c[157291]|0;while(1){j=h+4|0;k=+g[j>>2];if(k<e){c[220090]=d;l=k;m=+g[j>>2]}else{l=e;m=k}if(m>f){c[270774]=d;n=m}else{n=f}j=d+1|0;if((j|0)<(b|0)){d=j;e=l;f=n;h=h+20|0}else{o=l;p=n;break}}}else{o=3.4028234663852886e+38;p=-3.4028234663852886e+38}n=+aa(+o);if(n>=+aa(+p)){i=a;return}h=c[157292]|0;c[651320]=c[h>>2];c[145624]=c[h+4>>2];c[651324]=h+24;h=c[157291]|0;d=h+(b*20|0)|0;b=h;c[d>>2]=c[b>>2];c[d+4>>2]=c[b+4>>2];c[d+8>>2]=c[b+8>>2];c[d+12>>2]=c[b+12>>2];c[d+16>>2]=c[b+16>>2];pG();pC();pD();pB(c[145620]|0);i=a;return}function pI(){var b=0,d=0,e=0,f=0;b=i;d=c[155440]|0;e=c[155436]|0;if((a[d+e|0]|0)!=0){w1(96480,(f=i,i=i+8|0,c[f>>2]=111520,f)|0);i=f}if((a[d+(e+1)|0]|0)!=1){w1(96480,(f=i,i=i+8|0,c[f>>2]=111520,f)|0);i=f}if((a[d+(e+2)|0]|0)!=2){w1(96480,(f=i,i=i+8|0,c[f>>2]=111520,f)|0);i=f}if((a[d+(e+3)|0]|0)==3){i=b;return}w1(96480,(f=i,i=i+8|0,c[f>>2]=111520,f)|0);i=f;i=b;return}function pJ(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;if((c[169376]|0)==0){oW(77824,(f=i,i=i+8|0,c[f>>2]=(d|0)/1024|0,f)|0);i=f}c[155436]=d-4;d=b;c[155440]=d;c[155438]=d;c[b>>2]=0;c[(c[155440]|0)+4>>2]=0;c[(c[155440]|0)+28>>2]=c[155436];b=c[155440]|0;d=c[155436]|0;a[b+d|0]=0;a[b+(d+1)|0]=1;a[b+(d+2)|0]=2;a[b+(d+3)|0]=3;i=e;return}function pK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;if(a>>>0>256){w1(66208,(e=i,i=i+16|0,c[e>>2]=111504,c[e+8>>2]=a,e)|0);i=e}if((b-1|0)>>>0>65535){w1(58232,(e=i,i=i+16|0,c[e>>2]=111504,c[e+8>>2]=b,e)|0);i=e}f=51+b&-4;if((f|0)>(c[155436]|0)){w1(52624,(e=i,i=i+16|0,c[e>>2]=111504,c[e+8>>2]=f,e)|0);i=e}b=c[155438]|0;g=c[155440]|0;if((b|0)==0){h=473}else{if((b-g|0)>((c[155436]|0)-f|0)){h=473}else{j=0;k=b}}if((h|0)==473){c[155438]=g;j=(b|0)!=0|0;k=g}g=k+4|0;b=c[g>>2]|0;if((b|0)!=0){c[b>>2]=0}b=k+28|0;h=c[b>>2]|0;if((h|0)<(f|0)){l=k|0;while(1){m=c[c[155438]>>2]|0;c[155438]=m;if((m|0)==0){w1(48880,(e=i,i=i+8|0,c[e>>2]=111504,e)|0);i=e;n=c[155438]|0}else{n=m}m=c[n+4>>2]|0;if((m|0)==0){o=n}else{c[m>>2]=0;o=c[155438]|0}m=(c[b>>2]|0)+(c[o+28>>2]|0)|0;c[b>>2]=m;c[l>>2]=c[c[155438]>>2];if((m|0)>=(f|0)){p=m;break}}}else{p=h}if((p-f|0)>256){p=k;c[155438]=p+f;c[p+(f+28)>>2]=(c[b>>2]|0)-f;p=k|0;c[c[155438]>>2]=c[p>>2];c[(c[155438]|0)+32>>2]=0;c[(c[155438]|0)+4>>2]=0;c[p>>2]=c[155438];c[b>>2]=f}else{c[155438]=c[k>>2]}c[k+32>>2]=a;if((a|0)>0){c[k+36>>2]=((f-48|0)>>>0)/(a>>>0)|0}c[g>>2]=0;g=(j|0)!=0;if((c[351962]|0)==0){if(!g){pI();i=d;return k|0}c[351962]=1;pI();i=d;return k|0}do{if(!g){if((c[155438]|0)>>>0>=(c[352258]|0)>>>0){break}pI();i=d;return k|0}}while(0);c[157510]=1;pI();i=d;return k|0}function pL(a,e,f){a=a|0;e=e|0;f=f|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=uT(a,c[(c[e+72>>2]|0)+36>>2]|0)|0;c[157489]=h;a=c[1407984+(d[e+84|0]<<2)>>2]|0;c[157485]=a;i=c[1407984+(d[e+85|0]<<2)>>2]|0;c[157486]=i;j=c[1407984+(d[e+86|0]<<2)>>2]|0;c[157487]=j;k=c[1407984+(d[e+87|0]<<2)>>2]|0;c[157488]=k;l=e+48+(f<<2)|0;m=c[l>>2]|0;n=(m|0)!=0;do{if(n){if((c[m+24>>2]|0)!=0){break}if((c[e+76>>2]|0)==(c[2750]|0)){break}if((c[m+44>>2]|0)!=(h|0)){break}if((c[m+8>>2]|0)!=(a|0)){break}if((c[m+12>>2]|0)!=(i|0)){break}if((c[m+16>>2]|0)!=(j|0)){break}if((c[m+20>>2]|0)==(k|0)){o=m}else{break}return o|0}}while(0);g[710]=1.0/+(1<<f|0);c[157490]=f;k=b[e+68>>1]>>f;c[157491]=k;c[157483]=k;j=b[e+70>>1]>>f;c[157492]=j;if(n){p=m}else{m=pK(k,ab(k,j)|0)|0;c[l>>2]=m;c[m+4>>2]=l;g[m+40>>2]=+g[710];p=m}c[p+24>>2]=(c[e+76>>2]|0)==(c[2750]|0);c[157482]=p+48;c[p+44>>2]=c[157489];c[p+8>>2]=c[157485];c[p+12>>2]=c[157486];c[p+16>>2]=c[157487];c[p+20>>2]=c[157488];c[157484]=e;c[651342]=(c[651342]|0)+1;uY();o=c[l>>2]|0;return o|0}function pM(a){a=a|0;return xX(a)|0}function pN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[220466]|0;L716:do{if((d|0)>0){e=1073872;f=0;while(1){if((cS(a|0,e|0)|0)==0){g=e;h=f;break L716}j=e+72|0;k=f+1|0;if((k|0)<(d|0)){e=j;f=k}else{g=j;h=k;break}}}else{g=1073872;h=0}}while(0);if((h|0)==(d|0)){if((d|0)==128){w1(52584,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l;m=c[220466]|0}else{m=d}c[220466]=m+1;m=g|0;yQ(m|0,a|0)|0}m=g+64|0;g=yc(m)|0;if((g|0)!=0){n=g;i=b;return n|0}om(a,m);g=c[m>>2]|0;m=g;if((g|0)==0){w1(94928,(l=i,i=i+16|0,c[l>>2]=111488,c[l+8>>2]=a,l)|0);i=l}xS(m);n=m;i=b;return n|0}function pO(){var a=0;c[350712]=xX(76928)|0;c[350710]=xX(65584)|0;a=xX(57904)|0;c[350714]=a;c[157368]=c[a>>2];c[157366]=c[a+4>>2];c[157364]=a+8;c[157362]=c[a>>2];return}function pP(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=a[d]|0;if(e<<24>>24==0){return}else{f=b;g=d;h=e}while(1){pF(f,c,h<<24>>24);e=g+1|0;d=a[e]|0;if(d<<24>>24==0){break}else{f=f+8|0;g=e;h=d}}return}function pQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return}function pR(){var b=0,d=0.0,e=0,f=0,h=0;b=~~+g[5162];d=+g[5176];if(d==2.0){e=~~(+g[5586]+ +(((c[155150]|0)/2|0)+(c[155148]|0)|0));f=~~(+g[5572]+ +(((c[155151]|0)/2|0)+(c[155149]|0)|0));h=c[29386]|0;a[h+(e-1+(ab(f,c[29387]|0)|0))|0]=b;h=c[29386]|0;a[h+(e-3+(ab(c[29387]|0,f)|0))|0]=b;h=c[29386]|0;a[h+(e+1+(ab(c[29387]|0,f)|0))|0]=b;h=c[29386]|0;a[h+(e+3+(ab(c[29387]|0,f)|0))|0]=b;h=c[29386]|0;a[h+((ab(c[29387]|0,f-1|0)|0)+e)|0]=b;h=c[29386]|0;a[h+((ab(c[29387]|0,f-3|0)|0)+e)|0]=b;h=c[29386]|0;a[h+((ab(c[29387]|0,f+1|0)|0)+e)|0]=b;h=c[29386]|0;a[h+((ab(c[29387]|0,f+3|0)|0)+e)|0]=b;return}if(d==0.0){return}pF(~~(+g[5586]+ +((c[155148]|0)-4+((c[155150]|0)/2|0)|0)),~~(+g[5572]+ +((c[155149]|0)-4+((c[155151]|0)/2|0)|0)),43);return}function pS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;do{if((a|0)<0){f=547}else{if(((c[d>>2]|0)+a|0)>(c[29381]|0)|(b|0)<0){f=547;break}g=c[d+4>>2]|0;if((g+b|0)>(c[29382]|0)){f=547}else{h=g}}}while(0);if((f|0)==547){w1(52432,(f=i,i=i+8|0,c[f>>2]=111472,f)|0);i=f;h=c[d+4>>2]|0}f=d+4|0;if((h|0)<=0){i=e;return}h=(ab(c[29380]|0,b)|0)+a|0;a=d|0;b=(c[29376]|0)+h|0;h=d+8|0;d=0;g=c[a>>2]|0;while(1){yJ(b|0,h|0,g)|0;j=c[a>>2]|0;k=d+1|0;if((k|0)<(c[f>>2]|0)){b=b+(c[29380]|0)|0;h=h+j|0;d=k;g=j}else{break}}i=e;return}function pT(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=i;g=e|0;do{if((b|0)<0){h=557}else{j=c[g>>2]|0;if((j+b|0)>>>0>(c[29381]|0)>>>0|(d|0)<0){h=557;break}if(((c[e+4>>2]|0)+d|0)>>>0>(c[29382]|0)>>>0){h=557}else{k=j}}}while(0);if((h|0)==557){w1(52432,(h=i,i=i+8|0,c[h>>2]=111440,h)|0);i=h;k=c[g>>2]|0}g=e+8|0;h=c[29376]|0;j=c[29380]|0;l=h+((ab(j,d)|0)+b)|0;b=e|0;d=e+4|0;e=c[d>>2]|0;h=(e|0)>0;if((k&7|0)!=0){if(h){m=l;n=g;o=0;p=k;q=j;r=e}else{i=f;return}while(1){if((p|0)>0){s=0;t=p;while(1){u=a[n+s|0]|0;if(u<<24>>24==-1){v=t}else{a[m+s|0]=u;v=c[b>>2]|0}u=s+1|0;if((u|0)<(v|0)){s=u;t=v}else{break}}w=v;x=c[29380]|0;y=c[d>>2]|0}else{w=p;x=q;y=r}t=o+1|0;if((t|0)<(y|0)){m=m+x|0;n=n+w|0;o=t;p=w;q=x;r=y}else{break}}i=f;return}if(h){z=l;A=g;B=0;C=k;D=j;E=e}else{i=f;return}while(1){if((C|0)>0){e=0;do{j=a[A+e|0]|0;if(j<<24>>24!=-1){a[z+e|0]=j}j=e|1;k=a[A+j|0]|0;if(k<<24>>24!=-1){a[z+j|0]=k}k=e|2;j=a[A+k|0]|0;if(j<<24>>24!=-1){a[z+k|0]=j}j=e|3;k=a[A+j|0]|0;if(k<<24>>24!=-1){a[z+j|0]=k}k=e|4;j=a[A+k|0]|0;if(j<<24>>24!=-1){a[z+k|0]=j}j=e|5;k=a[A+j|0]|0;if(k<<24>>24!=-1){a[z+j|0]=k}k=e|6;j=a[A+k|0]|0;if(j<<24>>24!=-1){a[z+k|0]=j}j=e|7;k=a[A+j|0]|0;if(k<<24>>24!=-1){a[z+j|0]=k}e=e+8|0;F=c[b>>2]|0;}while((e|0)<(F|0));G=F;H=c[29380]|0;I=c[d>>2]|0}else{G=C;H=D;I=E}e=B+1|0;if((e|0)<(I|0)){z=z+H|0;A=A+G|0;B=e;C=G;D=H;E=I}else{break}}i=f;return}function pU(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;g=i;h=e|0;do{if((b|0)<0){j=595}else{k=c[h>>2]|0;if((k+b|0)>>>0>(c[29381]|0)>>>0|(d|0)<0){j=595;break}if(((c[e+4>>2]|0)+d|0)>>>0>(c[29382]|0)>>>0){j=595}else{l=k}}}while(0);if((j|0)==595){w1(52432,(j=i,i=i+8|0,c[j>>2]=111416,j)|0);i=j;l=c[h>>2]|0}h=e+8|0;j=c[29376]|0;k=c[29380]|0;m=j+((ab(k,d)|0)+b)|0;b=e|0;d=e+4|0;e=c[d>>2]|0;j=(e|0)>0;if((l&7|0)!=0){if(j){n=m;o=h;p=0;q=l;r=k;s=e}else{i=g;return}while(1){if((q|0)>0){t=0;u=q;while(1){v=a[o+t|0]|0;if(v<<24>>24==-1){w=u}else{a[n+t|0]=a[f+(v&255)|0]|0;w=c[b>>2]|0}v=t+1|0;if((v|0)<(w|0)){t=v;u=w}else{break}}x=w;y=c[29380]|0;z=c[d>>2]|0}else{x=q;y=r;z=s}u=p+1|0;if((u|0)<(z|0)){n=n+y|0;o=o+x|0;p=u;q=x;r=y;s=z}else{break}}i=g;return}if(j){A=m;B=h;C=0;D=l;E=k;F=e}else{i=g;return}while(1){if((D|0)>0){e=0;do{k=a[B+e|0]|0;if(k<<24>>24!=-1){a[A+e|0]=a[f+(k&255)|0]|0}k=e|1;l=a[B+k|0]|0;if(l<<24>>24!=-1){a[A+k|0]=a[f+(l&255)|0]|0}l=e|2;k=a[B+l|0]|0;if(k<<24>>24!=-1){a[A+l|0]=a[f+(k&255)|0]|0}k=e|3;l=a[B+k|0]|0;if(l<<24>>24!=-1){a[A+k|0]=a[f+(l&255)|0]|0}l=e|4;k=a[B+l|0]|0;if(k<<24>>24!=-1){a[A+l|0]=a[f+(k&255)|0]|0}k=e|5;l=a[B+k|0]|0;if(l<<24>>24!=-1){a[A+k|0]=a[f+(l&255)|0]|0}l=e|6;k=a[B+l|0]|0;if(k<<24>>24!=-1){a[A+l|0]=a[f+(k&255)|0]|0}k=e|7;l=a[B+k|0]|0;if(l<<24>>24!=-1){a[A+k|0]=a[f+(l&255)|0]|0}e=e+8|0;G=c[b>>2]|0;}while((e|0)<(G|0));H=G;I=c[29380]|0;J=c[d>>2]|0}else{H=D;I=E;J=F}e=C+1|0;if((e|0)<(J|0)){A=A+I|0;B=B+H|0;C=e;D=H;E=I;F=J}else{break}}i=g;return}function pV(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=pN(48728)|0;e=d+4|0;f=c[e>>2]|0;g=d|0;h=c[g>>2]|0;i=((h*43|0|0)/-320|0)+h+(ab(h,f-((f*14|0|0)/200|0)|0)|0)|0;j=0;k=h;h=f;while(1){f=a[44560+j|0]|0;l=h<<3;m=(l|0)/200|0;n=k<<3;o=(n|0)/320|0;p=c[350712]|0;q=f>>>4<<10|f<<3&120;f=20971520/(k|0)|0;if((l|0)>199&(n|0)>319){l=0;r=i+((ab(n,j)|0)/320|0)+(d+8)|0;while(1){n=(((l<<3|0)/(m|0)|0)<<7)+q|0;s=0;t=0;while(1){u=a[p+(n+(t>>16))|0]|0;if(u<<24>>24!=0){a[r+s|0]=u+96&255}u=s+1|0;if((u|0)<(o|0)){s=u;t=t+f|0}else{break}}t=c[g>>2]|0;s=l+1|0;if((s|0)<(m|0)){l=s;r=r+t|0}else{v=t;break}}}else{v=k}r=j+1|0;if((r|0)>=4){break}j=r;k=v;h=c[e>>2]|0}if((b|0)<=0){return}h=c[29386]|0;k=0;j=v;while(1){v=c[29389]|0;i=ab(j,(ab(k-b+v|0,c[e>>2]|0)|0)/(v|0)|0)|0;v=c[29388]|0;do{if((v|0)==(j|0)){r=d+8+i|0;yJ(h|0,r|0,j)|0}else{r=(j<<16|0)/(v|0)|0;if((v|0)>0){w=0;x=0}else{break}while(1){a[h+x|0]=a[(w>>16)+i+(d+8)|0]|0;l=w+r|0;a[h+(x|1)|0]=a[(l>>16)+i+(d+8)|0]|0;m=l+r|0;a[h+(x|2)|0]=a[(m>>16)+i+(d+8)|0]|0;l=m+r|0;a[h+(x|3)|0]=a[(l>>16)+i+(d+8)|0]|0;m=x+4|0;if((m|0)<(c[29388]|0)){w=l+r|0;x=m}else{break}}}}while(0);i=k+1|0;if((i|0)>=(b|0)){break}h=h+(c[29387]|0)|0;k=i;j=c[g>>2]|0}return}function pW(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;do{if((a|0)<0){g=654}else{if((d+a|0)>>>0>(c[29381]|0)>>>0|(b|0)<0){g=654;break}if((e+b|0)>>>0>(c[29382]|0)>>>0){g=654}}}while(0);if((g|0)==654){w1(52432,(g=i,i=i+8|0,c[g>>2]=111456,g)|0);i=g}c[157376]=a;c[157374]=b;c[157372]=d;c[157370]=e;if((e|0)<=0){i=f;return}g=c[157366]|0;h=b;j=e;e=(b|0)%(g|0)|0;b=a;a=d;d=g;while(1){g=d-e|0;k=(g|0)>(j|0)?j:g;g=c[157368]|0;l=(b|0)%(g|0)|0;L920:do{if((a|0)>0){if((k|0)>0){m=b;n=l;o=a;p=g}else{q=l;r=a;while(1){s=g-q|0;t=r-((s|0)>(r|0)?r:s)|0;if((t|0)>0){q=0;r=t}else{break L920}}}while(1){r=p-n|0;q=(r|0)>(o|0)?o:r;r=c[157362]|0;t=(ab(r,e)|0)+n|0;s=(c[157364]|0)+t|0;t=(ab(c[29380]|0,h)|0)+m|0;u=0;v=s;s=(c[29376]|0)+t|0;while(1){yJ(s|0,v|0,q)|0;t=u+1|0;if((t|0)<(k|0)){u=t;v=v+r|0;s=s+(c[29380]|0)|0}else{break}}s=o-q|0;if((s|0)<=0){break L920}m=q+m|0;n=0;o=s;p=c[157368]|0}}}while(0);g=j-k|0;if((g|0)<=0){break}h=k+h|0;j=g;e=0;b=c[157376]|0;a=c[157372]|0;d=c[157366]|0}i=f;return}function pX(){return}function pY(){return}function pZ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[29382]|0;if((b|0)<=0){return}d=0;e=c[29381]|0;f=b;while(1){b=c[29376]|0;g=ab(c[29380]|0,d)|0;h=d<<1&2;if((e|0)>0){i=0;j=e;while(1){if((i&3|0)==(h|0)){k=j}else{a[b+(i+g)|0]=0;k=c[29381]|0}l=i+1|0;if((l|0)<(k|0)){i=l;j=k}else{break}}m=k;n=c[29382]|0}else{m=e;n=f}j=d+1|0;if((j|0)<(n|0)){d=j;e=m;f=n}else{break}}return}function p_(a){a=a|0;var b=0,d=0,e=0,f=0.0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+32|0;d=b|0;e=b+24|0;if((c[46140]|0)==0){i=b;return}c[46140]=0;if((c[353150]|0)>>>0>1){nf()}f=+wZ();do{g=c[45876]|0;c[278816]=g;if((c[45874]|0)>0){h=g;g=0;j=0;while(1){do{if((c[h>>2]|0)==0){k=g}else{if((c[h+80>>2]|0)==0){k=g;break}l=(r7(c[h+24>>2]|0)|0)==0;m=c[278816]|0;n=c[m+24>>2]|0;if(l){r4(n)|0;k=g+1|0;break}else{l=m+64|0;r5(n,l)|0;nT((c[278816]|0)+64|0);k=g;break}}}while(0);l=j+1|0;n=(c[278816]|0)+33032|0;c[278816]=n;if((l|0)<(c[45874]|0)){h=n;g=k;j=l}else{o=k;break}}}else{o=0}}while(!(+wZ()-f>3.0|(o|0)==0));c[d+8>>2]=e;c[d+12>>2]=4;c[d+16>>2]=0;nV(d,2);e=r8(d,5.0)|0;if((e|0)!=0){oW(68576,(d=i,i=i+16|0,c[d>>2]=111264,c[d+8>>2]=e,d)|0);i=d}d=c[45876]|0;c[278816]=d;e=c[45874]|0;if((e|0)>0){o=d;k=0;j=e;while(1){if((c[o>>2]|0)==0){p=o;q=j}else{p5(a);p=c[278816]|0;q=c[45874]|0}e=k+1|0;g=p+33032|0;c[278816]=g;if((e|0)<(q|0)){o=g;k=e;j=q}else{break}}r=c[45876]|0}else{r=d}yG(184560,0,111104);yG(r|0,0,(c[45875]|0)*33032|0|0);i=b;return}function p$(){var a=0,b=0,d=0,e=0,f=0,g=0;a=i;c[45874]=1;b=ob(84040)|0;do{if((b|0)==0){c[353150]=1}else{c[353150]=0;if((b|0)==((c[353050]|0)-1|0)){c[45874]=8;break}else{c[45874]=nE(c[(c[353048]|0)+(b+1<<2)>>2]|0)|0;break}}}while(0);b=ob(81640)|0;do{if((b|0)==0){d=c[45874]|0;e=717}else{if((c[353150]|0)==0){w1(79776,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f}if((b|0)==((c[353050]|0)-1|0)){c[45874]=8;g=8;break}else{f=nE(c[(c[353048]|0)+(b+1<<2)>>2]|0)|0;c[45874]=f;d=f;e=717;break}}}while(0);do{if((e|0)==717){if((d|0)<1){c[45874]=8;g=8;break}if((d|0)<=16){g=d;break}c[45874]=16;g=16}}while(0);d=(g|0)<4?4:g;c[45875]=d;c[45876]=x1(d*33032|0,78176)|0;if((c[45874]|0)>1){pa(97272,1.0);i=a;return}else{pa(97272,0.0);i=a;return}}function p0(){qN();pb(18664);pb(18600);pb(1952);pb(3768);pb(19432);pb(1752);pb(1896);pb(5088);pb(15008);pb(3576);pb(20248);pb(21360);pb(14816);pb(1840);pb(20192);if((ob(76848)|0)==0){p$();h[2324]=1.0;return}pa(103728,1.0);p$();h[2324]=1.0;return}function p1(){var a=0,b=0,d=0,e=0;a=i;if(((c[278176]|0)==0&c[278808]|0)==0){i=a;return}b=oh(75376,(d=i,i=i+8|0,c[d>>2]=1411672,d)|0)|0;i=d;e=dc(b|0,74488)|0;if((e|0)==0){oW(73504,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}q_(e);pd(e);if((c[278468]&1|0)!=0){a5(72552,7,1,e|0)|0}aS(e|0)|0;i=a;return}function p2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;nV((c[278816]|0)+64|0,8);f=e;c[f>>2]=b;c[f+4>>2]=0;n$((c[278816]|0)+64|0,a,e|0);i=d;return}function p3(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+16|0;e=d|0;f=c[45874]|0;if((f|0)<=0){i=d;return}g=e|0;h=e;e=0;j=f;while(1){f=c[45876]|0;do{if((c[f+(e*33032|0)>>2]|0)==0){k=j}else{if((c[f+(e*33032|0)+4>>2]|0)==0){k=j;break}nV(f+(e*33032|0)+64|0,8);c[h>>2]=b;c[h+4>>2]=0;n$((c[45876]|0)+(e*33032|0)+64|0,a,g);k=c[45874]|0}}while(0);f=e+1|0;if((f|0)<(k|0)){e=f;j=k}else{break}}i=d;return}function p4(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;nV((c[278816]|0)+64|0,9);f=e;c[f>>2]=b;c[f+4>>2]=0;n$((c[278816]|0)+64|0,a,e|0);i=d;return}function p5(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;if((b|0)==0){if((r7(c[(c[278816]|0)+24>>2]|0)|0)!=0){nV((c[278816]|0)+64|0,2);b=c[278816]|0;e=c[b+24>>2]|0;f=b+64|0;r5(e,f)|0}f=c[278816]|0;e=c[f+32852>>2]|0;do{if((e|0)==0){g=f}else{if((c[f+4>>2]|0)==0){g=f;break}b=(c[157712]|0)+112|0;h=c[b>>2]|0;c[b>>2]=e-(c[49322]|0);tm(c[(c[157712]|0)+356>>2]|0);c[(c[157712]|0)+112>>2]=h;g=c[278816]|0}}while(0);wD(71560,(e=i,i=i+8|0,c[e>>2]=g+32856,e)|0);i=e}r3(c[(c[278816]|0)+24>>2]|0);c[(c[278816]|0)+24>>2]=0;c[c[278816]>>2]=0;a[(c[278816]|0)+32856|0]=0;c[(c[278816]|0)+33024>>2]=-999999;c[169356]=(c[169356]|0)-1;e=c[45874]|0;if((e|0)<=0){i=d;return}g=0;f=c[45876]|0;h=e;while(1){if((c[f>>2]|0)==0){j=h}else{e=f+64|0;nV(e,13);nV(e,((c[278816]|0)-(c[45876]|0)|0)/33032|0);n_(e,2659272);nV(e,14);nV(e,((c[278816]|0)-(c[45876]|0)|0)/33032|0);nW(e,0);nV(e,17);nV(e,((c[278816]|0)-(c[45876]|0)|0)/33032|0);nV(e,0);j=c[45874]|0}e=g+1|0;if((e|0)<(j|0)){g=e;f=f+33032|0;h=j}else{break}}i=d;return}function p6(){var a=0,b=0;a=i;oX(67512,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;pE();rF();b=c[278810]|0;if((b|0)!=0){x3(b)}c[353704]=0;yG(184560|0,0|0,111104|0);yG(2568976|0,0|0,9200|0);i=a;return}function p7(a){a=+a;var b=0,d=0,e=0,f=0,j=0,k=0.0,l=0.0,m=0.0,n=0,o=0;b=i;d=1;e=0;f=i;i=i+168|0;c[f>>2]=0;while(1)switch(d|0){case 1:j=yH(1115280,d,f)|0;d=26;break;case 26:if((j|0)==0){d=2;break}else{d=25;break};case 2:aF(36)|0;if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;k=a+ +h[1153];h[1153]=k;l=k- +h[1861];if((c[353698]|0)==0&l<.013888888888888888){d=25;break}else{d=3;break};case 3:h[2332]=l;h[1861]=k;m=+g[4670];if(m>0.0){d=4;break}else{d=5;break};case 4:h[2332]=m;d=9;break;case 5:if(l>.1){d=6;break}else{d=7;break};case 6:h[2332]=.1;d=9;break;case 7:if(l<.001){d=8;break}else{d=9;break};case 8:h[2332]=.001;d=9;break;case 9:aI(300);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(96);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(382);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(138);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;if((c[46140]|0)==0){d=11;break}else{d=10;break};case 10:aI(82);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;d=11;break;case 11:n=aF(12)|0;if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;if((n|0)==0){d=13;break}else{o=n;d=12;break};case 12:al(58,66448,(n=i,i=i+8|0,c[n>>2]=o,n)|0);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;i=n;n=aF(12)|0;if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;if((n|0)==0){d=13;break}else{o=n;d=12;break};case 13:if((c[46140]|0)==0){d=18;break}else{d=14;break};case 14:g[(c[157712]|0)+128>>2]=+h[2332];aI(286);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(250);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(312);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;if((c[46141]|0)==0){d=15;break}else{d=17;break};case 15:if((c[45874]|0)>1|(c[278172]|0)==0){d=16;break}else{d=17;break};case 16:aI(136);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;d=17;break;case 17:aI(468);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;if((c[46140]|0)==0){d=18;break}else{d=19;break};case 18:aI(82);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;d=19;break;case 19:h[2324]=+h[2332]+ +h[2324];if((c[353150]|0)>>>0>1){d=20;break}else{d=21;break};case 20:aF(40)|0;if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;d=21;break;case 21:aI(396);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(30);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;if((c[353150]|0)==4){d=22;break}else{d=23;break};case 22:aJ(12,629696,117328,117312,117296);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(516);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;d=24;break;case 23:aJ(12,117584,117584,117584,117584);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;d=24;break;case 24:aI(384);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;c[278812]=(c[278812]|0)+1;c[350560]=(c[350560]|0)+1;d=25;break;case 25:i=b;return;case-1:if((e|0)==1){j=t;d=26}s=t=0;break}}function p8(a){a=+a;var b=0,d=0.0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;if(+g[946]==0.0){p7(a);i=b;return}d=+wZ();p7(a);a=+wZ()-d;d=+h[14044]+a;h[14044]=d;e=(c[667358]|0)+1|0;c[667358]=e;if((e|0)<1e3){i=b;return}f=~~(d*1.0e3/+(e|0));c[667358]=0;h[14044]=0.0;e=c[45874]|0;if((e|0)>0){j=c[45876]|0;k=0;l=0;while(1){m=((c[j+(l*33032|0)>>2]|0)!=0)+k|0;n=l+1|0;if((n|0)<(e|0)){k=m;l=n}else{o=m;break}}}else{o=0}oW(65528,(l=i,i=i+16|0,c[l>>2]=o,c[l+8>>2]=f,l)|0);i=l;i=b;return}function p9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+4112|0;e=d|0;f=e;c[f>>2]=b;c[f+4>>2]=0;f=d+16|0;bV(f|0,4096,a|0,e|0)|0;oX(89664,(e=i,i=i+16|0,c[e>>2]=111304,c[e+8>>2]=f,e)|0);i=e;if((c[46140]|0)!=0){p_(0)}if((c[353150]|0)==0){w1(87976,(e=i,i=i+16|0,c[e>>2]=111304,c[e+8>>2]=f,e)|0);i=e}if((c[353663]|0)==-1){nf();eQ(1115280,1)}else{nj();eQ(1115280,1)}}function qa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+4112|0;f=e|0;if(a[112360]|0){w1(86280,(g=i,i=i+8|0,c[g>>2]=111288,g)|0);i=g}a[112360]=1;vf();h=f;c[h>>2]=d;c[h+4>>2]=0;h=e+16|0;bV(h|0,4096,b|0,f|0)|0;oW(89664,(g=i,i=i+16|0,c[g>>2]=111288,c[g+8>>2]=h,g)|0);i=g;if((c[46140]|0)!=0){p_(0)}if((c[353150]|0)!=0){nf();c[353663]=-1;a[112360]=0;eQ(1115280,1)}w1(87976,(g=i,i=i+16|0,c[g>>2]=111288,c[g+8>>2]=h,g)|0);i=g;nf();c[353663]=-1;a[112360]=0;eQ(1115280,1)}function qb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0;b=i;d=1;e=0;f=i;i=i+168|0;c[f>>2]=0;while(1)switch(d|0){case 1:c[220092]=(c[836]|0)==0?6619136:5570560;g=an(68,64648)|0;if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;if((g|0)==0){d=2;break}else{d=3;break};case 2:j=a+16|0;d=4;break;case 3:g=a+16|0;c[g>>2]=c[220092];j=g;d=4;break;case 4:g=a;c[278802]=c[g>>2];c[278803]=c[g+4>>2];c[278804]=c[g+8>>2];c[278805]=c[g+12>>2];c[278806]=c[g+16>>2];k=c[j>>2]|0;if((k|0)<(c[220092]|0)){d=5;break}else{d=6;break};case 5:al(46,63832,(l=i,i=i+8|0,h[l>>3]=+(k|0)*9.5367431640625e-7,l)|0);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;i=l;d=6;break;case 6:c[353050]=c[a+4>>2];c[353048]=c[a+8>>2];al(20,c[a+12>>2]|0,c[j>>2]|0);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(178);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(520);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(72);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(54);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(22);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(224);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;ak(32,63016);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(508);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(392);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(512);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(116);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;g=aF(14)|0;if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;ak(24,g|0);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(84);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(374);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;al(42,62480,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;i=l;al(42,61712,(l=i,i=i+8|0,h[l>>3]=+(c[j>>2]|0)*9.5367431640625e-7,l)|0);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;i=l;aI(198);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;if((c[353150]|0)==0){d=12;break}else{d=7;break};case 7:g=an(18,60536)|0;if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;c[278818]=g;if((g|0)==0){d=8;break}else{d=9;break};case 8:al(46,59432,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;i=l;d=9;break;case 9:g=an(18,58968)|0;if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;c[278814]=g;if((g|0)==0){d=10;break}else{d=11;break};case 10:al(46,58448,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;i=l;d=11;break;case 11:ak(82,c[278818]|0);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(332);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(228);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(194);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(216);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aF(8)|0;if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(256);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(36);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(206);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;d=12;break;case 12:aD(24,0,57880)|0;if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;g=aF(30)|0;if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;c[278810]=g;c[278808]=1;al(72,57336,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;i=l;m=yH(1115280,d,f)|0;d=15;break;case 15:if((m|0)==0){d=13;break}else{d=14;break};case 13:ak(130,56920);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;aI(382);if((s|0)!=0&(t|0)!=0){e=yI(c[s>>2]|0,f)|0;if((e|0)>0){d=-1;break}else return}s=t=0;d=14;break;case 14:i=b;return;case-1:if((e|0)==12){m=t;d=15}s=t=0;break}}function qc(){if(a[112344]|0){dl(3312)|0;return}a[112344]=1;c[155168]=1;p1();m2();se();vG();xw();if((c[353150]|0)==0){return}xI();return}function qd(){if((c[278172]|0)!=1&(c[353150]|0)!=0){rj();return}else{nf();p_(0);wW();return}}function qe(){var a=0,b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=i;do{if((c[353058]|0)==1){if((c[46140]|0)!=0){b=42;break}oF();i=a;return}else{b=12}}while(0);d=o8(93288)|0;ft[b&127](49024,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e;ft[b&127](75464,(e=i,i=i+8|0,c[e>>2]=64704,e)|0);i=e;if((c[45868]|0)!=0){ft[b&127](57392,(e=i,i=i+8|0,c[e>>2]=677440,e)|0);i=e}ft[b&127](52208,(e=i,i=i+8|0,c[e>>2]=184604,e)|0);i=e;d=c[45874]|0;ft[b&127](48464,(e=i,i=i+16|0,c[e>>2]=c[169356],c[e+8>>2]=d,e)|0);i=e;d=c[45874]|0;if((d|0)<=0){i=a;return}f=c[45876]|0;j=0;k=d;while(1){if((c[f>>2]|0)==0){l=k;m=j+1|0}else{d=f+24|0;n=~~(+h[1884]- +h[(c[d>>2]|0)+8>>3]);o=(n|0)/60|0;do{if((n+59|0)>>>0>118){p=n+(o*-60|0)|0;q=(n|0)/3600|0;if((n+3599|0)>>>0<=7198){r=q;s=o;t=p;break}r=q;s=(q*-60|0)+o|0;t=p}else{r=0;s=o;t=n}}while(0);n=j+1|0;o=~~+g[(c[f+32852>>2]|0)+292>>2];ft[b&127](44232,(e=i,i=i+48|0,c[e>>2]=n,c[e+8>>2]=f+32856,c[e+16>>2]=o,c[e+24>>2]=r,c[e+32>>2]=s,c[e+40>>2]=t,e)|0);i=e;ft[b&127](40152,(e=i,i=i+8|0,c[e>>2]=(c[d>>2]|0)+65636,e)|0);i=e;l=c[45874]|0;m=n}if((m|0)<(l|0)){f=f+33032|0;j=m;k=l}else{break}}i=a;return}function qf(){var a=0,b=0,d=0;a=i;if((c[353058]|0)==1){oF();i=a;return}if(+g[(c[157712]|0)+140>>2]!=0.0){i=a;return}b=(c[45880]|0)+400|0;g[b>>2]=+(~~+g[b>>2]^64|0);if((~~+g[(c[45880]|0)+400>>2]&64|0)==0){p2(36824,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}else{p2(107088,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}}function qg(){var a=0,b=0,d=0;a=i;if((c[353058]|0)==1){oF();i=a;return}if(+g[(c[157712]|0)+140>>2]!=0.0){i=a;return}b=(c[45880]|0)+400|0;g[b>>2]=+(~~+g[b>>2]^128|0);if((~~+g[(c[45880]|0)+400>>2]&128|0)==0){p2(103496,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}else{p2(100664,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}}function qh(){var a=0,b=0,d=0;a=i;if((c[353058]|0)==1){oF();i=a;return}if(+g[(c[157712]|0)+140>>2]!=0.0){i=a;return}b=(c[45880]|0)+128|0;if(+g[b>>2]!=8.0){c[159948]=1;g[b>>2]=8.0;p2(99016,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}else{c[159948]=0;g[b>>2]=3.0;p2(97072,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}}function qi(){var a=0,b=0,d=0;a=i;if((c[353058]|0)==1){oF();i=a;return}if(+g[(c[157712]|0)+140>>2]!=0.0){i=a;return}b=(c[45880]|0)+128|0;if(+g[b>>2]!=5.0){g[b>>2]=5.0;p2(94744,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}else{g[b>>2]=3.0;p2(93056,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}}function qj(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0;a=i;if((c[353058]|0)==1){oF();i=a;return}p2(91408,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;d=c[45874]|0;if((d|0)<=0){i=a;return}e=0;f=c[45876]|0;h=d;while(1){if((c[f>>2]|0)==0){j=h}else{p2(89512,(b=i,i=i+16|0,c[b>>2]=~~((+g[f+32892>>2]+0.0+ +g[f+32896>>2]+ +g[f+32900>>2]+ +g[f+32904>>2]+ +g[f+32908>>2]+ +g[f+32912>>2]+ +g[f+32916>>2]+ +g[f+32920>>2]+ +g[f+32924>>2]+ +g[f+32928>>2]+ +g[f+32932>>2]+ +g[f+32936>>2]+ +g[f+32940>>2]+ +g[f+32944>>2]+ +g[f+32948>>2]+ +g[f+32952>>2])*.0625*1.0e3),c[b+8>>2]=f+32856,b)|0);i=b;j=c[45874]|0}d=e+1|0;if((d|0)<(j|0)){e=d;f=f+33032|0;h=j}else{break}}i=a;return}function qk(){var b=0,d=0,e=0;b=i;i=i+64|0;if((c[353058]|0)!=1){i=b;return}if((oq()|0)>=2){c[353663]=-1;nf();p_(0);c[278172]=0;ve();c[45877]=0;d=b|0;e=os(1)|0;yQ(d|0,e|0)|0;wd(d);if(!((c[46140]|0)!=0&(c[353150]|0)!=0)){i=b;return}a[1412604]=0;if((oq()|0)>2){d=2;do{yR(1412604,os(d)|0)|0;e=1412604+(yF(1412604)|0)|0;x=32;a[e]=x&255;x=x>>8;a[e+1|0]=x&255;d=d+1|0;}while((d|0)<(oq()|0))}oy(76816,1);i=b;return}oW(87904,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;e=c[353150]|0;if((e|0)!=0){if(e>>>0<=1){i=b;return}oW(81528,(d=i,i=i+16|0,c[d>>2]=2577828,c[d+8>>2]=2577764,d)|0);i=d;i=b;return}if((c[46140]|0)==0){oW(83776,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=b;return}else{oW(86160,(d=i,i=i+8|0,c[d>>2]=184604,d)|0);i=d;i=b;return}}function ql(){var a=0,b=0,d=0;a=i;i=i+64|0;if((oq()|0)!=2){oW(75320,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}if((c[46140]|0)==0|(c[353697]|0)!=0){oW(74448,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}else{wc();b=a|0;d=os(1)|0;yQ(b|0,d|0)|0;wd(b);i=a;return}}function qm(){var a=0,b=0;a=i;i=i+64|0;if((c[46140]|0)==0|(c[353697]|0)!=0|(c[353058]|0)!=1){i=a;return}b=a|0;yQ(b|0,184604)|0;wd(b);i=a;return}function qn(){var a=0,b=0;a=i;ve();c[353704]=0;if((c[353150]|0)>>>0>=2){c[353150]=2;i=a;return}qa(73456,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;c[353150]=2;i=a;return}function qo(){var a=0,b=0;a=i;i=i+64|0;c[353663]=-1;if((c[353697]|0)!=0){m6();nf()}b=a|0;yQ(b|0,os(1)|0)|0;nh(b);ve();c[353704]=0;if((c[353150]|0)>>>0>=2){c[353150]=2;i=a;return}qa(73456,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;c[353150]=2;i=a;return}function qp(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0;b=i;i=i+320|0;d=b|0;e=b+24|0;f=b+280|0;if((c[353058]|0)!=1){i=b;return}if((c[46140]|0)==0){oW(71528,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;i=b;return}if((c[642381]|0)!=0){oW(70016,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;i=b;return}if((c[45874]|0)!=1){oW(68544,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;i=b;return}if((oq()|0)!=2){oW(67408,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;i=b;return}if((bw(os(1)|0,66440)|0)!=0){oW(65488,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;i=b;return}k=c[45874]|0;L1287:do{if((k|0)>0){l=c[45876]|0;m=0;while(1){if((c[l+(m*33032|0)>>2]|0)!=0){if(+g[(c[l+(m*33032|0)+32852>>2]|0)+288>>2]<=0.0){break}}m=m+1|0;if((m|0)>=(k|0)){break L1287}}oW(64608,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;i=b;return}}while(0);k=e|0;e=os(1)|0;cl(k|0,63824,(j=i,i=i+24|0,c[j>>2]=1411672,c[j+8>>2]=47,c[j+16>>2]=e,j)|0)|0;i=j;n9(k,63008);oW(62456,(j=i,i=i+8|0,c[j>>2]=k,j)|0);i=j;e=dc(k|0,61704)|0;if((e|0)==0){oW(60424,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;i=b;return}en(e|0,59424,(j=i,i=i+8|0,c[j>>2]=5,j)|0)|0;i=j;k=f|0;m=d|0;yG(k|0,32,39);d=yF(2577828)|0;yJ(k|0,2577828,d)|0;d=c[642263]|0;cl(m|0,72536,(j=i,i=i+16|0,c[j>>2]=c[642265],c[j+8>>2]=d,j)|0)|0;i=j;d=f+22|0;l=yF(m|0)|0;yJ(d|0,m|0,l)|0;l=0;do{m=f+l|0;if((a[m]|0)==32){a[m]=95}l=l+1|0;}while((l|0)<39);a[f+39|0]=0;en(e|0,58936,(j=i,i=i+8|0,c[j>>2]=k,j)|0)|0;i=j;k=0;do{en(e|0,58440,(j=i,i=i+8|0,h[j>>3]=+g[(c[45876]|0)+32960+(k<<2)>>2],j)|0)|0;i=j;k=k+1|0;}while((k|0)<16);en(e|0,57872,(j=i,i=i+8|0,c[j>>2]=c[352264],j)|0)|0;i=j;en(e|0,58936,(j=i,i=i+8|0,c[j>>2]=184604,j)|0)|0;i=j;en(e|0,58440,(j=i,i=i+8|0,h[j>>3]=+h[23072],j)|0)|0;i=j;k=0;do{f=c[197024+(k<<2)>>2]|0;if((f|0)==0){a5(57328,2,1,e|0)|0}else{en(e|0,58936,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j}k=k+1|0;}while((k|0)<64);tC(e);if((c[49320]|0)>0){k=0;do{ty(e,tq(k)|0);a_(e|0)|0;k=k+1|0;}while((k|0)<(c[49320]|0))}aS(e|0)|0;oW(56912,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;i=b;return}function qq(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;i=i+33048|0;d=b+192|0;e=b+200|0;f=b+208|0;j=b+32976|0;k=b+32984|0;if((c[353058]|0)!=1){i=b;return}if((oq()|0)!=2){oW(56456,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l;i=b;return}c[353663]=-1;m=b|0;n=os(1)|0;cl(m|0,63824,(l=i,i=i+24|0,c[l>>2]=1411672,c[l+8>>2]=47,c[l+16>>2]=n,l)|0)|0;i=l;n9(m,63008);oW(56064,(l=i,i=i+8|0,c[l>>2]=m,l)|0);i=l;n=dc(m|0,55528)|0;if((n|0)==0){oW(60424,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l;i=b;return}d_(n|0,59424,(l=i,i=i+8|0,c[l>>2]=j,l)|0)|0;i=l;if((c[j>>2]|0)!=5){aS(n|0)|0;oW(54592,(l=i,i=i+16|0,c[l>>2]=c[j>>2],c[l+8>>2]=5,l)|0);i=l;i=b;return}j=f|0;d_(n|0,58936,(l=i,i=i+8|0,c[l>>2]=j,l)|0)|0;i=l;m=k|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=m,l)|0)|0;i=l;o=k+4|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=o,l)|0)|0;i=l;p=k+8|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=p,l)|0)|0;i=l;q=k+12|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=q,l)|0)|0;i=l;r=k+16|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=r,l)|0)|0;i=l;s=k+20|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=s,l)|0)|0;i=l;t=k+24|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=t,l)|0)|0;i=l;u=k+28|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=u,l)|0)|0;i=l;v=k+32|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=v,l)|0)|0;i=l;w=k+36|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=w,l)|0)|0;i=l;x=k+40|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=x,l)|0)|0;i=l;y=k+44|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=y,l)|0)|0;i=l;z=k+48|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=z,l)|0)|0;i=l;A=k+52|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=A,l)|0)|0;i=l;B=k+56|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=B,l)|0)|0;i=l;C=k+60|0;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=C,l)|0)|0;i=l;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=e,l)|0)|0;i=l;k=~~(+g[e>>2]+.1);c[352264]=k;pa(53688,+(k|0));k=b+128|0;d_(n|0,58936,(l=i,i=i+8|0,c[l>>2]=k,l)|0)|0;i=l;d_(n|0,58440,(l=i,i=i+8|0,c[l>>2]=d,l)|0)|0;i=l;ng();wd(k);if((c[46140]|0)==0){oW(53040,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l;i=b;return}c[46141]=1;c[46142]=1;k=0;do{d_(n|0,58936,(l=i,i=i+8|0,c[l>>2]=j,l)|0)|0;i=l;e=x2((yF(j|0)|0)+1|0)|0;yQ(e|0,j|0)|0;c[197024+(k<<2)>>2]=e;k=k+1|0;}while((k|0)<64);L1345:do{if((et(n|0)|0)==0){k=-1;while(1){e=0;while(1){if(e>>>0>=32767){D=e;break}E=bT(n|0)|0;if((E|0)==(-1|0)|(E|0)==0){D=e;break}a[f+e|0]=E&255;F=e+1|0;if((E|0)==125){D=F;break}else{e=F}}if((D|0)==32767){w1(52752,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l}a[f+D|0]=0;e=oa(j)|0;if((a[1410640]|0)==0){G=k;break L1345}if((cS(1410640,52416)|0)!=0){w1(52168,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l}do{if((k|0)==-1){tD(e)}else{F=tq(k)|0;yG(F+96|0,0,c[(c[157544]|0)+56>>2]<<2|0);E=F|0;c[E>>2]=0;tF(e,F)|0;if((c[E>>2]|0)!=0){break}yn(F,0)}}while(0);e=k+1|0;if((et(n|0)|0)==0){k=e}else{G=e;break}}}else{G=-1}}while(0);c[49320]=G;h[23072]=+g[d>>2];aS(n|0)|0;g[(c[45876]|0)+32960>>2]=+g[m>>2];g[(c[45876]|0)+32964>>2]=+g[o>>2];g[(c[45876]|0)+32968>>2]=+g[p>>2];g[(c[45876]|0)+32972>>2]=+g[q>>2];g[(c[45876]|0)+32976>>2]=+g[r>>2];g[(c[45876]|0)+32980>>2]=+g[s>>2];g[(c[45876]|0)+32984>>2]=+g[t>>2];g[(c[45876]|0)+32988>>2]=+g[u>>2];g[(c[45876]|0)+32992>>2]=+g[v>>2];g[(c[45876]|0)+32996>>2]=+g[w>>2];g[(c[45876]|0)+33e3>>2]=+g[x>>2];g[(c[45876]|0)+33004>>2]=+g[y>>2];g[(c[45876]|0)+33008>>2]=+g[z>>2];g[(c[45876]|0)+33012>>2]=+g[A>>2];g[(c[45876]|0)+33016>>2]=+g[B>>2];g[(c[45876]|0)+33020>>2]=+g[C>>2];if((c[353150]|0)==0){i=b;return}nh(51880);ve();c[353704]=0;if((c[353150]|0)>>>0<2){qa(73456,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l}c[353150]=2;i=b;return}function qr(){var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;d=b|0;if((oq()|0)==1){oW(51512,(e=i,i=i+8|0,c[e>>2]=c[5527],e)|0);i=e;i=b;return}f=d|0;if((oq()|0)==2){g=os(1)|0;yP(f|0,g|0,16)|0}else{g=or()|0;yP(f|0,g|0,16)|0}a[d+15|0]=0;if((c[353058]|0)==1){if((cS(c[5527]|0,f|0)|0)==0){i=b;return}o9(51248,f);if((c[353150]|0)>>>0<=1){i=b;return}oF();i=b;return}else{d=c[278816]|0;g=d+32856|0;do{if((a[g]|0)==0){h=d}else{if((cS(g|0,51032)|0)==0){h=d;break}if((cS(g|0,f|0)|0)==0){h=d;break}oW(50272,(e=i,i=i+16|0,c[e>>2]=g,c[e+8>>2]=f,e)|0);i=e;h=c[278816]|0}}while(0);e=h+32856|0;yQ(e|0,f|0)|0;f=to((c[278816]|0)+32856|0)|0;c[(c[(c[278816]|0)+32852>>2]|0)+392>>2]=f;nV(230084,13);nV(230084,((c[278816]|0)-(c[45876]|0)|0)/33032|0);n_(230084,(c[278816]|0)+32856|0);i=b;return}}function qs(){var a=0,b=0;a=i;oW(49712,(b=i,i=i+8|0,c[b>>2]=64704,b)|0);i=b;oW(49304,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}function qt(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+64|0;e=d|0;do{if((c[353058]|0)==1){if((c[353150]|0)==0){f=1;h=0;break}oF();i=d;return}else{f=0;h=b}}while(0);if((oq()|0)<2){i=d;return}b=c[278816]|0;j=e|0;if((f|0)==0){f=b+32856|0;cl(j|0,49016,(k=i,i=i+16|0,c[k>>2]=1,c[k+8>>2]=f,k)|0)|0;i=k}else{f=c[4635]|0;cl(j|0,48696,(k=i,i=i+16|0,c[k>>2]=1,c[k+8>>2]=f,k)|0)|0;i=k}f=yF(j|0)|0;l=64-f-2|0;m=or()|0;if((a[m]|0)==34){n=m+1|0;o=(yF(m|0)|0)-2|0;p=o>>>0<l>>>0?o:l;ev(j|0,n|0,p|0)|0;p=(yF(m|0)|0)-2|0;a[e+((p>>>0<l>>>0?p:l)+f)|0]=0}else{ev(j|0,m|0,l|0)|0;p=yF(m|0)|0;a[e+((p>>>0<l>>>0?p:l)+f)|0]=0}f=e+(yF(j|0)|0)|0;x=10;a[f]=x&255;x=x>>8;a[f+1|0]=x&255;f=c[45876]|0;l=c[45874]|0;L1416:do{if((l|0)>0){p=b+32852|0;if((h|0)==0){m=0;n=f;o=l;while(1){do{if((n|0)==0){q=o}else{if((c[n>>2]|0)==0){q=o;break}if((c[n+4>>2]|0)==0){q=o;break}c[278816]=n;p2(48168,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;q=c[45874]|0}}while(0);r=m+1|0;if((r|0)<(q|0)){m=r;n=n+33032|0;o=q}else{break L1416}}}else{s=0;t=f;u=l}while(1){do{if((t|0)==0){v=u}else{if((c[t>>2]|0)==0){v=u;break}if((c[t+4>>2]|0)==0){v=u;break}if(+g[478]!=0.0){if(+g[(c[t+32852>>2]|0)+408>>2]!=+g[(c[p>>2]|0)+408>>2]){v=u;break}}c[278816]=t;p2(48168,(k=i,i=i+8|0,c[k>>2]=j,k)|0);i=k;v=c[45874]|0}}while(0);o=s+1|0;if((o|0)<(v|0)){s=o;t=t+33032|0;u=v}else{break}}}}while(0);c[278816]=b;wD(48168,(k=i,i=i+8|0,c[k>>2]=e+1,k)|0);i=k;i=d;return}function qu(){qt(0);return}function qv(){qt(1);return}function qw(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+64|0;d=b|0;if((c[353058]|0)==1){oF();i=b;return}if((oq()|0)<3){i=b;return}e=d|0;yQ(e|0,(c[278816]|0)+32856|0)|0;f=d+(yF(e|0)|0)|0;a[f]=a[47744]|0;a[f+1|0]=a[47745|0]|0;a[f+2|0]=a[47746|0]|0;f=yF(e|0)|0;g=64-f-2|0;h=or()|0;if((a[h]|0)==34){j=h+1|0;k=(yF(h|0)|0)-2|0;l=(k|0)<(g|0)?k:g;ev(e|0,j|0,l|0)|0;l=(yF(h|0)|0)-2|0;a[d+(((l|0)<(g|0)?l:g)+f)|0]=0}else{ev(e|0,h|0,g|0)|0;l=yF(h|0)|0;a[d+(((l|0)<(g|0)?l:g)+f)|0]=0}f=d+(yF(e|0)|0)|0;x=10;a[f]=x&255;x=x>>8;a[f+1|0]=x&255;f=c[278816]|0;d=c[45874]|0;L1452:do{if((d|0)>0){g=0;l=c[45876]|0;h=d;L1454:while(1){do{if((c[l>>2]|0)==0){m=h}else{if((c[l+4>>2]|0)==0){m=h;break}if((yM(l+32856|0,os(1)|0)|0)==0){break L1454}m=c[45874]|0}}while(0);j=g+1|0;if((j|0)<(m|0)){g=j;l=l+33032|0;h=m}else{break L1452}}c[278816]=l;p2(48168,(h=i,i=i+8|0,c[h>>2]=e,h)|0);i=h}}while(0);c[278816]=f;i=b;return}function qx(){var a=0,b=0,d=0,e=0;a=i;if((oq()|0)==1){b=~~+g[5600];oW(47496,(d=i,i=i+16|0,c[d>>2]=b>>4,c[d+8>>2]=b&15,d)|0);i=d;oW(47184,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}d=(oq()|0)==2;b=fi(os(1)|0)|0;if(d){e=b}else{e=fi(os(2)|0)|0}d=b&15;b=e&15;e=b>>>0>13?13:b;b=e|(d>>>0>13?208:d<<4);if((c[353058]|0)!=1){c[(c[278816]|0)+32888>>2]=b;g[(c[(c[278816]|0)+32852>>2]|0)+408>>2]=+(e+1|0);nV(230084,17);nV(230084,((c[278816]|0)-(c[45876]|0)|0)/33032|0);nV(230084,c[(c[278816]|0)+32888>>2]|0);i=a;return}pa(46400,+(b|0));if((c[353150]|0)>>>0<=1){i=a;return}oF();i=a;return}function qy(){var a=0,b=0;a=i;if((c[353058]|0)==1){oF();i=a;return}if(+g[(c[45880]|0)+288>>2]>0.0){g[(c[157712]|0)+124>>2]=+h[23072];c[(c[157712]|0)+112>>2]=(c[45880]|0)-(c[49322]|0);tm(c[(c[157712]|0)+344>>2]|0);i=a;return}else{p2(45608,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}}function qz(){var a=0,b=0,d=0,e=0;a=i;if((c[353058]|0)==1){oF();i=a;return}if(+g[3708]==0.0){p2(45152,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}d=c[46141]|0;c[46141]=d^1;e=ti(c[(c[45880]|0)+392>>2]|0)|0;if((d|0)==1){p3(44536,(b=i,i=i+8|0,c[b>>2]=e,b)|0);i=b}else{p3(44776,(b=i,i=i+8|0,c[b>>2]=e,b)|0);i=b}nV(230084,24);nV(230084,c[46141]|0);i=a;return}function qA(){var a=0,b=0,d=0;a=i;if((c[353058]|0)==1){oW(44160,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}d=c[278816]|0;if((c[d+4>>2]|0)==0){nZ(d+64|0,c[65720]|0,c[65722]|0);nV((c[278816]|0)+64|0,25);nV((c[278816]|0)+64|0,2);c[(c[278816]|0)+12>>2]=1;i=a;return}else{oW(43888,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}}function qB(){var a=0,b=0,d=0,e=0,f=0.0,j=0;a=i;if((c[353058]|0)==1){oW(43576,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}d=c[278816]|0;if((c[d+4>>2]|0)!=0){oW(43216,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}if((c[46142]|0)==0){e=c[d+32852>>2]|0;yG(e+96|0,0,c[(c[157544]|0)+56>>2]<<2|0);g[e+404>>2]=+(tx(e)|0);g[e+408>>2]=+((c[(c[278816]|0)+32888>>2]&15)+1|0);c[e+392>>2]=to((c[278816]|0)+32856|0)|0;g[(c[157712]|0)+172>>2]=+g[(c[278816]|0)+32960>>2];g[(c[157712]|0)+176>>2]=+g[(c[278816]|0)+32964>>2];g[(c[157712]|0)+180>>2]=+g[(c[278816]|0)+32968>>2];g[(c[157712]|0)+184>>2]=+g[(c[278816]|0)+32972>>2];g[(c[157712]|0)+188>>2]=+g[(c[278816]|0)+32976>>2];g[(c[157712]|0)+192>>2]=+g[(c[278816]|0)+32980>>2];g[(c[157712]|0)+196>>2]=+g[(c[278816]|0)+32984>>2];g[(c[157712]|0)+200>>2]=+g[(c[278816]|0)+32988>>2];g[(c[157712]|0)+204>>2]=+g[(c[278816]|0)+32992>>2];g[(c[157712]|0)+208>>2]=+g[(c[278816]|0)+32996>>2];g[(c[157712]|0)+212>>2]=+g[(c[278816]|0)+33e3>>2];g[(c[157712]|0)+216>>2]=+g[(c[278816]|0)+33004>>2];g[(c[157712]|0)+220>>2]=+g[(c[278816]|0)+33008>>2];g[(c[157712]|0)+224>>2]=+g[(c[278816]|0)+33012>>2];g[(c[157712]|0)+228>>2]=+g[(c[278816]|0)+33016>>2];g[(c[157712]|0)+232>>2]=+g[(c[278816]|0)+33020>>2];g[(c[157712]|0)+124>>2]=+h[23072];c[(c[157712]|0)+112>>2]=(c[45880]|0)-(c[49322]|0);tm(c[(c[157712]|0)+348>>2]|0);f=+wZ();e=c[278816]|0;if(f- +h[(c[e+24>>2]|0)+8>>3]<=+h[23072]){wD(42848,(b=i,i=i+8|0,c[b>>2]=e+32856,b)|0);i=b}tm(c[(c[157712]|0)+352>>2]|0);j=c[278816]|0}else{c[46141]=0;j=d}nT(j+64|0);nV((c[278816]|0)+64|0,7);nY((c[278816]|0)+64|0,+h[23072]);if((c[45874]|0)>0){j=0;d=c[45876]|0;while(1){nV((c[278816]|0)+64|0,13);nV((c[278816]|0)+64|0,j);n_((c[278816]|0)+64|0,d+32856|0);nV((c[278816]|0)+64|0,14);nV((c[278816]|0)+64|0,j);nW((c[278816]|0)+64|0,c[d+33024>>2]|0);nV((c[278816]|0)+64|0,17);nV((c[278816]|0)+64|0,j);nV((c[278816]|0)+64|0,c[d+32888>>2]|0);b=j+1|0;if((b|0)<(c[45874]|0)){j=b;d=d+33032|0}else{break}}}d=0;j=(c[278816]|0)+64|0;do{nV(j,12);nV((c[278816]|0)+64|0,d<<24>>24);n_((c[278816]|0)+64|0,c[197024+(d<<2)>>2]|0);d=d+1|0;j=(c[278816]|0)+64|0}while((d|0)<64);nV(j,3);nV((c[278816]|0)+64|0,11);nX((c[278816]|0)+64|0,~~+g[(c[157712]|0)+156>>2]);nV((c[278816]|0)+64|0,3);nV((c[278816]|0)+64|0,12);nX((c[278816]|0)+64|0,~~+g[(c[157712]|0)+160>>2]);nV((c[278816]|0)+64|0,3);nV((c[278816]|0)+64|0,13);nX((c[278816]|0)+64|0,~~+g[(c[157712]|0)+164>>2]);nV((c[278816]|0)+64|0,3);nV((c[278816]|0)+64|0,14);nX((c[278816]|0)+64|0,~~+g[(c[157712]|0)+168>>2]);j=tq((((c[278816]|0)-(c[45876]|0)|0)/33032|0)+1|0)|0;nV((c[278816]|0)+64|0,10);n2((c[278816]|0)+64|0,+g[j+172>>2]);n2((c[278816]|0)+64|0,+g[j+176>>2]);n2((c[278816]|0)+64|0,0.0);v6(c[45880]|0,(c[278816]|0)+64|0);nV((c[278816]|0)+64|0,25);nV((c[278816]|0)+64|0,3);c[(c[278816]|0)+12>>2]=1;i=a;return}function qC(){var a=0,b=0;a=i;if((c[353058]|0)==1){oW(42400,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}else{c[(c[278816]|0)+4>>2]=1;i=a;return}}function qD(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;do{if((c[353058]|0)==1){if((c[46140]|0)!=0){break}oF();i=b;return}else{if(+g[(c[157712]|0)+140>>2]==0.0){break}i=b;return}}while(0);d=c[278816]|0;do{if((oq()|0)>2){if((cS(os(1)|0,41600)|0)!=0){e=1163;break}f=~~(+nF(os(2)|0)+-1.0);h=c[45874]|0;if(!((f|0)>-1&(f|0)<(h|0))){i=b;return}j=(c[45876]|0)+(f*33032|0)|0;if((c[j>>2]|0)==0){i=b;return}else{c[278816]=j;k=1;l=f;m=h;break}}else{e=1163}}while(0);L1562:do{if((e|0)==1163){h=c[45876]|0;c[278816]=h;f=c[45874]|0;if((f|0)>0){n=h;o=0;p=f}else{k=0;l=0;m=f;break}while(1){if((c[n>>2]|0)==0){q=n;r=p}else{if((yM(n+32856|0,os(1)|0)|0)==0){break}q=c[278816]|0;r=c[45874]|0}f=o+1|0;h=q+33032|0;c[278816]=h;if((f|0)<(r|0)){n=h;o=f;p=r}else{k=0;l=f;m=r;break L1562}}k=0;l=o;m=c[45874]|0}}while(0);if((l|0)<(m|0)){if((c[353058]|0)==1){s=(c[353150]|0)==0?41160:c[5527]|0}else{s=d+32856|0}if((c[278816]|0)==(d|0)){i=b;return}do{if((oq()|0)>2){m=oa(or()|0)|0;if((k|0)==0){t=m}else{l=m;while(1){m=l+1|0;if((a[m]|0)==32){l=m}else{break}}t=l+((yF(os(2)|0)|0)+1)|0}while(1){if((a[t]|0)==32){t=t+1|0}else{break}}if((t|0)==0){e=1181;break}p2(40736,(u=i,i=i+16|0,c[u>>2]=s,c[u+8>>2]=t,u)|0);i=u}else{e=1181}}while(0);if((e|0)==1181){p2(40408,(u=i,i=i+8|0,c[u>>2]=s,u)|0);i=u}p5(0)}c[278816]=d;i=b;return}function qE(){var b=0,d=0,e=0,f=0,h=0,i=0,j=0.0;if((c[353058]|0)==1){oF();return}if(+g[(c[157712]|0)+140>>2]!=0.0){return}b=os(1)|0;d=fi(os(2)|0)|0;e=a[b]|0;f=e<<24>>24;switch(f|0){case 115:{do{if((c[155622]|0)!=0){h=ts(c[45880]|0,40184)|0;if((h|0)==0){break}g[h>>2]=+(d|0)}}while(0);g[(c[45880]|0)+312>>2]=+(d|0);return};case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:{if((c[278834]|0)==0){if(e<<24>>24<=49){return}h=(c[45880]|0)+328|0;g[h>>2]=+(~~+g[h>>2]|1<<f-50|0);return}if((e<<24>>24|0)==57){h=(c[45880]|0)+328|0;g[h>>2]=+(~~+g[h>>2]|8388608|0);return}else if((e<<24>>24|0)==54){h=(c[45880]|0)+328|0;i=~~+g[h>>2];if((a[b+1|0]|0)==97){g[h>>2]=+(i|65536|0);return}else{g[h>>2]=+(i|16|0);return}}else if((e<<24>>24|0)==48){i=(c[45880]|0)+328|0;g[i>>2]=+(~~+g[i>>2]|128|0);return}else{if(e<<24>>24<=49){return}e=(c[45880]|0)+328|0;g[e>>2]=+(~~+g[e>>2]|1<<f-50|0);return}break};case 99:{if((c[155622]|0)==0){g[(c[45880]|0)+324>>2]=+(d|0);return}f=ts(c[45880]|0,38680)|0;if((f|0)==0){return}j=+(d|0);g[f>>2]=j;f=c[45880]|0;if(+g[f+296>>2]>64.0){return}g[f+324>>2]=j;return};case 104:{g[(c[45880]|0)+288>>2]=+(d|0);return};case 114:{if((c[155622]|0)==0){g[(c[45880]|0)+320>>2]=+(d|0);return}f=ts(c[45880]|0,39256)|0;if((f|0)==0){return}j=+(d|0);g[f>>2]=j;f=c[45880]|0;if(+g[f+296>>2]>64.0){return}g[f+320>>2]=j;return};case 112:{if((c[155622]|0)==0){return}f=ts(c[45880]|0,37960)|0;if((f|0)==0){return}j=+(d|0);g[f>>2]=j;f=c[45880]|0;if(+g[f+296>>2]<=64.0){return}g[f+324>>2]=j;return};case 109:{if((c[155622]|0)==0){return}f=ts(c[45880]|0,39048)|0;if((f|0)==0){return}j=+(d|0);g[f>>2]=j;f=c[45880]|0;if(+g[f+296>>2]<=64.0){return}g[f+320>>2]=j;return};case 110:{if((c[155622]|0)==0){g[(c[45880]|0)+316>>2]=+(d|0);return}f=ts(c[45880]|0,39944)|0;if((f|0)==0){return}j=+(d|0);g[f>>2]=j;f=c[45880]|0;if(+g[f+296>>2]>64.0){return}g[f+316>>2]=j;return};case 108:{if((c[155622]|0)==0){return}f=ts(c[45880]|0,39712)|0;if((f|0)==0){return}j=+(d|0);g[f>>2]=j;f=c[45880]|0;if(+g[f+296>>2]<=64.0){return}g[f+316>>2]=j;return};default:{return}}}function qF(){var a=0,b=0,d=0,e=0,f=0;a=i;b=0;while(1){if((b|0)>=(c[49320]|0)){d=1279;break}e=tq(b)|0;if((cS(ti(c[e+208>>2]|0)|0,37624)|0)==0){break}else{b=b+1|0}}if((d|0)==1279){oW(37304,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;i=a;return}if((e|0)==0){i=a;return}d=rG(os(1)|0,0)|0;if((d|0)==0){b=os(1)|0;oW(37024,(f=i,i=i+8|0,c[f>>2]=b,f)|0);i=f;i=a;return}else{g[e+216>>2]=0.0;c[2569572+(~~+g[e+96>>2]<<2)>>2]=d;i=a;return}}function qG(b){b=b|0;var d=0,e=0,f=0,g=0;if((b|0)==-1){d=40648;return d|0}if((b-33|0)>>>0<94){a[2669408]=b&255;a[2669409]=0;d=2669408;return d|0}else{e=16064}while(1){f=c[e>>2]|0;if((f|0)==0){d=40320;g=1295;break}if((c[e+4>>2]|0)==(b|0)){d=f;g=1298;break}else{e=e+8|0}}if((g|0)==1298){return d|0}else if((g|0)==1295){return d|0}return 0}function qH(){var a=0,b=0,d=0,e=0,f=0;a=i;b=0;while(1){if((b|0)>=(c[49320]|0)){d=1302;break}e=tq(b)|0;if((cS(ti(c[e+208>>2]|0)|0,37624)|0)==0){break}else{b=b+1|0}}if((d|0)==1302){oW(37304,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}if((e|0)==0){i=a;return}d=c[2569572+(~~+g[e+96>>2]<<2)>>2]|0;b=fi(os(1)|0)|0;f=c[d+72>>2]|0;g[e+216>>2]=+(((b|0)<(f|0)?b:f-1|0)|0);i=a;return}function qI(){var a=0,b=0,d=0,e=0,f=0,h=0.0,j=0.0;a=i;b=0;while(1){if((b|0)>=(c[49320]|0)){d=1312;break}e=tq(b)|0;if((cS(ti(c[e+208>>2]|0)|0,37624)|0)==0){break}else{b=b+1|0}}if((d|0)==1312){oW(37304,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;i=a;return}if((e|0)==0){i=a;return}d=c[2569572+(~~+g[e+96>>2]<<2)>>2]|0;b=e+216|0;h=+g[b>>2]+1.0;g[b>>2]=h;e=c[d+72>>2]|0;if(h<+(e|0)){j=h}else{h=+(e-1|0);g[b>>2]=h;j=h}b=~~j;e=rQ(d)|0;if((e|0)==0){i=a;return}oW(36864,(f=i,i=i+16|0,c[f>>2]=b,c[f+8>>2]=e+76+(b*36|0)+20,f)|0);i=f;i=a;return}function qJ(){var a=0,b=0,d=0,e=0,f=0,h=0.0,j=0.0;a=i;b=0;while(1){if((b|0)>=(c[49320]|0)){d=1326;break}e=tq(b)|0;if((cS(ti(c[e+208>>2]|0)|0,37624)|0)==0){break}else{b=b+1|0}}if((d|0)==1326){oW(37304,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;i=a;return}if((e|0)==0){i=a;return}d=c[2569572+(~~+g[e+96>>2]<<2)>>2]|0;b=e+216|0;h=+g[b>>2]+-1.0;j=h<0.0?0.0:h;g[b>>2]=j;b=~~j;e=rQ(d)|0;if((e|0)==0){i=a;return}oW(36864,(f=i,i=i+16|0,c[f>>2]=b,c[f+8>>2]=e+76+(b*36|0)+20,f)|0);i=f;i=a;return}function qK(){var a=0,b=0,d=0,e=0,f=0,g=0;a=i;if((c[353150]|0)==0){if((c[46140]|0)!=0){i=a;return}ov(36600,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}d=oq()|0;e=d-1|0;if((e|0)>8){oW(36416,(b=i,i=i+8|0,c[b>>2]=8,b)|0);i=b;oW(36152,(b=i,i=i+8|0,c[b>>2]=8,b)|0);i=b;f=9;g=1341}else{oW(36152,(b=i,i=i+8|0,c[b>>2]=e,b)|0);i=b;if((e|0)>0){f=d;g=1341}}if((g|0)==1341){g=1;do{yP(1414656+(g-1<<4)|0,os(g)|0,15)|0;g=g+1|0;}while((g|0)<(f|0))}if((c[353663]|0)==-1|(c[46140]|0)!=0|(c[353697]|0)!=0){c[353663]=-1;i=a;return}else{c[353663]=0;nj();i=a;return}}function qL(){if((c[353150]|0)==0){return}if((c[353663]|0)==-1){c[353663]=1}ng();nj();return}function qM(){if(!((c[353150]|0)!=0&(c[353697]|0)!=0)){return}m6();nf();return}function qN(){oE(109072,150);oE(108712,126);oE(108024,240);oE(107784,56);oE(107560,356);oE(107352,294);oE(107128,264);oE(106928,174);oK(107128,84);oK(106928,84);oE(106688,108);oE(106224,488);oE(106e3,354);oE(105496,434);oE(104672,40);oE(104352,426);oE(104064,320);oE(103768,212);oE(103624,202);oE(103184,478);oE(102872,352);oE(102744,306);oE(102536,324);oE(102208,492);oE(101736,314);oE(101272,494);oE(100960,128);oE(100832,342);oE(100720,376);oE(100536,158);oE(100368,490);oE(100264,388);oE(100160,184);oE(99944,524);oE(99480,46);oE(99360,360);return}function qO(a){a=a|0;var b=0,d=0;b=xZ(20)|0;d=b;if((b|0)==0){return d|0}c[b>>2]=0;c[b+4>>2]=0;c[b+8>>2]=-1;c[b+16>>2]=0;vl();oj(d,99232,a,99128,1);return d|0}function qP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=1104481+(c[350594]<<8)|0;d=cn(b|0,59)|0;if((d|0)==0){e=b;f=a[b]|0}else{b=d;while(1){d=b+1|0;g=a[d]|0;if(g<<24>>24==32){b=d}else{e=d;f=g;break}}}if((f<<24>>24|0)==92|(f<<24>>24|0)==47){h=e+1|0}else{h=e}e=oQ(h)|0;if((e|0)!=0){f=c[350594]|0;c[278168]=h-(1104480+(f<<8));if((h|0)==(1104481+(f<<8)|0)){a[h]=47;c[278168]=(c[278168]|0)+1;i=h+1|0}else{i=h}yQ(i|0,e|0)|0;i=yF(e|0)|0;f=(c[278168]|0)+i|0;c[278168]=f;a[1104480+(c[350594]<<8)+f|0]=0;xY(e);return}e=b7(h|0,32)|0;if((e|0)==0){return}f=e-h|0;e=xZ(f+1|0)|0;yP(e|0,h|0,f|0)|0;a[e+f|0]=0;do{if((oL(e)|0)==0){if((o4(e)|0)==0){break}i=h+f|0;while(1){if((a[i]|0)==32){i=i+1|0}else{break}}j=o6(e,i)|0;k=i;l=1387}else{b=h+f|0;while(1){if((a[b]|0)==32){b=b+1|0}else{break}}j=oO(e,b)|0;k=b;l=1387}}while(0);do{if((l|0)==1387){if((j|0)==0){break}c[278168]=k-(1104480+(c[350594]<<8));yQ(k|0,j|0)|0;f=yF(j|0)|0;c[278168]=(c[278168]|0)+f;xY(j)}}while(0);xY(e);return}function qQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+128|0;e=d|0;if((b|0)==9){if(!(a[112336]|0)){a[112336]=1;qP();i=d;return}f=1104481+(c[350594]<<8)|0;g=cn(f|0,59)|0;if((g|0)==0){h=f;j=a[f]|0}else{f=g;while(1){g=f+1|0;k=a[g]|0;if(k<<24>>24==32){f=g}else{h=g;j=k;break}}}if((j<<24>>24|0)==92|(j<<24>>24|0)==47){l=h+1|0}else{l=h}h=oP(l)|0;do{if((h|0)==0){m=1420}else{if((c[h>>2]|0)==0){m=1420;break}oW(41960,(n=i,i=i+8|0,c[n>>2]=1104480+(c[350594]<<8),n)|0);i=n;o0(h);xY(h)}}while(0);do{if((m|0)==1420){h=b7(l|0,32)|0;if((h|0)==0){break}j=h-l|0;h=xZ(j+1|0)|0;yP(h|0,l|0,j|0)|0;a[h+j|0]=0;do{if((oL(h)|0)==0){if((o4(h)|0)==0){break}f=l+j|0;while(1){if((a[f]|0)==32){f=f+1|0}else{break}}k=o5(h,f)|0;if((k|0)==0){break}if((c[k>>2]|0)==0){break}oW(41960,(n=i,i=i+8|0,c[n>>2]=1104480+(c[350594]<<8),n)|0);i=n;o0(k);xY(k)}else{k=l+j|0;while(1){if((a[k]|0)==32){k=k+1|0}else{break}}f=oN(h,k)|0;if((f|0)==0){break}if((c[f>>2]|0)==0){break}oW(41960,(n=i,i=i+8|0,c[n>>2]=1104480+(c[350594]<<8),n)|0);i=n;o0(f);xY(f)}}while(0);xY(h)}}while(0);a[112336]=0;i=d;return}a[112336]=0;switch(b|0){case 275:case 8:{l=c[278168]|0;if((l|0)<=1){i=d;return}c[278168]=l-1;i=d;return};case 278:{l=c[352658]|0;c[l+12>>2]=(c[l+4>>2]|0)+10-(c[352638]|0);i=d;return};case 273:{l=c[350594]|0;j=c[278832]|0;while(1){o=j+31&31;if((o|0)==(l|0)){m=1441;break}if((a[1104481+(o<<8)|0]|0)==0){j=o}else{m=1440;break}}if((m|0)==1440){if((o|0)==(l|0)){m=1441}else{p=o}}if((m|0)==1441){p=l+1&31}c[278832]=p;yQ(1104480+(l<<8)|0,1104480+(p<<8)|0)|0;c[278168]=yF(1104480+(c[350594]<<8)|0)|0;i=d;return};case 326:case 280:{p=(c[352658]|0)+12|0;c[p>>2]=(c[p>>2]|0)-2;i=d;return};case 327:case 281:{p=(c[352658]|0)+12|0;c[p>>2]=(c[p>>2]|0)+2;p=c[352658]|0;l=p+12|0;o=c[p+4>>2]|0;if((c[l>>2]|0)<=(o|0)){i=d;return}c[l>>2]=o;i=d;return};case 274:{o=c[278832]|0;l=c[350594]|0;if((o|0)==(l|0)){i=d;return}else{q=o}while(1){r=q+1&31;if((r|0)==(l|0)){m=1445;break}if((a[1104481+(r<<8)|0]|0)==0){q=r}else{m=1447;break}}do{if((m|0)==1447){c[278832]=r;q=1104480+(l<<8)|0;if((r|0)==(l|0)){s=q;break}o=1104480+(r<<8)|0;yQ(q|0,o|0)|0;c[278168]=yF(1104480+(c[350594]<<8)|0)|0;i=d;return}else if((m|0)==1445){c[278832]=l;s=1104480+(l<<8)|0}}while(0);a[s]=93;c[278168]=1;i=d;return};case 13:{s=c[350594]|0;l=1104481+(s<<8)|0;m=a[l]|0;L1933:do{if((m<<24>>24|0)==92|(m<<24>>24|0)==47){ov(107888,(n=i,i=i+8|0,c[n>>2]=1104482+(s<<8),n)|0);i=n}else{r=e|0;o=0;while(1){q=o+1|0;p=a[1104480+(s<<8)+q|0]|0;if(p<<24>>24<33){t=o;break}a[e+o|0]=p;if(q>>>0<127){o=q}else{t=q;break}}a[e+t|0]=0;do{if((oL(r)|0)==0){if((o4(r)|0)!=0){break}if((oM(r)|0)!=0){break}if((c[353150]|0)>>>0>1){ov(107672,(n=i,i=i+1|0,i=i+7>>3<<3,c[n>>2]=0,n)|0);i=n}ov(107888,(n=i,i=i+8|0,c[n>>2]=l,n)|0);i=n;break L1933}}while(0);ov(107888,(n=i,i=i+8|0,c[n>>2]=l,n)|0);i=n}}while(0);ov(107480,(n=i,i=i+1|0,i=i+7>>3<<3,c[n>>2]=0,n)|0);i=n;oW(41960,(n=i,i=i+8|0,c[n>>2]=1104480+(c[350594]<<8),n)|0);i=n;n=(c[350594]|0)+1&31;c[350594]=n;c[278832]=n;a[1104480+(n<<8)|0]=93;c[278168]=1;if((c[353150]|0)!=1){i=d;return}vd();i=d;return};case 279:{n=c[352658]|0;c[n+12>>2]=c[n+4>>2];i=d;return};default:{n=c[278168]|0;if(!((b-32|0)>>>0<96&(n|0)<255)){i=d;return}l=c[350594]|0;a[1104480+(l<<8)+n|0]=b&255;b=n+1|0;c[278168]=b;a[1104480+(l<<8)+b|0]=0;i=d;return}}}function qR(a,b){a=a|0;b=b|0;var d=0;if((a|0)==-1){return}d=1101536+(a<<2)|0;a=c[d>>2]|0;if((a|0)!=0){xY(a);c[d>>2]=0}if((b|0)==0){return}a=xZ((yF(b|0)|0)+1|0)|0;yQ(a|0,b|0)|0;c[d>>2]=a;return}function qS(a){a=+a;return+(+(~~(a*182.04444444444445)&65535|0)*.0054931640625)}function qT(){a[1104481+(c[350594]<<8)|0]=0;c[278168]=1;return}function qU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0;d=a+4|0;e=b+8|0;f=a+8|0;h=b+4|0;g[c>>2]=+g[d>>2]*+g[e>>2]- +g[f>>2]*+g[h>>2];g[c+4>>2]=+g[f>>2]*+g[b>>2]- +g[a>>2]*+g[e>>2];g[c+8>>2]=+g[a>>2]*+g[h>>2]- +g[d>>2]*+g[b>>2];return}function qV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a|0;e=b|0;f=a+4|0;h=b+12|0;i=a+8|0;j=b+24|0;g[c>>2]=+g[d>>2]*+g[e>>2]+ +g[f>>2]*+g[h>>2]+ +g[i>>2]*+g[j>>2];k=b+4|0;l=b+16|0;m=b+28|0;g[c+4>>2]=+g[d>>2]*+g[k>>2]+ +g[f>>2]*+g[l>>2]+ +g[i>>2]*+g[m>>2];n=b+8|0;o=b+20|0;p=b+32|0;g[c+8>>2]=+g[d>>2]*+g[n>>2]+ +g[f>>2]*+g[o>>2]+ +g[i>>2]*+g[p>>2];i=a+12|0;f=a+16|0;d=a+20|0;g[c+12>>2]=+g[i>>2]*+g[e>>2]+ +g[f>>2]*+g[h>>2]+ +g[d>>2]*+g[j>>2];g[c+16>>2]=+g[i>>2]*+g[k>>2]+ +g[f>>2]*+g[l>>2]+ +g[d>>2]*+g[m>>2];g[c+20>>2]=+g[i>>2]*+g[n>>2]+ +g[f>>2]*+g[o>>2]+ +g[d>>2]*+g[p>>2];d=a+24|0;f=a+28|0;i=a+32|0;g[c+24>>2]=+g[d>>2]*+g[e>>2]+ +g[f>>2]*+g[h>>2]+ +g[i>>2]*+g[j>>2];g[c+28>>2]=+g[d>>2]*+g[k>>2]+ +g[f>>2]*+g[l>>2]+ +g[i>>2]*+g[m>>2];g[c+32>>2]=+g[d>>2]*+g[n>>2]+ +g[f>>2]*+g[o>>2]+ +g[i>>2]*+g[p>>2];return}function qW(a){a=a|0;var b=0,c=0;b=+g[a>>2]<0.0|0;c=+g[a+4>>2]<0.0?b|2:b;return(+g[a+8>>2]<0.0?c|4:c)|0}function qX(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;if((oq()|0)!=2){oW(40064,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=b;return}e=os(1)|0;L1981:do{if((e|0)!=0){f=a[e]|0;if(f<<24>>24==0){break}if((a[e+1|0]|0)==0){g=f<<24>>24}else{f=16064;while(1){h=c[f>>2]|0;if((h|0)==0){break L1981}if((yM(e|0,h|0)|0)==0){break}else{f=f+8|0}}g=c[f+4>>2]|0}if((g|0)==-1){break}h=1101536+(g<<2)|0;j=c[h>>2]|0;if((j|0)==0){i=b;return}xY(j);c[h>>2]=0;i=b;return}}while(0);g=os(1)|0;oW(39864,(d=i,i=i+8|0,c[d>>2]=g,d)|0);i=d;i=b;return}function qY(){var a=0,b=0,d=0;a=0;do{b=1101536+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){xY(d);c[b>>2]=0}a=a+1|0;}while((a|0)<367);return}function qZ(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+1024|0;d=b|0;e=oq()|0;if((e-2|0)>>>0>1){oW(39480,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;i=b;return}g=os(1)|0;L2010:do{if((g|0)!=0){h=a[g]|0;if(h<<24>>24==0){break}if((a[g+1|0]|0)==0){j=h<<24>>24}else{h=16064;while(1){k=c[h>>2]|0;if((k|0)==0){break L2010}if((yM(g|0,k|0)|0)==0){break}else{h=h+8|0}}j=c[h+4>>2]|0}if((j|0)==-1){break}if((e|0)==2){k=1101536+(j<<2)|0;l=(c[k>>2]|0)==0;m=os(1)|0;if(l){oW(39e3,(f=i,i=i+8|0,c[f>>2]=m,f)|0);i=f;i=b;return}else{l=c[k>>2]|0;oW(39240,(f=i,i=i+16|0,c[f>>2]=m,c[f+8>>2]=l,f)|0);i=f;i=b;return}}l=d|0;a[l]=0;L2029:do{if((e|0)>2){m=2;k=0;while(1){n=(m|0)>2;k=(n&1)+k+(yF(os(m)|0)|0)|0;if(k>>>0>1023){break}if(n){n=d+(yF(l|0)|0)|0;x=32;a[n]=x&255;x=x>>8;a[n+1|0]=x&255}yR(l|0,os(m)|0)|0;m=m+1|0;if((m|0)>=(e|0)){break L2029}}oW(38240,(f=i,i=i+8|0,c[f>>2]=1024,f)|0);i=f;i=b;return}}while(0);h=1101536+(j<<2)|0;m=c[h>>2]|0;if((m|0)!=0){xY(m);c[h>>2]=0}m=xZ((yF(l|0)|0)+1|0)|0;yQ(m|0,l|0)|0;c[h>>2]=m;i=b;return}}while(0);j=os(1)|0;oW(39864,(f=i,i=i+8|0,c[f>>2]=j,f)|0);i=f;i=b;return}function q_(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=0;do{f=c[1101536+(e<<2)>>2]|0;if((f|0)!=0){L2050:do{if((e-33|0)>>>0<94){a[2669408]=e&255;a[2669409]=0;g=2669408}else{h=16064;while(1){j=c[h>>2]|0;if((j|0)==0){g=40320;break L2050}if((c[h+4>>2]|0)==(e|0)){g=j;break}else{h=h+8|0}}}}while(0);en(b|0,37464,(h=i,i=i+16|0,c[h>>2]=g,c[h+8>>2]=f,h)|0)|0;i=h}e=e+1|0;}while((e|0)<367);i=d;return}function q$(){var b=0,d=0,e=0;b=0;do{a[1104480+(b<<8)|0]=93;a[1104481+(b<<8)|0]=0;b=b+1|0;}while((b|0)<32);c[278168]=1;b=32;do{c[1409072+(b<<2)>>2]=1;b=b+1|0;}while((b|0)<128);c[352281]=1;c[352277]=1;c[352543]=1;c[352544]=1;c[352541]=1;c[352542]=1;c[352276]=1;c[352546]=1;c[352547]=1;c[352548]=1;c[352549]=1;c[352572]=1;c[352571]=1;c[352594]=1;c[352595]=1;b=0;while(1){c[1098584+(b<<2)>>2]=b;d=b+1|0;if((d|0)<367){b=d}else{e=97;break}}do{c[1098584+(e<<2)>>2]=e-32;e=e+1|0;}while((e|0)<123);c[274742]=126;c[274695]=33;c[274696]=64;c[274697]=35;c[274698]=36;c[274699]=37;c[274700]=94;c[274701]=38;c[274702]=42;c[274703]=40;c[274694]=41;c[274691]=95;c[274707]=43;c[274738]=124;c[274737]=123;c[274739]=125;c[274705]=58;c[274685]=34;c[274690]=60;c[274692]=62;c[274693]=63;c[220125]=1;c[220380]=1;c[220381]=1;c[220382]=1;c[220383]=1;c[220384]=1;c[220385]=1;c[220386]=1;c[220387]=1;c[220388]=1;c[220389]=1;c[220390]=1;c[220391]=1;c[220392]=1;c[220393]=1;c[220394]=1;oE(37208,34);oE(36976,118);oE(36768,436);return}function q0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;c[1100064+(b<<2)>>2]=d;f=(d|0)!=0;if(!f){c[1103008+(b<<2)>>2]=0}c[278170]=b;g=c[278174]|0;c[278174]=g+1;if((g|0)<0){i=e;return}do{if(f){g=1103008+(b<<2)|0;h=c[g>>2]|0;c[g>>2]=h+1;if((b|0)==8|(b|0)==19|(b|0)==280|(b|0)==281){break}if((h|0)>0){i=e;return}if(b>>>0<=322){j=1574;break}if((c[1101536+(b<<2)>>2]|0)!=0){j=1574;break}L2085:do{if((b|0)==-1){k=40648}else{if((b-33|0)>>>0<94){a[2669408]=b&255;a[2669409]=0;k=2669408;break}else{l=16064}while(1){h=c[l>>2]|0;if((h|0)==0){k=40320;break L2085}if((c[l+4>>2]|0)==(b|0)){k=h;break}else{l=l+8|0}}}}while(0);oW(36568,(m=i,i=i+8|0,c[m>>2]=k,m)|0);i=m;j=1574}else{j=1574}}while(0);do{if((j|0)==1574){if((b|0)==303){c[155604]=d}else if((b|0)==304){c[270926]=d}else if((b|0)==27){if(!f){i=e;return}k=c[278172]|0;if((k|0)==0|(k|0)==1){ri();i=e;return}else if((k|0)==3){ru(27);i=e;return}else if((k|0)==2){c[278172]=0;c[644594]=0;a[2578384]=0;i=e;return}else{w1(36336,(m=i,i=i+1|0,i=i+7>>3<<3,c[m>>2]=0,m)|0);i=m;i=e;return}}if(f){break}k=c[1101536+(b<<2)>>2]|0;do{if((k|0)!=0){if((a[k]|0)!=43){break}ov(36120,(m=i,i=i+16|0,c[m>>2]=k+1,c[m+8>>2]=b,m)|0);i=m}}while(0);k=c[1098584+(b<<2)>>2]|0;if((k|0)==(b|0)){i=e;return}l=c[1101536+(k<<2)>>2]|0;if((l|0)==0){i=e;return}if((a[l]|0)!=43){i=e;return}ov(36120,(m=i,i=i+16|0,c[m>>2]=l+1,c[m+8>>2]=b,m)|0);i=m;i=e;return}}while(0);do{if((c[353697]|0)==0){n=c[278172]|0;j=1597}else{f=c[278172]|0;if(!((c[1409072+(b<<2)>>2]|0)!=0&(f|0)==0)){n=f;j=1597;break}f=c[1101536+(b<<2)>>2]|0;if((f|0)!=0){if((cS(f|0,109032)|0)==0){j=1600;break}}ri();i=e;return}}while(0);do{if((j|0)==1597){if((n|0)==0){j=1600;break}else if((n|0)==3){if((c[880392+(b<<2)>>2]|0)==0){o=3;break}else{j=1602;break}}else if((n|0)==1){if((c[1409072+(b<<2)>>2]|0)==0){j=1602;break}else{o=1;break}}else{o=n;break}}}while(0);do{if((j|0)==1600){if((c[352656]|0)==0){j=1602;break}if((c[1409072+(b<<2)>>2]|0)==0){j=1602}else{o=0}}}while(0);if((j|0)==1602){j=c[1101536+(b<<2)>>2]|0;if((j|0)==0){i=e;return}if((a[j]|0)==43){ov(108224,(m=i,i=i+16|0,c[m>>2]=j,c[m+8>>2]=b,m)|0);i=m;i=e;return}else{ov(41960,(m=i,i=i+8|0,c[m>>2]=j,m)|0);i=m;i=e;return}}if((c[155604]|c[270926]|0)==0){p=b}else{p=c[1098584+(b<<2)>>2]|0}if((o|0)==2){if((p|0)==27){c[278172]=0;c[644594]=0;a[2578384]=0;i=e;return}else if((p|0)==13){if((c[644592]|0)==0){ov(40992,(m=i,i=i+8|0,c[m>>2]=2578384,m)|0);i=m}else{ov(41352,(m=i,i=i+8|0,c[m>>2]=2578384,m)|0);i=m}c[278172]=0;c[644594]=0;a[2578384]=0;i=e;return}else{if((p-32|0)>>>0>95){i=e;return}b=c[644594]|0;if((p|0)==8){if((b|0)==0){i=e;return}j=b-1|0;c[644594]=j;a[2578384+j|0]=0;i=e;return}else{if((b|0)==255){i=e;return}j=b+1|0;c[644594]=j;a[2578384+b|0]=p&255;a[2578384+j|0]=0;i=e;return}}}else if((o|0)==3){ru(p);i=e;return}else if((o|0)==0|(o|0)==1){qQ(p);i=e;return}else{w1(36336,(m=i,i=i+1|0,i=i+7>>3<<3,c[m>>2]=0,m)|0);i=m;i=e;return}}function q1(a){a=a|0;var b=0.0,c=0,d=0.0,e=0,f=0.0,h=0.0,i=0.0;b=+g[a>>2];c=a+4|0;d=+g[c>>2];e=a+8|0;f=+g[e>>2];h=+R(+(b*b+d*d+f*f));if(h==0.0){return+h}i=1.0/h;g[a>>2]=b*i;g[c>>2]=i*d;g[e>>2]=i*f;return+h}function q2(){c[278172]=3;c[270782]=7;a[15512]=1;return}function q3(a){a=a|0;var b=0,c=0;b=0;c=a;while(1){a=c>>1;if((a|0)==0){break}else{b=b+1|0;c=a}}return b|0}function q4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=b;b=a;while(1){if((b|0)>(c|0)){d=c}else{if((b|0)==0){e=c;f=1667;break}else{g=c}while(1){a=(g|0)%(b|0)|0;if((b|0)>-1){d=a;break}else{g=a}}}if((d|0)==0){e=b;f=1666;break}c=(b|0)%(d|0)|0;b=d}if((f|0)==1666){return e|0}else if((f|0)==1667){return e|0}return 0}function q5(){if((c[278172]|0)!=3){c[270786]=c[353663];c[353663]=-1}c[278172]=3;c[270782]=1;a[15512]=1;return}function q6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=0;while(1){if((c|0)>=3){d=1;e=1676;break}if(+g[a+(c<<2)>>2]!=+g[b+(c<<2)>>2]){d=0;e=1675;break}else{c=c+1|0}}if((e|0)==1676){return d|0}else if((e|0)==1675){return d|0}return 0}function q7(a,b,c,d){a=a|0;b=+b;c=c|0;d=d|0;g[d>>2]=+g[a>>2]+ +g[c>>2]*b;g[d+4>>2]=+g[a+4>>2]+ +g[c+4>>2]*b;g[d+8>>2]=+g[a+8>>2]+ +g[c+8>>2]*b;return}function q8(a){a=a|0;var b=0;g[a>>2]=-0.0- +g[a>>2];b=a+4|0;g[b>>2]=-0.0- +g[b>>2];b=a+8|0;g[b>>2]=-0.0- +g[b>>2];return}function q9(a,b,c){a=a|0;b=+b;c=c|0;g[c>>2]=+g[a>>2]*b;g[c+4>>2]=+g[a+4>>2]*b;g[c+8>>2]=+g[a+8>>2]*b;return}function ra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a|0;e=b|0;f=a+4|0;h=b+16|0;i=a+8|0;j=b+32|0;g[c>>2]=+g[d>>2]*+g[e>>2]+ +g[f>>2]*+g[h>>2]+ +g[i>>2]*+g[j>>2];k=b+4|0;l=b+20|0;m=b+36|0;g[c+4>>2]=+g[d>>2]*+g[k>>2]+ +g[f>>2]*+g[l>>2]+ +g[i>>2]*+g[m>>2];n=b+8|0;o=b+24|0;p=b+40|0;g[c+8>>2]=+g[d>>2]*+g[n>>2]+ +g[f>>2]*+g[o>>2]+ +g[i>>2]*+g[p>>2];q=b+12|0;r=b+28|0;s=b+44|0;g[c+12>>2]=+g[a+12>>2]+(+g[d>>2]*+g[q>>2]+ +g[f>>2]*+g[r>>2]+ +g[i>>2]*+g[s>>2]);i=a+16|0;f=a+20|0;d=a+24|0;g[c+16>>2]=+g[i>>2]*+g[e>>2]+ +g[f>>2]*+g[h>>2]+ +g[d>>2]*+g[j>>2];g[c+20>>2]=+g[i>>2]*+g[k>>2]+ +g[f>>2]*+g[l>>2]+ +g[d>>2]*+g[m>>2];g[c+24>>2]=+g[i>>2]*+g[n>>2]+ +g[f>>2]*+g[o>>2]+ +g[d>>2]*+g[p>>2];g[c+28>>2]=+g[a+28>>2]+(+g[i>>2]*+g[q>>2]+ +g[f>>2]*+g[r>>2]+ +g[d>>2]*+g[s>>2]);d=a+32|0;f=a+36|0;i=a+40|0;g[c+32>>2]=+g[d>>2]*+g[e>>2]+ +g[f>>2]*+g[h>>2]+ +g[i>>2]*+g[j>>2];g[c+36>>2]=+g[d>>2]*+g[k>>2]+ +g[f>>2]*+g[l>>2]+ +g[i>>2]*+g[m>>2];g[c+40>>2]=+g[d>>2]*+g[n>>2]+ +g[f>>2]*+g[o>>2]+ +g[i>>2]*+g[p>>2];g[c+44>>2]=+g[a+44>>2]+(+g[d>>2]*+g[q>>2]+ +g[f>>2]*+g[r>>2]+ +g[i>>2]*+g[s>>2]);return}function rb(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,h=0.0,j=0.0,k=0.0,l=0.0,m=0.0;f=i;switch(d[e+17|0]|0|0){case 2:{h=+g[e>>2];j=+g[e+4>>2];k=+g[e+8>>2];l=h*+g[a>>2]+j*+g[b+4>>2]+k*+g[a+8>>2];m=h*+g[b>>2]+j*+g[a+4>>2]+k*+g[b+8>>2];break};case 7:{k=+g[e>>2];j=+g[e+4>>2];h=+g[e+8>>2];l=k*+g[b>>2]+j*+g[b+4>>2]+h*+g[b+8>>2];m=k*+g[a>>2]+j*+g[a+4>>2]+h*+g[a+8>>2];break};case 3:{h=+g[e>>2];j=+g[e+4>>2];k=+g[e+8>>2];l=h*+g[b>>2]+j*+g[b+4>>2]+k*+g[a+8>>2];m=h*+g[a>>2]+j*+g[a+4>>2]+k*+g[b+8>>2];break};case 6:{k=+g[e>>2];j=+g[e+4>>2];h=+g[e+8>>2];l=k*+g[a>>2]+j*+g[b+4>>2]+h*+g[b+8>>2];m=k*+g[b>>2]+j*+g[a+4>>2]+h*+g[a+8>>2];break};case 4:{h=+g[e>>2];j=+g[e+4>>2];k=+g[e+8>>2];l=h*+g[a>>2]+j*+g[a+4>>2]+k*+g[b+8>>2];m=h*+g[b>>2]+j*+g[b+4>>2]+k*+g[a+8>>2];break};case 0:{k=+g[e>>2];j=+g[e+4>>2];h=+g[e+8>>2];l=k*+g[a>>2]+j*+g[a+4>>2]+h*+g[a+8>>2];m=k*+g[b>>2]+j*+g[b+4>>2]+h*+g[b+8>>2];break};case 1:{h=+g[e>>2];j=+g[e+4>>2];k=+g[e+8>>2];l=h*+g[b>>2]+j*+g[a+4>>2]+k*+g[a+8>>2];m=h*+g[a>>2]+j*+g[b+4>>2]+k*+g[b+8>>2];break};case 5:{k=+g[e>>2];j=+g[e+4>>2];h=+g[e+8>>2];l=k*+g[b>>2]+j*+g[a+4>>2]+h*+g[b+8>>2];m=k*+g[a>>2]+j*+g[b+4>>2]+h*+g[a+8>>2];break};default:{w1(40344,(a=i,i=i+8|0,c[a>>2]=111912,a)|0);i=a;l=0.0;m=0.0}}h=+g[e+12>>2];e=m>=h|0;i=f;return(l<h?e|2:e)|0}function rc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0.0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0;e=+g[a+4>>2]*.017453292519943295;f=+U(+e);h=+T(+e);e=+g[a>>2]*.017453292519943295;i=+U(+e);j=+T(+e);e=+g[a+8>>2]*.017453292519943295;k=+U(+e);l=+T(+e);g[b>>2]=h*j;g[b+4>>2]=f*j;g[b+8>>2]=-0.0-i;e=k*-1.0;m=i*e;n=l*-1.0;g[c>>2]=h*m+n*(-0.0-f);g[c+4>>2]=f*m+h*n;g[c+8>>2]=j*e;e=i*l;g[d>>2]=f*k+h*e;g[d+4>>2]=h*(-0.0-k)+f*e;g[d+8>>2]=j*l;return}function rd(a){a=a|0;var b=0.0,c=0.0,d=0.0;b=+g[a>>2];c=+g[a+4>>2];d=+g[a+8>>2];return+(+R(+(b*b+0.0+c*c+d*d)))}function re(a,b,d,e){a=+a;b=+b;d=d|0;e=e|0;var f=0,g=0,j=0.0,k=0.0,l=0,m=0,n=0;f=i;if(b<=0.0){w1(89672,(g=i,i=i+16|0,c[g>>2]=111320,h[g+8>>3]=b,g)|0);i=g}do{if(a<0.0){j=-0.0-a;k=+P(+(j/b));g=~~k;l=~~+P(+(j-k*b));if((l|0)==0){m=0;n=-g|0;break}m=~~b-l|0;n=~g}else{k=+P(+(a/b));m=~~+P(+(a-k*b));n=~~k}}while(0);c[d>>2]=n;c[e>>2]=m;i=f;return}function rf(a,b,d){a=a|0;b=b|0;d=d|0;pF(((c[29381]|0)-320>>1)+a|0,b,d);return}function rg(a,b,d){a=a|0;b=b|0;d=d|0;pS(((c[29381]|0)-320>>1)+a|0,b,d);return}function rh(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=pN(39888)|0;pT(((c[29381]|0)-320>>1)+a|0,b,f);f=pN(89376)|0;g=(e|0)>0;if(g){h=e<<3;i=b;j=0;do{i=i+8|0;pT(((c[29381]|0)-320>>1)+a|0,i,f);j=j+1|0;}while((j|0)<(e|0));k=h+b|0}else{k=b}h=pN(73384)|0;pT(((c[29381]|0)-320>>1)+a|0,k+8|0,h);h=a+8|0;if((d|0)>0){if(g){k=(e<<3)+b|0;j=d;f=h;while(1){i=pN(62936)|0;pT(((c[29381]|0)-320>>1)+f|0,b,i);i=pN(56392)|0;l=b;m=0;while(1){n=l+8|0;if((m|0)==1){o=pN(51488)|0}else{o=i}pT(((c[29381]|0)-320>>1)+f|0,n,o);p=m+1|0;if((p|0)<(e|0)){i=o;l=n;m=p}else{break}}m=pN(47720)|0;pT(((c[29381]|0)-320>>1)+f|0,k+8|0,m);m=j-2|0;if((m|0)>0){j=m;f=f+16|0}else{break}}}else{f=d;j=h;while(1){k=pN(62936)|0;pT(((c[29381]|0)-320>>1)+j|0,b,k);pN(56392)|0;k=pN(47720)|0;pT(((c[29381]|0)-320>>1)+j|0,b+8|0,k);k=f-2|0;if((k|0)>0){f=k;j=j+16|0}else{break}}}q=((d+536870911|0)>>>1<<4)+a+24|0}else{q=h}h=pN(43544)|0;pT(((c[29381]|0)-320>>1)+q|0,b,h);h=pN(39464)|0;if(!g){r=b;s=pN(36320)|0;t=r+8|0;u=c[29381]|0;v=u-320|0;w=v>>1;x=w+q|0;pT(x,t,s);return}g=e<<3;a=b;d=0;do{a=a+8|0;pT(((c[29381]|0)-320>>1)+q|0,a,h);d=d+1|0;}while((d|0)<(e|0));r=g+b|0;s=pN(36320)|0;t=r+8|0;u=c[29381]|0;v=u-320|0;w=v>>1;x=w+q|0;pT(x,t,s);return}function ri(){var b=0;a[15512]=1;b=c[278172]|0;if((b|0)==3){if((c[270782]|0)==1){c[278172]=0;c[270782]=0;return}else{c[278172]=3;c[270782]=1;a[15512]=1;return}}else if((b|0)==1){oR();return}else{c[270786]=c[353663];c[353663]=-1;c[278172]=3;c[270782]=1;a[15512]=1;return}}function rj(){var b=0;b=c[270782]|0;if((b|0)==11){return}c[29316]=(c[278172]|0)==3;c[278172]=3;c[270800]=b;c[270782]=11;a[15512]=1;c[169382]=(aQ()|0)&7;return}function rk(){oE(106488,474);oE(102848,4);oE(100328,26);oE(98808,506);oE(96688,442);oE(94528,318);oE(92784,484);oE(91224,346);oE(89280,284);oE(87696,16);oE(85968,214);oE(83264,52);return}function rl(){c[278172]=3;c[270782]=2;a[15512]=1;return}function rm(){c[278172]=3;c[270782]=5;a[15512]=1;return}function rn(){c[278172]=3;c[270782]=9;a[15512]=1;return}function ro(){c[278172]=3;c[270782]=8;a[15512]=1;return}function rp(){c[278172]=3;c[270782]=10;a[15512]=1;c[278836]=0;return}function rq(){a[15512]=1;c[270782]=3;c[278172]=3;ry();return}function rr(){if((c[46140]|0)==0|(c[642381]|0)!=0|(c[45874]|0)!=1){return}a[15512]=1;c[270782]=4;c[278172]=3;ry();return}function rs(){var b=0,d=0;c[278172]=3;c[270782]=6;a[15512]=1;yQ(620464,c[5527]|0)|0;yQ(620480,c[4635]|0)|0;b=~~+g[5600];d=b>>4;c[155112]=d;c[155110]=d;d=b&15;c[155114]=d;c[155124]=d;return}function rt(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0.0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0;b=i;i=i+160|0;d=b|0;e=b+8|0;f=b+72|0;j=c[270782]|0;if((j|0)==0|(c[278172]|0)!=3){i=b;return}if(a[15392]|0){a[15392]=0;k=j}else{c[155172]=1;if(+g[1180]!=0.0){pV(c[29382]|0)}else{pZ()}c[155162]=0;k=c[270782]|0}L2324:do{switch(k|0){case 2:{j=pN(75512)|0;pT(((c[29381]|0)-320>>1)+16|0,4,j);j=pN(63744)|0;pS(((c[29381]|0)-320>>1)+((320-(c[j>>2]|0)|0)/2|0)|0,4,j);j=pN(63712)|0;pT(((c[29381]|0)-320>>1)+72|0,32,j);j=((c[270784]|0)*20|0)+32|0;l=oh(63952,(m=i,i=i+8|0,c[m>>2]=((~~(+h[2324]*10.0)|0)%6|0)+1,m)|0)|0;i=m;n=pN(l)|0;pT(((c[29381]|0)-320>>1)+54|0,j,n);break};case 1:{n=pN(75512)|0;pT(((c[29381]|0)-320>>1)+16|0,4,n);n=pN(63672)|0;pS(((c[29381]|0)-320>>1)+((320-(c[n>>2]|0)|0)/2|0)|0,4,n);n=pN(63648)|0;pT(((c[29381]|0)-320>>1)+72|0,32,n);n=((c[270804]|0)*20|0)+32|0;j=oh(63952,(m=i,i=i+8|0,c[m>>2]=((~~(+h[2324]*10.0)|0)%6|0)+1,m)|0)|0;i=m;l=pN(j)|0;pT(((c[29381]|0)-320>>1)+54|0,n,l);break};case 6:{l=pN(75512)|0;pT(((c[29381]|0)-320>>1)+16|0,4,l);l=pN(76568)|0;pS(((c[29381]|0)-320>>1)+((320-(c[l>>2]|0)|0)/2|0)|0,4,l);pF(((c[29381]|0)-320>>1)+64|0,40,200);pF(((c[29381]|0)-320>>1)+72|0,40,239);pF(((c[29381]|0)-320>>1)+80|0,40,243);pF(((c[29381]|0)-320>>1)+88|0,40,244);pF(((c[29381]|0)-320>>1)+96|0,40,238);pF(((c[29381]|0)-320>>1)+104|0,40,225);pF(((c[29381]|0)-320>>1)+112|0,40,237);pF(((c[29381]|0)-320>>1)+120|0,40,229);rh(160,32,16,1);l=a[620480]|0;if(l<<24>>24!=0){n=168;j=620480;o=l;while(1){pF(((c[29381]|0)-320>>1)+n|0,40,(o<<24>>24)+128|0);l=j+1|0;p=a[l]|0;if(p<<24>>24==0){break}else{n=n+8|0;j=l;o=p}}}pF(((c[29381]|0)-320>>1)+64|0,56,217);pF(((c[29381]|0)-320>>1)+72|0,56,239);pF(((c[29381]|0)-320>>1)+80|0,56,245);pF(((c[29381]|0)-320>>1)+88|0,56,242);pF(((c[29381]|0)-320>>1)+96|0,56,160);pF(((c[29381]|0)-320>>1)+104|0,56,238);pF(((c[29381]|0)-320>>1)+112|0,56,225);pF(((c[29381]|0)-320>>1)+120|0,56,237);pF(((c[29381]|0)-320>>1)+128|0,56,229);rh(160,48,16,1);o=a[620464]|0;if(o<<24>>24==0){q=64;r=64544;s=83}else{j=168;n=620464;p=o;while(1){pF(((c[29381]|0)-320>>1)+j|0,56,(p<<24>>24)+128|0);o=n+1|0;l=a[o]|0;if(l<<24>>24==0){q=64;r=64544;s=83;break}else{j=j+8|0;n=o;p=l}}}while(1){pF(((c[29381]|0)-320>>1)+q|0,80,(s<<24>>24)+128|0);p=r+1|0;n=a[p]|0;if(n<<24>>24==0){t=64;u=64504;v=80;break}else{q=q+8|0;r=p;s=n}}while(1){pF(((c[29381]|0)-320>>1)+t|0,104,(v<<24>>24)+128|0);n=u+1|0;p=a[n]|0;if(p<<24>>24==0){break}else{t=t+8|0;u=n;v=p}}rh(64,132,14,1);p=72;n=64440;j=65;while(1){pF(((c[29381]|0)-320>>1)+p|0,140,(j<<24>>24)+128|0);l=n+1|0;o=a[l]|0;if(o<<24>>24==0){break}else{p=p+8|0;n=l;j=o}}j=pN(64424)|0;pT(((c[29381]|0)-320>>1)+160|0,64,j);j=pN(64168)|0;n=c[155110]|0;p=c[155124]|0;o=0;do{a[1114056+o|0]=o&255;o=o+1|0;}while((o|0)<256);o=n<<4;l=p<<4;yJ(183192,1114056,256)|0;if((o|0)<128){w=1114056+o|0;yJ(183208,w|0,16)|0}else{a[183208]=a[1114056+(o|15)|0]|0;a[183209]=a[1114056+(o|14)|0]|0;a[183210]=a[1114056+(o|13)|0]|0;a[183211]=a[1114056+(o|12)|0]|0;a[183212]=a[1114056+(o|11)|0]|0;a[183213]=a[1114056+(o|10)|0]|0;a[183214]=a[1114056+(o|9)|0]|0;a[183215]=a[1114056+(o|8)|0]|0;a[183216]=a[1114056+(o|7)|0]|0;a[183217]=a[1114056+(o|6)|0]|0;a[183218]=a[1114056+(o|5)|0]|0;a[183219]=a[1114056+(o|4)|0]|0;a[183220]=a[1114056+(o|3)|0]|0;a[183221]=a[1114056+(o|2)|0]|0;a[183222]=a[1114056+(o|1)|0]|0;a[183223]=a[1114056+o|0]|0}if((l|0)<128){o=1114056+l|0;yJ(183288,o|0,16)|0}else{a[183288]=a[1114056+(l|15)|0]|0;a[183289]=a[1114056+(l|14)|0]|0;a[183290]=a[1114056+(l|13)|0]|0;a[183291]=a[1114056+(l|12)|0]|0;a[183292]=a[1114056+(l|11)|0]|0;a[183293]=a[1114056+(l|10)|0]|0;a[183294]=a[1114056+(l|9)|0]|0;a[183295]=a[1114056+(l|8)|0]|0;a[183296]=a[1114056+(l|7)|0]|0;a[183297]=a[1114056+(l|6)|0]|0;a[183298]=a[1114056+(l|5)|0]|0;a[183299]=a[1114056+(l|4)|0]|0;a[183300]=a[1114056+(l|3)|0]|0;a[183301]=a[1114056+(l|2)|0]|0;a[183302]=a[1114056+(l|1)|0]|0;a[183303]=a[1114056+l|0]|0}pU(((c[29381]|0)-320>>1)+172|0,72,j,183192);pF(((c[29381]|0)-320>>1)+56|0,c[3736+(c[940]<<2)>>2]|0,~~(+h[1153]*4.0)&1|12);l=c[940]|0;if((l|0)==0){o=((yF(620480)|0)<<3)+168|0;pF(o+((c[29381]|0)-320>>1)|0,40,~~(+h[1153]*4.0)&1|10);x=c[940]|0}else{x=l}if((x|0)!=1){break L2324}l=((yF(620464)|0)<<3)+168|0;pF(l+((c[29381]|0)-320>>1)|0,56,~~(+h[1153]*4.0)&1|10);break};case 5:{l=pN(75512)|0;pT(((c[29381]|0)-320>>1)+16|0,4,l);l=pN(76568)|0;pS(((c[29381]|0)-320>>1)+((320-(c[l>>2]|0)|0)/2|0)|0,4,l);l=pN(64056)|0;pT(((c[29381]|0)-320>>1)+72|0,32,l);l=((c[270802]|0)*20|0)+32|0;o=oh(63952,(m=i,i=i+8|0,c[m>>2]=((~~(+h[2324]*10.0)|0)%6|0)+1,m)|0)|0;i=m;w=pN(o)|0;pT(((c[29381]|0)-320>>1)+54|0,l,w);if((c[45868]|0)==0){y=52;z=63904;A=78}else{break L2324}while(1){pF(((c[29381]|0)-320>>1)+y|0,148,A<<24>>24);w=z+1|0;l=a[w]|0;if(l<<24>>24==0){break}else{y=y+8|0;z=w;A=l}}break};case 3:{j=pN(63768)|0;pS(((c[29381]|0)-320>>1)+((320-(c[j>>2]|0)|0)/2|0)|0,4,j);j=0;do{p=(j<<3)+32|0;n=1083224+(j*40|0)|0;l=a[n]|0;if(l<<24>>24!=0){w=16;o=n;n=l;while(1){pF(((c[29381]|0)-320>>1)+w|0,p,(n<<24>>24)+128|0);l=o+1|0;B=a[l]|0;if(B<<24>>24==0){break}else{w=w+8|0;o=l;n=B}}}j=j+1|0;}while((j|0)<12);pF(((c[29381]|0)-320>>1)+8|0,(c[274556]<<3)+32|0,~~(+h[1153]*4.0)&1|12);break};case 4:{j=pN(63888)|0;pS(((c[29381]|0)-320>>1)+((320-(c[j>>2]|0)|0)/2|0)|0,4,j);j=0;do{n=(j<<3)+32|0;o=1083224+(j*40|0)|0;w=a[o]|0;if(w<<24>>24!=0){p=16;B=o;o=w;while(1){pF(((c[29381]|0)-320>>1)+p|0,n,(o<<24>>24)+128|0);w=B+1|0;l=a[w]|0;if(l<<24>>24==0){break}else{p=p+8|0;B=w;o=l}}}j=j+1|0;}while((j|0)<12);pF(((c[29381]|0)-320>>1)+8|0,(c[274556]<<3)+32|0,~~(+h[1153]*4.0)&1|12);break};case 7:{j=pN(75512)|0;pT(((c[29381]|0)-320>>1)+16|0,4,j);j=pN(67312)|0;pS(((c[29381]|0)-320>>1)+((320-(c[j>>2]|0)|0)/2|0)|0,4,j);j=16;o=67240;B=32;while(1){pF(((c[29381]|0)-320>>1)+j|0,32,(B<<24>>24)+128|0);p=o+1|0;n=a[p]|0;if(n<<24>>24==0){C=16;D=67216;E=32;break}else{j=j+8|0;o=p;B=n}}while(1){pF(((c[29381]|0)-320>>1)+C|0,40,(E<<24>>24)+128|0);B=D+1|0;o=a[B]|0;if(o<<24>>24==0){F=16;G=66856;H=32;break}else{C=C+8|0;D=B;E=o}}while(1){pF(((c[29381]|0)-320>>1)+F|0,48,(H<<24>>24)+128|0);o=G+1|0;B=a[o]|0;if(B<<24>>24==0){I=16;J=66696;K=32;break}else{F=F+8|0;G=o;H=B}}while(1){pF(((c[29381]|0)-320>>1)+I|0,56,(K<<24>>24)+128|0);B=J+1|0;o=a[B]|0;if(o<<24>>24==0){break}else{I=I+8|0;J=B;K=o}}rx(56,(+g[1034]+-30.0)/90.0);o=16;B=66608;j=32;while(1){pF(((c[29381]|0)-320>>1)+o|0,64,(j<<24>>24)+128|0);n=B+1|0;p=a[n]|0;if(p<<24>>24==0){break}else{o=o+8|0;B=n;j=p}}rx(64,(1.0- +g[234])*2.0);j=16;B=66480;o=32;while(1){pF(((c[29381]|0)-320>>1)+j|0,72,(o<<24>>24)+128|0);p=B+1|0;n=a[p]|0;if(n<<24>>24==0){break}else{j=j+8|0;B=p;o=n}}rx(72,(+g[960]+-1.0)/10.0);o=16;B=66456;j=32;while(1){pF(((c[29381]|0)-320>>1)+o|0,80,(j<<24>>24)+128|0);n=B+1|0;p=a[n]|0;if(p<<24>>24==0){break}else{o=o+8|0;B=n;j=p}}rx(80,+g[6730]);j=16;B=66360;o=32;while(1){pF(((c[29381]|0)-320>>1)+j|0,88,(o<<24>>24)+128|0);p=B+1|0;n=a[p]|0;if(n<<24>>24==0){break}else{j=j+8|0;B=p;o=n}}rx(88,+g[46]);o=16;B=66328;j=32;while(1){pF(((c[29381]|0)-320>>1)+o|0,96,(j<<24>>24)+128|0);n=B+1|0;p=a[n]|0;if(p<<24>>24==0){break}else{o=o+8|0;B=n;j=p}}j=+g[5558]>200.0;pF(((c[29381]|0)-320>>1)+220|0,96,239);B=((c[29381]|0)-320>>1)+228|0;if(j){pF(B,96,238);L=16;M=66288;N=32}else{pF(B,96,230);pF(((c[29381]|0)-320>>1)+236|0,96,230);L=16;M=66288;N=32}while(1){pF(((c[29381]|0)-320>>1)+L|0,104,(N<<24>>24)+128|0);B=M+1|0;j=a[B]|0;if(j<<24>>24==0){break}else{L=L+8|0;M=B;N=j}}j=+g[3854]<0.0;pF(((c[29381]|0)-320>>1)+220|0,104,239);B=((c[29381]|0)-320>>1)+228|0;if(j){pF(B,104,238);O=16;P=66232;Q=32}else{pF(B,104,230);pF(((c[29381]|0)-320>>1)+236|0,104,230);O=16;P=66232;Q=32}while(1){pF(((c[29381]|0)-320>>1)+O|0,112,(Q<<24>>24)+128|0);B=P+1|0;j=a[B]|0;if(j<<24>>24==0){break}else{O=O+8|0;P=B;Q=j}}j=(~~+g[3898]|0)==0;pF(((c[29381]|0)-320>>1)+220|0,112,239);B=((c[29381]|0)-320>>1)+228|0;if(j){pF(B,112,230);pF(((c[29381]|0)-320>>1)+236|0,112,230);R=16;S=66184;T=32}else{pF(B,112,238);R=16;S=66184;T=32}while(1){pF(((c[29381]|0)-320>>1)+R|0,120,(T<<24>>24)+128|0);B=S+1|0;j=a[B]|0;if(j<<24>>24==0){break}else{R=R+8|0;S=B;T=j}}j=(~~+g[3884]|0)==0;pF(((c[29381]|0)-320>>1)+220|0,120,239);B=((c[29381]|0)-320>>1)+228|0;if(j){pF(B,120,230);pF(((c[29381]|0)-320>>1)+236|0,120,230)}else{pF(B,120,238)}if((c[29372]|0)!=0){B=16;j=65864;o=32;while(1){pF(((c[29381]|0)-320>>1)+B|0,128,(o<<24>>24)+128|0);p=j+1|0;n=a[p]|0;if(n<<24>>24==0){break}else{B=B+8|0;j=p;o=n}}}o=o4(78184)|0;j=16;B=65776;n=32;while(1){pF(((c[29381]|0)-320>>1)+j|0,136,(n<<24>>24)+128|0);p=B+1|0;l=a[p]|0;if(l<<24>>24==0){break}else{j=j+8|0;B=p;n=l}}n=(~~+g[o+16>>2]|0)==0;pF(((c[29381]|0)-320>>1)+220|0,136,239);B=((c[29381]|0)-320>>1)+228|0;if(n){pF(B,136,230);pF(((c[29381]|0)-320>>1)+236|0,136,230)}else{pF(B,136,238)}B=o4(78032)|0;n=16;j=65640;l=32;while(1){pF(((c[29381]|0)-320>>1)+n|0,144,(l<<24>>24)+128|0);p=j+1|0;w=a[p]|0;if(w<<24>>24==0){break}else{n=n+8|0;j=p;l=w}}l=(~~+g[B+16>>2]|0)==0;pF(((c[29381]|0)-320>>1)+220|0,144,239);j=((c[29381]|0)-320>>1)+228|0;if(l){pF(j,144,230);pF(((c[29381]|0)-320>>1)+236|0,144,230)}else{pF(j,144,238)}j=o4(77976)|0;l=16;n=65592;o=32;while(1){pF(((c[29381]|0)-320>>1)+l|0,152,(o<<24>>24)+128|0);w=n+1|0;p=a[w]|0;if(p<<24>>24==0){break}else{l=l+8|0;n=w;o=p}}o=(~~+g[j+16>>2]|0)==0;pF(((c[29381]|0)-320>>1)+220|0,152,239);n=((c[29381]|0)-320>>1)+228|0;if(o){pF(n,152,230);pF(((c[29381]|0)-320>>1)+236|0,152,230)}else{pF(n,152,238)}n=o4(77936)|0;o=16;l=65568;B=32;while(1){pF(((c[29381]|0)-320>>1)+o|0,160,(B<<24>>24)+128|0);p=l+1|0;w=a[p]|0;if(w<<24>>24==0){break}else{o=o+8|0;l=p;B=w}}B=(~~+g[n+16>>2]|0)==0;pF(((c[29381]|0)-320>>1)+220|0,160,239);l=((c[29381]|0)-320>>1)+228|0;if(B){pF(l,160,230);pF(((c[29381]|0)-320>>1)+236|0,160,230)}else{pF(l,160,238)}l=o4(77864)|0;B=16;o=65424;j=32;while(1){pF(((c[29381]|0)-320>>1)+B|0,168,(j<<24>>24)+128|0);w=o+1|0;p=a[w]|0;if(p<<24>>24==0){break}else{B=B+8|0;o=w;j=p}}j=((c[29381]|0)-320>>1)+220|0;if(+g[l+16>>2]==60.0){pF(j,168,182);pF(((c[29381]|0)-320>>1)+228|0,168,176);pF(((c[29381]|0)-320>>1)+236|0,168,230);pF(((c[29381]|0)-320>>1)+244|0,168,240);pF(((c[29381]|0)-320>>1)+252|0,168,243)}else{pF(j,168,181);pF(((c[29381]|0)-320>>1)+228|0,168,176);pF(((c[29381]|0)-320>>1)+236|0,168,230);pF(((c[29381]|0)-320>>1)+244|0,168,240);pF(((c[29381]|0)-320>>1)+252|0,168,243)}j=o4(77808)|0;o=16;B=65304;n=32;while(1){pF(((c[29381]|0)-320>>1)+o|0,176,(n<<24>>24)+128|0);p=B+1|0;w=a[p]|0;if(w<<24>>24==0){break}else{o=o+8|0;B=p;n=w}}n=+g[j+16>>2]==1.0;pF(((c[29381]|0)-320>>1)+220|0,176,195);pF(((c[29381]|0)-320>>1)+228|0,176,236);B=((c[29381]|0)-320>>1)+236|0;if(n){pF(B,176,225);pF(((c[29381]|0)-320>>1)+244|0,176,237);pF(((c[29381]|0)-320>>1)+252|0,176,240);pF(((c[29381]|0)-320>>1)+260|0,176,229);pF(((c[29381]|0)-320>>1)+268|0,176,228)}else{pF(B,176,233);pF(((c[29381]|0)-320>>1)+244|0,176,240);pF(((c[29381]|0)-320>>1)+252|0,176,240);pF(((c[29381]|0)-320>>1)+260|0,176,229);pF(((c[29381]|0)-320>>1)+268|0,176,228)}B=o4(77680)|0;n=16;o=64832;l=32;while(1){pF(((c[29381]|0)-320>>1)+n|0,182,(l<<24>>24)+128|0);w=o+1|0;p=a[w]|0;if(p<<24>>24==0){break}else{n=n+8|0;o=w;l=p}}l=+g[B+16>>2]==0.0;pF(((c[29381]|0)-320>>1)+220|0,182,239);o=((c[29381]|0)-320>>1)+228|0;if(l){pF(o,182,238)}else{pF(o,182,230);pF(((c[29381]|0)-320>>1)+236|0,182,230)}pF(((c[29381]|0)-320>>1)+200|0,(c[159934]<<3)+32|0,~~(+h[1153]*4.0)&1|12);break};case 9:{o=pN(67632)|0;pS(((c[29381]|0)-320>>1)+((320-(c[o>>2]|0)|0)/2|0)|0,4,o);if(a[26896]|0){o=12;l=67576;n=80;while(1){pF(((c[29381]|0)-320>>1)+o|0,32,(n<<24>>24)+128|0);j=l+1|0;p=a[j]|0;if(p<<24>>24==0){break}else{o=o+8|0;l=j;n=p}}}else{n=18;l=67536;o=69;while(1){pF(((c[29381]|0)-320>>1)+n|0,32,(o<<24>>24)+128|0);B=l+1|0;p=a[B]|0;if(p<<24>>24==0){break}else{n=n+8|0;l=B;o=p}}}o=d|0;l=d+4|0;n=0;do{p=(n<<3)+48|0;B=c[26716+(n<<3)>>2]|0;j=a[B]|0;if(j<<24>>24!=0){w=16;U=B;B=j;while(1){pF(((c[29381]|0)-320>>1)+w|0,p,(B<<24>>24)+128|0);j=U+1|0;V=a[j]|0;if(V<<24>>24==0){break}else{w=w+8|0;U=j;B=V}}}B=c[26712+(n<<3)>>2]|0;c[l>>2]=-1;c[o>>2]=-1;U=yF(B|0)|0;w=0;V=0;L2490:while(1){j=c[1101536+(w<<2)>>2]|0;do{if((j|0)==0){W=V}else{if((bN(j|0,B|0,U|0)|0)!=0){W=V;break}c[d+(V<<2)>>2]=w;X=V+1|0;if((X|0)==2){break L2490}else{W=X}}}while(0);j=w+1|0;if((j|0)<367){w=j;V=W}else{break}}V=c[o>>2]|0;do{if((V|0)==-1){pF(((c[29381]|0)-320>>1)+140|0,p,191);pF(((c[29381]|0)-320>>1)+148|0,p,191);pF(((c[29381]|0)-320>>1)+156|0,p,191)}else{w=qG(V)|0;U=a[w]|0;if(U<<24>>24!=0){B=140;j=w;X=U;while(1){pF(((c[29381]|0)-320>>1)+B|0,p,(X<<24>>24)+128|0);U=j+1|0;Y=a[U]|0;if(Y<<24>>24==0){break}else{B=B+8|0;j=U;X=Y}}}X=c[l>>2]|0;if((X|0)==-1){break}j=(yF(w|0)|0)<<3;pF(j+148+((c[29381]|0)-320>>1)|0,p,239);pF(j+156+((c[29381]|0)-320>>1)|0,p,242);B=qG(X)|0;X=a[B]|0;if(X<<24>>24==0){break}Y=j+172|0;j=B;B=X;while(1){pF(((c[29381]|0)-320>>1)+Y|0,p,(B<<24>>24)+128|0);X=j+1|0;U=a[X]|0;if(U<<24>>24==0){break}else{Y=Y+8|0;j=X;B=U}}}}while(0);n=n+1|0;}while(n>>>0<19);n=(c[275014]<<3)+48|0;if(a[26896]|0){pF(((c[29381]|0)-320>>1)+130|0,n,61);break L2324}else{pF(((c[29381]|0)-320>>1)+130|0,n,~~(+h[1153]*4.0)&1|12);break L2324}break};case 8:{fQ[c[29372]&1023]();break};case 10:{n=oh(67680,(m=i,i=i+8|0,c[m>>2]=c[278836],m)|0)|0;i=m;l=pN(n)|0;pS((c[29381]|0)-320>>1,0,l);break};case 11:{if((c[29316]|0)!=0){c[270782]=c[270800];a[15392]=1;rt();c[270782]=11}rh(56,76,24,4);l=c[169382]|0;n=c[13528+(l<<2<<2)>>2]|0;o=a[n]|0;if(o<<24>>24==0){Z=l}else{l=64;p=n;n=o;while(1){pF(((c[29381]|0)-320>>1)+l|0,84,(n<<24>>24)+128|0);o=p+1|0;V=a[o]|0;if(V<<24>>24==0){break}else{l=l+8|0;p=o;n=V}}Z=c[169382]|0}n=c[13528+((Z<<2|1)<<2)>>2]|0;p=a[n]|0;if(p<<24>>24==0){_=Z}else{l=64;V=n;n=p;while(1){pF(((c[29381]|0)-320>>1)+l|0,92,(n<<24>>24)+128|0);p=V+1|0;o=a[p]|0;if(o<<24>>24==0){break}else{l=l+8|0;V=p;n=o}}_=c[169382]|0}n=c[13528+((_<<2|2)<<2)>>2]|0;V=a[n]|0;if(V<<24>>24==0){$=_}else{l=64;o=n;n=V;while(1){pF(((c[29381]|0)-320>>1)+l|0,100,(n<<24>>24)+128|0);V=o+1|0;p=a[V]|0;if(p<<24>>24==0){break}else{l=l+8|0;o=V;n=p}}$=c[169382]|0}n=c[13528+(($<<2|3)<<2)>>2]|0;o=a[n]|0;if(o<<24>>24==0){break L2324}else{aa=64;ab=n;ac=o}while(1){pF(((c[29381]|0)-320>>1)+aa|0,108,(ac<<24>>24)+128|0);o=ab+1|0;n=a[o]|0;if(n<<24>>24==0){break}else{aa=aa+8|0;ab=o;ac=n}}break};case 12:{n=pN(75512)|0;pT(((c[29381]|0)-320>>1)+16|0,4,n);n=pN(76568)|0;o=(320-(c[n>>2]|0)|0)/2|0;pS(((c[29381]|0)-320>>1)+o|0,4,n);n=oh(72504,(m=i,i=i+16|0,c[m>>2]=(c[270802]|0)==1?72576:72560,c[m+8>>2]=72520,m)|0)|0;i=m;l=a[n]|0;if(l<<24>>24!=0){p=o;V=n;n=l;while(1){pF(((c[29381]|0)-320>>1)+p|0,32,(n<<24>>24)+128|0);l=V+1|0;B=a[l]|0;if(B<<24>>24==0){break}else{p=p+8|0;V=l;n=B}}}n=o+8|0;pF(((c[29381]|0)-320>>1)+n|0,52,193);V=o+16|0;pF(((c[29381]|0)-320>>1)+V|0,52,228);p=o+24|0;pF(((c[29381]|0)-320>>1)+p|0,52,228);B=o+32|0;pF(((c[29381]|0)-320>>1)+B|0,52,242);pF(o+40+((c[29381]|0)-320>>1)|0,52,229);pF(o+48+((c[29381]|0)-320>>1)|0,52,243);pF(o+56+((c[29381]|0)-320>>1)|0,52,243);pF(o+64+((c[29381]|0)-320>>1)|0,52,186);l=o+80|0;j=a[677440]|0;if(j<<24>>24!=0){Y=l;w=677440;U=j;while(1){pF(((c[29381]|0)-320>>1)+Y|0,52,(U<<24>>24)+128|0);j=w+1|0;X=a[j]|0;if(X<<24>>24==0){break}else{Y=Y+8|0;w=j;U=X}}}pF(((c[29381]|0)-320>>1)+n|0,72,208);pF(((c[29381]|0)-320>>1)+V|0,72,239);pF(((c[29381]|0)-320>>1)+p|0,72,242);pF(((c[29381]|0)-320>>1)+B|0,72,244);rh(o+72|0,64,6,1);U=a[1098536]|0;if(U<<24>>24!=0){w=l;Y=1098536;X=U;while(1){pF(((c[29381]|0)-320>>1)+w|0,72,(X<<24>>24)+128|0);U=Y+1|0;j=a[U]|0;if(j<<24>>24==0){break}else{w=w+8|0;Y=U;X=j}}}do{if((c[270802]|0)==0){X=n;Y=72336;w=83;while(1){pF(((c[29381]|0)-320>>1)+X|0,92,(w<<24>>24)+128|0);B=Y+1|0;j=a[B]|0;if(j<<24>>24==0){ad=n;ae=71920;af=74;break}else{X=X+8|0;Y=B;w=j}}while(1){pF(((c[29381]|0)-320>>1)+ad|0,108,(af<<24>>24)+128|0);w=ae+1|0;Y=a[w]|0;if(Y<<24>>24==0){break}else{ad=ad+8|0;ae=w;af=Y}}rh(V,116,22,1);Y=a[1098552]|0;if(Y<<24>>24==0){break}else{ag=p;ah=1098552;ai=Y}while(1){pF(((c[29381]|0)-320>>1)+ag|0,124,(ai<<24>>24)+128|0);Y=ah+1|0;w=a[Y]|0;if(w<<24>>24==0){break}else{ag=ag+8|0;ah=Y;ai=w}}}else{rh(n,84,2,1);pF(((c[29381]|0)-320>>1)+V|0,92,207);pF(((c[29381]|0)-320>>1)+p|0,92,203)}}while(0);pF(((c[29381]|0)-320>>1)+o|0,c[16040+(c[4014]<<2)>>2]|0,~~(+h[1153]*4.0)&1|12);V=c[4014]|0;if((V|0)==0){w=((yF(1098536)|0)<<3)+l|0;pF(w+((c[29381]|0)-320>>1)|0,72,~~(+h[1153]*4.0)&1|10);aj=c[4014]|0}else{aj=V}if((aj|0)==2){V=((yF(1098552)|0)<<3)+p|0;pF(V+((c[29381]|0)-320>>1)|0,124,~~(+h[1153]*4.0)&1|10)}V=a[1083160]|0;if(V<<24>>24==0){break L2324}else{ak=n;al=1083160;am=V}while(1){pF(((c[29381]|0)-320>>1)+ak|0,148,am<<24>>24);V=al+1|0;w=a[V]|0;if(w<<24>>24==0){break}else{ak=ak+8|0;al=V;am=w}}break};case 13:{n=pN(75512)|0;pT(((c[29381]|0)-320>>1)+16|0,4,n);n=pN(76568)|0;pS(((c[29381]|0)-320>>1)+((320-(c[n>>2]|0)|0)/2|0)|0,4,n);rh(152,32,10,1);pF(((c[29381]|0)-320>>1)+160|0,40,226);pF(((c[29381]|0)-320>>1)+168|0,40,229);pF(((c[29381]|0)-320>>1)+176|0,40,231);pF(((c[29381]|0)-320>>1)+184|0,40,233);pF(((c[29381]|0)-320>>1)+192|0,40,238);pF(((c[29381]|0)-320>>1)+200|0,40,160);pF(((c[29381]|0)-320>>1)+208|0,40,231);pF(((c[29381]|0)-320>>1)+216|0,40,225);pF(((c[29381]|0)-320>>1)+224|0,40,237);pF(((c[29381]|0)-320>>1)+232|0,40,229);n=0;p=75392;l=32;while(1){pF(((c[29381]|0)-320>>1)+n|0,56,(l<<24>>24)+128|0);o=p+1|0;w=a[o]|0;if(w<<24>>24==0){break}else{n=n+8|0;p=o;l=w}}l=oh(75304,(m=i,i=i+8|0,c[m>>2]=c[270772],m)|0)|0;i=m;p=a[l]|0;if(p<<24>>24==0){an=0;ao=75248;ap=32}else{n=160;w=l;l=p;while(1){pF(((c[29381]|0)-320>>1)+n|0,56,(l<<24>>24)+128|0);p=w+1|0;o=a[p]|0;if(o<<24>>24==0){an=0;ao=75248;ap=32;break}else{n=n+8|0;w=p;l=o}}}while(1){pF(((c[29381]|0)-320>>1)+an|0,64,(ap<<24>>24)+128|0);l=ao+1|0;w=a[l]|0;if(w<<24>>24==0){break}else{an=an+8|0;ao=l;ap=w}}if(+g[5344]!=0.0){w=160;l=75200;n=67;while(1){pF(((c[29381]|0)-320>>1)+w|0,64,(n<<24>>24)+128|0);o=l+1|0;p=a[o]|0;if(p<<24>>24==0){aq=0;ar=75128;as=32;break}else{w=w+8|0;l=o;n=p}}}else{pF(((c[29381]|0)-320>>1)+160|0,64,196);pF(((c[29381]|0)-320>>1)+168|0,64,229);pF(((c[29381]|0)-320>>1)+176|0,64,225);pF(((c[29381]|0)-320>>1)+184|0,64,244);pF(((c[29381]|0)-320>>1)+192|0,64,232);pF(((c[29381]|0)-320>>1)+200|0,64,237);pF(((c[29381]|0)-320>>1)+208|0,64,225);pF(((c[29381]|0)-320>>1)+216|0,64,244);pF(((c[29381]|0)-320>>1)+224|0,64,227);pF(((c[29381]|0)-320>>1)+232|0,64,232);aq=0;ar=75128;as=32}while(1){pF(((c[29381]|0)-320>>1)+aq|0,72,(as<<24>>24)+128|0);n=ar+1|0;l=a[n]|0;if(l<<24>>24==0){break}else{aq=aq+8|0;ar=n;as=l}}l=~~+g[478];do{if((c[155622]|0)==0){if((l|0)==2){at=74704}else if((l|0)==1){at=74776}else{at=74392}n=a[at]|0;if(n<<24>>24==0){au=0;av=74360;aw=32;break}else{ax=160;ay=at;az=n}while(1){pF(((c[29381]|0)-320>>1)+ax|0,72,(az<<24>>24)+128|0);n=ay+1|0;w=a[n]|0;if(w<<24>>24==0){au=0;av=74360;aw=32;break}else{ax=ax+8|0;ay=n;az=w}}}else{switch(l|0){case 2:{aA=74704;break};case 3:{aA=74560;break};case 4:{aA=74512;break};case 5:{aA=74496;break};case 6:{aA=74424;break};case 1:{aA=74776;break};default:{aA=74392}}w=a[aA]|0;if(w<<24>>24==0){au=0;av=74360;aw=32;break}else{aB=160;aC=aA;aD=w}while(1){pF(((c[29381]|0)-320>>1)+aB|0,72,(aD<<24>>24)+128|0);w=aC+1|0;n=a[w]|0;if(n<<24>>24==0){au=0;av=74360;aw=32;break}else{aB=aB+8|0;aC=w;aD=n}}}}while(0);while(1){pF(((c[29381]|0)-320>>1)+au|0,80,(aw<<24>>24)+128|0);l=av+1|0;n=a[l]|0;if(n<<24>>24==0){break}else{au=au+8|0;av=l;aw=n}}aE=+g[898];L2606:do{if(aE==0.0){n=160;l=74320;w=69;while(1){pF(((c[29381]|0)-320>>1)+n|0,80,(w<<24>>24)+128|0);p=l+1|0;o=a[p]|0;if(o<<24>>24==0){aF=0;aG=73608;aH=32;break}else{n=n+8|0;l=p;w=o}}}else{if(aE==1.0){w=160;l=74208;n=78;while(1){pF(((c[29381]|0)-320>>1)+w|0,80,(n<<24>>24)+128|0);o=l+1|0;p=a[o]|0;if(p<<24>>24==0){aF=0;aG=73608;aH=32;break L2606}else{w=w+8|0;l=o;n=p}}}if(aE==2.0){n=160;l=73872;w=72;while(1){pF(((c[29381]|0)-320>>1)+n|0,80,(w<<24>>24)+128|0);p=l+1|0;o=a[p]|0;if(o<<24>>24==0){aF=0;aG=73608;aH=32;break}else{n=n+8|0;l=p;w=o}}}else{w=160;l=73728;n=78;while(1){pF(((c[29381]|0)-320>>1)+w|0,80,(n<<24>>24)+128|0);o=l+1|0;p=a[o]|0;if(p<<24>>24==0){aF=0;aG=73608;aH=32;break}else{w=w+8|0;l=o;n=p}}}}}while(0);while(1){pF(((c[29381]|0)-320>>1)+aF|0,88,(aH<<24>>24)+128|0);n=aG+1|0;l=a[n]|0;if(l<<24>>24==0){break}else{aF=aF+8|0;aG=n;aH=l}}aE=+g[4862];do{if(aE==0.0){pF(((c[29381]|0)-320>>1)+160|0,88,238);pF(((c[29381]|0)-320>>1)+168|0,88,239);pF(((c[29381]|0)-320>>1)+176|0,88,238);pF(((c[29381]|0)-320>>1)+184|0,88,229);aI=0;aJ=73424;aK=32}else{l=oh(73536,(m=i,i=i+8|0,c[m>>2]=~~aE,m)|0)|0;i=m;n=a[l]|0;if(n<<24>>24==0){aI=0;aJ=73424;aK=32;break}else{aL=160;aM=l;aN=n}while(1){pF(((c[29381]|0)-320>>1)+aL|0,88,(aN<<24>>24)+128|0);n=aM+1|0;l=a[n]|0;if(l<<24>>24==0){aI=0;aJ=73424;aK=32;break}else{aL=aL+8|0;aM=n;aN=l}}}}while(0);while(1){pF(((c[29381]|0)-320>>1)+aI|0,96,(aK<<24>>24)+128|0);l=aJ+1|0;n=a[l]|0;if(n<<24>>24==0){break}else{aI=aI+8|0;aJ=l;aK=n}}aE=+g[442];do{if(aE==0.0){pF(((c[29381]|0)-320>>1)+160|0,96,238);pF(((c[29381]|0)-320>>1)+168|0,96,239);pF(((c[29381]|0)-320>>1)+176|0,96,238);pF(((c[29381]|0)-320>>1)+184|0,96,229);aO=0;aP=73328;aQ=32}else{n=oh(73400,(m=i,i=i+8|0,c[m>>2]=~~aE,m)|0)|0;i=m;l=a[n]|0;if(l<<24>>24==0){aO=0;aP=73328;aQ=32;break}else{aR=160;aS=n;aT=l}while(1){pF(((c[29381]|0)-320>>1)+aR|0,96,(aT<<24>>24)+128|0);l=aS+1|0;n=a[l]|0;if(n<<24>>24==0){aO=0;aP=73328;aQ=32;break}else{aR=aR+8|0;aS=l;aT=n}}}}while(0);while(1){pF(((c[29381]|0)-320>>1)+aO|0,112,(aQ<<24>>24)+128|0);n=aP+1|0;l=a[n]|0;if(l<<24>>24==0){break}else{aO=aO+8|0;aP=n;aQ=l}}do{if((c[278834]|0)==0){l=c[145608]|0;if((c[155622]|0)==0){n=c[19512+(l*12|0)>>2]|0;w=a[n]|0;if(w<<24>>24==0){aU=0;aV=73280;aW=32;break}else{aX=160;aY=n;aZ=w}while(1){pF(((c[29381]|0)-320>>1)+aX|0,112,(aZ<<24>>24)+128|0);w=aY+1|0;n=a[w]|0;if(n<<24>>24==0){aU=0;aV=73280;aW=32;break}else{aX=aX+8|0;aY=w;aZ=n}}}else{n=c[5456+(l*12|0)>>2]|0;w=a[n]|0;if(w<<24>>24==0){aU=0;aV=73280;aW=32;break}else{a_=160;a$=n;a0=w}while(1){pF(((c[29381]|0)-320>>1)+a_|0,112,(a0<<24>>24)+128|0);w=a$+1|0;n=a[w]|0;if(n<<24>>24==0){aU=0;aV=73280;aW=32;break}else{a_=a_+8|0;a$=w;a0=n}}}}else{l=c[18880+((c[145608]|0)*12|0)>>2]|0;n=a[l]|0;if(n<<24>>24==0){aU=0;aV=73280;aW=32;break}else{a1=160;a2=l;a3=n}while(1){pF(((c[29381]|0)-320>>1)+a1|0,112,(a3<<24>>24)+128|0);n=a2+1|0;l=a[n]|0;if(l<<24>>24==0){aU=0;aV=73280;aW=32;break}else{a1=a1+8|0;a2=n;a3=l}}}}while(0);while(1){pF(((c[29381]|0)-320>>1)+aU|0,120,(aW<<24>>24)+128|0);l=aV+1|0;n=a[l]|0;if(n<<24>>24==0){break}else{aU=aU+8|0;aV=l;aW=n}}do{if((c[278834]|0)==0){n=c[145608]|0;if((c[155622]|0)==0){l=c[19516+(n*12|0)>>2]|0;w=c[145606]|0;p=c[15740+(w+l<<3)>>2]|0;o=a[p]|0;if(o<<24>>24==0){a4=l;a5=w}else{w=160;l=p;p=o;while(1){pF(((c[29381]|0)-320>>1)+w|0,120,(p<<24>>24)+128|0);o=l+1|0;V=a[o]|0;if(V<<24>>24==0){break}else{w=w+8|0;l=o;p=V}}a4=c[19516+((c[145608]|0)*12|0)>>2]|0;a5=c[145606]|0}p=c[15736+(a4+a5<<3)>>2]|0;l=a[p]|0;if(l<<24>>24==0){break}else{a6=160;a7=p;a8=l}while(1){pF(((c[29381]|0)-320>>1)+a6|0,128,(a8<<24>>24)+128|0);l=a7+1|0;p=a[l]|0;if(p<<24>>24==0){break}else{a6=a6+8|0;a7=l;a8=p}}}else{p=c[5460+(n*12|0)>>2]|0;l=c[145606]|0;w=c[5324+(l+p<<3)>>2]|0;V=a[w]|0;if(V<<24>>24==0){a9=p;ba=l}else{l=160;p=w;w=V;while(1){pF(((c[29381]|0)-320>>1)+l|0,120,(w<<24>>24)+128|0);V=p+1|0;o=a[V]|0;if(o<<24>>24==0){break}else{l=l+8|0;p=V;w=o}}a9=c[5460+((c[145608]|0)*12|0)>>2]|0;ba=c[145606]|0}w=c[5320+(a9+ba<<3)>>2]|0;p=a[w]|0;if(p<<24>>24==0){break}else{bb=160;bc=w;bd=p}while(1){pF(((c[29381]|0)-320>>1)+bb|0,128,(bd<<24>>24)+128|0);p=bc+1|0;w=a[p]|0;if(w<<24>>24==0){break}else{bb=bb+8|0;bc=p;bd=w}}}}else{w=c[18884+((c[145608]|0)*12|0)>>2]|0;p=c[145606]|0;l=c[18740+(p+w<<3)>>2]|0;n=a[l]|0;if(n<<24>>24==0){be=w;bf=p}else{p=160;w=l;l=n;while(1){pF(((c[29381]|0)-320>>1)+p|0,120,(l<<24>>24)+128|0);n=w+1|0;o=a[n]|0;if(o<<24>>24==0){break}else{p=p+8|0;w=n;l=o}}be=c[18884+((c[145608]|0)*12|0)>>2]|0;bf=c[145606]|0}l=c[18736+(be+bf<<3)>>2]|0;w=a[l]|0;if(w<<24>>24==0){break}else{bg=160;bh=l;bi=w}while(1){pF(((c[29381]|0)-320>>1)+bg|0,128,(bi<<24>>24)+128|0);w=bh+1|0;l=a[w]|0;if(l<<24>>24==0){break}else{bg=bg+8|0;bh=w;bi=l}}}}while(0);pF(((c[29381]|0)-320>>1)+144|0,c[19264+(c[285140]<<2)>>2]|0,~~(+h[1153]*4.0)&1|12);if(!(a[15376]|0)){break L2324}if(+h[1153]- +h[1923]>=5.0){a[15376]=0;break L2324}rh(56,138,24,4);l=64;w=73232;p=32;while(1){pF(((c[29381]|0)-320>>1)+l|0,146,(p<<24>>24)+128|0);o=w+1|0;n=a[o]|0;if(n<<24>>24==0){bj=64;bk=72800;bl=32;break}else{l=l+8|0;w=o;p=n}}while(1){pF(((c[29381]|0)-320>>1)+bj|0,154,(bl<<24>>24)+128|0);p=bk+1|0;w=a[p]|0;if(w<<24>>24==0){bm=64;bn=72720;bo=108;break}else{bj=bj+8|0;bk=p;bl=w}}while(1){pF(((c[29381]|0)-320>>1)+bm|0,162,(bo<<24>>24)+128|0);w=bn+1|0;p=a[w]|0;if(p<<24>>24==0){bp=64;bq=72616;br=32;break}else{bm=bm+8|0;bn=w;bo=p}}while(1){pF(((c[29381]|0)-320>>1)+bp|0,170,(br<<24>>24)+128|0);p=bq+1|0;w=a[p]|0;if(w<<24>>24==0){break}else{bp=bp+8|0;bq=p;br=w}}break};case 14:{w=pN(76568)|0;pS(((c[29381]|0)-320>>1)+((320-(c[w>>2]|0)|0)/2|0)|0,4,w);rh(108,32,12,1);w=116;p=75928;l=83;while(1){pF(((c[29381]|0)-320>>1)+w|0,40,(l<<24>>24)+128|0);n=p+1|0;o=a[n]|0;if(o<<24>>24==0){break}else{w=w+8|0;p=n;l=o}}if((c[153848]|0)!=0){r1();break L2324}if(!(a[3880]|0)){a[3880]=1;h[486]=+h[1153]}if((c[278830]|0)==0){bs=72;bt=75736;bu=78}else{c[278172]=3;c[270782]=15;a[15512]=1;c[153842]=0;c[270798]=0;a[1083160]=0;a[3480]=0;break L2324}while(1){pF(((c[29381]|0)-320>>1)+bs|0,64,bu<<24>>24);l=bt+1|0;p=a[l]|0;if(p<<24>>24==0){break}else{bs=bs+8|0;bt=l;bu=p}}if(+h[1153]- +h[486]<3.0){break L2324}c[278172]=3;c[270782]=12;a[15512]=1;p=c[4014]|0;l=c[270802]|0;do{if((p|0)==-1){if((l|0)==0){c[4014]=2;break}else{c[4014]=1;break}}else{if(!((l|0)==1&(p|0)==2)){break}c[4014]=1}}while(0);p=c[28092]|0;c[274636]=p;cl(1098536,76584,(m=i,i=i+8|0,c[m>>2]=p,m)|0)|0;i=m;c[270798]=0;a[1083160]=0;break};case 15:{p=e|0;l=f|0;if(!(a[3480]|0)){w=c[278830]|0;L2720:do{if((w|0)>1){o=0;L2721:while(1){n=o+1|0;if((n|0)>=(w|0)){break L2720}V=1114504+(o*88|0)|0;Y=n;while(1){X=1114504+(Y*88|0)|0;if((cS(X|0,V|0)|0)<0){yJ(l|0,X|0,88)|0;yJ(X|0,V|0,88)|0;yJ(V|0,l|0,88)|0}X=Y+1|0;if((X|0)<(w|0)){Y=X}else{o=n;continue L2721}}}}}while(0);a[3480]=1}w=pN(76568)|0;pS(((c[29381]|0)-320>>1)+((320-(c[w>>2]|0)|0)/2|0)|0,4,w);if((c[278830]|0)>0){w=0;do{l=c[1114572+(w*88|0)>>2]|0;o=1114504+(w*88|0)|0;n=1114520+(w*88|0)|0;if((l|0)==0){cl(p|0,76304,(m=i,i=i+16|0,c[m>>2]=o,c[m+8>>2]=n,m)|0)|0;i=m}else{Y=c[1114568+(w*88|0)>>2]|0;cl(p|0,76480,(m=i,i=i+32|0,c[m>>2]=o,c[m+8>>2]=n,c[m+16>>2]=Y,c[m+24>>2]=l,m)|0)|0;i=m}l=(w<<3)+32|0;Y=a[p]|0;if(Y<<24>>24!=0){n=16;o=p;V=Y;while(1){pF(((c[29381]|0)-320>>1)+n|0,l,(V<<24>>24)+128|0);Y=o+1|0;X=a[Y]|0;if(X<<24>>24==0){break}else{n=n+8|0;o=Y;V=X}}}w=w+1|0;}while((w|0)<(c[278830]|0))}pF((c[29381]|0)-320>>1,(c[153842]<<3)+32|0,~~(+h[1153]*4.0)&1|12);w=a[1083160]|0;if(w<<24>>24==0){break L2324}else{bv=16;bw=1083160;bx=w}while(1){pF(((c[29381]|0)-320>>1)+bv|0,148,bx<<24>>24);w=bw+1|0;p=a[w]|0;if(p<<24>>24==0){break}else{bv=bv+8|0;bw=w;bx=p}}break};default:{}}}while(0);if(!(a[15512]|0)){i=b;return}vP(81096);a[15512]=0;i=b;return}function ru(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+88|0;e=d|0;f=d+80|0;switch(c[270782]|0){case 5:{if((b|0)==27){if((c[278172]|0)!=3){c[270786]=c[353663];c[353663]=-1}c[278172]=3;c[270782]=1;a[15512]=1;i=d;return}else if((b|0)==13){a[15512]=1;h=c[270802]|0;if((h|0)==1){if((c[45868]|0)==0){i=d;return}c[278172]=3;c[270782]=12;a[15512]=1;j=c[4014]|0;if((j|0)==(-1|0)){c[4014]=1}else if((j|0)==2){c[4014]=1}j=c[28092]|0;c[274636]=j;cl(1098536,76584,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;c[270798]=0;a[1083160]=0;i=d;return}else if((h|0)==0){if((c[45868]|0)==0){i=d;return}c[278172]=3;c[270782]=12;a[15512]=1;if((c[4014]|0)==-1){c[4014]=2}j=c[28092]|0;c[274636]=j;cl(1098536,76584,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;c[270798]=0;a[1083160]=0;i=d;return}else if((h|0)==2){c[278172]=3;c[270782]=6;a[15512]=1;yQ(620464,c[5527]|0)|0;yQ(620480,c[4635]|0)|0;h=~~+g[5600];j=h>>4;c[155112]=j;c[155110]=j;j=h&15;c[155114]=j;c[155124]=j;i=d;return}else{i=d;return}}else if((b|0)==274){vP(79328);j=(c[270802]|0)+1|0;c[270802]=j;if((j|0)<=2){i=d;return}c[270802]=0;i=d;return}else if((b|0)==273){vP(79328);j=(c[270802]|0)-1|0;c[270802]=j;if((j|0)>=0){i=d;return}c[270802]=2;i=d;return}else{i=d;return}break};case 1:{if((b|0)==27){c[278172]=0;c[270782]=0;j=c[270786]|0;c[353663]=j;if(!((c[353697]|0)==0&(j|0)!=-1&(c[353150]|0)>>>0<3)){i=d;return}nj();i=d;return}else if((b|0)==273){vP(79328);j=(c[270804]|0)-1|0;c[270804]=j;if((j|0)>=0){i=d;return}c[270804]=4;i=d;return}else if((b|0)==13){a[15512]=1;switch(c[270804]|0){case 0:{c[278172]=3;c[270782]=2;a[15512]=1;i=d;return};case 1:{c[278172]=3;c[270782]=5;a[15512]=1;i=d;return};case 3:{c[278172]=3;c[270782]=10;a[15512]=1;c[278836]=0;i=d;return};case 4:{c[29316]=(c[278172]|0)==3;c[278172]=3;c[270800]=1;c[270782]=11;a[15512]=1;c[169382]=(aQ()|0)&7;i=d;return};case 2:{c[278172]=3;c[270782]=7;a[15512]=1;i=d;return};default:{i=d;return}}}else if((b|0)==274){vP(79328);j=(c[270804]|0)+1|0;c[270804]=j;if((j|0)<=4){i=d;return}c[270804]=0;i=d;return}else{i=d;return}break};case 2:{if((b|0)==273){vP(79328);j=(c[270784]|0)-1|0;c[270784]=j;if((j|0)>=0){i=d;return}c[270784]=2;i=d;return}else if((b|0)==13){a[15512]=1;j=c[270784]|0;if((j|0)==0){c[278172]=0;if((c[46140]|0)!=0){ov(74344,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k}ov(76728,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k;ov(76648,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k;i=d;return}else if((j|0)==1){a[15512]=1;c[270782]=3;c[278172]=3;ry();i=d;return}else if((j|0)==2){if((c[46140]|0)==0|(c[642381]|0)!=0|(c[45874]|0)!=1){i=d;return}a[15512]=1;c[270782]=4;c[278172]=3;ry();i=d;return}else{i=d;return}}else if((b|0)==274){vP(79328);j=(c[270784]|0)+1|0;c[270784]=j;if((j|0)<=2){i=d;return}c[270784]=0;i=d;return}else if((b|0)==27){if((c[278172]|0)!=3){c[270786]=c[353663];c[353663]=-1}c[278172]=3;c[270782]=1;a[15512]=1;i=d;return}else{i=d;return}break};case 3:{switch(b|0){case 274:case 276:{vP(79328);j=(c[274556]|0)+1|0;c[274556]=j;if((j|0)<=11){i=d;return}c[274556]=0;i=d;return};case 27:{c[278172]=3;c[270782]=2;a[15512]=1;i=d;return};case 273:case 275:{vP(79328);j=(c[274556]|0)-1|0;c[274556]=j;if((j|0)>=0){i=d;return}c[274556]=11;i=d;return};case 13:{vP(81096);if((c[1098176+(c[274556]<<2)>>2]|0)==0){i=d;return}c[270782]=0;c[278172]=0;ve();ov(76832,(k=i,i=i+8|0,c[k>>2]=c[274556],k)|0);i=k;i=d;return};default:{i=d;return}}break};case 4:{switch(b|0){case 273:case 275:{vP(79328);j=(c[274556]|0)-1|0;c[274556]=j;if((j|0)>=0){i=d;return}c[274556]=11;i=d;return};case 274:case 276:{vP(79328);j=(c[274556]|0)+1|0;c[274556]=j;if((j|0)<=11){i=d;return}c[274556]=0;i=d;return};case 27:{c[278172]=3;c[270782]=2;a[15512]=1;i=d;return};case 13:{c[270782]=0;c[278172]=0;ov(76944,(k=i,i=i+8|0,c[k>>2]=c[274556],k)|0);i=k;i=d;return};default:{i=d;return}}break};case 6:{L2894:do{switch(b|0){case 275:{if((c[940]|0)<2){i=d;return}vP(75184);j=c[940]|0;if((j|0)==2){h=(c[155110]|0)-1|0;c[155110]=h;l=h;break L2894}else if((j|0)==3){c[155124]=(c[155124]|0)-1;m=2132;break L2894}else{m=2132;break L2894}break};case 27:{c[278172]=3;c[270782]=5;a[15512]=1;m=2132;break};case 273:{vP(79328);j=(c[940]|0)-1|0;c[940]=j;if((j|0)>=0){m=2132;break L2894}c[940]=4;m=2132;break};case 274:{vP(79328);j=(c[940]|0)+1|0;c[940]=j;if((j|0)<=4){m=2132;break L2894}c[940]=0;m=2132;break};case 276:{if((c[940]|0)>=2){m=2110;break L2894}i=d;return};case 13:{j=c[940]|0;if(j>>>0<2){i=d;return}if((j-2|0)>>>0<2){m=2110;break L2894}if((cS(c[5527]|0,620464)|0)!=0){ov(77360,(k=i,i=i+8|0,c[k>>2]=620464,k)|0);i=k}if((cS(c[4635]|0,620480)|0)!=0){o9(77224,620480)}j=c[155110]|0;h=c[155124]|0;if(!((j|0)==(c[155112]|0)&(h|0)==(c[155114]|0))){ov(77024,(k=i,i=i+16|0,c[k>>2]=j,c[k+8>>2]=h,k)|0);i=k}c[278172]=3;c[270782]=5;a[15512]=1;m=2132;break};case 8:{h=c[940]|0;if(!((h|0)!=0|(a[620480]|0)==0)){a[620480+((yF(620480)|0)-1)|0]=0}if((h|0)!=1|(a[620464]|0)==0){m=2132;break L2894}a[620464+((yF(620464)|0)-1)|0]=0;m=2132;break};default:{if((b-32|0)>>>0>95){m=2132;break L2894}h=c[940]|0;if((h|0)==0){j=yF(620480)|0;if((j|0)>=15){m=2132;break L2894}a[j+620481|0]=0;a[620480+j|0]=b&255;m=2132;break L2894}else if((h|0)==1){h=yF(620464)|0;if((h|0)>=15){m=2132;break L2894}a[h+620465|0]=0;a[620464+h|0]=b&255;m=2132;break L2894}else{m=2132;break L2894}}}}while(0);do{if((m|0)==2110){vP(75184);h=c[940]|0;if((h|0)==2){j=(c[155110]|0)+1|0;c[155110]=j;l=j;break}else if((h|0)==3){c[155124]=(c[155124]|0)+1;m=2132;break}else{m=2132;break}}}while(0);if((m|0)==2132){l=c[155110]|0}do{if((l|0)>13){c[155110]=0}else{if((l|0)>=0){break}c[155110]=13}}while(0);l=c[155124]|0;if((l|0)>13){c[155124]=0;i=d;return}if((l|0)>=0){i=d;return}c[155124]=13;i=d;return};case 7:{L2957:do{switch(b|0){case 27:{if((c[278172]|0)!=3){c[270786]=c[353663];c[353663]=-1}c[278172]=3;c[270782]=1;a[15512]=1;break};case 13:{a[15512]=1;l=c[159934]|0;if((l|0)==0){c[278172]=3;c[270782]=9;a[15512]=1;i=d;return}else if((l|0)==1){c[270782]=0;oR();i=d;return}else if((l|0)==2){ov(80008,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k;i=d;return}else if((l|0)==12){c[278172]=3;c[270782]=8;a[15512]=1;i=d;return}else{rw(1);i=d;return}break};case 273:{vP(79328);l=(c[159934]|0)-1|0;c[159934]=l;if((l|0)>=0){break L2957}c[159934]=19;break};case 274:{vP(79328);l=(c[159934]|0)+1|0;c[159934]=l;if((l|0)<=19){break L2957}c[159934]=0;break};case 275:{rw(-1);break};case 276:{rw(1);break};default:{}}}while(0);if((c[159934]|0)!=12|(c[29372]|0)!=0){i=d;return}if((b|0)==273){c[159934]=11;i=d;return}else{c[159934]=13;i=d;return}break};case 9:{l=e|0;if(a[26896]|0){vP(79328);if((b|0)==27){a[26896]=0}else if((b|0)!=96){e=qG(b)|0;m=c[26712+(c[275014]<<3)>>2]|0;cl(l|0,88e3,(k=i,i=i+16|0,c[k>>2]=e,c[k+8>>2]=m,k)|0)|0;i=k;ow(l)}a[26896]=0;i=d;return}switch(b|0){case 27:{c[278172]=3;c[270782]=7;a[15512]=1;i=d;return};case 275:case 273:{vP(79328);l=(c[275014]|0)-1|0;c[275014]=l;if((l|0)>=0){i=d;return}c[275014]=18;i=d;return};case 274:case 276:{vP(79328);l=(c[275014]|0)+1|0;c[275014]=l;if(l>>>0<=18){i=d;return}c[275014]=0;i=d;return};case 13:{l=c[26712+(c[275014]<<3)>>2]|0;m=f+4|0;c[m>>2]=-1;c[f>>2]=-1;e=yF(l|0)|0;h=0;j=0;L3012:while(1){n=c[1101536+(h<<2)>>2]|0;do{if((n|0)==0){o=j}else{if((bN(n|0,l|0,e|0)|0)!=0){o=j;break}c[f+(j<<2)>>2]=h;p=j+1|0;if((p|0)==2){break L3012}else{o=p}}}while(0);n=h+1|0;if((n|0)<367){h=n;j=o}else{break}}vP(81096);if((c[m>>2]|0)!=-1){m=c[26712+(c[275014]<<3)>>2]|0;o=yF(m|0)|0;j=0;do{h=c[1101536+(j<<2)>>2]|0;do{if((h|0)!=0){if((bN(h|0,m|0,o|0)|0)!=0){break}qR(j,0)}}while(0);j=j+1|0;}while((j|0)<367)}a[26896]=1;i=d;return};case 8:case 127:{vP(81096);j=c[26712+(c[275014]<<3)>>2]|0;o=yF(j|0)|0;m=0;do{h=c[1101536+(m<<2)>>2]|0;do{if((h|0)!=0){if((bN(h|0,j|0,o|0)|0)!=0){break}qR(m,0)}}while(0);m=m+1|0;}while((m|0)<367);i=d;return};default:{i=d;return}}break};case 8:{fs[c[29370]&255](b);i=d;return};case 10:{switch(b|0){case 27:{if((c[278172]|0)!=3){c[270786]=c[353663];c[353663]=-1}c[278172]=3;c[270782]=1;a[15512]=1;i=d;return};case 273:case 276:{a[15512]=1;m=(c[278836]|0)+1|0;c[278836]=m;if((m|0)<=5){i=d;return}c[278836]=0;i=d;return};case 274:case 275:{a[15512]=1;m=(c[278836]|0)-1|0;c[278836]=m;if((m|0)>=0){i=d;return}c[278836]=5;i=d;return};default:{i=d;return}}break};case 11:{c[278172]=1;qd();fL[c[350582]&63](7,0)|0;i=d;return};case 12:{L3061:do{switch(b|0){case 27:{c[278172]=3;c[270782]=5;a[15512]=1;break};case 273:{vP(79328);m=(c[4014]|0)-1|0;c[4014]=m;if((m|0)>=0){break L3061}c[4014]=2;break};case 274:{vP(79328);m=(c[4014]|0)+1|0;c[4014]=m;if((m|0)<=2){break L3061}c[4014]=0;break};case 13:{if((c[4014]|0)==0){break L3061}a[15512]=1;ov(88120,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k;c[169350]=c[274636];m=c[4014]|0;if((m|0)==2){c[270788]=c[270782];c[270798]=1;c[278172]=0;c[270782]=0;ov(77880,(k=i,i=i+8|0,c[k>>2]=1098552,k)|0);i=k;break L3061}else if((m|0)!=1){break L3061}m=(c[270802]|0)==1;c[278172]=3;if(!m){c[270782]=14;a[15512]=0;c[153844]=1;c[886]=0;a[3880]=0;r$();break L3061}c[270782]=13;a[15512]=1;m=c[270772]|0;if((m|0)==0){o=c[45874]|0;c[270772]=o;q=o}else{q=m}if((q|0)>=2){break L3061}c[270772]=c[45875];break};case 8:{m=c[4014]|0;if(!((m|0)!=0|(a[1098536]|0)==0)){a[1098536+((yF(1098536)|0)-1)|0]=0}if((m|0)!=2|(a[1098552]|0)==0){break L3061}a[1098552+((yF(1098552)|0)-1)|0]=0;break};default:{if((b-32|0)>>>0>95){break L3061}m=c[4014]|0;if((m|0)==2){o=yF(1098552)|0;if((o|0)>=21){break L3061}a[o+1098553|0]=0;a[1098552+o|0]=b&255;break L3061}if(!((b-48|0)>>>0<10&(m|0)==0)){break L3061}m=yF(1098536)|0;if((m|0)>=5){break L3061}a[m+1098537|0]=0;a[1098536+m|0]=b&255}}}while(0);do{if((c[270802]|0)==1&(c[4014]|0)==2){if((b|0)==273){c[4014]=1;break}else{c[4014]=0;break}}}while(0);q=nE(1098536)|0;m=(q|0)<65535?q:65535;c[274636]=m;cl(1098536,76584,(k=i,i=i+8|0,c[k>>2]=m,k)|0)|0;i=k;i=d;return};case 13:{switch(b|0){case 27:{c[278172]=3;c[270782]=5;a[15512]=1;i=d;return};case 273:{vP(79328);m=(c[285140]|0)-1|0;c[285140]=m;if((m|0)>=0){i=d;return}c[285140]=8;i=d;return};case 274:{vP(79328);m=(c[285140]|0)+1|0;c[285140]=m;if((m|0)<=8){i=d;return}c[285140]=0;i=d;return};case 275:{if((c[285140]|0)==0){i=d;return}vP(75184);rv(-1);i=d;return};case 276:{if((c[285140]|0)==0){i=d;return}vP(75184);rv(1);i=d;return};case 13:{vP(81096);if((c[285140]|0)!=0){rv(1);i=d;return}if((c[46140]|0)!=0){ov(74344,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k}ov(73312,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k;ov(72456,(k=i,i=i+8|0,c[k>>2]=c[270772],k)|0);i=k;ve();if((c[278834]|0)!=0){ov(71376,(k=i,i=i+8|0,c[k>>2]=c[18736+((c[145606]|0)+(c[18884+((c[145608]|0)*12|0)>>2]|0)<<3)>>2],k)|0);i=k;i=d;return}m=c[145608]|0;if((c[155622]|0)==0){ov(71376,(k=i,i=i+8|0,c[k>>2]=c[15736+((c[145606]|0)+(c[19516+(m*12|0)>>2]|0)<<3)>>2],k)|0);i=k;i=d;return}else{ov(71376,(k=i,i=i+8|0,c[k>>2]=c[5320+((c[145606]|0)+(c[5460+(m*12|0)>>2]|0)<<3)>>2],k)|0);i=k;i=d;return}break};default:{i=d;return}}break};case 15:{switch(b|0){case 27:{c[278172]=3;c[270782]=12;a[15512]=1;b=c[4014]|0;m=c[270802]|0;do{if((b|0)==-1){if((m|0)==0){c[4014]=2;break}else{c[4014]=1;break}}else{if(!((m|0)==1&(b|0)==2)){break}c[4014]=1}}while(0);b=c[28092]|0;c[274636]=b;cl(1098536,76584,(k=i,i=i+8|0,c[k>>2]=b,k)|0)|0;i=k;c[270798]=0;a[1083160]=0;i=d;return};case 32:{c[278172]=3;c[270782]=14;a[15512]=0;c[153844]=1;c[886]=0;a[3880]=0;r$();i=d;return};case 273:case 275:{vP(79328);b=(c[153842]|0)-1|0;c[153842]=b;if((b|0)>=0){i=d;return}c[153842]=(c[278830]|0)-1;i=d;return};case 274:case 276:{vP(79328);b=(c[153842]|0)+1|0;c[153842]=b;if((b|0)<(c[278830]|0)){i=d;return}c[153842]=0;i=d;return};case 13:{vP(81096);c[270788]=c[270782];c[270798]=1;a[3480]=0;c[278172]=0;c[270782]=0;ov(77880,(k=i,i=i+8|0,c[k>>2]=1114536+((c[153842]|0)*88|0),k)|0);i=k;i=d;return};default:{i=d;return}}break};default:{i=d;return}}}function rv(b){b=b|0;var d=0.0,e=0.0,f=0.0,i=0,j=0,k=0,l=0.0,m=0.0,n=0,o=0;switch(c[285140]|0){case 3:{d=(c[155622]|0)==0?2.0:6.0;pa(89160,+(b|0)+ +g[478]);e=+g[478];if(e>d){pa(89160,0.0);return}if(e>=0.0){return}pa(89160,d);return};case 4:{pa(88920,+(b|0)+ +g[898]);d=+g[898];if(d>3.0){pa(88920,0.0);f=+g[898]}else{f=d}if(f>=0.0){return}pa(88920,3.0);return};case 1:{i=(c[270772]|0)+b|0;c[270772]=i;j=c[45875]|0;if((i|0)>(j|0)){c[270772]=j;a[15376]=1;h[1923]=+h[1153];k=j}else{k=i}if((k|0)>=2){return}c[270772]=2;return};case 2:{pa(89232,+(+g[5344]==0.0|0));return};case 5:{pa(88456,+(b*10|0|0)+ +g[4862]);f=+g[4862];if(f>100.0){pa(88456,0.0);l=+g[4862]}else{l=f}if(l>=0.0){return}pa(88456,100.0);return};case 6:{pa(88288,+(b*5|0|0)+ +g[442]);l=+g[442];if(l>60.0){pa(88288,0.0);m=+g[442]}else{m=l}if(m>=0.0){return}pa(88288,60.0);return};case 7:{k=(c[145608]|0)+b|0;c[145608]=k;do{if((c[278834]|0)==0){if((c[155622]|0)!=0){n=4;break}n=+g[2296]!=0.0?7:2}else{n=6}}while(0);do{if((k|0)<0){c[145608]=n-1}else{if((k|0)<(n|0)){break}c[145608]=0}}while(0);c[145606]=0;return};case 8:{n=(c[145606]|0)+b|0;c[145606]=n;do{if((c[278834]|0)==0){b=c[145608]|0;if((c[155622]|0)==0){o=19520+(b*12|0)|0;break}else{o=5464+(b*12|0)|0;break}}else{o=18888+((c[145608]|0)*12|0)|0}}while(0);b=c[o>>2]|0;if((n|0)<0){c[145606]=b-1;return}if((n|0)<(b|0)){return}c[145606]=0;return};default:{return}}}function rw(a){a=a|0;var b=0.0,d=0.0;vP(75184);switch(c[159934]|0){case 4:{b=+g[234]- +(a|0)*.05;d=b<.5?.5:b;b=d>1.0?1.0:d;g[234]=b;pa(79712,b);return};case 3:{b=+(a*10|0|0)+ +g[1034];d=b<30.0?30.0:b;b=d>120.0?120.0:d;g[1034]=b;pa(79832,b);return};case 9:{pa(78576,-0.0- +g[3854]);return};case 7:{b=+(a|0)*.1+ +g[46];d=b<0.0?0.0:b;b=d>1.0?1.0:d;g[46]=b;pa(79320,b);return};case 6:{b=+(a|0)*.1+ +g[6730];d=b<0.0?0.0:b;b=d>1.0?1.0:d;g[6730]=b;pa(79424,b);return};case 10:{pa(78432,+(+g[3898]==0.0|0));return};case 8:{if(+g[5558]>200.0){pa(79224,200.0);pa(79072,200.0);return}else{pa(79224,400.0);pa(79072,400.0);return}break};case 5:{b=+(a|0)*.5+ +g[960];d=b<1.0?1.0:b;b=d>11.0?11.0:d;g[960]=b;pa(79544,b);return};case 11:{pa(78248,+(+g[3884]==0.0|0));return};case 13:{pa(78184,+g[(o4(78184)|0)+16>>2]!=0.0?0.0:1.0);return};case 14:{pa(78032,+g[(o4(78032)|0)+16>>2]!=0.0?0.0:1.0);return};case 15:{pa(77976,+g[(o4(77976)|0)+16>>2]!=0.0?0.0:1.0);return};case 16:{pa(77936,+g[(o4(77936)|0)+16>>2]!=0.0?0.0:1.0);return};case 17:{pa(77864,+g[(o4(77864)|0)+16>>2]==60.0?50.0:60.0);return};case 18:{pa(77808,+(+g[(o4(77808)|0)+16>>2]==0.0|0));return};case 19:{pa(77680,+(+g[(o4(77680)|0)+16>>2]==0.0|0));return};default:{return}}}function rx(a,b){a=a|0;b=+b;var d=0.0;d=b<0.0?0.0:b;pF(((c[29381]|0)-320>>1)+212|0,a,128);rf(220,a,129);rf(228,a,129);rf(236,a,129);rf(244,a,129);rf(252,a,129);rf(260,a,129);rf(268,a,129);rf(276,a,129);rf(284,a,129);rf(292,a,129);rf(300,a,130);rf(~~((d>1.0?72.0:d*72.0)+220.0),a,131);return}function ry(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+136|0;d=b+128|0;e=b|0;f=0;do{g=1083224+(f*40|0)|0;yJ(g|0,63200,20)|0;h=1098176+(f<<2)|0;c[h>>2]=0;cl(e|0,63136,(j=i,i=i+24|0,c[j>>2]=1411672,c[j+8>>2]=47,c[j+16>>2]=f,j)|0)|0;i=j;k=dc(e|0,63104)|0;if((k|0)!=0){d_(k|0,63032,(j=i,i=i+8|0,c[j>>2]=d,j)|0)|0;i=j;d_(k|0,63024,(j=i,i=i+8|0,c[j>>2]=e,j)|0)|0;i=j;yP(g|0,e|0,39)|0;g=0;do{j=1083224+(f*40|0)+g|0;if((a[j]|0)==95){a[j]=32}g=g+1|0;}while((g|0)<39);c[h>>2]=1;aS(k|0)|0}f=f+1|0;}while((f|0)<12);i=b;return}function rz(a){a=a|0;oE(107760,230);c[169396]=a;return}function rA(){var a=0,b=0,d=0;a=i;b=c[651352]|0;oW(76400,(d=i,i=i+16|0,c[d>>2]=c[651354],c[d+8>>2]=b,d)|0);i=d;i=a;return}function rB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0.0,m=0.0,n=0.0;d=i;e=a+164|0;if((a|0)==0){f=2479}else{a=c[e>>2]|0;if((a|0)==0){f=2479}else{h=a}}if((f|0)==2479){w1(105984,(f=i,i=i+8|0,c[f>>2]=110424,f)|0);i=f;h=c[e>>2]|0}if((c[h>>2]|0)<0){j=h;k=j;i=d;return k|0}l=+g[b>>2];m=+g[b+4>>2];n=+g[b+8>>2];b=h;while(1){h=c[b+40>>2]|0;e=c[(l*+g[h>>2]+m*+g[h+4>>2]+n*+g[h+8>>2]- +g[h+12>>2]>0.0?b+44|0:b+48|0)>>2]|0;if((c[e>>2]|0)<0){j=e;break}else{b=e}}k=j;i=d;return k|0}function rC(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((c[157536]|0)==(b|0)&(c[157537]|0)==(e|0)){c[651354]=(c[651354]|0)+1;f=c[157538]|0;return f|0}if((c[157539]|0)==(b|0)&(c[157540]|0)==(e|0)){c[651354]=(c[651354]|0)+1;g=c[157539]|0;h=c[157540]|0;i=c[157541]|0}else{j=c[157541]|0;do{if((c[b+140>>2]|0)==(e|0)){c[j>>2]=c[b+136>>2];yG(j+4|0,-1|0,c[157534]|0)}else{k=c[e+40>>2]|0;l=c[b+136>>2]|0;m=j|0;c[m>>2]=l;n=j+4|0;o=n;p=c[157534]|0;if((k|0)==0){yG(o|0,-1|0,p|0);break}yG(o|0,0,p|0);p=k;k=0;o=0;q=n;n=l;while(1){l=a[p]|0;r=p+1|0;do{if(l<<24>>24==0){s=d[r]|0;t=p+2|0;u=s>>>2;v=s<<3;s=(v&24)+k|0;w=v+o|0;if((s|0)<=31){x=t;y=s;z=w;A=q+(u<<2)|0;B=n;break}x=t;y=s-32|0;z=w;A=q+(u+1<<2)|0;B=n}else{c[q>>2]=c[q>>2]|(l&255)<<k;u=k+8|0;w=(u|0)==32;x=r;y=w?0:u;z=o+8|0;A=w?q+4|0:q;B=c[m>>2]|0}}while(0);if((z|0)<(B|0)){p=x;k=y;o=z;q=A;n=B}else{break}}}}while(0);c[651352]=(c[651352]|0)+1;g=b;h=e;i=j}yN(630156,630144,12);c[157536]=g;c[157537]=h;c[157538]=i;f=i;return f|0}function rD(a,b){a=a|0;b=b|0;c[c[350574]>>2]=c[a+136>>2];yG((c[350574]|0)+4|0,0,c[157534]|0);rE(a,b,c[a+164>>2]|0);return c[350574]|0}function rE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0;e=i;f=c[d>>2]|0;if((f|0)<0){h=d;j=f}else{f=b+4|0;k=b+8|0;l=d;while(1){d=c[l+40>>2]|0;m=+g[b>>2]*+g[d>>2]+ +g[f>>2]*+g[d+4>>2]+ +g[k>>2]*+g[d+8>>2]- +g[d+12>>2];do{if(m>8.0){n=l+44|0}else{if(m<-8.0){n=l+48|0;break}else{rE(a,b,c[l+44>>2]|0);n=l+48|0;break}}}while(0);d=c[n>>2]|0;o=c[d>>2]|0;if((o|0)<0){h=d;j=o;break}else{l=d}}}if((j|0)==-2){i=e;return}j=rC(a,h)|0;h=c[350574]|0;a=j|0;l=c[a>>2]|0;n=c[h>>2]|0;if((l|0)==(n|0)){p=l}else{w1(85736,(b=i,i=i+24|0,c[b>>2]=111064,c[b+8>>2]=l,c[b+16>>2]=n,b)|0);i=b;p=c[a>>2]|0}a=(p+31|0)>>>5;if((a|0)==0){i=e;return}p=0;b=j+4|0;j=h+4|0;while(1){c[j>>2]=c[j>>2]|c[b>>2];h=p+1|0;if((h|0)<(a|0)){p=h;b=b+4|0;j=j+4|0}else{break}}i=e;return}function rF(){var a=0,b=0,d=0;if((c[169394]|0)>0){a=0;b=677592;while(1){d=c[b+68>>2]|0;do{if((d|0)!=2){c[b+64>>2]=1;if((d|0)!=1){break}c[b+388>>2]=0}}while(0);d=a+1|0;if((d|0)<(c[169394]|0)){a=d;b=b+396|0}else{break}}}c[350574]=0;yG(630144,0,24);c[157532]=0;c[157534]=0;c[651352]=0;c[651354]=0;return}function rG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;if((a[b]|0)==0){w1(79160,(f=i,i=i+8|0,c[f>>2]=111032,f)|0);i=f}g=c[169394]|0;L3373:do{if((g|0)>0){h=0;j=677592;while(1){if((cS(j|0,b|0)|0)==0){k=h;l=j;break L3373}m=h+1|0;n=j+396|0;if((m|0)<(g|0)){h=m;j=n}else{k=m;l=n;break}}}else{k=0;l=677592}}while(0);if((k|0)!=(g|0)){o=rH(l,d)|0;i=e;return o|0}if((g|0)==512){w1(77768,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f}yP(l|0,b|0,63)|0;a[l+63|0]=0;c[l+64>>2]=1;c[169394]=(c[169394]|0)+1;o=rH(l,d)|0;i=e;return o|0}function rH(d,f){d=d|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0.0,ag=0,ah=0,ai=0.0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0.0,aH=0,aI=0,aJ=0,aK=0;h=i;i=i+1144|0;j=h|0;k=h+16|0;l=h+56|0;m=h+96|0;n=h+112|0;o=h+1136|0;p=d+64|0;do{if((c[p>>2]|0)==0){if((c[d+68>>2]|0)!=2){q=d;i=h;return q|0}if((yc(d+388|0)|0)==0){break}else{q=d}i=h;return q|0}}while(0);r=d|0;s=on(r,n|0,1024,o)|0;if((s|0)==0){if((f|0)==0){q=0;i=h;return q|0}w1(50872,(t=i,i=i+16|0,c[t>>2]=110640,c[t+8>>2]=r,t)|0);i=t;q=0;i=h;return q|0}f=s;n8(r,1098088,64);c[274538]=d;c[p>>2]=0;p=c[f>>2]|0;if((p|0)==1330660425){m3(c[169396]|0,d,s,c[274538]|0,1098088);q=d;i=h;return q|0}else if((p|0)==1347634249){vV(d,s,1098088);q=d;i=h;return q|0}else{p=c[o>>2]|0;o=m|0;c[(c[274538]|0)+68>>2]=0;m=c[f>>2]|0;if(!((m|0)==29|(m|0)==1112756274)){w1(46960,(t=i,i=i+40|0,c[t>>2]=110912,c[t+8>>2]=r,c[t+16>>2]=m,c[t+24>>2]=29,c[t+32>>2]=1112756274,t)|0);i=t}c[220086]=s;m=s+4|0;r=m;n=0;do{u=c[r+(n<<3)>>2]|0;v=c[r+(n<<3)+4>>2]|0;w=v+u|0;if((v|0)<0|w>>>0>p>>>0|(u|0)<0|(w|0)<0){v=c[274538]|0;w1(42712,(t=i,i=i+16|0,c[t>>2]=110912,c[t+8>>2]=v,t)|0);i=t;x=0}else{x=0}do{v=c[r+(x<<3)>>2]|0;if((u|0)<(v|0)&(w|0)>(v|0)){y=2558}else{if((v|0)<(u|0)&((c[r+(x<<3)+4>>2]|0)+v|0)>(u|0)){y=2558}}if((y|0)==2558){y=0;v=c[274538]|0;w1(38848,(t=i,i=i+16|0,c[t>>2]=110912,c[t+8>>2]=v,t)|0);i=t}x=x+1|0;}while((x|0)<15);n=n+1|0;}while((n|0)<15);n=(c[220086]|0)+(c[s+28>>2]|0)|0;x=s+32|0;r=c[x>>2]|0;if(((r>>>0)%12|0|0)==0){z=r}else{r=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110440,c[t+8>>2]=r,t)|0);i=t;z=c[x>>2]|0}x=(z>>>0)/12|0;r=x1(x*12|0,1098088)|0;c[(c[274538]|0)+148>>2]=r;c[(c[274538]|0)+144>>2]=x;if(z>>>0>11){z=r;r=0;p=n;while(1){g[z>>2]=+g[p>>2];g[z+4>>2]=+g[p+4>>2];g[z+8>>2]=+g[p+8>>2];n=r+1|0;if((n|0)<(x|0)){z=z+12|0;r=n;p=p+12|0}else{break}}}p=(c[220086]|0)+(c[s+100>>2]|0)|0;do{if((c[f>>2]|0)==29){r=s+104|0;z=c[r>>2]|0;if((z&3|0)==0){A=z}else{z=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110816,c[t+8>>2]=z,t)|0);i=t;A=c[r>>2]|0}r=A>>>2;z=x1((r*12|0)+12|0,1098088)|0;c[(c[274538]|0)+156>>2]=z;c[(c[274538]|0)+152>>2]=r;if((r|0)==0){break}else{B=z;C=0;D=p}while(1){c[B>>2]=e[D>>1]|0;c[B+4>>2]=e[D+2>>1]|0;z=C+1|0;if((z|0)<(r|0)){B=B+12|0;C=z;D=D+4|0}else{break}}}else{r=s+104|0;z=c[r>>2]|0;if((z&7|0)==0){E=z}else{z=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110840,c[t+8>>2]=z,t)|0);i=t;E=c[r>>2]|0}r=E>>>3;z=x1((r*12|0)+12|0,1098088)|0;c[(c[274538]|0)+156>>2]=z;c[(c[274538]|0)+152>>2]=r;if((r|0)==0){break}else{F=z;G=0;H=p}while(1){c[F>>2]=c[H>>2];c[F+4>>2]=c[H+4>>2];z=G+1|0;if((z|0)<(r|0)){F=F+12|0;G=z;H=H+8|0}else{break}}}}while(0);H=(c[220086]|0)+(c[s+108>>2]|0)|0;G=s+112|0;F=c[G>>2]|0;if((F&3|0)==0){I=F}else{F=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110480,c[t+8>>2]=F,t)|0);i=t;I=c[G>>2]|0}G=I>>>2;I=x1(G<<2,1098088)|0;c[(c[274538]|0)+188>>2]=I;c[(c[274538]|0)+184>>2]=G;if((G|0)!=0){F=0;do{c[I+(F<<2)>>2]=c[H+(F<<2)>>2];F=F+1|0;}while((F|0)<(G|0))}G=k;F=l;do{if((c[s+24>>2]|0)==0){c[(c[274538]|0)+372>>2]=0}else{H=c[220086]|0;I=c[s+20>>2]|0;p=H+I|0;c[(c[274538]|0)+368>>2]=c[p>>2];E=x1(c[p>>2]<<2,1098088)|0;c[(c[274538]|0)+372>>2]=E;if((c[p>>2]|0)<=0){break}E=H+(I+4)|0;D=0;do{C=c[E+(D<<2)>>2]|0;do{if((C|0)!=-1){B=C+I|0;A=H+B|0;r=H+(B+16)|0;z=H+(B+20)|0;x=c[r>>2]|0;if((x&15|0)==0){n=c[z>>2]|0;if((n&15|0)==0){J=x;K=n}else{y=2587}}else{y=2587}if((y|0)==2587){y=0;w1(85432,(t=i,i=i+8|0,c[t>>2]=A,t)|0);i=t;J=c[r>>2]|0;K=c[z>>2]|0}n=((ab(J,K)|0)>>>6)*85|0;x=x1(n+60|0,1098088)|0;u=x;c[(c[(c[274538]|0)+372>>2]|0)+(D<<2)>>2]=u;yJ(x|0,A|0,16)|0;c[x+16>>2]=c[r>>2];c[x+20>>2]=c[z>>2];c[x+44>>2]=(c[H+(B+24)>>2]|0)+20;c[x+48>>2]=(c[H+(B+28)>>2]|0)+20;c[x+52>>2]=(c[H+(B+32)>>2]|0)+20;c[x+56>>2]=(c[H+(B+36)>>2]|0)+20;z=x+60|0;x=H+(B+40)|0;yJ(z|0,x|0,n)|0;if((bN(A|0,94328,3)|0)!=0){break}uN(u)}}while(0);D=D+1|0;L=c[p>>2]|0;}while((D|0)<(L|0));if((L|0)<=0){break}D=l|0;H=k|0;I=0;E=0;C=L;while(1){u=c[(c[(c[274538]|0)+372>>2]|0)+(E<<2)>>2]|0;do{if((u|0)==0){M=I;N=C}else{A=u|0;if((a[A]|0)!=43){M=I;N=C;break}if((c[u+36>>2]|0)!=0){M=I;N=C;break}yG(G|0,0,40);yG(F|0,0,40);n=a[u+1|0]|0;x=n<<24>>24;z=(n-97&255)<26?x-32|0:x;x=z-48|0;do{if(x>>>0<10){c[k+(x<<2)>>2]=u;O=0;P=z-47|0;R=C}else{n=z-65|0;if(n>>>0<10){c[l+(n<<2)>>2]=u;O=z-64|0;P=0;R=C;break}else{w1(82888,(t=i,i=i+8|0,c[t>>2]=A,t)|0);i=t;O=I;P=z;R=c[p>>2]|0;break}}}while(0);z=E+1|0;L3480:do{if((z|0)<(R|0)){x=u+2|0;n=P;B=O;r=z;w=R;while(1){v=B;S=r;T=w;L3484:while(1){U=S;V=T;L3486:while(1){W=c[(c[(c[274538]|0)+372>>2]|0)+(U<<2)>>2]|0;do{if((W|0)==0){X=V}else{if((a[W|0]|0)!=43){X=V;break}if((cS(W+2|0,x|0)|0)!=0){X=V;break}Y=a[W+1|0]|0;Z=Y<<24>>24;_=(Y-97&255)<26?Z-32|0:Z;$=_-48|0;if($>>>0<10){break L3484}aa=_-65|0;if(aa>>>0<10){break L3486}w1(82888,(t=i,i=i+8|0,c[t>>2]=A,t)|0);i=t;X=c[p>>2]|0}}while(0);Z=U+1|0;if((Z|0)<(X|0)){U=Z;V=X}else{ac=v;ad=n;break L3480}}c[l+(aa<<2)>>2]=W;Z=_-64|0;Y=(Z|0)>(v|0)?Z:v;Z=U+1|0;if((Z|0)<(V|0)){v=Y;S=Z;T=V}else{ac=Y;ad=n;break L3480}}c[k+($<<2)>>2]=W;T=_-47|0;S=(T|0)>(n|0)?T:n;T=U+1|0;if((T|0)<(V|0)){n=S;B=v;r=T;w=V}else{ac=v;ad=S;break}}}else{ac=O;ad=P}}while(0);if((ad|0)>0){z=ad<<1;w=c[D>>2]|0;if((ac|0)==0){r=0;do{B=c[k+(r<<2)>>2]|0;if((B|0)==0){w1(80904,(t=i,i=i+16|0,c[t>>2]=r,c[t+8>>2]=A,t)|0);i=t}c[B+24>>2]=z;c[B+28>>2]=r<<1;r=r+1|0;c[B+32>>2]=r<<1;c[B+36>>2]=c[k+(((r|0)==(ad|0)?0:r)<<2)>>2];}while((r|0)<(ad|0))}else{r=0;do{B=c[k+(r<<2)>>2]|0;if((B|0)==0){w1(80904,(t=i,i=i+16|0,c[t>>2]=r,c[t+8>>2]=A,t)|0);i=t}c[B+24>>2]=z;c[B+28>>2]=r<<1;r=r+1|0;c[B+32>>2]=r<<1;c[B+36>>2]=c[k+(((r|0)==(ad|0)?0:r)<<2)>>2];c[B+40>>2]=w;}while((r|0)<(ad|0))}}if((ac|0)>0){r=ac<<1;w=c[H>>2]|0;if((ad|0)==0){z=0;do{B=c[l+(z<<2)>>2]|0;if((B|0)==0){w1(80904,(t=i,i=i+16|0,c[t>>2]=z,c[t+8>>2]=A,t)|0);i=t}c[B+24>>2]=r;c[B+28>>2]=z<<1;z=z+1|0;c[B+32>>2]=z<<1;c[B+36>>2]=c[l+(((z|0)==(ac|0)?0:z)<<2)>>2];}while((z|0)<(ac|0))}else{z=0;do{B=c[l+(z<<2)>>2]|0;if((B|0)==0){w1(80904,(t=i,i=i+16|0,c[t>>2]=z,c[t+8>>2]=A,t)|0);i=t}c[B+24>>2]=r;c[B+28>>2]=z<<1;z=z+1|0;c[B+32>>2]=z<<1;c[B+36>>2]=c[l+(((z|0)==(ac|0)?0:z)<<2)>>2];c[B+40>>2]=w;}while((z|0)<(ac|0))}}M=ac;N=c[p>>2]|0}}while(0);u=E+1|0;if((u|0)<(N|0)){I=M;E=u;C=N}else{break}}}}while(0);N=s+72|0;M=c[N>>2]|0;if((M|0)==0){c[(c[274538]|0)+380>>2]=0}else{ac=x1(M,1098088)|0;c[(c[274538]|0)+380>>2]=ac;ac=c[(c[274538]|0)+380>>2]|0;M=(c[220086]|0)+(c[s+68>>2]|0)|0;l=c[N>>2]|0;yJ(ac|0,M|0,l)|0}l=(c[220086]|0)+(c[s+12>>2]|0)|0;M=s+16|0;ac=c[M>>2]|0;if(((ac>>>0)%20|0|0)==0){ae=ac}else{ac=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110576,c[t+8>>2]=ac,t)|0);i=t;ae=c[M>>2]|0}M=(ae>>>0)/20|0;ac=x1(M*40|0,1098088)|0;c[(c[274538]|0)+132>>2]=ac;c[(c[274538]|0)+128>>2]=M;if(ae>>>0>19){ae=ac;ac=l;l=0;while(1){af=+g[ac>>2];g[ae>>2]=af;N=af<0.0|0;af=+g[ac+4>>2];g[ae+4>>2]=af;ad=af<0.0?N|2:N;af=+g[ac+8>>2];g[ae+8>>2]=af;if(af<0.0){ag=(ad|4)&255}else{ag=ad&255}g[ae+12>>2]=+g[ac+12>>2];a[ae+16|0]=c[ac+16>>2]&255;a[ae+17|0]=ag;ad=l+1|0;if((ad|0)<(M|0)){ae=ae+20|0;ac=ac+20|0;l=ad}else{break}}}l=(c[220086]|0)+(c[s+52>>2]|0)|0;ac=s+56|0;ae=c[ac>>2]|0;if(((ae>>>0)%40|0|0)==0){ah=ae}else{ae=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110464,c[t+8>>2]=ae,t)|0);i=t;ah=c[ac>>2]|0}ac=(ah>>>0)/40|0;ae=x1(ac*44|0,1098088)|0;c[(c[274538]|0)+172>>2]=ae;c[(c[274538]|0)+168>>2]=ac;if(ah>>>0>39){ah=0;M=ae;ae=l;while(1){l=M|0;g[l>>2]=+g[ae>>2];ag=M+16|0;g[ag>>2]=+g[ae+16>>2];g[M+4>>2]=+g[ae+4>>2];g[M+20>>2]=+g[ae+20>>2];g[M+8>>2]=+g[ae+8>>2];g[M+24>>2]=+g[ae+24>>2];g[M+12>>2]=+g[ae+12>>2];g[M+28>>2]=+g[ae+28>>2];af=+rd(l);ai=(af+ +rd(ag))*.5;do{if(ai<.32){g[M+32>>2]=4.0}else{if(ai<.49){g[M+32>>2]=3.0;break}ag=M+32|0;if(ai<.99){g[ag>>2]=2.0;break}else{g[ag>>2]=1.0;break}}}while(0);ag=c[ae+32>>2]|0;l=M+40|0;c[l>>2]=c[ae+36>>2];ad=c[274538]|0;N=c[ad+372>>2]|0;do{if((N|0)==0){c[M+36>>2]=c[157438];c[l>>2]=0}else{if((ag|0)<(c[ad+368>>2]|0)){aj=N}else{w1(87368,(t=i,i=i+1|0,i=i+7>>3<<3,c[t>>2]=0,t)|0);i=t;aj=c[(c[274538]|0)+372>>2]|0}k=c[aj+(ag<<2)>>2]|0;P=M+36|0;c[P>>2]=k;if((k|0)!=0){break}c[P>>2]=c[157438];c[l>>2]=0}}while(0);l=ah+1|0;if((l|0)<(ac|0)){ah=l;M=M+44|0;ae=ae+40|0}else{break}}}ae=(c[220086]|0)+(c[s+60>>2]|0)|0;do{if((c[f>>2]|0)==29){M=s+64|0;ah=c[M>>2]|0;if(((ah>>>0)%20|0|0)==0){ak=ah}else{ah=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110768,c[t+8>>2]=ah,t)|0);i=t;ak=c[M>>2]|0}M=(ak>>>0)/20|0;ah=x1(M*92|0,1098088)|0;c[(c[274538]|0)+180>>2]=ah;c[(c[274538]|0)+176>>2]=M;if(ak>>>0>19){ac=0;aj=ah;ah=ae;while(1){c[aj+40>>2]=c[ah+4>>2];l=b[ah+8>>1]|0;c[aj+44>>2]=l<<16>>16;ag=aj+36|0;c[ag>>2]=0;if(l<<16>>16<1){l=c[274538]|0;w1(89056,(t=i,i=i+16|0,c[t>>2]=110768,c[t+8>>2]=l,t)|0);i=t}l=b[ah>>1]|0;if((b[ah+2>>1]|0)!=0){c[ag>>2]=c[ag>>2]|2}c[aj+32>>2]=(c[(c[274538]|0)+132>>2]|0)+(l*20|0);l=aj+72|0;c[l>>2]=(c[(c[274538]|0)+172>>2]|0)+((b[ah+10>>1]|0)*44|0);rU(aj);rM(aj);a[aj+84|0]=a[ah+12|0]|0;a[aj+85|0]=a[ah+13|0]|0;a[aj+86|0]=a[ah+14|0]|0;a[aj+87|0]=a[ah+15|0]|0;N=c[ah+16>>2]|0;if((N|0)==-1){c[aj+88>>2]=0}else{c[aj+88>>2]=(c[(c[274538]|0)+380>>2]|0)+N}N=c[(c[l>>2]|0)+36>>2]|0;do{if((bN(N|0,94328,3)|0)==0){c[ag>>2]=c[ag>>2]|36}else{if((a[N]|0)!=42){break}c[ag>>2]=c[ag>>2]|48;b[aj+68>>1]=16384;b[aj+64>>1]=-8192;b[aj+70>>1]=16384;b[aj+66>>1]=-8192}}while(0);ag=ac+1|0;if((ag|0)<(M|0)){ac=ag;aj=aj+92|0;ah=ah+20|0}else{break}}}ah=(c[220086]|0)+(c[s+92>>2]|0)|0;aj=s+96|0;ac=c[aj>>2]|0;if((ac&1|0)==0){al=ac}else{ac=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110656,c[t+8>>2]=ac,t)|0);i=t;al=c[aj>>2]|0}aj=al>>>1;ac=x1(aj<<2,1098088)|0;c[(c[274538]|0)+204>>2]=ac;c[(c[274538]|0)+200>>2]=aj;if((aj|0)==0){break}else{am=0}do{M=e[ah+(am<<1)>>1]|0;ag=c[274538]|0;if((M|0)<(c[ag+176>>2]|0)){an=ag}else{w1(96384,(t=i,i=i+8|0,c[t>>2]=110656,t)|0);i=t;an=c[274538]|0}c[ac+(am<<2)>>2]=(c[an+180>>2]|0)+(M*92|0);am=am+1|0;}while((am|0)<(aj|0))}else{aj=s+64|0;ac=c[aj>>2]|0;if(((ac>>>0)%28|0|0)==0){ao=ac}else{ac=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110792,c[t+8>>2]=ac,t)|0);i=t;ao=c[aj>>2]|0}aj=(ao>>>0)/28|0;ac=x1(aj*92|0,1098088)|0;c[(c[274538]|0)+180>>2]=ac;c[(c[274538]|0)+176>>2]=aj;if(ao>>>0>27){ah=0;M=ac;ac=ae;while(1){c[M+40>>2]=c[ac+8>>2];c[M+44>>2]=c[ac+12>>2];ag=M+36|0;c[ag>>2]=0;N=c[ac>>2]|0;if((c[ac+4>>2]|0)!=0){c[ag>>2]=2}c[M+32>>2]=(c[(c[274538]|0)+132>>2]|0)+(N*20|0);N=M+72|0;c[N>>2]=(c[(c[274538]|0)+172>>2]|0)+((c[ac+16>>2]|0)*44|0);rU(M);rM(M);a[M+84|0]=a[ac+20|0]|0;a[M+85|0]=a[ac+21|0]|0;a[M+86|0]=a[ac+22|0]|0;a[M+87|0]=a[ac+23|0]|0;l=c[ac+24>>2]|0;if((l|0)==-1){c[M+88>>2]=0}else{c[M+88>>2]=(c[(c[274538]|0)+380>>2]|0)+l}l=c[(c[N>>2]|0)+36>>2]|0;do{if((bN(l|0,94328,3)|0)==0){c[ag>>2]=c[ag>>2]|36}else{if((a[l]|0)!=42){break}c[ag>>2]=c[ag>>2]|48;b[M+68>>1]=16384;b[M+64>>1]=-8192;b[M+70>>1]=16384;b[M+66>>1]=-8192}}while(0);ag=ah+1|0;if((ag|0)<(aj|0)){ah=ag;M=M+92|0;ac=ac+28|0}else{break}}}ac=(c[220086]|0)+(c[s+92>>2]|0)|0;M=s+96|0;ah=c[M>>2]|0;if((ah&3|0)==0){ap=ah}else{ah=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110688,c[t+8>>2]=ah,t)|0);i=t;ap=c[M>>2]|0}M=ap>>>2;ah=x1(M<<2,1098088)|0;c[(c[274538]|0)+204>>2]=ah;c[(c[274538]|0)+200>>2]=M;if((M|0)==0){break}else{aq=0}do{aj=c[ac+(aq<<2)>>2]|0;ag=c[274538]|0;if((aj|0)<(c[ag+176>>2]|0)){ar=ag}else{w1(96384,(t=i,i=i+8|0,c[t>>2]=110688,t)|0);i=t;ar=c[274538]|0}c[ah+(aq<<2)>>2]=(c[ar+180>>2]|0)+(aj*92|0);aq=aq+1|0;}while((aq|0)<(M|0))}}while(0);aq=s+40|0;ar=c[aq>>2]|0;if((ar|0)==0){c[(c[274538]|0)+376>>2]=0}else{ap=x1(ar,1098088)|0;c[(c[274538]|0)+376>>2]=ap;ap=c[(c[274538]|0)+376>>2]|0;ar=(c[220086]|0)+(c[s+36>>2]|0)|0;ae=c[aq>>2]|0;yJ(ap|0,ar|0,ae)|0}ae=(c[220086]|0)+(c[s+84>>2]|0)|0;do{if((c[f>>2]|0)==29){ar=s+88|0;ap=c[ar>>2]|0;if(((ap>>>0)%28|0|0)==0){as=ap}else{ap=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110720,c[t+8>>2]=ap,t)|0);i=t;as=c[ar>>2]|0}ar=(as>>>0)/28|0;ap=x1(ar<<6,1098088)|0;c[(c[274538]|0)+140>>2]=ap;c[(c[274538]|0)+136>>2]=ar;if(as>>>0>27){aq=ap;ap=0;ao=ae;while(1){g[aq+12>>2]=+(b[ao+8>>1]|0);g[aq+24>>2]=+(b[ao+14>>1]|0);g[aq+16>>2]=+(b[ao+10>>1]|0);g[aq+28>>2]=+(b[ao+16>>1]|0);g[aq+20>>2]=+(b[ao+12>>1]|0);g[aq+32>>2]=+(b[ao+18>>1]|0);c[aq>>2]=c[ao>>2];c[aq+48>>2]=(c[(c[274538]|0)+204>>2]|0)+(e[ao+20>>1]<<2);c[aq+52>>2]=e[ao+22>>1]|0;am=c[ao+4>>2]|0;if((am|0)==-1){c[aq+40>>2]=0}else{c[aq+40>>2]=(c[(c[274538]|0)+376>>2]|0)+am}c[aq+44>>2]=0;a[aq+60|0]=a[ao+24|0]|0;a[aq+61|0]=a[ao+25|0]|0;a[aq+62|0]=a[ao+26|0]|0;a[aq+63|0]=a[ao+27|0]|0;am=ap+1|0;if((am|0)<(ar|0)){aq=aq+64|0;ap=am;ao=ao+28|0}else{break}}}ao=(c[220086]|0)+(c[s+44>>2]|0)|0;ap=s+48|0;aq=c[ap>>2]|0;if(((aq>>>0)%24|0|0)==0){at=aq}else{aq=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110592,c[t+8>>2]=aq,t)|0);i=t;at=c[ap>>2]|0}ap=(at>>>0)/24|0;aq=x1(ap*60|0,1098088)|0;c[(c[274538]|0)+164>>2]=aq;c[(c[274538]|0)+160>>2]=ap;if(at>>>0>23){ar=0;am=ao;ao=aq;while(1){g[ao+12>>2]=+(b[am+8>>1]|0);g[ao+24>>2]=+(b[am+14>>1]|0);g[ao+16>>2]=+(b[am+10>>1]|0);g[ao+28>>2]=+(b[am+16>>1]|0);g[ao+20>>2]=+(b[am+12>>1]|0);g[ao+32>>2]=+(b[am+18>>1]|0);c[ao+40>>2]=(c[(c[274538]|0)+132>>2]|0)+((c[am>>2]|0)*20|0);c[ao+52>>2]=e[am+20>>1]|0;c[ao+56>>2]=e[am+22>>1]|0;aq=b[am+4>>1]|0;an=aq<<16>>16;al=c[274538]|0;if(aq<<16>>16>-1){c[ao+44>>2]=(c[al+164>>2]|0)+(an*60|0)}else{c[ao+44>>2]=(c[al+140>>2]|0)+(~an<<6)}an=b[am+6>>1]|0;al=an<<16>>16;aq=c[274538]|0;if(an<<16>>16>-1){c[ao+48>>2]=(c[aq+164>>2]|0)+(al*60|0)}else{c[ao+48>>2]=(c[aq+140>>2]|0)+(~al<<6)}al=ar+1|0;if((al|0)<(ap|0)){ar=al;am=am+24|0;ao=ao+60|0}else{break}}}rT(c[(c[274538]|0)+164>>2]|0,0);ao=(c[220086]|0)+(c[s+76>>2]|0)|0;am=s+80|0;ar=c[am>>2]|0;if((ar&7|0)==0){au=ar}else{ar=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110864,c[t+8>>2]=ar,t)|0);i=t;au=c[am>>2]|0}am=au>>>3;ar=x1(am*12|0,1098088)|0;c[(c[274538]|0)+196>>2]=ar;c[(c[274538]|0)+192>>2]=am;ap=c[274538]|0;c[ap+248>>2]=ar;c[ap+256>>2]=0;al=am-1|0;c[ap+260>>2]=al;c[ap+252>>2]=c[(c[274538]|0)+132>>2];g[ap+264>>2]=-16.0;g[ap+268>>2]=-16.0;g[ap+272>>2]=-24.0;g[ap+276>>2]=16.0;g[ap+280>>2]=16.0;g[ap+284>>2]=32.0;ap=c[274538]|0;c[ap+288>>2]=ar;c[ap+296>>2]=0;c[ap+300>>2]=al;c[ap+292>>2]=c[(c[274538]|0)+132>>2];g[ap+304>>2]=-32.0;g[ap+308>>2]=-32.0;g[ap+312>>2]=-24.0;g[ap+316>>2]=32.0;g[ap+320>>2]=32.0;g[ap+324>>2]=64.0;if((am|0)==0){break}else{av=0;aw=ar;ax=ao}while(1){c[aw>>2]=c[ax>>2];ao=b[ax+4>>1]|0;ar=ao&65535;ap=(ao&65535)>65520?ar|-65536:ar;c[aw+4>>2]=ap;if((ap|0)>=(am|0)){w1(98584,(t=i,i=i+8|0,c[t>>2]=110864,t)|0);i=t}ap=b[ax+6>>1]|0;ar=ap&65535;ao=(ap&65535)>65520?ar|-65536:ar;c[aw+8>>2]=ao;if((ao|0)>=(am|0)){w1(98584,(t=i,i=i+8|0,c[t>>2]=110864,t)|0);i=t}ao=av+1|0;if((ao|0)<(am|0)){av=ao;aw=aw+12|0;ax=ax+8|0}else{break}}}else{am=s+88|0;ao=c[am>>2]|0;if((ao&31|0)==0){ay=ao}else{ao=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110744,c[t+8>>2]=ao,t)|0);i=t;ay=c[am>>2]|0}am=ay>>>5;ao=x1(am<<6,1098088)|0;c[(c[274538]|0)+140>>2]=ao;c[(c[274538]|0)+136>>2]=am;if((am|0)!=0){ar=ao;ao=0;ap=ae;while(1){g[ar+12>>2]=+(b[ap+8>>1]|0);g[ar+24>>2]=+(b[ap+14>>1]|0);g[ar+16>>2]=+(b[ap+10>>1]|0);g[ar+28>>2]=+(b[ap+16>>1]|0);g[ar+20>>2]=+(b[ap+12>>1]|0);g[ar+32>>2]=+(b[ap+18>>1]|0);c[ar>>2]=c[ap>>2];c[ar+48>>2]=(c[(c[274538]|0)+204>>2]|0)+(c[ap+20>>2]<<2);c[ar+52>>2]=c[ap+24>>2];al=c[ap+4>>2]|0;if((al|0)==-1){c[ar+40>>2]=0}else{c[ar+40>>2]=(c[(c[274538]|0)+376>>2]|0)+al}c[ar+44>>2]=0;a[ar+60|0]=a[ap+28|0]|0;a[ar+61|0]=a[ap+29|0]|0;a[ar+62|0]=a[ap+30|0]|0;a[ar+63|0]=a[ap+31|0]|0;al=ao+1|0;if((al|0)<(am|0)){ar=ar+64|0;ao=al;ap=ap+32|0}else{break}}}ap=(c[220086]|0)+(c[s+44>>2]|0)|0;ao=s+48|0;ar=c[ao>>2]|0;if((ar&31|0)==0){az=ar}else{ar=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110616,c[t+8>>2]=ar,t)|0);i=t;az=c[ao>>2]|0}ao=az>>>5;ar=x1(ao*60|0,1098088)|0;c[(c[274538]|0)+164>>2]=ar;c[(c[274538]|0)+160>>2]=ao;if((ao|0)!=0){am=0;al=ap;ap=ar;while(1){g[ap+12>>2]=+(b[al+12>>1]|0);g[ap+24>>2]=+(b[al+18>>1]|0);g[ap+16>>2]=+(b[al+14>>1]|0);g[ap+28>>2]=+(b[al+20>>1]|0);g[ap+20>>2]=+(b[al+16>>1]|0);g[ap+32>>2]=+(b[al+22>>1]|0);c[ap+40>>2]=(c[(c[274538]|0)+132>>2]|0)+((c[al>>2]|0)*20|0);c[ap+52>>2]=c[al+24>>2];c[ap+56>>2]=c[al+28>>2];ar=c[al+4>>2]|0;aq=c[274538]|0;if((ar|0)>-1){c[ap+44>>2]=(c[aq+164>>2]|0)+(ar*60|0)}else{c[ap+44>>2]=(c[aq+140>>2]|0)+(~ar<<6)}ar=c[al+8>>2]|0;aq=c[274538]|0;if((ar|0)>-1){c[ap+48>>2]=(c[aq+164>>2]|0)+(ar*60|0)}else{c[ap+48>>2]=(c[aq+140>>2]|0)+(~ar<<6)}ar=am+1|0;if((ar|0)<(ao|0)){am=ar;al=al+32|0;ap=ap+60|0}else{break}}}rT(c[(c[274538]|0)+164>>2]|0,0);ap=(c[220086]|0)+(c[s+76>>2]|0)|0;al=s+80|0;am=c[al>>2]|0;if(((am>>>0)%12|0|0)==0){aA=am}else{am=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110888,c[t+8>>2]=am,t)|0);i=t;aA=c[al>>2]|0}al=(aA>>>0)/12|0;am=x1(al*12|0,1098088)|0;c[(c[274538]|0)+196>>2]=am;c[(c[274538]|0)+192>>2]=al;ao=c[274538]|0;c[ao+248>>2]=am;c[ao+256>>2]=0;ar=al-1|0;c[ao+260>>2]=ar;c[ao+252>>2]=c[(c[274538]|0)+132>>2];g[ao+264>>2]=-16.0;g[ao+268>>2]=-16.0;g[ao+272>>2]=-24.0;g[ao+276>>2]=16.0;g[ao+280>>2]=16.0;g[ao+284>>2]=32.0;ao=c[274538]|0;c[ao+288>>2]=am;c[ao+296>>2]=0;c[ao+300>>2]=ar;c[ao+292>>2]=c[(c[274538]|0)+132>>2];g[ao+304>>2]=-32.0;g[ao+308>>2]=-32.0;g[ao+312>>2]=-24.0;g[ao+316>>2]=32.0;g[ao+320>>2]=32.0;g[ao+324>>2]=64.0;if(aA>>>0>11){aB=0;aC=am;aD=ap}else{break}while(1){c[aC>>2]=c[aD>>2];ap=c[aD+4>>2]|0;c[aC+4>>2]=ap;if((ap|0)>=(al|0)){w1(98584,(t=i,i=i+8|0,c[t>>2]=110888,t)|0);i=t}ap=c[aD+8>>2]|0;c[aC+8>>2]=ap;if((ap|0)>=(al|0)){w1(98584,(t=i,i=i+8|0,c[t>>2]=110888,t)|0);i=t}ap=aB+1|0;if((ap|0)<(al|0)){aB=ap;aC=aC+12|0;aD=aD+12|0}else{break}}}}while(0);aD=s+8|0;aC=c[aD>>2]|0;if((aC|0)==0){c[(c[274538]|0)+384>>2]=0}else{aB=x1(aC,1098088)|0;c[(c[274538]|0)+384>>2]=aB;aB=c[(c[274538]|0)+384>>2]|0;aC=(c[220086]|0)+(c[m>>2]|0)|0;m=c[aD>>2]|0;yJ(aB|0,aC|0,m)|0}m=(c[220086]|0)+(c[s+116>>2]|0)|0;aC=s+120|0;s=c[aC>>2]|0;if((s&63|0)==0){aE=s}else{s=c[274538]|0;w1(100112,(t=i,i=i+16|0,c[t>>2]=110504,c[t+8>>2]=s,t)|0);i=t;aE=c[aC>>2]|0}aC=aE>>>6;aE=x1(aC<<6,1098088)|0;c[(c[274538]|0)+124>>2]=aE;c[(c[274538]|0)+120>>2]=aC;if((aC|0)!=0){s=aE;aE=0;aB=m;while(1){g[s>>2]=+g[aB>>2]+-1.0;g[s+12>>2]=+g[aB+12>>2]+1.0;g[s+24>>2]=+g[aB+24>>2];g[s+4>>2]=+g[aB+4>>2]+-1.0;g[s+16>>2]=+g[aB+16>>2]+1.0;g[s+28>>2]=+g[aB+28>>2];g[s+8>>2]=+g[aB+8>>2]+-1.0;g[s+20>>2]=+g[aB+20>>2]+1.0;g[s+32>>2]=+g[aB+32>>2];c[s+36>>2]=c[aB+36>>2];c[s+40>>2]=c[aB+40>>2];c[s+44>>2]=c[aB+44>>2];c[s+48>>2]=c[aB+48>>2];c[s+52>>2]=c[aB+52>>2];c[s+56>>2]=c[aB+56>>2];c[s+60>>2]=c[aB+60>>2];m=aE+1|0;if((m|0)<(aC|0)){s=s+64|0;aE=m;aB=aB+64|0}else{break}}}aB=c[274538]|0;aE=c[aB+164>>2]|0;s=c[aB+160>>2]|0;aC=x1(s*12|0,1098088)|0;c[aB+208>>2]=aC;c[aB+216>>2]=0;c[aB+220>>2]=s-1;c[aB+212>>2]=c[(c[274538]|0)+132>>2];if((s|0)>0){aB=0;m=aC;aC=aE;while(1){c[m>>2]=((c[aC+40>>2]|0)-(c[(c[274538]|0)+132>>2]|0)|0)/20|0;aE=c[aC+44>>2]|0;aD=c[aE>>2]|0;if((aD|0)<0){c[m+4>>2]=aD}else{c[m+4>>2]=(aE-(c[(c[274538]|0)+164>>2]|0)|0)/60|0}aE=c[aC+48>>2]|0;aD=c[aE>>2]|0;if((aD|0)<0){c[m+8>>2]=aD}else{c[m+8>>2]=(aE-(c[(c[274538]|0)+164>>2]|0)|0)/60|0}aE=aB+1|0;if((aE|0)<(s|0)){aB=aE;m=m+12|0;aC=aC+60|0}else{break}}}c[d+72>>2]=2;c[d+80>>2]=0;aC=d+136|0;m=c[aC>>2]|0;aB=c[157532]|0;if((m|0)>(aB|0)){if((c[157538]|0)==0){aF=m}else{s=c[274538]|0;w1(108904,(t=i,i=i+32|0,c[t>>2]=110912,c[t+8>>2]=aB,c[t+16>>2]=s,c[t+24>>2]=m,t)|0);i=t;aF=c[aC>>2]|0}c[157532]=aF;aC=aF+31|0;c[157534]=aC>>>3&536870908;aF=(aC>>>5<<2)+4|0;c[350574]=x1(aF,102472)|0;yG(630144,0,24);aC=x1(aF<<1,107760)|0;c[157538]=aC;c[157541]=aC+aF}aF=d+120|0;if((c[aF>>2]|0)<=0){q=d;i=h;return q|0}aC=j|0;m=j+4|0;s=j+8|0;j=0;aB=d;aE=aF;while(1){aF=c[aB+124>>2]|0;c[aB+216>>2]=c[aF+(j<<6)+36>>2];c[aB+256>>2]=c[aF+(j<<6)+40>>2];aD=(c[aB+192>>2]|0)-1|0;c[aB+260>>2]=aD;c[aB+296>>2]=c[aF+(j<<6)+44>>2];c[aB+300>>2]=aD;c[aB+336>>2]=c[aF+(j<<6)+48>>2];c[aB+340>>2]=aD;c[aB+112>>2]=c[aF+(j<<6)+56>>2];c[aB+116>>2]=c[aF+(j<<6)+60>>2];ai=+g[aF+(j<<6)+12>>2];g[aB+96>>2]=ai;aD=aB+100|0;g[aD>>2]=+g[aF+(j<<6)+16>>2];aA=aB+104|0;g[aA>>2]=+g[aF+(j<<6)+20>>2];af=+g[aF+(j<<6)>>2];g[aB+84>>2]=af;az=aB+88|0;g[az>>2]=+g[aF+(j<<6)+4>>2];ae=aB+92|0;g[ae>>2]=+g[aF+(j<<6)+8>>2];aG=+Q(+af);g[aC>>2]=+Q(+(aG>+Q(+ai)?af:ai));ai=+g[az>>2];af=+Q(+ai);aG=+g[aD>>2];g[m>>2]=+Q(+(af>+Q(+aG)?ai:aG));aG=+g[ae>>2];ai=+Q(+aG);af=+g[aA>>2];g[s>>2]=+Q(+(ai>+Q(+af)?aG:af));g[aB+108>>2]=+rd(aC);c[aB+136>>2]=c[aF+(j<<6)+52>>2];aF=j+1|0;if((j|0)<((c[aE>>2]|0)-1|0)){bR(o|0,10,105680,(t=i,i=i+8|0,c[t>>2]=aF,t)|0)|0;i=t;if((a[o]|0)==0){w1(79160,(t=i,i=i+8|0,c[t>>2]=111032,t)|0);i=t}aA=c[169394]|0;L3749:do{if((aA|0)>0){ae=0;aD=677592;while(1){if((cS(aD|0,o|0)|0)==0){aH=ae;aI=aD;break L3749}az=ae+1|0;ay=aD+396|0;if((az|0)<(aA|0)){ae=az;aD=ay}else{aH=az;aI=ay;break}}}else{aH=0;aI=677592}}while(0);if((aH|0)==(aA|0)){if((aA|0)==512){w1(77768,(t=i,i=i+1|0,i=i+7>>3<<3,c[t>>2]=0,t)|0);i=t}aD=aI|0;yP(aD|0,o|0,63)|0;a[aI+63|0]=0;c[aI+64>>2]=1;c[169394]=(c[169394]|0)+1;aJ=aD}else{aJ=aI|0}c[274538]=aI;aD=aB|0;yJ(aJ|0,aD|0,396)|0;yQ(aJ|0,o|0)|0;aK=c[274538]|0}else{aK=aB}aD=aK+120|0;if((aF|0)<(c[aD>>2]|0)){j=aF;aB=aK;aE=aD}else{q=d;break}}i=h;return q|0}return 0}function rI(){return}function rJ(a){a=a|0;return}function rK(a){a=a|0;return 1}function rL(){return((c[353150]|0)==0)<<31>>31|0}function rM(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0;b=a+16|0;g[b>>2]=3.4028234663852886e+38;d=a+12|0;g[d>>2]=3.4028234663852886e+38;e=a+8|0;g[e>>2]=3.4028234663852886e+38;f=a+28|0;g[f>>2]=-3.4028234663852886e+38;h=a+24|0;g[h>>2]=-3.4028234663852886e+38;i=a+20|0;g[i>>2]=-3.4028234663852886e+38;j=c[a+44>>2]|0;if((j|0)<=0){return}k=c[a+40>>2]|0;a=0;l=3.4028234663852886e+38;m=-3.4028234663852886e+38;n=3.4028234663852886e+38;o=-3.4028234663852886e+38;p=3.4028234663852886e+38;q=-3.4028234663852886e+38;while(1){r=c[274538]|0;s=c[(c[r+188>>2]|0)+(k+a<<2)>>2]|0;if((s|0)>-1){t=(c[r+148>>2]|0)+((c[(c[r+156>>2]|0)+(s*12|0)>>2]|0)*12|0)|0}else{t=(c[r+148>>2]|0)+((c[(c[r+156>>2]|0)+((-s|0)*12|0)+4>>2]|0)*12|0)|0}s=t|0;u=+g[s>>2];if(l>u){g[e>>2]=u;v=u;w=+g[s>>2]}else{v=l;w=u}if(m<w){g[i>>2]=w;x=w}else{x=m}s=t+4|0;u=+g[s>>2];if(n>u){g[d>>2]=u;y=u;z=+g[s>>2]}else{y=n;z=u}if(o<z){g[h>>2]=z;A=z}else{A=o}s=t+8|0;u=+g[s>>2];if(p>u){g[b>>2]=u;B=u;C=+g[s>>2]}else{B=p;C=u}if(q<C){g[f>>2]=C;D=C}else{D=q}s=a+1|0;if((s|0)<(j|0)){a=s;l=v;m=x;n=y;o=A;p=B;q=D}else{break}}return}function rN(){var a=0;if((c[274518]|0)==0){a=0;return a|0}c[274518]=0;c[(c[270928]|0)+76>>2]=0;c[(c[270928]|0)+32856>>2]=0;c[(c[270928]|0)+36>>2]=1;c[(c[270930]|0)+76>>2]=0;c[(c[270930]|0)+32856>>2]=0;c[(c[270930]|0)+36>>2]=1;a=c[270928]|0;return a|0}function rO(a){a=a|0;var b=0;if((c[a+60>>2]|0)==0){b=0;return b|0}b=c[a+36>>2]|0;return b|0}function rP(a){a=a|0;var b=0;b=c[a+60>>2]|0;if((b|0)!=0){c[b+60>>2]=0}c[a+32856>>2]=0;c[a+76>>2]=0;c[a+36>>2]=1;if((c[270930]|0)==(a|0)){c[270930]=0;return}else{c[270928]=0;return}}function rQ(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=a+388|0;e=yc(d)|0;if((e|0)!=0){f=e;i=b;return f|0}rH(a,1)|0;a=d|0;d=c[a>>2]|0;if((d|0)!=0){f=d;i=b;return f|0}w1(71272,(d=i,i=i+8|0,c[d>>2]=111048,d)|0);i=d;f=c[a>>2]|0;i=b;return f|0}function rR(){var a=0,b=0,d=0,e=0,f=0;a=i;oW(61480,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;if((c[169394]|0)>0){d=0;e=677592}else{i=a;return}while(1){f=c[e+388>>2]|0;oW(55440,(b=i,i=i+24|0,c[b>>2]=10,c[b+8>>2]=f,c[b+16>>2]=e,b)|0);i=b;f=d+1|0;if((f|0)<(c[169394]|0)){d=f;e=e+396|0}else{break}}i=a;return}function rS(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;if((a[b]|0)==0){w1(79160,(e=i,i=i+8|0,c[e>>2]=111032,e)|0);i=e}f=c[169394]|0;L3833:do{if((f|0)>0){g=0;h=677592;while(1){if((cS(h|0,b|0)|0)==0){j=g;k=h;break L3833}l=g+1|0;m=h+396|0;if((l|0)<(f|0)){g=l;h=m}else{j=l;k=m;break}}}else{j=0;k=677592}}while(0);if((j|0)==(f|0)){if((f|0)==512){w1(77768,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e}e=k|0;yP(e|0,b|0,63)|0;a[k+63|0]=0;b=k+64|0;c[b>>2]=1;c[169394]=(c[169394]|0)+1;n=b}else{n=k+64|0}if((c[n>>2]|0)!=0){i=d;return}if((c[k+68>>2]|0)!=2){i=d;return}yc(k+388|0)|0;i=d;return}function rT(a,b){a=a|0;b=b|0;var d=0;c[a+36>>2]=b;if((c[a>>2]|0)<0){return}else{d=a}while(1){rT(c[d+44>>2]|0,d);a=c[d+48>>2]|0;c[a+36>>2]=d;if((c[a>>2]|0)<0){break}else{d=a}}return}function rU(a){a=a|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0,s=0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0;d=i;e=c[a+72>>2]|0;f=c[a+44>>2]|0;if((f|0)>0){h=c[a+40>>2]|0;j=c[274538]|0;k=c[j+188>>2]|0;l=j+156|0;m=j+148|0;j=0;n=3.4028234663852886e+38;o=-3.4028234663852886e+38;p=3.4028234663852886e+38;q=-3.4028234663852886e+38;while(1){r=c[k+(h+j<<2)>>2]|0;if((r|0)>-1){s=(c[m>>2]|0)+((c[(c[l>>2]|0)+(r*12|0)>>2]|0)*12|0)|0}else{s=(c[m>>2]|0)+((c[(c[l>>2]|0)+((-r|0)*12|0)+4>>2]|0)*12|0)|0}t=+g[s>>2];u=+g[s+4>>2];v=+g[s+8>>2];w=+g[e+12>>2]+(t*+g[e>>2]+u*+g[e+4>>2]+v*+g[e+8>>2]);x=w<n?w:n;y=w>o?w:o;w=+g[e+28>>2]+(t*+g[e+16>>2]+u*+g[e+20>>2]+v*+g[e+24>>2]);v=w<p?w:p;u=w>q?w:q;r=j+1|0;if((r|0)<(f|0)){j=r;n=x;o=y;p=v;q=u}else{z=x;A=y;B=v;C=u;break}}}else{z=3.4028234663852886e+38;A=-3.4028234663852886e+38;B=3.4028234663852886e+38;C=-3.4028234663852886e+38}j=e+40|0;e=~~+P(+(z*.0625));f=~~+aa(+(A*.0625));b[a+64>>1]=e<<4&65535;s=f-e<<4&65535;b[a+68>>1]=s;if((c[j>>2]&1|0)==0&s<<16>>16>256){w1(90968,(D=i,i=i+1|0,i=i+7>>3<<3,c[D>>2]=0,D)|0);i=D}s=~~+P(+(B*.0625));e=~~+aa(+(C*.0625));b[a+66>>1]=s<<4&65535;f=e-s<<4&65535;b[a+70>>1]=f;if(!((c[j>>2]&1|0)==0&f<<16>>16>256)){i=d;return}w1(90968,(D=i,i=i+1|0,i=i+7>>3<<3,c[D>>2]=0,D)|0);i=D;i=d;return}function rV(b){b=b|0;if((c[46140]|0)==0){return}c[278830]=1;b=c[4635]|0;if((cS(b|0,106920)|0)==0){a[1114504]=a[105792]|0;a[1114505|0]=a[105793|0]|0;a[1114506|0]=a[105794|0]|0;a[1114507|0]=a[105795|0]|0;a[1114508|0]=a[105796|0]|0;a[1114509|0]=a[105797|0]|0}else{yQ(1114504,b|0)|0}yQ(1114520,184604)|0;c[278642]=c[169356];c[278643]=c[45874];c[278644]=c[169354];a[1114536]=a[105792]|0;a[1114537|0]=a[105793|0]|0;a[1114538|0]=a[105794|0]|0;a[1114539|0]=a[105795|0]|0;a[1114540|0]=a[105796|0]|0;a[1114541|0]=a[105797|0]|0;return}function rW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;if((cS(b|0,105792)|0)!=0){e=0;i=d;return e|0}c[274518]=1;b=c[270930]|0;do{if((b|0)==0){f=r_()|0;c[270930]=f;if((f|0)!=0){g=f+65636|0;yJ(g|0,71224,10)|0;h=f;break}oW(85648,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;e=0;i=d;return e|0}else{h=b}}while(0);c[h+32856>>2]=0;c[(c[270930]|0)+76>>2]=0;c[(c[270930]|0)+36>>2]=1;c[(c[270930]|0)+56>>2]=32768;h=c[270928]|0;do{if((h|0)==0){b=r_()|0;c[270928]=b;if((b|0)!=0){f=b+65636|0;a[f]=a[61448]|0;a[f+1|0]=a[61449|0]|0;a[f+2|0]=a[61450|0]|0;a[f+3|0]=a[61451|0]|0;a[f+4|0]=a[61452|0]|0;a[f+5|0]=a[61453|0]|0;k=b;break}oW(85648,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;e=0;i=d;return e|0}else{k=h}}while(0);c[k+32856>>2]=0;c[(c[270928]|0)+76>>2]=0;c[(c[270928]|0)+36>>2]=1;c[(c[270928]|0)+56>>2]=32768;c[(c[270930]|0)+60>>2]=c[270928];c[(c[270928]|0)+60>>2]=c[270930];e=c[270930]|0;i=d;return e|0}function rX(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b+32856|0;if((c[e>>2]|0)==0){f=0;return f|0}g=b+32860|0;h=a[g]|0;i=h&255;j=(d[b+32862|0]|0)<<8|(d[b+32861|0]|0);nT(677376);nZ(677376,b+32864|0,j);k=j+7&131068;j=c[e>>2]|0;l=j-k|0;c[e>>2]=l;if((j|0)!=(k|0)){yN(g|0,b+32860+k|0,l|0)}l=c[b+60>>2]|0;if(!((l|0)!=0&h<<24>>24==1)){f=i;return f|0}c[l+36>>2]=1;f=i;return f|0}function rY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=b+60|0;g=c[f>>2]|0;if((g|0)==0){h=-1;i=e;return h|0}j=g+32856|0;k=c[j>>2]|0;l=d+16|0;if((k+4+(c[l>>2]|0)|0)>32768){w1(55392,(m=i,i=i+8|0,c[m>>2]=111096,m)|0);i=m;n=c[f>>2]|0;o=c[j>>2]|0}else{n=g;o=k}a[n+(o+32860)|0]=1;a[n+(o+32861)|0]=c[l>>2]&255;a[n+(o+32862)|0]=(c[l>>2]|0)>>>8&255;k=n+(o+32864)|0;o=c[d+8>>2]|0;d=c[l>>2]|0;yJ(k|0,o|0,d)|0;c[j>>2]=(c[j>>2]|0)+7+(c[l>>2]|0)&-4;c[b+36>>2]=0;h=1;i=e;return h|0}function rZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c[b+60>>2]|0;if((e|0)==0){f=-1;return f|0}b=e+32856|0;g=c[b>>2]|0;h=d+16|0;if((g+3+(c[h>>2]|0)|0)>>>0>32768){f=0;return f|0}a[e+(g+32860)|0]=2;a[e+(g+32861)|0]=c[h>>2]&255;a[e+(g+32862)|0]=(c[h>>2]|0)>>>8&255;i=e+(g+32864)|0;g=c[d+8>>2]|0;d=c[h>>2]|0;yJ(i|0,g|0,d)|0;c[b>>2]=(c[b>>2]|0)+7+(c[h>>2]|0)&-4;f=1;return f|0}function r_(){var a=0,b=0,d=0;a=c[169352]|0;if((a|0)==0){b=0;return b|0}if((c[169356]|0)>=(c[45874]|0)){b=0;return b|0}d=a|0;c[169352]=c[d>>2];c[d>>2]=c[169358];c[169358]=a;c[a+32>>2]=0;h[a+8>>3]=+h[1884];d=a+65636|0;yJ(d|0,55368,14)|0;c[a+44>>2]=c[169354];c[a+52>>2]=0;c[a+60>>2]=0;c[a+36>>2]=1;c[a+40>>2]=0;h[a+16>>3]=+h[1884];c[a+32848>>2]=0;c[a+32852>>2]=0;c[a+32856>>2]=0;yG(a+64|0,0,16);b=a;return b|0}function r$(){var a=0,b=0,d=0.0,e=0,f=0,g=0,j=0;a=i;if((c[153848]|0)!=0){i=a;return}if((c[153844]|0)==0){oW(46896,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;oW(62176,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;oW(61320,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;c[153846]=0}c[153848]=1;h[436]=+wZ();d=+wZ()+0.0;h[438]=d;b=0;e=635016;while(1){f=c[e>>2]|0;if((f|0)==0){g=0;break}if(+h[f+8>>3]<d){b=f;e=f|0}else{g=f;break}}if((b|0)==0){c[874]=c[158754];c[158754]=3496}else{c[874]=g;c[b>>2]=3496}d=+wZ()+.1;h[441]=d;b=0;g=635016;while(1){e=c[g>>2]|0;if((e|0)==0){j=0;break}if(+h[e+8>>3]<d){b=e;g=e|0}else{j=e;break}}if((b|0)==0){c[880]=c[158754];c[158754]=3520}else{c[880]=j;c[b>>2]=3520}c[278830]=0;i=a;return}function r0(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;e=c[3770]|0;h[1884]=+wZ();L3963:do{if((b|0)==0){f=0;g=2963}else{j=(a[b]|0)==0?0:b;if((j|0)==0){f=0;g=2963;break}if((yM(j|0,42672)|0)==0){k=j;l=1;g=2977;break}m=c[278830]|0;if((m|0)==0){f=j;g=2963;break}else{n=0}while(1){if((n|0)>=(m|0)){f=j;g=2963;break L3963}if((yM(j|0,1114504+(n*88|0)|0)|0)==0){break}else{n=n+1|0}}o=1114536+(n*88|0)|0;g=2976}}while(0);L3971:do{if((g|0)==2963){c[153844]=(f|0)!=0;r$();if((c[153848]|0)!=0){do{p=+wZ();h[1884]=p;n=c[158754]|0;L3976:do{if((n|0)!=0){if(+h[n+8>>3]>p){break}else{q=n}do{b=q|0;c[158754]=c[b>>2];fs[c[q+16>>2]&255](c[q+20>>2]|0);q=c[b>>2]|0;if((q|0)==0){break L3976}}while(+h[q+8>>3]<=+h[1884])}}while(0);}while((c[153848]|0)!=0)}do{if((f|0)==0){if((c[278830]|0)==1){oW(38800,(r=i,i=i+16|0,c[r>>2]=1114504,c[r+8>>2]=1114536,r)|0);i=r;s=1114536;break}else{t=0;i=d;return t|0}}else{s=f}}while(0);n=c[278830]|0;if((n|0)==0){o=s;g=2976;break}else{u=0}while(1){if((u|0)>=(n|0)){o=s;g=2976;break L3971}if((yM(s|0,1114504+(u*88|0)|0)|0)==0){break}else{u=u+1|0}}o=1114536+(u*88|0)|0;g=2976}}while(0);if((g|0)==2976){if((e|0)>0){k=o;l=e;g=2977}else{v=o}}L3995:do{if((g|0)==2977){o=0;while(1){c[169354]=15144+(o*60|0);if((c[15148+(o*60|0)>>2]|0)!=0){e=fv[c[15164+(o*60|0)>>2]&127](k)|0;if((e|0)!=0){t=e;break}}e=o+1|0;if((e|0)<(l|0)){o=e}else{v=k;break L3995}}i=d;return t|0}}while(0);if((v|0)==0){t=0;i=d;return t|0}oW(108880,(r=i,i=i+1|0,i=i+7>>3<<3,c[r>>2]=0,r)|0);i=r;oW(62176,(r=i,i=i+1|0,i=i+7>>3<<3,c[r>>2]=0,r)|0);i=r;oW(61320,(r=i,i=i+1|0,i=i+7>>3<<3,c[r>>2]=0,r)|0);i=r;c[153846]=0;v=c[278830]|0;if((v|0)>0){k=0;while(1){l=c[1114572+(k*88|0)>>2]|0;g=1114504+(k*88|0)|0;o=1114520+(k*88|0)|0;if((l|0)==0){oW(62816,(r=i,i=i+16|0,c[r>>2]=g,c[r+8>>2]=o,r)|0);i=r}else{e=c[1114568+(k*88|0)>>2]|0;oW(63616,(r=i,i=i+32|0,c[r>>2]=g,c[r+8>>2]=o,c[r+16>>2]=e,c[r+24>>2]=l,r)|0);i=r}l=k+1|0;e=c[278830]|0;if((l|0)<(e|0)){k=l}else{w=l;x=e;break}}}else{w=0;x=v}c[153846]=w;if((x|0)==0){oW(64392,(r=i,i=i+1|0,i=i+7>>3<<3,c[r>>2]=0,r)|0);i=r;t=0;i=d;return t|0}else{oW(65264,(r=i,i=i+1|0,i=i+7>>3<<3,c[r>>2]=0,r)|0);i=r;t=0;i=d;return t|0}return 0}function r1(){var a=0.0,b=0,d=0,e=0.0,f=0,g=0;a=+wZ();h[1884]=a;b=c[158754]|0;if((b|0)==0){return}else{d=b;e=a}while(1){if(+h[d+8>>3]>e){f=3002;break}b=d|0;c[158754]=c[b>>2];fs[c[d+16>>2]&255](c[d+20>>2]|0);g=c[b>>2]|0;if((g|0)==0){f=3001;break}d=g;e=+h[1884]}if((f|0)==3001){return}else if((f|0)==3002){return}}function r2(){var a=0,b=0,d=0,e=0,f=0,g=0;h[1884]=+wZ();a=c[3770]|0;if((a|0)>0){b=0;d=a}else{e=0;return e|0}L4033:while(1){c[169354]=15144+(b*60|0);do{if((c[15148+(b*60|0)>>2]|0)==0){f=d}else{if((b|0)!=0&(c[274558]|0)==0){f=d;break}a=fN[c[15168+(b*60|0)>>2]&63]()|0;if((a|0)!=0){e=a;g=3011;break L4033}f=c[3770]|0}}while(0);a=b+1|0;if((a|0)<(f|0)){b=a;d=f}else{e=0;g=3013;break}}if((g|0)==3013){return e|0}else if((g|0)==3011){return e|0}return 0}function r3(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0;b=i;if((a|0)==0){i=b;return}d=a+32|0;if((c[d>>2]|0)!=0){i=b;return}h[1884]=+wZ();fs[c[(c[a+44>>2]|0)+48>>2]&255](a);e=c[169358]|0;do{if((e|0)==(a|0)){f=a|0;c[169358]=c[f>>2];g=f}else{f=e;while(1){if((f|0)==0){j=3021;break}k=f|0;l=c[k>>2]|0;if((l|0)==(a|0)){j=3020;break}else{f=l}}if((j|0)==3021){w1(50816,(f=i,i=i+8|0,c[f>>2]=110408,f)|0);i=f;g=a|0;break}else if((j|0)==3020){f=a|0;c[k>>2]=c[f>>2];g=f;break}}}while(0);c[g>>2]=c[169352];c[169352]=a;c[d>>2]=1;i=b;return}function r4(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;if((a|0)==0){d=-1;i=b;return d|0}e=a+32|0;if((c[e>>2]|0)!=0){oW(105616,(f=i,i=i+8|0,c[f>>2]=110392,f)|0);i=f;d=-1;i=b;return d|0}h[1884]=+wZ();j=a+44|0;k=fv[c[(c[j>>2]|0)+28>>2]&127](a)|0;do{if((k|0)==0){if((c[j>>2]|0)==15144){d=0;i=b;return d|0}if(+h[1884]- +h[a+16>>3]<=+g[3776]){break}if((c[e>>2]|0)!=0){d=-1;i=b;return d|0}h[1884]=+wZ();fs[c[(c[j>>2]|0)+48>>2]&255](a);l=c[169358]|0;do{if((l|0)==(a|0)){m=a|0;c[169358]=c[m>>2];n=m}else{m=l;while(1){if((m|0)==0){o=3039;break}p=m|0;q=c[p>>2]|0;if((q|0)==(a|0)){o=3038;break}else{m=q}}if((o|0)==3038){m=a|0;c[p>>2]=c[m>>2];n=m;break}else if((o|0)==3039){w1(50816,(f=i,i=i+8|0,c[f>>2]=110408,f)|0);i=f;n=a|0;break}}}while(0);c[n>>2]=c[169352];c[169352]=a;c[e>>2]=1;d=-1;i=b;return d|0}}while(0);if((k|0)<=0){d=k;i=b;return d|0}if((c[j>>2]|0)==15144){d=k;i=b;return d|0}h[a+16>>3]=+h[1884];if((k|0)==2){c[29410]=(c[29410]|0)+1;d=2;i=b;return d|0}else if((k|0)==1){c[220096]=(c[220096]|0)+1;d=1;i=b;return d|0}else{d=k;i=b;return d|0}return 0}function r5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;do{if((a|0)==0){e=-1}else{if((c[a+32>>2]|0)!=0){oW(105616,(f=i,i=i+8|0,c[f>>2]=110360,f)|0);i=f;e=-1;break}h[1884]=+wZ();f=a+44|0;g=fL[c[(c[f>>2]|0)+32>>2]&63](a,b)|0;if((g|0)!=1){e=g;break}if((c[f>>2]|0)==15144){e=1;break}c[220094]=(c[220094]|0)+1;e=1}}while(0);i=d;return e|0}
function fS(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7>>3<<3;return b|0}function fT(){return i|0}function fU(a){a=a|0;i=a}function fV(a,b){a=a|0;b=b|0;if((s|0)==0){s=a;t=b}}function fW(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0]}function fX(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0];a[k+4|0]=a[b+4|0];a[k+5|0]=a[b+5|0];a[k+6|0]=a[b+6|0];a[k+7|0]=a[b+7|0]}function fY(a){a=a|0;F=a}function fZ(a){a=a|0;G=a}function f_(a){a=a|0;H=a}function f$(a){a=a|0;I=a}function f0(a){a=a|0;J=a}function f1(a){a=a|0;K=a}function f2(a){a=a|0;L=a}function f3(a){a=a|0;M=a}function f4(a){a=a|0;N=a}function f5(a){a=a|0;O=a}function f6(){}function f7(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=d<<1;if((e|0)==0){return d|0}else{f=0}do{g=b[a+(f<<1)>>1]|0;h=(c[335658]|0)-1|0;c[335658]=h;b[(c[335657]|0)+(h<<1)>>1]=g;f=f+1|0;}while(f>>>0<e>>>0);return d|0}function f8(b,d){b=b|0;d=d|0;var e=0,f=0;fg(800,600);gx();gj();e=gy(b,d)|0;if((e|0)!=0){f=e;return f|0}kH();e=1400528;d=c[e+4>>2]|0;b=1400528;c[b>>2]=c[e>>2]|1;c[b+4>>2]=d;if((a[1401613]&1)==0){kB()}eT(528,((a[1140656]&1)!=0?0:2147483647)|0,1);f=0;return f|0}function f9(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+24|0;d=b|0;if((a[1230628]|0)==0){i=b;return}do{if((a[1157111]&1)!=0|(c[335625]|0)!=0){e=c[350657]|0;if((c[e+48>>2]|0)==0){f=23;break}g=e+44|0;if((c[g>>2]|0)==0){f=23;break}yG(d|0,0,24);ft[c[g>>2]&127](c[350660]|0,d);g=d+8|0;e=c[g>>2]|0;if((e|0)==0){f=28;break}h=d+12|0;j=c[h>>2]|0;if((j|0)==0){f=28;break}k=yx(ab(e*3|0,j)|0)|0;if((k|0)==0){f=28;break}if(fL[c[(c[350657]|0)+48>>2]&63](c[350660]|0,k)|0){j=c[g>>2]|0;g=jf(1230628,k,j,c[h>>2]|0,j*3|0,1)|0;yz(k);if(g){f=26;break}else{f=28;break}}else{yz(k);f=28;break}}else{f=23}}while(0);do{if((f|0)==23){d=c[350070]|0;k=d;if((k|0)==(-1|0)|(k|0)==0){k=c[350134]|0;g=(k|0)!=0?k:c[p>>2]|0;a5(109224,103,1,g|0)|0;g=c[350134]|0;k=(g|0)!=0?g:c[p>>2]|0;a_(k|0)|0;f=28;break}else{k=c[350071]|0;g=c[350072]|0;j=c[350073]|0;if(jf(1230628,d+(ab(g-1|0,j)|0)|0,k,g,-j|0,0)|0){f=26;break}else{f=28;break}}}}while(0);do{if((f|0)==26){if((a[1243488]&1)==0){l=87512;break}j=c[350134]|0;g=(j|0)!=0?j:c[p>>2]|0;a5(102608,30,1,g|0)|0;g=c[350134]|0;j=(g|0)!=0?g:c[p>>2]|0;a_(j|0)|0;l=87512}else if((f|0)==28){j=c[350134]|0;a5(72400,50,1,((j|0)!=0?j:c[p>>2]|0)|0)|0;j=c[350134]|0;a_(((j|0)!=0?j:c[p>>2]|0)|0)|0;l=62272}}while(0);ip(c[348003]|0);f=c[348003]|0;if((a[1400239]&1)==0){iq(f,l,1,180);i=b;return}else{iq(f,l,1,1);ga();i=b;return}}function ga(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[350070]|0;d=(b|0)==-1?0:b;b=c[350071]|0;e=c[350072]|0;f=c[350073]|0;if((a[1243490]&1)==0){return}c[350070]=d;c[350071]=b;c[350072]=e;c[350073]=f;do{if((c[334462]|0)==0){g=d;if((g|0)==(-1|0)|(g|0)==0){h=d;i=f;break}c[350668]=b;c[350669]=e;c[350671]=b;c[350672]=e;c[350670]=f;c[350673]=b<<1;jN(1402672,c[350700]|0,d);h=c[350700]|0;i=c[350673]|0}else{h=d;i=f}}while(0);f=ir(c[348003]|0)|0;c[350709]=f;if(fu[c[(c[350657]|0)+4>>2]&15](c[350660]|0,h,b,e,i,f)|0){return}a[1243490]=0;return}function gb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((a[1243490]&1)==0){return}c[350070]=b;c[350071]=d;c[350072]=e;c[350073]=f;do{if((c[334462]|0)==0){g=b;if((g|0)==(-1|0)|(g|0)==0){h=b;i=f;break}c[350668]=d;c[350669]=e;c[350671]=d;c[350672]=e;c[350670]=f;c[350673]=d<<1;jN(1402672,c[350700]|0,b);h=c[350700]|0;i=c[350673]|0}else{h=b;i=f}}while(0);f=ir(c[348003]|0)|0;c[350709]=f;if(fu[c[(c[350657]|0)+4>>2]&15](c[350660]|0,h,d,e,i,f)|0){return}a[1243490]=0;return}function gc(b,c){b=b|0;c=c|0;var d=0,e=0;d=c>>>0>1024?1024:c;if(gd(b,d<<1)|0){e=a[1243489]&1}else{e=0}a[1243489]=e;return d|0}function gd(b,d){b=b|0;d=d|0;var e=0,f=0,j=0,k=0.0,l=0,m=0,n=0.0;e=i;i=i+24|0;f=e|0;if((a[1400239]&1)!=0){j=1;i=e;return j|0}if((a[1342617]&1)!=0){j=1;i=e;return j|0}if((a[1243489]&1)==0){j=0;i=e;return j|0}yG(f|0,0,24);jj(c[335646]|0,b,d,+g[335668]);c[f>>2]=c[335646];c[f+8>>2]=d>>>1;c[f+4>>2]=c[335655];if((a[1342652]&1)==0){k=+h[167826]}else{d=fv[c[(c[350656]|0)+32>>2]&127](c[350659]|0)|0;b=1375448;l=c[b>>2]|0;m=yT(l,c[b+4>>2]|0,1,0)|0;b=1375448;c[b>>2]=m;c[b+4>>2]=F;c[1342680+((l&8191)<<2)>>2]=d;l=(c[335666]|0)>>>1;n=+h[167832]*(+(d-l|0)/+(l|0)*+g[291341]+1.0);h[167826]=n;k=n}l=f+16|0;h[l>>3]=k;if((a[1400241]&1)!=0){h[l>>3]=k*+g[309708]}ft[c[(c[335645]|0)+4>>2]&127](c[335644]|0,f);l=c[335655]|0;d=c[f+12>>2]|0;if((a[1342616]&1)==0){jk(c[335656]|0,l,d<<1);if((fA[c[(c[350656]|0)+4>>2]&63](c[350659]|0,c[335656]|0,d<<2)|0)>=0){j=1;i=e;return j|0}f=c[350134]|0;b=(f|0)!=0?f:c[p>>2]|0;a5(75528,81,1,b|0)|0;b=c[350134]|0;f=(b|0)!=0?b:c[p>>2]|0;a_(f|0)|0;j=0;i=e;return j|0}else{if((fA[c[(c[350656]|0)+4>>2]&63](c[350659]|0,l,d<<3)|0)>=0){j=1;i=e;return j|0}d=c[350134]|0;l=(d|0)!=0?d:c[p>>2]|0;a5(75528,81,1,l|0)|0;l=c[350134]|0;d=(l|0)!=0?l:c[p>>2]|0;a_(d|0)|0;j=0;i=e;return j|0}return 0}function ge(){var a=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;a=i;i=i+16|0;d=a|0;fs[c[(c[350658]|0)+4>>2]&255](c[350661]|0);e=c[350702]|0;if((e|0)==0){i=a;return}yG(1402816,0,16);f=jD(e)|0?65542:6;if((fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,0,0,f,0,2)|0)<<16>>16==0){jC(c[350702]|0);i=a;return}e=d|0;g=d+8|0;h=d+10|0;j=d+12|0;k=d+14|0;l=0;do{m=fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,0,0,f,l,0)|0;n=fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,0,0,f,l,1)|0;jI(c[350702]|0,d,m,n);n=1402816;m=c[n+4>>2]|c[e+4>>2];o=1402816;c[o>>2]=c[n>>2]|c[e>>2];c[o+4>>2]=m;if((b[701412]|0)==0){b[701412]=b[g>>1]|0}if((b[701413]|0)==0){b[701413]=b[h>>1]|0}if((b[701414]|0)==0){b[701414]=b[j>>1]|0}if((b[701415]|0)==0){b[701415]=b[k>>1]|0}l=l+1|0;}while((fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,0,0,f,l,2)|0)<<16>>16!=0);i=a;return}function gf(){var a=0;a=c[348003]|0;if((a|0)==0){return}io(a);c[348003]=0;return}function gg(){var b=0,d=0,e=0,f=0,g=0,h=0;b=i;if((a[1238820]&1)==0|(c[348005]|0)!=0){i=b;return}if((c[335617]|0)!=0){d=c[350134]|0;e=(d|0)!=0?d:c[p>>2]|0;a5(47376,76,1,e|0)|0;e=c[350134]|0;d=(e|0)!=0?e:c[p>>2]|0;a_(d|0)|0;i=b;return}d=fN[c[157564]&63]()|0;c[348007]=d;if((d|0)==0){e=c[350134]|0;f=(e|0)!=0?e:c[p>>2]|0;a5(43088,85,1,f|0)|0;f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0;i=b;return}e=d+3&-4;f=yy(1,e)|0;c[348006]=f;if((f|0)==0){g=c[350134]|0;h=(g|0)!=0?g:c[p>>2]|0;a5(39144,66,1,h|0)|0;h=c[350134]|0;g=(h|0)!=0?h:c[p>>2]|0;a_(g|0)|0;i=b;return}if(!(fL[c[157566]&63](f,d)|0)){d=c[350134]|0;f=(d|0)!=0?d:c[p>>2]|0;a5(109144,73,1,f|0)|0;f=c[350134]|0;d=(f|0)!=0?f:c[p>>2]|0;a_(d|0)|0;yz(c[348006]|0);c[348006]=0;i=b;return}if((a[1243488]&1)!=0){d=c[350134]|0;f=(d|0)!=0?d:c[p>>2]|0;d=((c[309706]|0)>>>0)/1e6|0;en(f|0,106088,(f=i,i=i+8|0,c[f>>2]=d,f)|0)|0;i=f;f=c[350134]|0;d=(f|0)!=0?f:c[p>>2]|0;a_(d|0)|0}d=iz(e,c[309706]|0,c[348006]|0)|0;c[348005]=d;if((d|0)!=0){i=b;return}d=c[350134]|0;a5(101456,78,1,((d|0)!=0?d:c[p>>2]|0)|0)|0;d=c[350134]|0;a_(((d|0)!=0?d:c[p>>2]|0)|0)|0;i=b;return}function gh(){var a=0;a=c[348005]|0;if((a|0)!=0){is(a)}c[348005]=0;yz(c[348006]|0);c[348006]=0;return}function gi(){var b=0,d=0,e=0,f=0,g=0,h=0;if((a[1337840]&1)!=0){a[1337840]=0;kF();if(!((a[1400542]&1)==0|(a[1264018]|0)==0)){hR(1264018)|0}if((a[1400540]&1)==0){gf();gx();ck(0)}gC();gf();gx();ck(0)}if(a[15216]|0){if(kI()|0){return}a[15216]=0;hg((a[1402656]&1)!=0);b=c[350659]|0;do{if((b|0)!=0){if(fv[c[(c[350656]|0)+12>>2]&127](b)|0){break}d=c[350134]|0;e=(d|0)!=0?d:c[p>>2]|0;a5(109328,81,1,e|0)|0;e=c[350134]|0;d=(e|0)!=0?e:c[p>>2]|0;a_(d|0)|0;a[1243489]=0}}while(0);b=1400528;d=c[b+4>>2]|0;e=1400528;c[e>>2]=c[b>>2]&-5;c[e+4>>2]=d;return}d=1400528;e=c[d>>2]|0;b=c[d+4>>2]|0;if(!((e&2|0)==0&(b&0|0)==0)){kC();if(!(kE()|0)){return}d=1400528;f=c[d+4>>2]|0|0;g=1400528;c[g>>2]=c[d>>2]&-4|1;c[g+4>>2]=f;return}if((e&1|0)==0&(b&0|0)==0){if((e&4|0)==0&(b&0|0)==0){a[1337840]=1;return}f=1400528;c[f>>2]=e|32;c[f+4>>2]=b;ft[c[(c[350657]|0)+8>>2]&127](c[350660]|0,0);b=c[350659]|0;if((b|0)!=0){f=c[(c[350656]|0)+8>>2]|0;fv[f&127](b)|0}a[15216]=1;return}do{if((a[1400239]&1)==0){h=144}else{if((a[1400240]&1)!=0){h=144;break}if(!(gE()|0)){break}return}}while(0);do{if((h|0)==144){if(!(gz()|0)){break}return}}while(0);h=1400528;b=c[h+4>>2]|0;f=1400528;c[f>>2]=c[h>>2]&-2;c[f+4>>2]=b;return}function gj(){var a=0,b=0,d=0;a=i;if((c[348003]|0)!=0){i=a;return}b=im(8)|0;c[348003]=b;if((b|0)==0){b=c[350134]|0;d=(b|0)!=0?b:c[p>>2]|0;en(d|0,55960,(d=i,i=i+16|0,c[d>>2]=51192,c[d+8>>2]=1408,d)|0)|0;i=d;d=c[350134]|0;b=(d|0)!=0?d:c[p>>2]|0;a_(b|0)|0;ck(2)}else{i=a;return}}function gk(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=i;i=i+4608|0;b=c[334438]|0;d=a|0;if((b|0)==0){bR(d|0,4096,98720,(e=i,i=i+8|0,c[e>>2]=1304978,e)|0)|0;i=e}else{bR(d|0,4096,100240,(e=i,i=i+16|0,c[e>>2]=1304978,c[e+8>>2]=b,e)|0)|0;i=e}b=a+4096|0;if(gN(d)|0){f=c[334438]|0;bR(b|0,512,96512,(e=i,i=i+8|0,c[e>>2]=f,e)|0)|0;i=e;g=c[348003]|0;ip(g);h=c[348003]|0;iq(h,b,2,180);i=a;return}else{bR(b|0,512,94416,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;g=c[348003]|0;ip(g);h=c[348003]|0;iq(h,b,2,180);i=a;return}}function gl(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+4608|0;d=c[334438]|0;if((a[1238849]&1)==0){e=d}else{f=d+1|0;c[334438]=f;e=f}f=b|0;if((e|0)==0){bR(f|0,4096,98720,(g=i,i=i+8|0,c[g>>2]=1304978,g)|0)|0;i=g}else{bR(f|0,4096,100240,(g=i,i=i+16|0,c[g>>2]=1304978,c[g+8>>2]=e,g)|0)|0;i=g}e=b+4096|0;if(gM(f)|0){d=c[334438]|0;bR(e|0,512,92688,(g=i,i=i+8|0,c[g>>2]=d,g)|0)|0;i=g;h=c[348003]|0;ip(h);j=c[348003]|0;iq(j,e,2,180);i=b;return}else{bR(e|0,512,91136,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;h=c[348003]|0;ip(h);j=c[348003]|0;iq(j,e,2,180);i=b;return}}function gm(b){b=b|0;a[1140640]=b&1;a[1402649]=a[1342528]&1;a[1402650]=0;hl();hj();a[1402649]=0;b=c[350658]|0;if((b|0)==0){return}fs[c[b+4>>2]&255](c[350661]|0);return}function gn(){var b=0,d=0,e=0,f=0;b=i;i=i+256|0;d=(c[334438]|0)+1|0;c[334438]=d;e=c[348003]|0;if((e|0)==0){f=d}else{ip(e);f=c[334438]|0}e=b|0;bR(e|0,256,89184,(d=i,i=i+8|0,c[d>>2]=f,d)|0)|0;i=d;f=c[348003]|0;if((f|0)!=0){iq(f,e,1,180)}if((a[1243488]&1)==0){i=b;return}f=c[350134]|0;en(((f|0)!=0?f:c[p>>2]|0)|0,87496,(d=i,i=i+8|0,c[d>>2]=e,d)|0)|0;i=d;d=c[350134]|0;a_(((d|0)!=0?d:c[p>>2]|0)|0)|0;i=b;return}function go(){var b=0,d=0,e=0,f=0,g=0;b=i;i=i+256|0;d=c[334438]|0;if((d|0)==0){e=0}else{f=d-1|0;c[334438]=f;e=f}f=c[348003]|0;if((f|0)==0){g=e}else{ip(f);g=c[334438]|0}f=b|0;bR(f|0,256,89184,(e=i,i=i+8|0,c[e>>2]=g,e)|0)|0;i=e;g=c[348003]|0;if((g|0)!=0){iq(g,f,1,180)}if((a[1243488]&1)==0){i=b;return}g=c[350134]|0;en(((g|0)!=0?g:c[p>>2]|0)|0,87496,(e=i,i=i+8|0,c[e>>2]=f,e)|0)|0;i=e;e=c[350134]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;i=b;return}function gp(){var b=0,d=0;if((a[1243488]&1)!=0){b=c[350134]|0;d=(b|0)!=0?b:c[p>>2]|0;a5(85880,27,1,d|0)|0;d=c[350134]|0;b=(d|0)!=0?d:c[p>>2]|0;a_(b|0)|0}ip(c[348003]|0);iq(c[348003]|0,83104,1,120);fQ[c[157570]&1023]();gq();return}function gq(){var b=0,d=0,e=0,f=0,g=0;b=i;d=0;do{e=c[1243492+(d<<2)>>2]|0;L274:do{if((e|0)!=1){ft[c[157558]&127](d,e);switch(e|0){case 772:{if((a[1243488]&1)==0){break L274}f=c[350134]|0;en(((f|0)!=0?f:c[p>>2]|0)|0,76432,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[350134]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L274;break};case 257:{if((a[1243488]&1)==0){break L274}f=c[350134]|0;en(((f|0)!=0?f:c[p>>2]|0)|0,75976,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[350134]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L274;break};case 260:{if((a[1243488]&1)==0){break L274}f=c[350134]|0;en(((f|0)!=0?f:c[p>>2]|0)|0,75760,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[350134]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L274;break};case 0:{if((a[1243488]&1)==0){break L274}f=c[350134]|0;en(((f|0)!=0?f:c[p>>2]|0)|0,76760,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[350134]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L274;break};case 5:{if((a[1243488]&1)==0){break L274}f=c[350134]|0;en(((f|0)!=0?f:c[p>>2]|0)|0,76664,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[350134]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L274;break};case 2:{if((a[1243488]&1)==0){break L274}f=c[350134]|0;en(((f|0)!=0?f:c[p>>2]|0)|0,76592,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[350134]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L274;break};case 516:{if((a[1243488]&1)==0){break L274}f=c[350134]|0;en(((f|0)!=0?f:c[p>>2]|0)|0,76512,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[350134]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L274;break};default:{break L274}}}}while(0);d=d+1|0;}while(d>>>0<8);i=b;return}function gr(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+528|0;e=d|0;gs(1,0);fN[c[335624]&63]()|0;f=fN[c[335622]&63]()|0;if((f|0)==0){i=d;return}g=f-1|0;yG(e|0,0,16);c[e>>2]=b;fL[c[335623]&63](g,e)|0;gt(g);g=d+16|0;bR(g|0,512,81056,(e=i,i=i+8|0,c[e>>2]=b,e)|0)|0;i=e;if((a[1243488]&1)!=0){f=c[350134]|0;h=(f|0)!=0?f:c[p>>2]|0;en(h|0,87496,(e=i,i=i+8|0,c[e>>2]=g,e)|0)|0;i=e;e=c[350134]|0;h=(e|0)!=0?e:c[p>>2]|0;a_(h|0)|0}ip(c[348003]|0);iq(c[348003]|0,g,0,180);gu(b);gv();gs(0,0);i=d;return}function gs(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+256|0;if((c[335622]|0)==0){i=e;return}f=e|0;a[f]=0;if(fv[c[335618]&127](b)|0){g=b?77856:76560;bR(f|0,256,79296,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=0}else{g=b?74336:73304;bR(f|0,256,75152,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=1}if((a[f]|0)==0){i=e;return}do{if(j){g=c[350134]|0;b=(g|0)!=0?g:c[p>>2]|0;en(b|0,72368,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[350134]|0;g=(b|0)!=0?b:c[p>>2]|0;a_(g|0)|0}else{if((a[1243488]&1)==0){break}g=c[350134]|0;b=(g|0)!=0?g:c[p>>2]|0;en(b|0,87496,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[350134]|0;g=(b|0)!=0?b:c[p>>2]|0;a_(g|0)|0}}while(0);if(!d){i=e;return}ip(c[348003]|0);iq(c[348003]|0,f,1,180);i=e;return}function gt(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+256|0;e=c[335622]|0;if((e|0)==0){i=d;return}f=d|0;a[f]=0;g=fN[e&63]()|0;e=g>>>0>b>>>0;do{if(fv[c[335621]&127](b)|0){if(e){h=b+1|0;bR(f|0,256,71344,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=0;break}else{bR(f|0,256,69536,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=0;break}}else{if(e){h=b+1|0;bR(f|0,256,68264,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=1;break}else{bR(f|0,256,67264,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=1;break}}}while(0);if((a[f]|0)==0){i=d;return}do{if(k){g=c[350134]|0;b=(g|0)!=0?g:c[p>>2]|0;en(b|0,72368,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[350134]|0;g=(b|0)!=0?b:c[p>>2]|0;a_(g|0)|0}else{if((a[1243488]&1)==0){break}g=c[350134]|0;b=(g|0)!=0?g:c[p>>2]|0;en(b|0,87496,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[350134]|0;g=(b|0)!=0?b:c[p>>2]|0;a_(g|0)|0}}while(0);ip(c[348003]|0);iq(c[348003]|0,f,1,180);i=d;return}function gu(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;i5(1280402,b,4096)|0;i5(1276306,b,4096)|0;e=cn(1276306,46)|0;if((e|0)!=0){a[e]=0}if((a[1264016]&1)==0){g7(1284498,1276306,78448,4096)}if((a[1264017]&1)==0){g7(1304978,1276306,78200,4096)}do{if(g_(1284498)|0){g8(1284498,1276306,78448,4096);if((a[1243488]&1)==0){break}e=c[350134]|0;f=(e|0)!=0?e:c[p>>2]|0;en(f|0,77424,(g=i,i=i+8|0,c[g>>2]=1284498,g)|0)|0;i=g;f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0}}while(0);do{if(g_(1304978)|0){g8(1304978,1276306,78200,4096);if((a[1243488]&1)==0){break}e=c[350134]|0;f=(e|0)!=0?e:c[p>>2]|0;en(f|0,77240,(g=i,i=i+8|0,c[g>>2]=1304978,g)|0)|0;i=g;f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0}}while(0);if((a[1234724]|0)==0){hb(1234724,b,4096)}if((a[1264018]|0)==0){i=d;return}if(!(g_(1264018)|0)){i=d;return}g8(1264018,1276306,77040,4096);if((a[1243488]&1)!=0){b=c[350134]|0;e=(b|0)!=0?b:c[p>>2]|0;en(e|0,76960,(g=i,i=i+8|0,c[g>>2]=1264018,g)|0)|0;i=g;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0}if(g$(1264018)|0){i=d;return}a[1264018]=0;if((a[1243488]&1)==0){i=d;return}e=c[350134]|0;a5(76864,59,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[350134]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;i=d;return}function gv(){var b=0,d=0,e=0;b=c[311906]|0;do{if((b|0)==4){if(!((a[1264016]&1)==0|(a[1255824]|0)==0|(a[1259920]|0)==0)){d=c[350134]|0;e=(d|0)!=0?d:c[p>>2]|0;a5(78064,109,1,e|0)|0;e=c[350134]|0;d=(e|0)!=0?e:c[p>>2]|0;a_(d|0)|0}g6(1296786,1255824,78448,4096);g6(1300882,1259920,78448,4096);if((a[1264017]&1)!=0){break}g6(1304978,(a[1255824]|0)!=0?1255824:1259920,78200,4096)}else if((b|0)==1){if((a[1264016]&1)==0){g6(1284498,1247632,78448,4096)}if((a[1264017]&1)==0){g6(1304978,1247632,78200,4096)}g6(1288594,1284498,77992,4096)}else if((b|0)==2|(b|0)==3){if((a[1264016]&1)==0){g6(1284498,1251728,78448,4096)}g6(1292690,1284498,78304,4096);if((a[1264017]&1)!=0){break}g6(1304978,1251728,78200,4096)}else{g6(1288594,1284498,77992,4096)}}while(0);g6(1392040,1284498,2659328,4096);if((a[1276306]|0)==0){return}if((a[1325462]|0)==0){g7(1325462,1276306,77952,4096)}if((a[1329558]|0)==0){g7(1329558,1276306,77896,4096)}if((a[1333654]|0)==0){g7(1333654,1276306,77848,4096)}if((a[1309074]|0)==0){g7(1309074,1276306,77800,4096)}if((a[1230628]|0)!=0){return}hb(1230628,1276306,4096);return}function gw(){var b=0,d=0,e=0;if((c[350702]|0)==0){return}do{if((a[1402655]&1)==0){b=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,51)|0;d=1402816;if((c[d>>2]&0|b&1|0)==0&(c[d+4>>2]&524288|0)==0){e=0;break}if((a[628736]&1)!=0){e=1;break}jJ(c[350702]|0);e=1}else{e=0}}while(0);a[628736]=e;return}function gx(){var b=0;yG(1140568,0,102392);b=c[350134]|0;if((b|0)!=0){aS(b|0)|0}yG(1243488,0,158128);a[1243490]=1;a[1243489]=1;c[311906]=0;c[310873]=1;c[310874]=1;c[310875]=1;c[310876]=1;c[310877]=1;c[310878]=1;c[310879]=1;c[310880]=1;return}function gy(b,d){b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0;e=i;i=i+12800|0;f=1;j=0;k=i;i=i+168|0;c[k>>2]=0;while(1)switch(f|0){case 1:l=e|0;m=e+4096|0;n=e+8192|0;o=e+12288|0;q=e+12296|0;r=e+12304|0;a[1243490]=1;a[1243489]=1;c[311906]=0;c[310873]=1;c[310874]=1;c[310875]=1;c[310876]=1;c[310877]=1;c[310878]=1;c[310879]=1;c[310880]=1;u=yH(1401568,f,k)|0;f=131;break;case 131:if((u|0)>0){f=2;break}else{f=3;break};case 2:v=c[350134]|0;as(22,((v|0)!=0?v:c[p>>2]|0)|0,62840,(w=i,i=i+8|0,c[w>>2]=1400543,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;x=u;f=130;break;case 3:a[1400541]=1;a[1401612]=0;a[1401613]=0;a[1264016]=0;a[1264017]=0;if((b|0)<2){f=4;break}else{f=5;break};case 4:a[1401613]=1;f=63;break;case 5:c[3718]=0;c[q>>2]=0;c[r>>2]=103824;c[r+4>>2]=0;c[r+8>>2]=q;c[r+12>>2]=77;c[r+16>>2]=103704;c[r+20>>2]=0;c[r+24>>2]=0;c[r+28>>2]=104;c[r+32>>2]=103312;c[r+36>>2]=1;c[r+40>>2]=0;c[r+44>>2]=115;c[r+48>>2]=103056;c[r+52>>2]=0;c[r+56>>2]=0;c[r+60>>2]=102;c[r+64>>2]=102816;c[r+68>>2]=0;c[r+72>>2]=0;c[r+76>>2]=118;c[r+80>>2]=102600;c[r+84>>2]=1;c[r+88>>2]=0;c[r+92>>2]=103;c[r+96>>2]=102480;c[r+100>>2]=1;c[r+104>>2]=0;c[r+108>>2]=99;c[r+112>>2]=101896;c[r+116>>2]=1;c[r+120>>2]=q;c[r+124>>2]=67;c[r+128>>2]=101256;c[r+132>>2]=1;c[r+136>>2]=0;c[r+140>>2]=109;c[r+144>>2]=101064;c[r+148>>2]=1;c[r+152>>2]=0;c[r+156>>2]=78;c[r+160>>2]=100872;c[r+164>>2]=0;c[r+168>>2]=0;c[r+172>>2]=112;c[r+176>>2]=100768;c[r+180>>2]=0;c[r+184>>2]=0;c[r+188>>2]=106;c[r+192>>2]=100584;c[r+196>>2]=0;c[r+200>>2]=0;c[r+204>>2]=74;c[r+208>>2]=100464;c[r+212>>2]=1;c[r+216>>2]=0;c[r+220>>2]=65;c[r+224>>2]=100304;c[r+228>>2]=1;c[r+232>>2]=0;c[r+236>>2]=83;c[r+240>>2]=100232;c[r+244>>2]=1;c[r+248>>2]=0;c[r+252>>2]=98;c[r+256>>2]=100144;c[r+260>>2]=1;c[r+264>>2]=0;c[r+268>>2]=66;c[r+272>>2]=99584;c[r+276>>2]=0;c[r+280>>2]=0;c[r+284>>2]=52;c[r+288>>2]=99392;c[r+292>>2]=1;c[r+296>>2]=0;c[r+300>>2]=89;c[r+304>>2]=99272;c[r+308>>2]=1;c[r+312>>2]=0;c[r+316>>2]=90;c[r+320>>2]=99176;c[r+324>>2]=1;c[r+328>>2]=0;c[r+332>>2]=80;c[r+336>>2]=99096;c[r+340>>2]=1;c[r+344>>2]=0;c[r+348>>2]=82;c[r+352>>2]=98944;c[r+356>>2]=1;c[r+360>>2]=0;c[r+364>>2]=77;c[r+368>>2]=98880;c[r+372>>2]=1;c[r+376>>2]=0;c[r+380>>2]=85;c[r+384>>2]=98792;c[r+388>>2]=1;c[r+392>>2]=q;c[r+396>>2]=66;c[r+400>>2]=98712;c[r+404>>2]=1;c[r+408>>2]=q;c[r+412>>2]=73;c[r+416>>2]=98616;c[r+420>>2]=0;c[r+424>>2]=q;c[r+428>>2]=110;c[r+432>>2]=97976;c[r+436>>2]=1;c[r+440>>2]=0;c[r+444>>2]=88;c[r+448>>2]=97736;c[r+452>>2]=0;c[r+456>>2]=0;c[r+460>>2]=68;c[r+464>>2]=97536;c[r+468>>2]=0;c[r+472>>2]=q;c[r+476>>2]=102;yG(r+480|0,0,16);f=6;break;case 6:c[q>>2]=0;y=ar(2,b|0,d|0,97352,r|0,0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;switch(y|0){case 68:{f=6;break};case 104:{f=7;break};case 52:{f=8;break};case 106:{f=9;break};case 74:{f=10;break};case 65:{f=11;break};case 115:{f=14;break};case 102:{f=15;break};case 103:{f=16;break};case 98:{f=17;break};case 66:{f=18;break};case 89:{f=19;break};case 90:{f=20;break};case 83:{f=21;break};case 118:{f=22;break};case 109:{f=23;break};case 78:{f=26;break};case 112:{f=29;break};case 99:{f=30;break};case 80:case 82:{f=31;break};case 77:{f=32;break};case 85:{f=40;break};case 88:{f=41;break};case 0:{f=42;break};case 63:{f=49;break};case-1:{f=51;break};default:{f=50;break}}break;case 7:aI(38);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(118,0);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;return 0;case 8:c[310874]=257;f=6;break;case 9:c[310874]=516;f=6;break;case 10:c[310874]=772;f=6;break;case 11:v=as(32,c[159936]|0,0,0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;z=v-1|0;if(z>>>0>7){f=12;break}else{f=13;break};case 12:v=c[350134]|0;aG(4,97200,57,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aI(38);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(16,96976);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;return 0;case 13:c[1243492+(z<<2)>>2]=5;f=6;break;case 14:as(4,1284498,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;a[1264016]=1;f=6;break;case 15:a[1243491]=1;f=6;break;case 16:as(4,1247632,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;c[311906]=1;f=6;break;case 17:as(4,1251728,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;c[311906]=2;f=6;break;case 18:as(4,1251728,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;c[311906]=3;f=6;break;case 19:as(4,1255824,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;c[311906]=4;f=6;break;case 20:as(4,1259920,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;c[311906]=4;f=6;break;case 21:as(4,1304978,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;a[1264017]=1;f=6;break;case 22:a[1243488]=1;f=6;break;case 23:v=as(32,c[159936]|0,0,0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;A=v-1|0;if(A>>>0>7){f=24;break}else{f=25;break};case 24:v=c[350134]|0;aG(4,96832,52,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aI(38);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(16,96976);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;return 0;case 25:c[1243492+(A<<2)>>2]=2;f=6;break;case 26:v=as(32,c[159936]|0,0,0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;B=v-1|0;if(B>>>0>7){f=27;break}else{f=28;break};case 27:v=c[350134]|0;aG(4,96616,58,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aI(38);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(16,96976);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;return 0;case 28:c[1243492+(B<<2)>>2]=0;f=6;break;case 29:c[310874]=260;f=6;break;case 30:as(4,1264018,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=6;break;case 31:as(4,1396137,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;a[1400234]=(y|0)==80|0;a[1400233]=(y|0)==82|0;f=6;break;case 32:C=c[159936]|0;v=aD(18,C|0,96496)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if((v|0)==0){f=33;break}else{f=34;break};case 33:a[1400236]=1;a[1400237]=1;f=6;break;case 34:v=aD(18,C|0,96408)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if((v|0)==0){f=35;break}else{f=36;break};case 35:a[1400236]=1;f=6;break;case 36:v=aD(18,C|0,95712)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if((v|0)==0){f=37;break}else{f=38;break};case 37:a[1400237]=1;f=6;break;case 38:v=aD(18,C|0,95440)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if((v|0)==0){f=6;break}else{f=39;break};case 39:v=c[350134]|0;aG(4,95112,54,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aI(38);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(16,96976);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;return 0;case 40:as(4,1325462,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;a[1325459]=1;f=6;break;case 41:as(4,1309074,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=6;break;case 42:switch(c[q>>2]|0){case 77:{f=43;break};case 67:{f=44;break};case 66:{f=45;break};case 73:{f=46;break};case 110:{f=47;break};case 102:{f=48;break};default:{f=6;break}}break;case 43:a[1401613]=1;f=6;break;case 44:as(4,1268114,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=6;break;case 45:as(4,1329558,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;a[1325460]=1;f=6;break;case 46:as(4,1333654,c[159936]|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;a[1325461]=1;f=6;break;case 47:a[1325458]=1;f=6;break;case 48:an(30,10)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;an(8,94616)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=94408,c[w+8>>2]=94336,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=93768,c[w+8>>2]=93576,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=93424,c[w+8>>2]=93272,c[w+16>>2]=37712,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=93120,c[w+8>>2]=93008,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=92928,c[w+8>>2]=92760,c[w+16>>2]=37712,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=92680,c[w+8>>2]=92608,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=92136,c[w+8>>2]=91808,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=91656,c[w+8>>2]=91528,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=91472,c[w+8>>2]=91528,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=91376,c[w+8>>2]=91528,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=91320,c[w+8>>2]=91528,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=91208,c[w+8>>2]=91528,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=91120,c[w+8>>2]=91528,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=90992,c[w+8>>2]=91528,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=90368,c[w+8>>2]=91528,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=90056,c[w+8>>2]=89904,c[w+16>>2]=37712,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=89800,c[w+8>>2]=91528,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=89648,c[w+8>>2]=89456,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=89368,c[w+8>>2]=89256,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=89176,c[w+8>>2]=89096,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=88552,c[w+8>>2]=88320,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=88136,c[w+8>>2]=88016,c[w+16>>2]=37712,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=87968,c[w+8>>2]=87840,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=87784,c[w+8>>2]=87640,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=87480,c[w+8>>2]=87408,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=86808,c[w+8>>2]=86616,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aD(36,94512,(w=i,i=i+24|0,c[w>>2]=86456,c[w+8>>2]=86344,c[w+16>>2]=37424,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;ak(118,0);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;return 0;case 49:aI(38);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(16,96976);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;return 0;case 50:v=c[350134]|0;aG(4,94952,46,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(16,96976);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;return 0;case 51:D=c[3718]|0;E=(D|0)<(b|0);if((a[1401613]&1)==0){f=54;break}else{f=52;break};case 52:if(E){f=53;break}else{f=57;break};case 53:v=c[350134]|0;aG(4,94808,71,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(16,96976);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;return 0;case 54:if(E){f=55;break}else{f=56;break};case 55:ak(20,c[d+(D<<2)>>2]|0);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=57;break;case 56:a[1401612]=1;f=57;break;case 57:if((a[1264016]&1)==0){f=60;break}else{f=58;break};case 58:v=an(22,1284498)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if(v){f=59;break}else{f=60;break};case 59:as(4,1313170,1284498,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=60;break;case 60:if((a[1264017]&1)==0){f=63;break}else{f=61;break};case 61:v=an(22,1304978)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if(v){f=62;break}else{f=63;break};case 62:as(4,1317266,1304978,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=63;break;case 63:if((a[1243488]&1)==0){f=66;break}else{f=64;break};case 64:v=c[350134]|0;aG(4,62216,49,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[p>>2]|0;aG(4,106072,11,1,v|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;as(22,v|0,105696,(w=i,i=i+16|0,c[w>>2]=104832,c[w+8>>2]=32,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;as(22,v|0,104416,(w=i,i=i+8|0,c[w>>2]=104224,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;if((a[1243488]&1)==0){f=66;break}else{f=65;break};case 65:v=c[350134]|0;aG(4,61552,50,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=66;break;case 66:ak(112,o|0);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aI(88);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(80,(a[1401613]&1)!=0|0);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(c[157578]|0,1337776);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[334444]|0;if((v|0)==0){f=67;break}else{G=v;f=68;break};case 67:c[334444]=66256;G=66256;f=68;break;case 68:v=c[334445]|0;if((v|0)==0){f=69;break}else{H=v;f=70;break};case 69:c[334445]=65368;H=65368;f=70;break;case 70:aG(6,1400300,64,64456,(w=i,i=i+16|0,c[w>>2]=G,c[w+8>>2]=H,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;v=c[334446]|0;as(4,1338368,((v|0)==0?63696:v)|0,4096)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;a[1337852]=a[1337789]&1;aI(412);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=a[1243488]|0;if((v&1)==0){I=v;f=72;break}else{f=71;break};case 71:v=c[350134]|0;J=(v|0)!=0?v:c[p>>2]|0;v=aF(c[157594]|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;as(22,J|0,106976,(w=i,i=i+8|0,c[w>>2]=v,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;I=a[1243488]|0;f=72;break;case 72:if((I&1)==0){f=74;break}else{f=73;break};case 73:v=c[350134]|0;as(22,((v|0)!=0?v:c[p>>2]|0)|0,106768,(w=i,i=i+8|0,c[w>>2]=1,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=74;break;case 74:v=aF(c[157594]|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if((v|0)==1){f=76;break}else{f=75;break};case 75:v=c[350134]|0;aG(4,106328,117,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=76;break;case 76:aI(c[157576]|0);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;K=(a[1401613]&1)==0;L=a[1401612]|0;if(K){f=77;break}else{M=0;f=78;break};case 77:M=L&1^1;f=78;break;case 78:a[1400238]=M;if((L&1)==0){f=81;break}else{f=79;break};case 79:if(K){f=80;break}else{f=121;break};case 80:v=an(86,c[311906]|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if(v){f=121;break}else{f=129;break};case 81:if(K){f=82;break}else{f=121;break};case 82:aI(182);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=an(86,c[311906]|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if(v){f=83;break}else{f=129;break};case 83:N=l|0;O=m|0;R=n|0;if((a[1238849]&1)==0){f=95;break}else{f=84;break};case 84:aH(74,N|0,1304978,4096);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aH(60,O|0,1304978,4096);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;S=as(20,N|0,0,0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if((S|0)==0){f=95;break}else{f=85;break};case 85:T=S+4|0;if((c[T>>2]|0)==0){U=0;f=93;break}else{f=86;break};case 86:V=0;W=0;f=87;break;case 87:X=c[(c[S>>2]|0)+(V<<3)>>2]|0;aH(60,R|0,X|0,4096);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=an(54,O|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;J=as(12,R|0,O|0,v|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if((J|0)==0){f=88;break}else{Y=W;f=92;break};case 88:J=an(54,X|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;Z=X+J|0;f=89;break;case 89:if(Z>>>0>X>>>0){f=90;break}else{f=91;break};case 90:J=Z-1|0;if(((a[J]|0)-48|0)>>>0<10){Z=J;f=89;break}else{f=91;break};case 91:J=as(8,Z|0,0,0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;Y=J>>>0>W>>>0?J:W;f=92;break;case 92:J=V+1|0;if(J>>>0<(c[T>>2]|0)>>>0){V=J;W=Y;f=87;break}else{U=Y;f=93;break};case 93:ak(6,S|0);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;c[334438]=U;if((a[1243488]&1)==0){f=95;break}else{f=94;break};case 94:J=c[350134]|0;as(22,((J|0)!=0?J:c[p>>2]|0)|0,107192,(w=i,i=i+8|0,c[w>>2]=U,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;J=c[350134]|0;an(48,((J|0)!=0?J:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=95;break;case 95:if((a[1400236]&1)==0){f=96;break}else{f=101;break};case 96:switch(c[311906]|0){case 0:{f=97;break};case 1:{f=98;break};case 2:case 3:{f=99;break};case 4:{f=100;break};default:{f=103;break}}break;case 97:al(122,1284498,0);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;al(122,1288594,1);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=103;break;case 98:al(122,1284498,1280);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;al(122,1288594,1537);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=103;break;case 99:al(122,1284498,256);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;al(122,1292690,512);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=103;break;case 100:al(122,1296786,768);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;al(122,1300882,1024);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=103;break;case 101:if((a[1243488]&1)==0){f=103;break}else{f=102;break};case 102:J=c[350134]|0;aG(4,59920,31,1,((J|0)!=0?J:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;J=c[350134]|0;an(48,((J|0)!=0?J:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=103;break;case 103:if((a[1238851]&1)==0){f=109;break}else{f=104;break};case 104:aJ(46,N|0,1304978,52992,4096);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;J=an(92,N|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if(J){f=105;break}else{f=109;break};case 105:if((a[1243488]&1)==0){f=107;break}else{f=106;break};case 106:J=c[350134]|0;as(22,((J|0)!=0?J:c[p>>2]|0)|0,107608,(w=i,i=i+8|0,c[w>>2]=N,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;J=c[350134]|0;an(48,((J|0)!=0?J:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=107;break;case 107:J=an(72,N|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aG(6,O|0,4096,107408,(w=i,i=i+16|0,c[w>>2]=N,c[w+8>>2]=J?52352:52096,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;aJ(34,c[348003]|0,O|0,1,180);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if((a[1243488]&1)==0){f=109;break}else{f=108;break};case 108:J=c[350134]|0;as(22,((J|0)!=0?J:c[p>>2]|0)|0,87496,(w=i,i=i+8|0,c[w>>2]=O,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;J=c[350134]|0;an(48,((J|0)!=0?J:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=109;break;case 109:if((a[1400234]&1)==0){f=115;break}else{f=110;break};case 110:J=aD(28,1396137,0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;c[348009]=J;if((J|0)==0){f=111;break}else{f=112;break};case 111:J=c[350134]|0;as(22,((J|0)!=0?J:c[p>>2]|0)|0,36224,(w=i,i=i+8|0,c[w>>2]=1396137,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;J=c[350134]|0;an(48,((J|0)!=0?J:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(16,109128);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;return 0;case 112:a[1396136]=1;aJ(34,c[348003]|0,108960,2,180);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if((a[1243488]&1)==0){f=114;break}else{f=113;break};case 113:J=c[350134]|0;aG(4,108128,36,1,((J|0)!=0?J:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;J=c[350134]|0;an(48,((J|0)!=0?J:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=114;break;case 114:c[309707]=1;f=121;break;case 115:if((a[1400233]&1)==0){f=121;break}else{f=116;break};case 116:aG(6,N|0,4096,43472,(w=i,i=i+8|0,c[w>>2]=1396137,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;J=aD(28,1396137,1)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;c[348009]=J;ak(102,c[348003]|0);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aJ(34,c[348003]|0,((c[348009]|0)!=0?N:43056)|0,1,180);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if((c[348009]|0)==0){f=120;break}else{f=117;break};case 117:if((a[1243488]&1)==0){f=119;break}else{f=118;break};case 118:J=c[350134]|0;as(22,((J|0)!=0?J:c[p>>2]|0)|0,42744,(w=i,i=i+8|0,c[w>>2]=1396137,w)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;i=w;J=c[350134]|0;an(48,((J|0)!=0?J:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=119;break;case 119:c[309707]=1;f=121;break;case 120:J=c[350134]|0;aG(4,41816,51,1,((J|0)!=0?J:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;J=c[350134]|0;an(48,((J|0)!=0?J:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=121;break;case 121:ak(c[157550]|0,8);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(c[157562]|0,70);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(c[157560]|0,20);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(c[157552]|0,10);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(c[157554]|0,270);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;ak(c[157580]|0,1337792);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;J=aF(26)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=1337768;c[v>>2]=J;c[v+4>>2]=F;_=+aB(2,+(1.0e6/(+h[167227]*+g[309709])));if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=+Q(_)>=1.0?_>0.0?(ag(+P(_/4294967296.0),4294967295.0)|0)>>>0:~~+aa((_- +(~~_>>>0))/4294967296.0)>>>0:0;J=1337760;c[J>>2]=~~_>>>0;c[J+4>>2]=v;aI(280);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aI(408);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aI(220);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;if((a[1400238]&1)==0){f=122;break}else{f=123;break};case 122:a[1400238]=0;f=124;break;case 123:v=a[1400237]&1;a[1400238]=v^1;if(v<<24>>24==0){f=126;break}else{f=124;break};case 124:if((a[1243488]&1)==0){f=126;break}else{f=125;break};case 125:v=c[350134]|0;aG(4,59320,35,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;v=c[350134]|0;an(48,((v|0)!=0?v:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;f=126;break;case 126:if((c[348009]|0)!=0|(a[1222436]|0)==0){f=128;break}else{f=127;break};case 127:v=an(26,1222436)|0;if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;c[350110]=v;f=128;break;case 128:a[1400541]=0;a[1400540]=1;x=0;f=130;break;case 129:aI(164);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aI(c[157548]|0);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aI(c[157588]|0);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;aI(254);if((s|0)!=0&(t|0)!=0){j=yI(c[s>>2]|0,k)|0;if((j|0)>0){f=-1;break}else return 0}s=t=0;a[1400540]=0;x=1;f=130;break;case 130:i=e;return x|0;case-1:if((j|0)==1){u=t;f=131}s=t=0;break}return 0}function gz(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0;b=i;i=i+8|0;d=b|0;if((a[1337840]&1)!=0){e=0;i=b;return e|0}do{if((a[1402655]&1)==0){f=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,30)|0;h=1402816;if((c[h>>2]&1073741824|f&1|0)==0&(c[h+4>>2]&0|0)==0){break}else{e=0}i=b;return e|0}}while(0);if(!(fv[c[(c[350657]|0)+12>>2]&127](c[350660]|0)|0)){e=0;i=b;return e|0}do{if((a[1402655]&1)==0){h=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,55)|0;f=1402816;if((c[f>>2]&0|h&1|0)==0&(c[f+4>>2]&8388608|0)==0){j=354;break}k=a[22800]|0;j=356}else{j=354}}while(0);do{if((j|0)==354){if((a[1401613]&1)==0){l=0;break}f=a[22800]|0;if((f&1)==0){k=f;j=356}else{l=0}}}while(0);do{if((j|0)==356){if((k&1)!=0){l=1;break}f=1400528;h=c[f+4>>2]|0;m=1400528;c[m>>2]=c[f>>2]|4;c[m+4>>2]=h;a[22800]=1;h=1342560;c[h>>2]=0;c[h+4>>2]=0;e=0;i=b;return e|0}}while(0);a[22800]=l;if((a[1392016]&1)!=0){a[1392016]=0;e=0;i=b;return e|0}gA();l=c[348009]|0;if((l|0)!=0){iy(l)}if((c[335636]|0)!=0){l=ks()|0;k=F;do{if((a[1400239]&1)==0){j=(a[1402656]&1)!=0;h=1342560;m=c[h>>2]|0;f=c[h+4>>2]|0;h=(m|0)==0&(f|0)==0|j;n=1342552;o=c[n>>2]|0;p=c[n+4>>2]|0;n=yU(l,k,m,f)|0;f=h?o:n;n=h?p:F;if(j){q=n;r=f;s=0;t=0;break}if((a[1400241]&1)==0){q=n;r=f;s=k;t=l;break}u=(+(f>>>0)+ +(n|0)*4294967296.0)/+g[309708];q=+Q(u)>=1.0?u>0.0?(ag(+P(u/4294967296.0),4294967295.0)|0)>>>0:~~+aa((u- +(~~u>>>0))/4294967296.0)>>>0:0;r=~~u>>>0;s=k;t=l}else{n=1342552;q=c[n+4>>2]|0;r=c[n>>2]|0;s=0;t=0}}while(0);l=1342560;c[l>>2]=t;c[l+4>>2]=s;ft[c[335636]&127](r,q)}fQ[c[157568]&1023]();do{if(+g[309709]>=0.0){q=ks()|0;r=1337768;s=1337760;l=c[s>>2]|0;t=c[s+4>>2]|0;s=yU(c[r>>2]|0,c[r+4>>2]|0,q,F)|0;q=yT(s,F,l,t)|0;t=F;l=0;if((t|0)>(l|0)|(t|0)==(l|0)&q>>>0>999>>>0){l=y_(q,t,1e3,0)|0;t=l;l=d;c[d>>2]=0;c[d+4>>2]=0;c[d>>2]=(t>>>0)/1e3|0;c[l+4>>2]=((t>>>0)%1e3|0)*1e6|0;dn(l|0,0)|0;l=1337760;t=1337768;q=yT(c[t>>2]|0,c[t+4>>2]|0,c[l>>2]|0,c[l+4>>2]|0)|0;l=1337768;c[l>>2]=q;c[l+4>>2]=F;break}else{l=ks()|0;q=1337768;c[q>>2]=l;c[q+4>>2]=F;break}}}while(0);d=c[348009]|0;if((d|0)==0){e=1;i=b;return e|0}iD(d);e=1;i=b;return e|0}function gA(){var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0,A=0.0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0;d=i;i=i+8968|0;e=d|0;f=d+512|0;j=d+4608|0;k=d+8704|0;l=d+8712|0;a[1402655]=0;m=1167408;if((c[291851]|0)==0&((c[m>>2]|0)==65535&(c[m+4>>2]|0)==0)&(c[291856]|0)==-1){n=385}else{m=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,48)|0;o=1402816;q=(c[o>>2]&0|m&1|0)==0&(c[o+4>>2]&65536|0)==0;a[1402655]=q&1;if(q){r=0}else{n=385}}do{if((n|0)==385){q=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,43)|0;o=1402816;if((c[o>>2]&0|q&1|0)==0&(c[o+4>>2]&2048|0)==0){r=0;break}if((a[2578208]&1)!=0){r=1;break}f9();r=1}}while(0);a[2578208]=r;r=a[1243489]|0;if((r&1)==0){s=r}else{do{if((a[1402655]&1)==0){r=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,45)|0;o=1402816;if((c[o>>2]&0|r&1|0)==0&(c[o+4>>2]&8192|0)==0){t=0;break}if((a[2578272]&1)!=0){t=1;break}o=a[1342617]&1;a[1342617]=o^1;r=o<<24>>24==0?36936:36712;ip(c[348003]|0);iq(c[348003]|0,r,1,180);o=c[350659]|0;do{if((o|0)!=0){q=c[350656]|0;if((a[1342617]&1)!=0){m=c[q+8>>2]|0;fv[m&127](o)|0;break}if(fv[c[q+12>>2]&127](o)|0){break}q=c[350134]|0;m=(q|0)!=0?q:c[p>>2]|0;a5(36496,45,1,m|0)|0;m=c[350134]|0;q=(m|0)!=0?m:c[p>>2]|0;a_(q|0)|0;a[1243489]=0}}while(0);if((a[1243488]&1)==0){t=1;break}o=c[350134]|0;q=(o|0)!=0?o:c[p>>2]|0;en(q|0,87496,(u=i,i=i+8|0,c[u>>2]=r,u)|0)|0;i=u;q=c[350134]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;t=1}else{t=0}}while(0);a[2578272]=t;s=a[1243489]|0}t=l|0;do{if((s&1)!=0){l=a[1402655]|0;if((l&1)==0){o=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,49)|0;q=1402816;v=(c[q>>2]&0|o&1|0)!=0|(c[q+4>>2]&131072|0)!=0;w=a[1402655]|0}else{v=0;w=l}if((w&1)==0){l=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,50)|0;q=1402816;x=(c[q>>2]&0|l&1|0)!=0|(c[q+4>>2]&262144|0)!=0}else{x=0}if(!(v|x)){break}y=v?.5:0.0;if(x){z=y+-.5}else{z=y}y=z+ +g[335667];g[335667]=y;do{if(y>12.0){g[335667]=12.0;A=12.0}else{if(y>=-80.0){A=y;break}g[335667]=-80.0;A=-80.0}}while(0);y=A;bR(t|0,256,37144,(u=i,i=i+8|0,h[u>>3]=y,u)|0)|0;i=u;ip(c[348003]|0);iq(c[348003]|0,t,1,180);if((a[1243488]&1)!=0){r=c[350134]|0;q=(r|0)!=0?r:c[p>>2]|0;en(q|0,87496,(u=i,i=i+8|0,c[u>>2]=t,u)|0)|0;i=u;q=c[350134]|0;r=(q|0)!=0?q:c[p>>2]|0;a_(r|0)|0}g[335668]=+S(10.0,+(+g[335667]/20.0))}}while(0);c[350067]=(c[350067]|0)+1;a[1400242]=(fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,22752,0,1,0,16)|0)<<16>>16!=0|0;a[1400243]=(fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,22752,1,1,0,16)|0)<<16>>16!=0|0;a[1400244]=(fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,22752,2,1,0,16)|0)<<16>>16!=0|0;a[1400245]=(fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,22752,3,1,0,16)|0)<<16>>16!=0|0;a[1400246]=(fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,22752,4,1,0,16)|0)<<16>>16!=0|0;a[1400247]=(fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,22752,5,1,0,16)|0)<<16>>16!=0|0;a[1400248]=(fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,22752,6,1,0,16)|0)<<16>>16!=0|0;a[1400249]=(fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,22752,7,1,0,16)|0)<<16>>16!=0|0;do{if((a[1402655]&1)==0){t=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,54)|0;x=1402816;if((c[x>>2]&0|t&1|0)==0&(c[x+4>>2]&4194304|0)==0){B=0;break}x=c[(c[350658]|0)+28>>2]|0;if((x|0)==0){B=0;break}if((a[2578288]&1)!=0){B=1;break}t=a[2578296]&1;v=t^1;a[2578296]=v;if((a[1243488]&1)==0){C=x;D=v}else{v=c[350134]|0;x=(v|0)!=0?v:c[p>>2]|0;v=t<<24>>24==0?37712:37424;en(x|0,38144,(u=i,i=i+8|0,c[u>>2]=v,u)|0)|0;i=u;v=c[350134]|0;x=(v|0)!=0?v:c[p>>2]|0;a_(x|0)|0;C=c[(c[350658]|0)+28>>2]|0;D=a[2578296]|0}ft[C&127](c[350661]|0,(D&1)!=0);x=c[350708]|0;if((x|0)==0){B=1;break}v=c[x+32>>2]|0;if((v|0)==0){B=1;break}ft[v&127](c[350660]|0,(a[2578296]&1)==0);B=1}else{B=0}}while(0);a[2578288]=B;if((c[350702]|0)!=0){do{if((a[1402655]&1)==0){B=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,51)|0;D=1402816;if((c[D>>2]&0|B&1|0)==0&(c[D+4>>2]&524288|0)==0){E=0;break}if((a[628736]&1)!=0){E=1;break}jJ(c[350702]|0);E=1}else{E=0}}while(0);a[628736]=E}if((a[1402655]&1)==0){E=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,35)|0;D=1402816;F=((c[D>>2]&0|E&1|0)!=0|(c[D+4>>2]&8|0)!=0)&1}else{F=0}do{if((a[1400239]&1)==0){if((a[1402655]&1)!=0){G=0;break}D=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,36)|0;E=1402816;G=((c[E>>2]&0|D&1|0)!=0|(c[E+4>>2]&16|0)!=0)&1}else{G=0}}while(0);E=G|F;if((a[1238840]&1)==0){H=1}else{H=fv[c[(c[350657]|0)+16>>2]&127](c[350660]|0)|0}do{if(E<<24>>24==0|H^1){n=450}else{if((a[2578248]&1)!=0){n=450;break}F=a[1400239]&1;a[1400239]=F^1;G=(a[1243488]&1)!=0;if(F<<24>>24==0){if(G){F=c[350134]|0;D=(F|0)!=0?F:c[p>>2]|0;a5(39408,19,1,D|0)|0;D=c[350134]|0;F=(D|0)!=0?D:c[p>>2]|0;a_(F|0)|0}F=c[350659]|0;if((F|0)==0){break}D=c[(c[350656]|0)+8>>2]|0;fv[D&127](F)|0;break}if(G){G=c[350134]|0;F=(G|0)!=0?G:c[p>>2]|0;a5(39120,21,1,F|0)|0;F=c[350134]|0;G=(F|0)!=0?F:c[p>>2]|0;a_(G|0)|0}G=c[350659]|0;if((G|0)==0){break}if((a[1342617]&1)!=0){break}if(fv[c[(c[350656]|0)+12>>2]&127](G)|0){break}G=c[350134]|0;F=(G|0)!=0?G:c[p>>2]|0;a5(38880,81,1,F|0)|0;F=c[350134]|0;G=(F|0)!=0?F:c[p>>2]|0;a_(G|0)|0;a[1243489]=0}}while(0);do{if((n|0)==450){G=(a[22792]&1)==0;if(!H){if(G){break}if((a[1243488]&1)!=0){F=c[350134]|0;D=(F|0)!=0?F:c[p>>2]|0;a5(39408,19,1,D|0)|0;D=c[350134]|0;F=(D|0)!=0?D:c[p>>2]|0;a_(F|0)|0}a[1400239]=1;F=c[350659]|0;if((F|0)==0){break}D=c[(c[350656]|0)+8>>2]|0;fv[D&127](F)|0;break}if(!G){break}if((a[1243488]&1)!=0){G=c[350134]|0;F=(G|0)!=0?G:c[p>>2]|0;a5(39120,21,1,F|0)|0;F=c[350134]|0;G=(F|0)!=0?F:c[p>>2]|0;a_(G|0)|0}a[1400239]=0;G=c[350659]|0;if((G|0)==0){break}if((a[1342617]&1)!=0){break}if(fv[c[(c[350656]|0)+12>>2]&127](G)|0){break}G=c[350134]|0;F=(G|0)!=0?G:c[p>>2]|0;a5(38880,81,1,F|0)|0;F=c[350134]|0;G=(F|0)!=0?F:c[p>>2]|0;a_(G|0)|0;a[1243489]=0}}while(0);a[22792]=H&1;a[2578248]=E;do{if((a[1402655]&1)==0){E=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,36)|0;H=1402816;if((c[H>>2]&0|E&1|0)==0&(c[H+4>>2]&16|0)==0){I=0;J=0;break}I=a[2578256]&1^1;J=1}else{I=0;J=0}}while(0);a[1400240]=I;a[2578256]=J;do{if((a[1402655]&1)==0){J=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,33)|0;I=1402816;if((c[I>>2]&0|J&1|0)==0&(c[I+4>>2]&2|0)==0){K=0;L=0;break}K=a[2578264]&1^1;L=1}else{K=0;L=0}}while(0);a[1400240]=(a[1400240]&1|K|0)!=0|0;a[2578264]=L;do{if((a[1402655]&1)==0){L=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,29)|0;K=1402816;if((c[K>>2]&536870912|L&1|0)==0&(c[K+4>>2]&0|0)==0){M=0;n=474;break}if((a[2578304]&1)!=0){M=1;n=474;break}a[1140640]=a[1140640]&1^1;a[1402649]=a[1342528]&1;a[1402650]=0;hl();hj();a[1402649]=0;K=c[350658]|0;if((K|0)!=0){fs[c[K+4>>2]&255](c[350661]|0)}a[2578304]=1;if((a[1400239]&1)==0){break}ga()}else{M=0;n=474}}while(0);if((n|0)==474){a[2578304]=M}do{if((a[1400239]&1)!=0){if((a[1400240]&1)!=0){break}i=d;return}}while(0);M=a[1402655]|0;if((M&1)==0){K=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,25)|0;L=1402816;N=(c[L>>2]&33554432|K&1|0)!=0|(c[L+4>>2]&0|0)!=0;O=a[1402655]|0}else{N=0;O=M}if((O&1)==0){O=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,26)|0;M=1402816;P=(c[M>>2]&67108864|O&1|0)!=0|(c[M+4>>2]&0|0)!=0}else{P=0}do{if(N){if((a[2578320]&1)!=0){n=486;break}M=a[1402656]&1;a[1402656]=M^1;hg(M<<24>>24==0)}else{n=486}}while(0);do{if((n|0)==486){if((a[2578312]&1|0)==(P&1|0)){break}a[1402656]=P&1;hg(P)}}while(0);a[2578320]=N&1;a[2578312]=P&1;do{if((a[1402655]&1)==0){P=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,31)|0;N=1402816;if((c[N>>2]&-2147483648|P&1|0)==0&(c[N+4>>2]&0|0)==0){Q=0;break}if((a[2578176]&1)!=0){Q=1;break}gn();Q=1}else{Q=0}}while(0);a[2578176]=Q;do{if((a[1402655]&1)==0){Q=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,32)|0;N=1402816;if((c[N>>2]&0|Q&1|0)==0&(c[N+4>>2]&1|0)==0){R=0;break}if((a[2578184]&1)!=0){R=1;break}go();R=1}else{R=0}}while(0);a[2578184]=R;R=(c[348009]|0)==0;do{if((a[1402655]&1)==0){N=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,28)|0;Q=1402816;if((c[Q>>2]&268435456|N&1|0)==0&(c[Q+4>>2]&0|0)==0){T=0;break}if((a[2578216]&1)!=0){T=1;break}gl();T=1}else{T=0}}while(0);a[2578216]=T&1;if(R){do{if((a[1402655]&1)==0){R=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,27)|0;Q=1402816;N=(c[Q>>2]&134217728|R&1|0)!=0|(c[Q+4>>2]&0|0)!=0;if(T|N^1){U=N;break}if((a[2578224]&1)!=0){U=N;break}gk();U=N}else{U=0}}while(0);a[2578224]=U&1}if((a[1392032]&1)!=0){U=c[335658]|0;if(gd((c[335657]|0)+(U<<1)|0,(c[335659]|0)-U|0)|0){V=a[1243489]&1}else{V=0}a[1243489]=V}a[1392032]=0;do{if(a[22784]|0){if((c[348005]|0)==0){break}do{if((a[1402655]&1)==0){V=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,33)|0;U=1402816;if((c[U>>2]&0|V&1|0)==0&(c[U+4>>2]&2|0)==0){n=522;break}ip(c[348003]|0);if(!(il(c[348005]|0,k)|0)){iq(c[348003]|0,39808,0,30);break}a[1392032]=1;U=c[335659]|0;c[335658]=U;L666:do{if((c[335647]|0)!=0){V=0;T=U;while(1){N=b[(c[335656]|0)+((V|1)<<1)>>1]|0;Q=T-1|0;c[335658]=Q;b[(c[335657]|0)+(Q<<1)>>1]=N;N=b[(c[335656]|0)+(V<<1)>>1]|0;Q=(c[335658]|0)-1|0;c[335658]=Q;b[(c[335657]|0)+(Q<<1)>>1]=N;N=V+2|0;if(N>>>0>=(c[335647]|0)>>>0){break L666}V=N;T=c[335658]|0}}}while(0);c[335647]=0;iq(c[348003]|0,40016,0,(a[1400239]&1)!=0?1:30);U=c[157546]|0;T=c[k>>2]|0;V=c[348007]|0;fL[U&63](T,V)|0;V=c[348009]|0;if((V|0)==0){break}iH(V)}else{n=522}}while(0);do{if((n|0)==522){V=c[309707]|0;T=(((c[644558]|0)+1|0)>>>0)%(((V|0)!=0?V:1)>>>0)|0;c[644558]=T;if(!((T|0)==0|(c[348009]|0)!=0)){break}T=c[157566]|0;V=c[348006]|0;U=c[348007]|0;fL[T&63](V,U)|0;U=c[348005]|0;V=c[348006]|0;it(U,V)|0}}while(0);fs[c[157562]&255]((a[1392032]&1)!=0?94:70);fs[c[157560]&255]((a[1392032]&1)!=0?34:20)}else{a[22784]=1}}while(0);do{if((a[1402655]&1)==0){k=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,47)|0;V=1402816;U=(c[V>>2]&0|k&1|0)!=0|(c[V+4>>2]&32768|0)!=0;a[1400241]=U&1;if(!U){break}ip(c[348003]|0);iq(c[348003]|0,(a[1392032]&1)!=0?40584:40272,0,30)}else{a[1400241]=0}}while(0);do{if((a[1402655]&1)==0){U=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,34)|0;V=1402816;if((c[V>>2]&0|U&1|0)==0&(c[V+4>>2]&4|0)==0){W=0;X=0;break}W=(a[2578280]&1)==0;X=1}else{W=0;X=0}}while(0);do{if((a[1396136]&1)==0){if(!W){break}V=f|0;U=j|0;if((c[348009]|0)!=0){ip(c[348003]|0);iq(c[348003]|0,44704,2,180);if((a[1243488]&1)!=0){k=c[350134]|0;T=(k|0)!=0?k:c[p>>2]|0;a5(44424,34,1,T|0)|0;T=c[350134]|0;k=(T|0)!=0?T:c[p>>2]|0;a_(k|0)|0}iu(c[348009]|0);c[348009]=0;break}c[309707]=1;k=c[334438]|0;if((k|0)==0){bR(V|0,4096,43848,(u=i,i=i+8|0,c[u>>2]=1392040,u)|0)|0;i=u}else{bR(V|0,4096,44096,(u=i,i=i+16|0,c[u>>2]=1392040,c[u+8>>2]=k,u)|0)|0;i=u}bR(U|0,4096,43472,(u=i,i=i+8|0,c[u>>2]=V,u)|0)|0;i=u;c[348009]=ix(V,1)|0;ip(c[348003]|0);iq(c[348003]|0,(c[348009]|0)!=0?U:43056,1,180);if((c[348009]|0)==0){U=c[350134]|0;k=(U|0)!=0?U:c[p>>2]|0;a5(41816,51,1,k|0)|0;k=c[350134]|0;U=(k|0)!=0?k:c[p>>2]|0;a_(U|0)|0;break}if((a[1243488]&1)==0){break}U=c[350134]|0;k=(U|0)!=0?U:c[p>>2]|0;en(k|0,42744,(u=i,i=i+8|0,c[u>>2]=V,u)|0)|0;i=u;V=c[350134]|0;k=(V|0)!=0?V:c[p>>2]|0;a_(k|0)|0}else{if(!((a[1400235]&1)!=0|W)){break}iq(c[348003]|0,41288,1,180);if((a[1243488]&1)!=0){k=c[350134]|0;V=(k|0)!=0?k:c[p>>2]|0;a5(40888,33,1,V|0)|0;V=c[350134]|0;k=(V|0)!=0?V:c[p>>2]|0;a_(k|0)|0}iu(c[348009]|0);c[348009]=0;a[1400235]=0;a[1396136]=0}}while(0);a[2578280]=X;X=e|0;L709:do{if((c[350091]|0)!=0){if((c[(c[350657]|0)+20>>2]|0)==0){break}e=a[1402655]|0;if((e&1)==0){W=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,38)|0;j=1402816;Y=(c[j>>2]&0|W&1|0)!=0|(c[j+4>>2]&64|0)!=0;Z=a[1402655]|0}else{Y=0;Z=e}if((Z&1)==0){e=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,39)|0;j=1402816;_=(c[j>>2]&0|e&1|0)!=0|(c[j+4>>2]&128|0)!=0}else{_=0}do{if(Y){if((a[2578200]&1)!=0){n=558;break}j=c[350091]|0;e=(((c[350092]|0)+1|0)>>>0)%((c[j+4>>2]|0)>>>0)|0;c[350092]=e;$=e;aa=j;n=563}else{n=558}}while(0);do{if((n|0)==558){if(!_){break}if((a[2578192]&1)!=0){break}j=c[350092]|0;if((j|0)==0){e=c[350091]|0;W=(c[e+4>>2]|0)-1|0;c[350092]=W;$=W;aa=e;n=563;break}else{e=j-1|0;c[350092]=e;$=e;aa=c[350091]|0;n=563;break}}}while(0);do{if((n|0)==563){e=c[(c[aa>>2]|0)+($<<3)>>2]|0;j=cn(e|0,46)|0;if((j|0)==0){break L709}do{if((cS(j|0,47680)|0)==0){ab=2}else{if((cS(j|0,47368)|0)==0){ab=0;break}if((cS(j|0,47120)|0)==0){ab=0}else{break L709}}}while(0);ip(c[348003]|0);j=c[350092]|0;bR(X|0,512,46152,(u=i,i=i+16|0,c[u>>2]=j,c[u+8>>2]=e,u)|0)|0;i=u;iq(c[348003]|0,X,1,120);if((a[1243488]&1)!=0){j=c[350134]|0;W=(j|0)!=0?j:c[p>>2]|0;en(W|0,45488,(u=i,i=i+8|0,c[u>>2]=e,u)|0)|0;i=u;W=c[350134]|0;j=(W|0)!=0?W:c[p>>2]|0;a_(j|0)|0}if(fA[c[(c[350657]|0)+20>>2]&63](c[350660]|0,ab,e)|0){break}j=c[350134]|0;W=(j|0)!=0?j:c[p>>2]|0;a5(45072,44,1,W|0)|0;W=c[350134]|0;j=(W|0)!=0?W:c[p>>2]|0;a_(j|0)|0}}while(0);a[2578200]=Y&1;a[2578192]=_&1}}while(0);if((c[350110]|0)!=0){_=a[1402655]|0;if((_&1)==0){Y=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,40)|0;ab=1402816;ac=(c[ab>>2]&0|Y&1|0)!=0|(c[ab+4>>2]&256|0)!=0;ad=a[1402655]|0}else{ac=0;ad=_}if((ad&1)==0){_=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,41)|0;ab=1402816;ae=(c[ab>>2]&0|_&1|0)!=0|(c[ab+4>>2]&512|0)!=0;af=a[1402655]|0}else{ae=0;af=ad}if((af&1)==0){af=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,42)|0;ad=1402816;ag=(c[ad>>2]&0|af&1|0)!=0|(c[ad+4>>2]&1024|0)!=0}else{ag=0}do{if(ac){if((a[2578360]&1)!=0){n=582;break}jo(c[350110]|0)}else{n=582}}while(0);L755:do{if((n|0)==582){do{if(ae){if((a[2578352]&1)!=0){break}jp(c[350110]|0);break L755}}while(0);if(!ag){break}if((a[2578344]&1)!=0){break}jm(c[350110]|0)}}while(0);a[2578352]=ae&1;a[2578360]=ac&1;a[2578344]=ag&1}if((c[335622]|0)!=0){ag=a[1402655]|0;if((ag&1)==0){ac=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,52)|0;ae=1402816;ah=(c[ae>>2]&0|ac&1|0)!=0|(c[ae+4>>2]&1048576|0)!=0;ai=a[1402655]|0}else{ah=0;ai=ag}if((ai&1)==0){ai=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,53)|0;ag=1402816;aj=(c[ag>>2]&0|ai&1|0)!=0|(c[ag+4>>2]&2097152|0)!=0}else{aj=0}do{if(ah){if((a[2578336]&1)!=0){n=597;break}gs((fN[c[335619]&63]()|0)^1,1)}else{n=597}}while(0);do{if((n|0)==597){if(!aj){break}if((a[2578328]&1)!=0){break}ag=fN[c[335622]&63]()|0;ai=fN[c[335620]&63]()|0;if((ag|0)==(-1|0)|(ag|0)==0){ae=c[350134]|0;ac=(ae|0)!=0?ae:c[p>>2]|0;a5(48080,59,1,ac|0)|0;ac=c[350134]|0;ae=(ac|0)!=0?ac:c[p>>2]|0;a_(ae|0)|0;break}if(ai>>>0<ag>>>0){ak=((ai+1|0)>>>0)%((ag+1|0)>>>0)|0}else{ak=0}gt(ak)}}while(0);a[2578336]=ah&1;a[2578328]=aj&1}do{if((a[1402655]&1)==0){aj=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,37)|0;ah=1402816;if((c[ah>>2]&0|aj&1|0)==0&(c[ah+4>>2]&32|0)==0){al=0;break}if((a[2578240]&1)!=0){al=1;break}gp();al=1}else{al=0}}while(0);a[2578240]=al;i=d;return}function gB(a,d){a=a|0;d=d|0;var e=0;e=(c[335658]|0)-1|0;c[335658]=e;b[(c[335657]|0)+(e<<1)>>1]=d;d=(c[335658]|0)-1|0;c[335658]=d;b[(c[335657]|0)+(d<<1)>>1]=a;return}function gC(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;b=i;i=i+4096|0;d=b|0;L796:do{if((a[1400238]&1)!=0){switch(c[311906]|0){case 2:case 3:{e=a[1243488]|0;if((e&1)==0){f=e}else{e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;a5(50048,30,1,g|0)|0;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;f=a[1243488]|0}if((f&1)==0){h=f}else{e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;en(g|0,49576,(j=i,i=i+8|0,c[j>>2]=1284498,j)|0)|0;i=j;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;h=a[1243488]|0}if((h&1)!=0){e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;en(g|0,49240,(j=i,i=i+8|0,c[j>>2]=1292690,j)|0)|0;i=j;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0}gP(1284498,256);gP(1292690,512);break L796;break};case 4:{e=a[1243488]|0;if((e&1)==0){k=e}else{e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;a5(48912,40,1,g|0)|0;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;k=a[1243488]|0}if((k&1)==0){l=k}else{e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;en(g|0,48616,(j=i,i=i+8|0,c[j>>2]=1296786,j)|0)|0;i=j;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;l=a[1243488]|0}if((l&1)!=0){e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;en(g|0,48344,(j=i,i=i+8|0,c[j>>2]=1300882,j)|0)|0;i=j;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0}gP(1296786,768);gP(1300882,1024);break L796;break};case 0:{e=a[1243488]|0;if((e&1)==0){m=e}else{e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;a5(51808,32,1,g|0)|0;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;m=a[1243488]|0}if((m&1)==0){n=m}else{e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;en(g|0,51424,(j=i,i=i+8|0,c[j>>2]=1284498,j)|0)|0;i=j;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;n=a[1243488]|0}if((n&1)!=0){e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;en(g|0,51168,(j=i,i=i+8|0,c[j>>2]=1288594,j)|0)|0;i=j;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0}gP(1284498,0);gP(1288594,1);break L796;break};case 1:{e=a[1243488]|0;if((e&1)==0){o=e}else{e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;a5(50936,32,1,g|0)|0;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;o=a[1243488]|0}if((o&1)==0){q=o}else{e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;en(g|0,51424,(j=i,i=i+8|0,c[j>>2]=1284498,j)|0)|0;i=j;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0;q=a[1243488]|0}if((q&1)!=0){e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;en(g|0,51168,(j=i,i=i+8|0,c[j>>2]=1288594,j)|0)|0;i=j;g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a_(e|0)|0}gP(1284498,1280);gP(1288594,1537);break L796;break};default:{break L796}}}}while(0);q=c[348005]|0;if((q|0)!=0){is(q)}c[348005]=0;yz(c[348006]|0);c[348006]=0;q=c[350110]|0;if((q|0)!=0){jl(q)}q=c[348009]|0;if((q|0)!=0){iu(q)}do{if((a[1401613]&1)==0){if((a[1401612]&1)!=0){break}q=d|0;if((a[1238850]&1)==0){break}g7(q,1304978,52992,4096);o=gM(q)|0;if((a[1243488]&1)==0){break}n=c[350134]|0;m=(n|0)!=0?n:c[p>>2]|0;n=o?52352:52096;en(m|0,52648,(j=i,i=i+16|0,c[j>>2]=q,c[j+8>>2]=n,j)|0)|0;i=j;n=c[350134]|0;q=(n|0)!=0?n:c[p>>2]|0;a_(q|0)|0}}while(0);hl();fQ[c[157548]&1023]();fQ[c[157588]&1023]();h9();if((a[1243524]&1)==0){a[1400540]=0;i=b;return}if((a[1243488]&1)!=0){d=c[350134]|0;q=(d|0)!=0?d:c[p>>2]|0;en(q|0,58808,(j=i,i=i+8|0,c[j>>2]=1243525,j)|0)|0;i=j;q=c[350134]|0;d=(q|0)!=0?q:c[p>>2]|0;a_(d|0)|0}if((bB(1243525)|0)<0){d=c[350134]|0;q=(d|0)!=0?d:c[p>>2]|0;en(q|0,58256,(j=i,i=i+8|0,c[j>>2]=1243525,j)|0)|0;i=j;j=c[350134]|0;q=(j|0)!=0?j:c[p>>2]|0;a_(q|0)|0}a[1243524]=0;a[1400540]=0;i=b;return}function gD(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+256|0;e=d|0;f=d+128|0;if((a[1400540]&1)!=0){gC()}g=e;yG(g|0,0,128);h=e|0;c[h>>2]=dy(57760)|0;do{if((a[b+21|0]&1)==0){j=b|0;k=c[j>>2]|0;l=(a[1243488]&1)!=0;if((k|0)==0){if(l){m=c[350134]|0;n=(m|0)!=0?m:c[p>>2]|0;a5(56792,40,1,n|0)|0;n=c[350134]|0;m=(n|0)!=0?n:c[p>>2]|0;a_(m|0)|0}c[e+4>>2]=dy(56336)|0;o=2;break}else{if(l){l=c[350134]|0;m=(l|0)!=0?l:c[p>>2]|0;en(m|0,57192,(m=i,i=i+8|0,c[m>>2]=k,m)|0)|0;i=m;m=c[350134]|0;l=(m|0)!=0?m:c[p>>2]|0;a_(l|0)|0;q=c[j>>2]|0}else{q=k}c[e+4>>2]=dy(q|0)|0;o=2;break}}else{o=1}}while(0);q=b+4|0;if((c[q>>2]|0)==0){r=o}else{c[e+(o<<2)>>2]=dy(55952)|0;c[e+(o+1<<2)>>2]=dy(c[q>>2]|0)|0;r=o+2|0}o=b+8|0;if((c[o>>2]|0)==0){s=r}else{c[e+(r<<2)>>2]=dy(55464)|0;c[e+(r+1<<2)>>2]=dy(c[o>>2]|0)|0;s=r+2|0}r=b+12|0;if((c[r>>2]|0)==0){t=s}else{c[e+(s<<2)>>2]=dy(54232)|0;c[e+(s+1<<2)>>2]=dy(c[r>>2]|0)|0;t=s+2|0}if((a[b+20|0]&1)==0){u=t}else{c[e+(t<<2)>>2]=dy(53600)|0;u=t+1|0}t=f;yJ(t|0,g|0,128)|0;g=gy(u,h)|0;h=0;do{yz(c[f+(h<<2)>>2]|0);h=h+1|0;}while(h>>>0<32);i=d;return g|0}function gE(){var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8|0;d=b|0;do{if((a[1402655]&1)==0){e=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,30)|0;f=1402816;if((c[f>>2]&1073741824|e&1|0)==0&(c[f+4>>2]&0|0)==0){break}else{g=0}i=b;return g|0}}while(0);if(!(fv[c[(c[350657]|0)+12>>2]&127](c[350660]|0)|0)){g=0;i=b;return g|0}gA();ge();f=d;c[d>>2]=0;c[d+4>>2]=0;c[d>>2]=0;c[f+4>>2]=1e7;dn(f|0,0)|0;g=1;i=b;return g|0}function gF(d,e){d=d|0;e=e|0;var f=0,g=0;f=c[335647]|0;c[335647]=f+1;b[(c[335656]|0)+(f<<1)>>1]=d;d=c[335647]|0;c[335647]=d+1;b[(c[335656]|0)+(d<<1)>>1]=e;e=c[335647]|0;if(e>>>0<(c[335648]|0)>>>0){return}if(gd(c[335656]|0,e)|0){g=a[1243489]&1}else{g=0}a[1243489]=g;c[335647]=0;return}function gG(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;i=i+8|0;k=j|0;l=f&255;f=c[348009]|0;do{if((f|0)!=0){if((a[1396136]&1)==0){break}if(!(iv(f,k)|0)){a[1400235]=1;break}m=b[k>>1]|0;i=j;return m|0}}while(0);if(h>>>0<25|(l|0)==3){n=fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,16736,d,l,g,h)|0}else{n=0}k=(l|0)==1;f=(d|0)==0;do{if(k&f){o=1402816;p=c[o>>2]|0;q=c[o+4>>2]|0;o=yV(1,0,h|0)|0;r=F;s=((p&o|0)!=0|(q&r|0)!=0)&1|n}else{if(!((l|0)==5&f)){s=n;break}s=(b[1402824+(((h|0)==1|((g|0)==1?2:0))<<1)>>1]|0)+n&65535}}while(0);do{if(k){if((h-4|0)>>>0<=3){t=s;break}n=s<<16>>16!=0;do{if(n){if((a[1400242+d|0]&1)==0){u=b[1400250+(d<<1)>>1]|0;v=1<<h;break}else{g=1<<h;f=1400250+(d<<1)|0;l=(e[f>>1]|0|g)&65535;b[f>>1]=l;u=l;v=g;break}}else{g=1<<h;l=1400250+(d<<1)|0;f=(e[l>>1]|0)&(g^65535)&65535;b[l>>1]=f;u=f;v=g}}while(0);if((u&65535&v|0)==0){w=n}else{w=(((c[350067]|0)>>>0)%((c[300484]|0)>>>0)|0)>>>0<(c[300485]|0)>>>0&n}t=w&1}else{t=s}}while(0);s=c[348009]|0;if((s|0)==0){m=t;i=j;return m|0}if((a[1396136]&1)!=0){m=t;i=j;return m|0}iw(s,t);m=t;i=j;return m|0}function gH(){var a=0,b=0,d=0;a=i;dl(86208|0)|0;dl(86096|0)|0;b=c[o>>2]|0;a5(106072|0,11,1,b|0)|0;en(b|0,105696|0,(d=i,i=i+16|0,c[d>>2]=104832,c[d+8>>2]=32,d)|0)|0;i=d;en(b|0,104416|0,(d=i,i=i+8|0,c[d>>2]=104224,d)|0)|0;i=d;dl(86208|0)|0;dl(86e3|0)|0;dl(85928|0)|0;dl(85792|0)|0;dl(85528|0)|0;dl(84832|0)|0;dl(84608|0)|0;dl(84472|0)|0;dl(84088|0)|0;dl(83856|0)|0;dl(83632|0)|0;dl(83392|0)|0;dl(83184|0)|0;dl(83040|0)|0;dl(82920|0)|0;dl(82392|0)|0;dl(82120|0)|0;c9(81816|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;c9(81664|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;c9(81568|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;dl(81392|0)|0;dl(81248|0)|0;dl(81112|0)|0;dl(80984|0)|0;dl(80928|0)|0;dl(80424|0)|0;dl(80168|0)|0;dl(80032|0)|0;dl(79872|0)|0;dl(79744|0)|0;dl(79560|0)|0;dl(79440|0)|0;dl(79344|0)|0;dl(79240|0)|0;dl(79176|0)|0;dl(78632|0)|0;i=a;return}function gI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=dc(a|0,75456)|0;if((d|0)==0){e=0;return e|0}a=(a5(b|0,1,c|0,d|0)|0)==(c|0);aS(d|0)|0;e=a;return e|0}function gJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=dc(b|0,100656|0)|0;do{if((e|0)!=0){eC(e|0,0,2)|0;b=ci(e|0)|0;eK(e|0);f=yx(b+1|0)|0;if((f|0)==0){g=c[350134]|0;h=(g|0)!=0?g:c[p>>2]|0;a5(81480|0,47,1,h|0)|0;h=c[350134]|0;g=(h|0)!=0?h:c[p>>2]|0;a_(g|0)|0;aS(e|0)|0;break}g=eh(f|0,1,b|0,e|0)|0;if((g|0)<(b|0)){h=c[350134]|0;i=(h|0)!=0?h:c[p>>2]|0;a5(68496|0,44,1,i|0)|0;i=c[350134]|0;h=(i|0)!=0?i:c[p>>2]|0;a_(h|0)|0}c[d>>2]=f;a[f+b|0]=0;aS(e|0)|0;j=g;return j|0}}while(0);c[d>>2]=0;j=-1;return j|0}function gK(b){b=b|0;var d=0,e=0;if((a[1400541]&1)==0){d=c[350134]|0;e=(d|0)!=0?d:c[p>>2]|0;en(e|0,55960,(e=i,i=i+16|0,c[e>>2]=107840,c[e+8>>2]=832,e)|0)|0;i=e;e=c[350134]|0;d=(e|0)!=0?e:c[p>>2]|0;a_(d|0)|0;ck(2)}else{i5(1400543,b,1024)|0;eQ(1401568,1)}}function gL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;c[d>>2]=0;e=dc(b|0,59416)|0;do{if((e|0)!=0){eC(e|0,0,2)|0;b=(ci(e|0)|0)+2|0;eK(e|0);f=yy(b,1)|0;c[d>>2]=f;if((f|0)==0){aS(e|0)|0;break}else{g=f}while(1){if((et(e|0)|0)!=0){h=g;break}b1(g|0,b-g+(c[d>>2]|0)|0,e|0)|0;f=g+(yF(g|0)|0)|0;if((f|0)==0){h=0;break}else{g=f}}b=b7(h|0,-1|0)|0;if((b|0)!=0){a[b]=0}aS(e|0)|0;i=1;return i|0}}while(0);e=c[d>>2]|0;if((e|0)==0){i=0;return i|0}yz(e);i=0;return i|0}function gM(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((a[1243488]&1)!=0){e=c[350134]|0;f=(e|0)!=0?e:c[p>>2]|0;en(f|0,53656,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0}e=fN[c[157564]&63]()|0;if((e|0)==0){h=0;i=d;return h|0}f=yx(e)|0;if((f|0)==0){j=c[350134]|0;k=(j|0)!=0?j:c[p>>2]|0;a5(49640,70,1,k|0)|0;k=c[350134]|0;j=(k|0)!=0?k:c[p>>2]|0;a_(j|0)|0;h=0;i=d;return h|0}if((a[1243488]&1)!=0){j=c[350134]|0;k=(j|0)!=0?j:c[p>>2]|0;en(k|0,45568,(g=i,i=i+8|0,c[g>>2]=e,g)|0)|0;i=g;k=c[350134]|0;j=(k|0)!=0?k:c[p>>2]|0;a_(j|0)|0}do{if(fL[c[157566]&63](f,e)|0){j=dc(b|0,75456)|0;if((j|0)==0){l=772;break}k=(a5(f|0,1,e|0,j|0)|0)==(e|0);aS(j|0)|0;if(k){m=1}else{l=772}}else{l=772}}while(0);if((l|0)==772){l=c[350134]|0;e=(l|0)!=0?l:c[p>>2]|0;en(e|0,41368,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;g=c[350134]|0;b=(g|0)!=0?g:c[p>>2]|0;a_(b|0)|0;m=0}yz(f);h=m;i=d;return h|0}function gN(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=f;if((a[1243488]&1)!=0){h=c[350134]|0;j=(h|0)!=0?h:c[p>>2]|0;en(j|0,37768,(k=i,i=i+8|0,c[k>>2]=b,k)|0)|0;i=k;j=c[350134]|0;h=(j|0)!=0?j:c[p>>2]|0;a_(h|0)|0}c[e>>2]=0;h=gJ(b,e)|0;if((h|0)<0){j=c[350134]|0;l=(j|0)!=0?j:c[p>>2]|0;en(l|0,107896,(k=i,i=i+8|0,c[k>>2]=b,k)|0)|0;i=k;b=c[350134]|0;l=(b|0)!=0?b:c[p>>2]|0;a_(l|0)|0;m=0;i=d;return m|0}if((a[1243488]&1)!=0){l=c[350134]|0;b=(l|0)!=0?l:c[p>>2]|0;en(b|0,104560,(k=i,i=i+8|0,c[k>>2]=h,k)|0)|0;i=k;k=c[350134]|0;b=(k|0)!=0?k:c[p>>2]|0;a_(b|0)|0}c[f>>2]=0;c[f+4>>2]=0;L1023:do{if((a[1238848]&1)==0){n=795}else{if((a[1243488]&1)!=0){b=c[350134]|0;k=(b|0)!=0?b:c[p>>2]|0;a5(101552,36,1,k|0)|0;k=c[350134]|0;b=(k|0)!=0?k:c[p>>2]|0;a_(b|0)|0}switch(c[311906]|0){case 2:case 3:{o=256;q=512;break};case 4:{o=768;q=1024;break};case 1:{o=1280;q=1537;break};case 0:{o=0;q=1;break};default:{n=795;break L1023}}b=fv[c[157584]&127](o)|0;k=fv[c[157584]&127](q)|0;if((b|0)==0){r=0;s=0}else{l=yx(b)|0;c[f>>2]=l;r=l;s=b}if((k|0)==0){t=0;u=0}else{b=yx(k)|0;c[g+4>>2]=b;t=b;u=k}do{if((r|0)!=0){k=fv[c[157586]&127](o)|0;if((k|0)==0){break}yJ(r|0,k|0,s)|0}}while(0);k=g+4|0;if((t|0)==0){v=t;w=u;x=o;y=q;z=s;A=r;B=k;break}b=fv[c[157586]&127](q)|0;if((b|0)==0){v=t;w=u;x=o;y=q;z=s;A=r;B=k;break}yJ(t|0,b|0,u)|0;v=t;w=u;x=o;y=q;z=s;A=r;B=k}}while(0);if((n|0)==795){v=0;w=0;x=-1;y=-1;z=0;A=0;B=g+4|0}g=fL[c[157546]&63](c[e>>2]|0,h)|0;do{if(g){do{if((A|0)!=0){h=fv[c[157586]&127](x)|0;if((h|0)==0){break}yJ(h|0,A|0,z)|0}}while(0);if((v|0)==0){break}h=fv[c[157586]&127](y)|0;if((h|0)==0){break}yJ(h|0,v|0,w)|0}}while(0);if((A|0)==0){C=v}else{yz(A);C=c[B>>2]|0}if((C|0)!=0){yz(C)}yz(c[e>>2]|0);m=g;i=d;return m|0}function gO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=fv[c[157584]&127](b)|0;g=fv[c[157586]&127](b)|0;if((f|0)==0|(g|0)==0){i=d;return}c[e>>2]=0;b=gJ(a,e)|0;a=c[e>>2]|0;if(!((b|0)<1|(b|0)>(f|0))){yJ(g|0,a|0,b)|0}yz(a);i=d;return}function gP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=i;i=i+8200|0;f=e|0;g=e+4096|0;h=e+8192|0;j=fv[c[157584]&127](d)|0;k=fv[c[157586]&127](d)|0;if((k|0)==0|(j|0)==0){i=e;return}l=dc(b|0,75456)|0;do{if((l|0)!=0){m=(a5(k|0,1,j|0,l|0)|0)==(j|0);aS(l|0)|0;if(!m){break}if((a[1243488]&1)==0){i=e;return}m=c[350134]|0;n=(m|0)!=0?m:c[p>>2]|0;en(n|0,95464,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;n=c[350134]|0;m=(n|0)!=0?n:c[p>>2]|0;a_(m|0)|0;i=e;return}}while(0);b=c[350134]|0;a5(99408,42,1,((b|0)!=0?b:c[p>>2]|0)|0)|0;b=c[350134]|0;a_(((b|0)!=0?b:c[p>>2]|0)|0)|0;b=c[350134]|0;a5(97760,46,1,((b|0)!=0?b:c[p>>2]|0)|0)|0;b=c[350134]|0;a_(((b|0)!=0?b:c[p>>2]|0)|0)|0;b=f|0;f=g|0;g=dM(64048)|0;do{if((g|0)!=0){bR(b|0,4096,63112,(o=i,i=i+8|0,c[o>>2]=g,o)|0)|0;i=o;eU(h|0)|0;l=bg(h|0)|0;c_(f|0,4096,62560,l|0)|0;i7(b,f,4096)|0;switch(d|0){case 1:case 1537:{q=59032;break};case 512:{q=58528;break};case 768:{q=57960;break};case 1024:{q=57432;break};case 0:case 1280:case 256:{q=59568;break};default:{q=2659248}}i7(b,q,4096)|0;l=dc(b|0,75456)|0;if((l|0)==0){break}m=(a5(k|0,1,j|0,l|0)|0)==(j|0);aS(l|0)|0;if(!m){break}m=c[350134]|0;l=(m|0)!=0?m:c[p>>2]|0;en(l|0,61760,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;l=c[350134]|0;m=(l|0)!=0?l:c[p>>2]|0;a_(m|0)|0;i=e;return}}while(0);o=c[350134]|0;a5(60736,57,1,((o|0)!=0?o:c[p>>2]|0)|0)|0;o=c[350134]|0;a_(((o|0)!=0?o:c[p>>2]|0)|0)|0;i=e;return}function gQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+32|0;e=d|0;f=d+16|0;g=d+24|0;do{if((a[1280402]|0)!=0){if((a[1337852]&1)!=0){break}h=gU(1280402)|0;if((h|0)==0){break}if((yM(h|0,93600)|0)!=0){break}a[1243524]=1;if(md(1280402,4096,1338368)|0){i5(1243525,1280402,4096)|0;break}h=c[350134]|0;j=(h|0)!=0?h:c[p>>2]|0;en(j|0,91824,(j=i,i=i+8|0,c[j>>2]=1280402,j)|0)|0;i=j;j=c[350134]|0;h=(j|0)!=0?j:c[p>>2]|0;a_(h|0)|0;a[1243524]=0;k=0;i=d;return k|0}}while(0);L1109:do{switch(b|0){case 1:{h=g|0;c[h>>2]=(a[1280402]|0)!=0?1280402:0;c[g+4>>2]=1247632;if(gR(260,h,2)|0){break L1109}else{k=0}i=d;return k|0};case 0:{if((a[1401612]&1)==0){c[f>>2]=1280402;if(gR(0,f,1)|0){break L1109}else{k=0}i=d;return k|0}if((a[1337854]&1)==0){h=c[350134]|0;j=(h|0)!=0?h:c[p>>2]|0;a5(64752,78,1,j|0)|0;j=c[350134]|0;h=(j|0)!=0?j:c[p>>2]|0;a_(h|0)|0;k=0;i=d;return k|0}else{if(fv[c[157574]&127](0)|0){break L1109}else{k=0}i=d;return k|0}break};case 2:{h=g|0;c[h>>2]=(a[1280402]|0)!=0?1280402:0;c[g+4>>2]=1251728;if(gR(257,h,2)|0){break L1109}else{k=0}i=d;return k|0};case 3:{h=g|0;c[h>>2]=(a[1280402]|0)!=0?1280402:0;c[g+4>>2]=1251728;if(gR(258,h,2)|0){break L1109}else{k=0}i=d;return k|0};case 4:{h=e|0;c[h>>2]=(a[1280402]|0)!=0?1280402:0;c[e+4>>2]=(a[1255824]|0)!=0?1255824:0;c[e+8>>2]=(a[1259920]|0)!=0?1259920:0;if(gR(259,h,3)|0){break L1109}else{k=0}i=d;return k|0};default:{h=c[350134]|0;a5(90184,39,1,((h|0)!=0?h:c[p>>2]|0)|0)|0;h=c[350134]|0;a_(((h|0)!=0?h:c[p>>2]|0)|0)|0;k=0;i=d;return k|0}}}while(0);k=1;i=d;return k|0}function gR(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=i;i=i+128|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+48|0;n=f+64|0;if((e|0)==0|e>>>0>4){o=0;i=f;return o|0}yG(l|0,0,16);yG(m|0,0,16);yG(n|0,0,64);c[k>>2]=0;do{if((a[1309074]|0)!=0){if(!(gL(1309074,k)|0)){break}if((a[1243488]&1)==0){break}q=c[350134]|0;r=(q|0)!=0?q:c[p>>2]|0;en(r|0,65728,(s=i,i=i+8|0,c[s>>2]=1309074,s)|0)|0;i=s;r=c[350134]|0;q=(r|0)!=0?r:c[p>>2]|0;a_(q|0)|0}}while(0);q=c[k>>2]|0;k=(a[1243488]&1)!=0;do{if((a[1337788]&1)==0){if(k){r=c[350134]|0;t=(r|0)!=0?r:c[p>>2]|0;r=c[d>>2]|0;en(t|0,88344,(s=i,i=i+8|0,c[s>>2]=r,s)|0)|0;i=s;r=c[350134]|0;t=(r|0)!=0?r:c[p>>2]|0;a_(t|0)|0}t=c[d>>2]|0;r=l|0;c[j>>2]=0;u=gJ(t,j)|0;if((u|0)<1){v=u;w=0}else{L1148:do{if((a[1325458]&1)==0){t=c[j>>2]|0;c[g>>2]=0;x=a[1325459]|0;y=a[1325460]|0;z=a[1325461]|0;if(((y&1)+(x&1)+(z&1)|0)>1){A=c[350134]|0;B=(A|0)!=0?A:c[p>>2]|0;a5(75808,77,1,B|0)|0;B=c[350134]|0;A=(B|0)!=0?B:c[p>>2]|0;a_(A|0)|0;C=u;D=t;break}A=(z|x)&1;B=((y|x)&1)!=0;if(((z|y)&1)!=0|(a[1325462]|0)==0){E=891}else{y=gJ(1325462,g)|0;if((y|0)>-1){F=74720;G=1325462;H=4;I=y}else{E=891}}do{if((E|0)==891){if(!(A<<24>>24!=0|(a[1329558]|0)==0)){y=gJ(1329558,g)|0;if((y|0)>-1){F=73752;G=1329558;H=6;I=y;break}}if(!(B|(a[1333654]|0)==0)){y=gJ(1333654,g)|0;if((y|0)>-1){F=72752;G=1333654;H=8;I=y;break}}if((a[1243488]&1)==0){C=u;D=t;break L1148}y=c[350134]|0;z=(y|0)!=0?y:c[p>>2]|0;a5(71768,43,1,z|0)|0;z=c[350134]|0;y=(z|0)!=0?z:c[p>>2]|0;a_(y|0)|0;C=u;D=t;break L1148}}while(0);if((a[1243488]&1)!=0){B=c[350134]|0;A=(B|0)!=0?B:c[p>>2]|0;en(A|0,70456,(s=i,i=i+16|0,c[s>>2]=F,c[s+8>>2]=G,s)|0)|0;i=s;A=c[350134]|0;B=(A|0)!=0?A:c[p>>2]|0;a_(B|0)|0}B=u<<2;c[h>>2]=B;A=yx(B)|0;if((A|0)==0){B=c[350134]|0;y=(B|0)!=0?B:c[p>>2]|0;a5(68872,67,1,y|0)|0;y=c[350134]|0;B=(y|0)!=0?y:c[p>>2]|0;a_(B|0)|0;c[j>>2]=t;yz(c[g>>2]|0);C=u;D=t;break}B=c[g>>2]|0;y=fu[H&15](B,I,t,u,A,h)|0;if((y|0)==1){if((a[1243488]&1)!=0){z=c[350134]|0;x=(z|0)!=0?z:c[p>>2]|0;en(x|0,67696,(s=i,i=i+8|0,c[s>>2]=F,s)|0)|0;i=s;x=c[350134]|0;z=(x|0)!=0?x:c[p>>2]|0;a_(z|0)|0}yz(t);c[j>>2]=A;J=c[h>>2]|0;K=A}else{A=c[350134]|0;z=(A|0)!=0?A:c[p>>2]|0;en(z|0,66720,(s=i,i=i+16|0,c[s>>2]=F,c[s+8>>2]=y,s)|0)|0;i=s;y=c[350134]|0;z=(y|0)!=0?y:c[p>>2]|0;a_(z|0)|0;J=u;K=t}yz(B);C=J;D=K}else{C=u;D=c[j>>2]|0}}while(0);c[311907]=me(0,D,C)|0;hS(1400372,D,C);if((a[1243488]&1)!=0){u=c[350134]|0;B=(u|0)!=0?u:c[p>>2]|0;u=c[311907]|0;en(B|0,77288,(s=i,i=i+16|0,c[s>>2]=u,c[s+8>>2]=1400372,s)|0)|0;i=s;u=c[350134]|0;B=(u|0)!=0?u:c[p>>2]|0;a_(B|0)|0}c[r>>2]=D;v=C;w=D}c[m>>2]=v;if((v|0)==-1){B=c[350134]|0;u=(B|0)!=0?B:c[p>>2]|0;a5(86640,46,1,u|0)|0;u=c[350134]|0;B=(u|0)!=0?u:c[p>>2]|0;a_(B|0)|0;L=0;break}if((a[1243488]&1)==0){M=w;N=v;E=916;break}B=c[350134]|0;u=(B|0)!=0?B:c[p>>2]|0;en(u|0,84648,(s=i,i=i+8|0,c[s>>2]=v,s)|0)|0;i=s;u=c[350134]|0;B=(u|0)!=0?u:c[p>>2]|0;a_(B|0)|0;M=w;N=v;E=916}else{if(!k){M=0;N=0;E=916;break}B=c[350134]|0;u=(B|0)!=0?B:c[p>>2]|0;a5(82168,72,1,u|0)|0;u=c[350134]|0;B=(u|0)!=0?u:c[p>>2]|0;a_(B|0)|0;M=0;N=0;E=916}}while(0);L1190:do{if((E|0)==916){k=n|0;c[n>>2]=c[d>>2];c[n+4>>2]=M;c[n+8>>2]=N;c[n+12>>2]=q;L1192:do{if(e>>>0>1){v=1;L1193:while(1){O=d+(v<<2)|0;w=c[O>>2]|0;do{if((w|0)==0){P=0}else{if((a[1337788]&1)!=0){P=w;break}D=gJ(w,l+(v<<2)|0)|0;c[m+(v<<2)>>2]=D;if((D|0)==-1){break L1193}P=c[O>>2]|0}}while(0);c[n+(v<<4)>>2]=P;c[n+(v<<4)+4>>2]=c[l+(v<<2)>>2];c[n+(v<<4)+8>>2]=c[m+(v<<2)>>2];v=v+1|0;if(v>>>0>=e>>>0){break L1192}}v=c[350134]|0;en(((v|0)!=0?v:c[p>>2]|0)|0,80256,(s=i,i=i+8|0,c[s>>2]=c[O>>2],s)|0)|0;i=s;v=c[350134]|0;a_(((v|0)!=0?v:c[p>>2]|0)|0)|0;L=0;break L1190}}while(0);if((b|0)==0){if(fv[c[157574]&127](k)|0){L=1;break}}else{if(fA[c[157572]&63](b,k,e)|0){L=1;break}}r=c[350134]|0;v=(r|0)!=0?r:c[p>>2]|0;a5(78456,42,1,v|0)|0;v=c[350134]|0;r=(v|0)!=0?v:c[p>>2]|0;a_(r|0)|0;L=0}}while(0);yz(c[l>>2]|0);yz(c[l+4>>2]|0);yz(c[l+8>>2]|0);yz(c[l+12>>2]|0);yz(q);o=L;i=f;return o|0}function gS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)==0){return}b=a+4|0;d=a|0;e=c[d>>2]|0;if((c[b>>2]|0)==0){f=e}else{g=0;h=e;while(1){yz(c[h+(g<<3)>>2]|0);e=g+1|0;i=c[d>>2]|0;if(e>>>0<(c[b>>2]|0)>>>0){g=e;h=i}else{f=i;break}}}yz(f);yz(a);return}function gT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==0){d=0;return d|0}e=a|0;f=c[a+4>>2]|0;a=0;while(1){if(a>>>0>=f>>>0){d=0;g=945;break}if((yM(c[(c[e>>2]|0)+(a<<3)>>2]|0,b|0)|0)==0){d=1;g=944;break}else{a=a+1|0}}if((g|0)==944){return d|0}else if((g|0)==945){return d|0}return 0}function gU(a){a=a|0;var b=0;b=cn(a|0,46)|0;return((b|0)==0?2659344:b+1|0)|0}function gV(a,b){a=a|0;b=b|0;if((a|0)==0){return}dq(c[a>>2]|0,c[a+4>>2]|0,8,(b?38:40)|0);return}function gW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=a[b+4|0]&1;f=a[d+4|0]&1;if(e<<24>>24==f<<24>>24){g=yM(c[b>>2]|0,c[d>>2]|0)|0;return g|0}else{g=(f&255)-(e&255)|0;return g|0}return 0}function gX(a,b){a=a|0;b=b|0;return yM(c[a>>2]|0,c[b>>2]|0)|0}function gY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;i=i+8|0;e=d|0;f=yy(1,12)|0;g=f;do{if((f|0)==0){h=0}else{j=f+4|0;k=c[j>>2]|0;if(k>>>0>=32){l=c[350134]|0;m=(l|0)!=0?l:c[p>>2]|0;en(m|0,45288,(n=i,i=i+16|0,c[n>>2]=41144,c[n+8>>2]=69,n)|0)|0;i=n;m=c[350134]|0;l=(m|0)!=0?m:c[p>>2]|0;a_(l|0)|0;ck(2);return 0}l=f;m=c[l>>2]|0;o=m;q=yA(o,256)|0;if((q|0)==0){if((k|0)!=0){r=0;do{yz(c[m+(r<<3)>>2]|0);r=r+1|0;}while(r>>>0<k>>>0)}yz(o);yz(f);h=0;break}r=q;c[l>>2]=r;m=f+8|0;c[m>>2]=32;s=dy(a|0)|0;L1253:do{if((s|0)==0){t=0;u=k;v=r}else{w=ej(s|0,b|0,e|0)|0;L1255:do{if((w|0)!=0){x=w;y=r;z=k;A=32;while(1){if(z>>>0<A>>>0){B=y;C=A}else{D=A<<1;if(z>>>0>=D>>>0){break}E=yA(y,A<<4)|0;if((E|0)==0){t=s;u=z;v=y;break L1253}F=E;c[l>>2]=F;c[m>>2]=D;B=F;C=D}D=dy(x|0)|0;if((D|0)==0){t=s;u=z;v=B;break L1253}c[B+(z<<3)>>2]=D;D=c[j>>2]|0;F=c[l>>2]|0;c[F+(D<<3)+4>>2]=0;E=D+1|0;c[j>>2]=E;D=ej(0,b|0,e|0)|0;if((D|0)==0){break L1255}else{x=D;y=F;z=E;A=C}}A=c[350134]|0;en(((A|0)!=0?A:c[p>>2]|0)|0,45288,(n=i,i=i+16|0,c[n>>2]=41144,c[n+8>>2]=69,n)|0)|0;i=n;A=c[350134]|0;a_(((A|0)!=0?A:c[p>>2]|0)|0)|0;ck(2);return 0}}while(0);yz(s);G=g;i=d;return G|0}}while(0);if((u|0)!=0){s=0;do{yz(c[v+(s<<3)>>2]|0);s=s+1|0;}while(s>>>0<u>>>0)}yz(v);yz(f);h=t}}while(0);yz(h);G=0;i=d;return G|0}function gZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)==0){return}b=a+4|0;d=a|0;e=c[d>>2]|0;if((c[b>>2]|0)==0){f=e}else{g=0;h=e;while(1){yz(c[h+(g<<3)>>2]|0);e=g+1|0;i=c[d>>2]|0;if(e>>>0<(c[b>>2]|0)>>>0){g=e;h=i}else{f=i;break}}}yz(f);yz(a);return}function g_(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+72|0;d=b|0;if((eP(a|0,d|0)|0)<0){e=0;i=b;return e|0}e=(c[d+8>>2]&61440|0)==16384;i=b;return e|0}function g$(a){a=a|0;var b=0,c=0;b=dc(a|0,49464|0)|0;if((b|0)==0){c=0;return c|0}aS(b|0)|0;c=1;return c|0}function g0(a){a=a|0;var b=0;b=cn(a|0,47)|0;return((b|0)==0?a:b+1|0)|0}function g1(b){b=b|0;var d=0,e=0;d=i;if((yF(b|0)|0)>>>0<2){i=d;return}e=cn(b|0,47)|0;if((e|0)==0){bR(b|0,3,107776|0,(b=i,i=i+8|0,c[b>>2]=93552,b)|0)|0;i=b;i=d;return}else{a[e+1|0]=0;i=d;return}}function g2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;i=i+8|0;e=d|0;eU(e|0)|0;c_(a|0,c|0,37600,bg(e|0)|0)|0;i7(a,b,c)|0;i=d;return}function g3(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+4096|0;if((d|0)==0){i=e;return}a[b]=0;f=b3()|0;g=e|0;h=d-1|0;d=0;while(1){if(d>>>0>=3){j=1015;break}k=c[19488+(d<<2)>>2]|0;bR(g|0,4096,97696,(l=i,i=i+16|0,c[l>>2]=f,c[l+8>>2]=k,l)|0)|0;i=l;m=eY(g|0,b|0,h|0)|0;if((m|0)>-1){j=1014;break}else{d=d+1|0}}if((j|0)==1014){a[b+m|0]=0;i=e;return}else if((j|0)==1015){j=c[350134]|0;a5(95336,78,1,((j|0)!=0?j:c[p>>2]|0)|0)|0;j=c[350134]|0;a_(((j|0)!=0?j:c[p>>2]|0)|0)|0;i=e;return}}function g4(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=i;i=i+8264|0;g=f|0;h=f+4096|0;j=f+4168|0;k=yy(1,12)|0;l=k;if((k|0)==0){m=0;i=f;return m|0}n=k+4|0;o=c[n>>2]|0;if(o>>>0>=32){q=c[350134]|0;r=(q|0)!=0?q:c[p>>2]|0;en(r|0,45288,(s=i,i=i+16|0,c[s>>2]=41144,c[s+8>>2]=69,s)|0)|0;i=s;r=c[350134]|0;q=(r|0)!=0?r:c[p>>2]|0;a_(q|0)|0;ck(2);return 0}q=k;r=c[q>>2]|0;t=r;u=yA(t,256)|0;if((u|0)==0){if((o|0)!=0){v=0;do{yz(c[r+(v<<3)>>2]|0);v=v+1|0;}while(v>>>0<o>>>0)}yz(t);yz(k);m=0;i=f;return m|0}t=u;c[q>>2]=t;u=k+8|0;c[u>>2]=32;if((d|0)==0){w=0}else{w=gY(d,80344)|0}d=bF(b|0)|0;L1334:do{if((d|0)==0){v=c[350134]|0;r=(v|0)!=0?v:c[p>>2]|0;en(r|0,53224,(s=i,i=i+8|0,c[s>>2]=b,s)|0)|0;i=s;r=c[350134]|0;v=(r|0)!=0?r:c[p>>2]|0;a_(v|0)|0;x=o;y=t}else{v=bX(d|0)|0;L1336:do{if((v|0)!=0){r=j|0;z=(w|0)==0;A=g|0;B=w|0;C=w+4|0;D=h+8|0;E=v;F=t;G=o;H=32;L1338:while(1){I=E+4|0;J=cn(I|0,46)|0;K=(J|0)==0?2659344:J+1|0;g5(r,b,I,4096);J=a[E+1036|0]|0;do{if((J<<24>>24|0)==0|(J<<24>>24|0)==10){if((eP(r|0,h|0)|0)<0){L=0;M=1036;break}N=(c[D>>2]&61440|0)==16384;M=1035}else if((J<<24>>24|0)==4){N=1;M=1035}else{L=0;M=1036}}while(0);if((M|0)==1035){M=0;if(e|N^1){L=N;M=1036}else{O=F;P=G;Q=H}}L1345:do{if((M|0)==1036){M=0;if((cS(I|0,67752)|0)==0){O=F;P=G;Q=H;break}if((cS(I|0,59056)|0)==0){O=F;P=G;Q=H;break}L1349:do{if(!(L|z)){bR(A|0,4096,68864,(s=i,i=i+16|0,c[s>>2]=67752,c[s+8>>2]=K,s)|0)|0;i=s;J=c[C>>2]|0;R=0;while(1){if(R>>>0>=J>>>0){O=F;P=G;Q=H;break L1345}S=c[(c[B>>2]|0)+(R<<3)>>2]|0;if((yM(S|0,K|0)|0)==0){break L1349}if((yM(S|0,A|0)|0)==0){break}else{R=R+1|0}}}}while(0);R=L&1;if(G>>>0<H>>>0){T=F;U=H}else{J=H<<1;if(G>>>0>=J>>>0){M=1046;break L1338}S=yA(F,H<<4)|0;if((S|0)==0){V=F;M=1055;break L1338}W=S;c[q>>2]=W;c[u>>2]=J;T=W;U=J}J=dy(r|0)|0;if((J|0)==0){V=T;M=1055;break L1338}c[T+(G<<3)>>2]=J;J=c[n>>2]|0;W=c[q>>2]|0;c[W+(J<<3)+4>>2]=R;R=J+1|0;c[n>>2]=R;O=W;P=R;Q=U}}while(0);K=bX(d|0)|0;if((K|0)==0){break L1336}else{E=K;F=O;G=P;H=Q}}if((M|0)==1046){H=c[350134]|0;F=(H|0)!=0?H:c[p>>2]|0;en(F|0,45288,(s=i,i=i+16|0,c[s>>2]=41144,c[s+8>>2]=69,s)|0)|0;i=s;F=c[350134]|0;H=(F|0)!=0?F:c[p>>2]|0;a_(H|0)|0;ck(2);return 0}else if((M|0)==1055){H=c[350134]|0;en(((H|0)!=0?H:c[p>>2]|0)|0,53224,(s=i,i=i+8|0,c[s>>2]=b,s)|0)|0;i=s;H=c[350134]|0;a_(((H|0)!=0?H:c[p>>2]|0)|0)|0;eW(d|0)|0;x=G;y=V;break L1334}}}while(0);eW(d|0)|0;if((w|0)==0){m=l;i=f;return m|0}v=w+4|0;H=w|0;F=c[H>>2]|0;if((c[v>>2]|0)==0){X=F}else{E=0;r=F;while(1){yz(c[r+(E<<3)>>2]|0);F=E+1|0;A=c[H>>2]|0;if(F>>>0<(c[v>>2]|0)>>>0){E=F;r=A}else{X=A;break}}}yz(X);yz(w);m=l;i=f;return m|0}}while(0);if((x|0)!=0){l=0;do{yz(c[y+(l<<3)>>2]|0);l=l+1|0;}while(l>>>0<x>>>0)}yz(y);yz(k);if((w|0)==0){m=0;i=f;return m|0}k=w+4|0;y=w|0;x=c[y>>2]|0;if((c[k>>2]|0)==0){Y=x}else{l=0;X=x;while(1){yz(c[X+(l<<3)>>2]|0);x=l+1|0;d=c[y>>2]|0;if(x>>>0<(c[k>>2]|0)>>>0){l=x;X=d}else{Y=d;break}}}yz(Y);yz(w);m=0;i=f;return m|0}function g5(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;if((i5(b,d,f)|0)>>>0>=f>>>0){d=c[350134]|0;h=(d|0)!=0?d:c[p>>2]|0;en(h|0,45288,(j=i,i=i+16|0,c[j>>2]=41144,c[j+8>>2]=573,j)|0)|0;i=j;h=c[350134]|0;d=(h|0)!=0?h:c[p>>2]|0;a_(d|0)|0;ck(2)}if((a[b]|0)!=0){g9(b,f)}if((i7(b,e,f)|0)>>>0<f>>>0){i=g;return}else{g=c[350134]|0;f=(g|0)!=0?g:c[p>>2]|0;en(f|0,45288,(j=i,i=i+16|0,c[j>>2]=41144,c[j+8>>2]=578,j)|0)|0;i=j;j=c[350134]|0;f=(j|0)!=0?j:c[p>>2]|0;a_(f|0)|0;ck(2)}}function g6(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+4096|0;h=g|0;if((i5(h,d,4096)|0)>>>0>=4096){d=c[350134]|0;j=(d|0)!=0?d:c[p>>2]|0;en(j|0,45288,(k=i,i=i+16|0,c[k>>2]=41144,c[k+8>>2]=409,k)|0)|0;i=k;j=c[350134]|0;d=(j|0)!=0?j:c[p>>2]|0;a_(d|0)|0;ck(2)}d=cn(h|0,46)|0;if((d|0)!=0){a[d]=0}if((i5(b,h,f)|0)>>>0>=f>>>0){h=c[350134]|0;d=(h|0)!=0?h:c[p>>2]|0;en(d|0,45288,(k=i,i=i+16|0,c[k>>2]=41144,c[k+8>>2]=414,k)|0)|0;i=k;d=c[350134]|0;h=(d|0)!=0?d:c[p>>2]|0;a_(h|0)|0;ck(2)}if((i7(b,e,f)|0)>>>0<f>>>0){i=g;return}else{g=c[350134]|0;f=(g|0)!=0?g:c[p>>2]|0;en(f|0,45288,(k=i,i=i+16|0,c[k>>2]=41144,c[k+8>>2]=415,k)|0)|0;i=k;k=c[350134]|0;f=(k|0)!=0?k:c[p>>2]|0;a_(f|0)|0;ck(2)}}function g7(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;if((i5(a,b,e)|0)>>>0>=e>>>0){b=c[350134]|0;g=(b|0)!=0?b:c[p>>2]|0;en(g|0,45288|0,(h=i,i=i+16|0,c[h>>2]=41144,c[h+8>>2]=420,h)|0)|0;i=h;g=c[350134]|0;b=(g|0)!=0?g:c[p>>2]|0;a_(b|0)|0;ck(2)}if((i7(a,d,e)|0)>>>0<e>>>0){i=f;return}else{f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;en(e|0,45288|0,(h=i,i=i+16|0,c[h>>2]=41144,c[h+8>>2]=421,h)|0)|0;i=h;h=c[350134]|0;e=(h|0)!=0?h:c[p>>2]|0;a_(e|0)|0;ck(2)}}function g8(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g9(a,e);g=cn(b|0,47)|0;if((i7(a,(g|0)==0?b:g+1|0,e)|0)>>>0>=e>>>0){g=c[350134]|0;b=(g|0)!=0?g:c[p>>2]|0;en(b|0,45288|0,(h=i,i=i+16|0,c[h>>2]=41144,c[h+8>>2]=457,h)|0)|0;i=h;b=c[350134]|0;g=(b|0)!=0?b:c[p>>2]|0;a_(g|0)|0;ck(2)}if((i7(a,d,e)|0)>>>0<e>>>0){i=f;return}else{f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;en(e|0,45288|0,(h=i,i=i+16|0,c[h>>2]=41144,c[h+8>>2]=458,h)|0)|0;i=h;h=c[350134]|0;e=(h|0)!=0?h:c[p>>2]|0;a_(e|0)|0;ck(2)}}function g9(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+8|0;f=e|0;g=cn(b|0,47)|0;if((g|0)==0){if((i7(b,93552,d)|0)>>>0<d>>>0){i=e;return}else{h=c[350134]|0;j=(h|0)!=0?h:c[p>>2]|0;en(j|0,45288,(k=i,i=i+16|0,c[k>>2]=41144,c[k+8>>2]=450,k)|0)|0;i=k;j=c[350134]|0;h=(j|0)!=0?j:c[p>>2]|0;a_(h|0)|0;ck(2)}}if((g|0)==(b+((yF(b|0)|0)-1)|0)){i=e;return}h=f|0;a[h]=a[g]|0;a[f+1|0]=0;if((i7(b,h,d)|0)>>>0<d>>>0){i=e;return}else{e=c[350134]|0;d=(e|0)!=0?e:c[p>>2]|0;en(d|0,45288,(k=i,i=i+16|0,c[k>>2]=41144,c[k+8>>2]=447,k)|0)|0;i=k;k=c[350134]|0;d=(k|0)!=0?k:c[p>>2]|0;a_(d|0)|0;ck(2)}}function ha(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=cn(b|0,47)|0;if((i5(a,(f|0)==0?b:f+1|0,d)|0)>>>0<d>>>0){i=e;return}else{e=c[350134]|0;d=(e|0)!=0?e:c[p>>2]|0;en(d|0,45288|0,(d=i,i=i+16|0,c[d>>2]=41144,c[d+8>>2]=470,d)|0)|0;i=d;d=c[350134]|0;e=(d|0)!=0?d:c[p>>2]|0;a_(e|0)|0;ck(2)}}function hb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;if((i5(b,d,e)|0)>>>0>=e>>>0){e=c[350134]|0;d=(e|0)!=0?e:c[p>>2]|0;en(d|0,45288|0,(g=i,i=i+16|0,c[g>>2]=41144,c[g+8>>2]=475,g)|0)|0;i=g;d=c[350134]|0;e=(d|0)!=0?d:c[p>>2]|0;a_(e|0)|0;ck(2)}if((yF(b|0)|0)>>>0<2){i=f;return}e=cn(b|0,47)|0;if((e|0)==0){bR(b|0,3,107776|0,(g=i,i=i+8|0,c[g>>2]=93552,g)|0)|0;i=g;i=f;return}else{a[e+1|0]=0;i=f;return}}function hc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+4096|0;e=d|0;i5(e,a,4096)|0;if(b>>>0<=4095){f=c[350134]|0;g=(f|0)!=0?f:c[p>>2]|0;en(g|0,45288,(g=i,i=i+16|0,c[g>>2]=41144,c[g+8>>2]=545,g)|0)|0;i=g;g=c[350134]|0;f=(g|0)!=0?g:c[p>>2]|0;a_(f|0)|0;ck(2)}if((eO(e|0,a|0)|0)!=0){i=d;return}i5(a,e,b)|0;i=d;return}function hd(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;if((a[e]|0)==47){if((i5(b,e,f)|0)>>>0<f>>>0){i=g;return}else{h=c[350134]|0;j=(h|0)!=0?h:c[p>>2]|0;en(j|0,45288,(k=i,i=i+16|0,c[k>>2]=41144,c[k+8>>2]=562,k)|0)|0;i=k;j=c[350134]|0;h=(j|0)!=0?j:c[p>>2]|0;a_(h|0)|0;ck(2)}}if((i5(b,d,f)|0)>>>0>=f>>>0){d=c[350134]|0;h=(d|0)!=0?d:c[p>>2]|0;en(h|0,45288,(k=i,i=i+16|0,c[k>>2]=41144,c[k+8>>2]=565,k)|0)|0;i=k;h=c[350134]|0;d=(h|0)!=0?h:c[p>>2]|0;a_(d|0)|0;ck(2)}do{if((yF(b|0)|0)>>>0>=2){d=cn(b|0,47)|0;if((d|0)==0){bR(b|0,3,107776,(k=i,i=i+8|0,c[k>>2]=93552,k)|0)|0;i=k;break}else{a[d+1|0]=0;break}}}while(0);if((i7(b,e,f)|0)>>>0<f>>>0){i=g;return}else{g=c[350134]|0;f=(g|0)!=0?g:c[p>>2]|0;en(f|0,45288,(k=i,i=i+16|0,c[k>>2]=41144,c[k+8>>2]=567,k)|0)|0;i=k;k=c[350134]|0;f=(k|0)!=0?k:c[p>>2]|0;a_(f|0)|0;ck(2)}}function he(b){b=+b;var d=0,e=0,f=0,j=0,k=0;d=i;i=i+256|0;e=d|0;bR(e|0,256,65328,(f=i,i=i+8|0,h[f>>3]=b,f)|0)|0;i=f;iq(c[348003]|0,e,1,180);if((a[1243488]&1)!=0){j=c[350134]|0;k=(j|0)!=0?j:c[p>>2]|0;en(k|0,99080,(f=i,i=i+8|0,c[f>>2]=e,f)|0)|0;i=f;f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0}g[287220]=b;hf();b=+((c[289288]|0)>>>0>>>0)/+g[289290];h[167826]=b;h[167832]=b;i=d;return}function hf(){var b=0,d=0.0,e=0.0,f=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0,q=0.0;b=i;a[1337853]=0;d=+h[167227];if(d<=0.0){i=b;return}e=+h[167228];if(e<=0.0){i=b;return}f=+g[287220];j=f;if(+Q(+(1.0-d/j))>.05000000074505806){if((a[1243488]&1)==0){k=d;l=f}else{m=c[350134]|0;n=(m|0)!=0?m:c[p>>2]|0;f=d;en(n|0,74568,(o=i,i=i+16|0,h[o>>3]=j,h[o+8>>3]=f,o)|0)|0;i=o;n=c[350134]|0;m=(n|0)!=0?n:c[p>>2]|0;a_(m|0)|0;k=+h[167227];l=+g[287220]}do{if(k>l){a[1337853]=1;if((a[1243488]&1)==0){break}m=c[350134]|0;n=(m|0)!=0?m:c[p>>2]|0;a5(73632,57,1,n|0)|0;n=c[350134]|0;m=(n|0)!=0?n:c[p>>2]|0;a_(m|0)|0}}while(0);q=+h[167228]}else{q=e*(j/d)}d=q;g[289290]=d;if((a[1243488]&1)!=0){m=c[350134]|0;n=(m|0)!=0?m:c[p>>2]|0;q=d;en(n|0,72672,(o=i,i=i+8|0,h[o>>3]=q,o)|0)|0;i=o;o=c[350134]|0;n=(o|0)!=0?o:c[p>>2]|0;a_(n|0)|0}n=c[350660]|0;if((n|0)==0){i=b;return}if((a[1337853]&1)!=0){ft[c[(c[350657]|0)+8>>2]&127](n,1);i=b;return}o=(a[1402656]&1)!=0;if((a[1243490]&1)!=0){ft[c[(c[350657]|0)+8>>2]&127](n,(a[1140656]&1)==0|o)}n=c[350659]|0;if((a[1243489]&1)!=0&(n|0)!=0){ft[c[(c[350656]|0)+16>>2]&127](n,(a[1161264]&1)==0|o)}c[335648]=o?c[335649]|0:c[335650]|0;i=b;return}function hg(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[350660]|0;if((a[1243490]&1)!=0&(d|0)!=0){if((a[1140656]&1)==0){e=1172}else{if((a[1337853]&1)==0){f=b}else{e=1172}}if((e|0)==1172){f=1}ft[c[(c[350657]|0)+8>>2]&127](d,f)}f=c[350659]|0;if(!((a[1243489]&1)!=0&(f|0)!=0)){g=c[335649]|0;h=c[335650]|0;i=b?g:h;c[335648]=i;return}ft[c[(c[350656]|0)+16>>2]&127](f,(a[1161264]&1)==0|b);g=c[335649]|0;h=c[335650]|0;i=b?g:h;c[335648]=i;return}function hh(){var a=0,b=0,d=0;a=c[350708]|0;if((a|0)==0){b=0;return b|0}d=c[a+4>>2]|0;if((d|0)==0){b=0;return b|0}b=fv[d&127](c[350660]|0)|0;return b|0}function hi(a){a=a|0;var b=0,d=0,e=0;b=c[350708]|0;if((b|0)==0){d=0;return d|0}e=c[b+8>>2]|0;if((e|0)==0){d=0;return d|0}d=fL[e&63](c[350660]|0,a)|0;return d|0}function hj(){var b=0,d=0,e=0,f=0,g=0,h=0;a[1402651]=(c[350660]|0)==0|0;a[1402652]=(c[350659]|0)==0|0;a[1402653]=(c[350661]|0)==0|0;hf();c[350074]=0;hm();b=c[335626]|0;if((a[1402650]&1)==0&(b|0)!=0){fQ[b&1023]()}a[1402650]=0;hn();if((a[1402656]&1)==0){d=1342560;e=0;f=0;g=d|0;c[g>>2]=e;h=d+4|0;c[h>>2]=f;return}b=c[350660]|0;if((a[1243490]&1)!=0&(b|0)!=0){ft[c[(c[350657]|0)+8>>2]&127](b,1)}b=c[350659]|0;if((a[1243489]&1)!=0&(b|0)!=0){ft[c[(c[350656]|0)+16>>2]&127](b,1)}c[335648]=c[335649];d=1342560;e=0;f=0;g=d|0;c[g>>2]=e;h=d+4|0;c[h>>2]=f;return}function hk(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;d=0;while(1){if(d>>>0>=2){e=1207;break}f=c[27104+(d<<2)>>2]|0;if((yM(1157116,c[f+28>>2]|0)|0)==0){break}else{d=d+1|0}}if((e|0)==1207){e=c[350134]|0;d=(e|0)!=0?e:c[p>>2]|0;en(d|0,63976,(g=i,i=i+8|0,c[g>>2]=1157116,g)|0)|0;i=g;d=c[350134]|0;e=(d|0)!=0?d:c[p>>2]|0;a_(e|0)|0;e=a[1243488]|0;if((e&1)==0){h=e}else{e=c[350134]|0;d=(e|0)!=0?e:c[p>>2]|0;a5(63072,29,1,d|0)|0;d=c[350134]|0;e=(d|0)!=0?d:c[p>>2]|0;a_(e|0)|0;h=a[1243488]|0}if((h&1)==0){j=h}else{h=c[350134]|0;e=(h|0)!=0?h:c[p>>2]|0;h=c[6763]|0;en(e|0,68784,(g=i,i=i+8|0,c[g>>2]=h,g)|0)|0;i=g;h=c[350134]|0;e=(h|0)!=0?h:c[p>>2]|0;a_(e|0)|0;j=a[1243488]|0}if((j&1)==0){hv(62536)}j=c[350134]|0;e=(j|0)!=0?j:c[p>>2]|0;j=c[6773]|0;en(e|0,68784,(g=i,i=i+8|0,c[g>>2]=j,g)|0)|0;i=g;j=c[350134]|0;e=(j|0)!=0?j:c[p>>2]|0;a_(e|0)|0;hv(62536)}c[350656]=f;f=c[63]|0;if((yM(1140568,f|0)|0)!=0){e=c[350134]|0;j=(e|0)!=0?e:c[p>>2]|0;en(j|0,66632,(g=i,i=i+8|0,c[g>>2]=1140568,g)|0)|0;i=g;j=c[350134]|0;e=(j|0)!=0?j:c[p>>2]|0;a_(e|0)|0;e=a[1243488]|0;if((e&1)==0){k=e}else{e=c[350134]|0;j=(e|0)!=0?e:c[p>>2]|0;a5(65696,29,1,j|0)|0;j=c[350134]|0;e=(j|0)!=0?j:c[p>>2]|0;a_(e|0)|0;k=a[1243488]|0}if((k&1)==0){hv(64728)}k=c[350134]|0;e=(k|0)!=0?k:c[p>>2]|0;en(e|0,68784,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0;hv(64728)}c[350657]=224;e=c[4198]|0;if((yM(1165408,e|0)|0)==0){c[350658]=16768;i=b;return}b=c[350134]|0;en(((b|0)!=0?b:c[p>>2]|0)|0,71704,(g=i,i=i+8|0,c[g>>2]=1165408,g)|0)|0;i=g;b=c[350134]|0;a_(((b|0)!=0?b:c[p>>2]|0)|0)|0;b=a[1243488]|0;if((b&1)==0){l=b}else{b=c[350134]|0;f=(b|0)!=0?b:c[p>>2]|0;a5(70384,29,1,f|0)|0;f=c[350134]|0;b=(f|0)!=0?f:c[p>>2]|0;a_(b|0)|0;l=a[1243488]|0}if((l&1)==0){hv(67656)}l=c[350134]|0;en(((l|0)!=0?l:c[p>>2]|0)|0,68784,(g=i,i=i+8|0,c[g>>2]=e,g)|0)|0;i=g;g=c[350134]|0;a_(((g|0)!=0?g:c[p>>2]|0)|0)|0;hv(67656)}function hl(){var b=0;ho();b=c[335633]|0;do{if((b|0)!=0){if((a[1402649]&1)!=0){break}fQ[b&1023]()}}while(0);hp();if((a[1402651]&1)!=0){c[350660]=0}if((a[1402652]&1)!=0){c[350659]=0}if((a[1402653]&1)==0){a[1402651]=0;a[1402652]=0;a[1402653]=0;return}c[350661]=0;a[1402651]=0;a[1402652]=0;a[1402653]=0;return}function hm(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0.0,q=0.0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=i;i=i+24|0;d=b|0;L1617:do{if((a[1148885]|0)!=0){e=g4(1148885,80120,0)|0;c[350091]=e;do{if((e|0)!=0){if((c[e+4>>2]|0)==0){break}c[350092]=0;gV(e,0);f=c[350091]|0;if((c[f+4>>2]|0)==0){break L1617}else{j=0;k=f}while(1){if((a[1243488]&1)==0){l=k}else{f=c[350134]|0;m=(f|0)!=0?f:c[p>>2]|0;f=c[(c[k>>2]|0)+(j<<3)>>2]|0;en(m|0,78312,(n=i,i=i+8|0,c[n>>2]=f,n)|0)|0;i=n;f=c[350134]|0;m=(f|0)!=0?f:c[p>>2]|0;a_(m|0)|0;l=c[350091]|0}m=j+1|0;if(m>>>0<(c[l+4>>2]|0)>>>0){j=m;k=l}else{break L1617}}}}while(0);gZ(e);c[350091]=0;c[350092]=0}}while(0);l=c[334450]|0;k=c[334451]|0;j=(l>>>0>k>>>0?l:k)-1|0;k=j>>>1|j;j=k>>>2|k;k=j>>>4|j;j=k>>>8|k;k=((j>>>16|j)+1|0)>>>8;j=(a[1391848]&1)==0?k>>>0>1?k:1:c[347967]|0;o=+g[285168];g[334458]=o;do{if(o<0.0){q=+g[334452];if(q>0.0){if((a[1140676]&1)==0){r=1256}else{s=q}}else{r=1256}if((r|0)==1256){s=+((c[334448]|0)>>>0>>>0)/+((c[334449]|0)>>>0>>>0)}g[334458]=s;if((a[1243488]&1)==0){break}k=c[350134]|0;l=(k|0)!=0?k:c[p>>2]|0;q=s;en(l|0,37480,(n=i,i=i+8|0,h[n>>3]=q,n)|0)|0;i=n;l=c[350134]|0;k=(l|0)!=0?l:c[p>>2]|0;a_(k|0)|0}}while(0);do{if((a[1140640]&1)==0){if((a[1140669]&1)==0){r=~~+bL(+(+((c[334448]|0)>>>0>>>0)*+g[285158]));t=r;u=~~+bL(+(+((c[334449]|0)>>>0>>>0)*+g[285159]));break}else{s=+((c[334449]|0)>>>0>>>0);o=+(~~+bL(+(s*+g[334458]))>>>0>>>0);r=~~+bL(+(+g[285158]*o));t=r;u=~~+bL(+(s*+g[285159]));break}}else{t=c[285162]|0;u=c[285163]|0}}while(0);r=(a[1243488]&1)==0;do{if((t|0)==0|(u|0)==0){if(r){break}k=c[350134]|0;l=(k|0)!=0?k:c[p>>2]|0;a5(104272,30,1,l|0)|0;l=c[350134]|0;k=(l|0)!=0?l:c[p>>2]|0;a_(k|0)|0}else{if(r){break}k=c[350134]|0;l=(k|0)!=0?k:c[p>>2]|0;en(l|0,107680,(n=i,i=i+16|0,c[n>>2]=t,c[n+8>>2]=u,n)|0)|0;i=n;l=c[350134]|0;k=(l|0)!=0?l:c[p>>2]|0;a_(k|0)|0}}while(0);c[350667]=0;c[350665]=0;c[350666]=0;n=j<<8;jM(1402672);yG(1402672,0,128);yz(c[350700]|0);c[350700]=0;do{if((c[334462]|0)==0){r=c[350134]|0;k=(r|0)!=0?r:c[p>>2]|0;a5(81896,120,1,k|0)|0;k=c[350134]|0;r=(k|0)!=0?k:c[p>>2]|0;a_(r|0)|0;c[350676]=1;c[350674]=2;c[350675]=3;if(jL(1402672)|0){c[350700]=yy(2,ab(n,n)|0)|0;break}else{r=c[350134]|0;k=(r|0)!=0?r:c[p>>2]|0;a5(101088,53,1,k|0)|0;k=c[350134]|0;r=(k|0)!=0?k:c[p>>2]|0;a_(r|0)|0;hv(99288)}}}while(0);n=d;c[n>>2]=c[4626];c[n+4>>2]=c[4627];c[n+8>>2]=c[4628];c[n+12>>2]=c[4629];c[n+16>>2]=c[4630];c[d>>2]=t;c[d+4>>2]=u;a[d+8|0]=a[1140640]&1;if((a[1140656]&1)==0){v=0}else{v=a[1337853]&1^1}a[d+9|0]=v;a[d+10|0]=a[1140669]&1;a[d+11|0]=a[1140668]&1;c[d+12>>2]=j;if((a[1391848]&1)==0){w=(c[334462]|0)==1|0}else{w=1}a[d+16|0]=w;w=c[350658]|0;j=fA[c[c[350657]>>2]&63](d,1402632,1402644)|0;c[350660]=j;if((j|0)==0){d=c[350134]|0;v=(d|0)!=0?d:c[p>>2]|0;a5(97592,62,1,v|0)|0;v=c[350134]|0;d=(v|0)!=0?v:c[p>>2]|0;a_(d|0)|0;hv(99288)}c[350708]=0;d=c[350657]|0;v=c[d+56>>2]|0;if((v|0)==0){x=d}else{ft[v&127](j,1402832);x=c[350657]|0}j=c[x+40>>2]|0;x=c[334459]|0;if((j|0)!=0&(x|0)!=0){ft[j&127](c[350660]|0,x)}x=c[350708]|0;do{if((x|0)!=0){j=c[x+12>>2]|0;v=c[285170]|0;if(!((j|0)!=0&(v|0)!=4)){break}ft[j&127](c[350660]|0,v)}}while(0);do{if((c[350658]|0)==0){if((a[1243488]&1)!=0){x=c[350134]|0;v=(x|0)!=0?x:c[p>>2]|0;a5(95184,101,1,v|0)|0;v=c[350134]|0;x=(v|0)!=0?v:c[p>>2]|0;a_(x|0)|0}c[350658]=w;if((w|0)==0){x=c[350134]|0;v=(x|0)!=0?x:c[p>>2]|0;a5(91664,59,1,v|0)|0;v=c[350134]|0;x=(v|0)!=0?v:c[p>>2]|0;a_(x|0)|0;hv(99288)}x=fN[c[w>>2]&63]()|0;c[350661]=x;if((x|0)!=0){break}x=c[350134]|0;v=(x|0)!=0?x:c[p>>2]|0;a5(93432,59,1,v|0)|0;v=c[350134]|0;x=(v|0)!=0?v:c[p>>2]|0;a_(x|0)|0;hv(99288)}}while(0);w=c[350702]|0;if((w|0)!=0){jB(w);c[350702]=0}if((a[1201944]|0)==0){y=1391840;z=0;A=0;B=y|0;c[B>>2]=z;C=y+4|0;c[C>>2]=A;i=b;return}w=jz(1201944)|0;c[350702]=w;if((w|0)!=0){y=1391840;z=0;A=0;B=y|0;c[B>>2]=z;C=y+4|0;c[C>>2]=A;i=b;return}w=c[350134]|0;a5(79648,45,1,((w|0)!=0?w:c[p>>2]|0)|0)|0;w=c[350134]|0;a_(((w|0)!=0?w:c[p>>2]|0)|0)|0;y=1391840;z=0;A=0;B=y|0;c[B>>2]=z;C=y+4|0;c[C>>2]=A;i=b;return}function hn(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0.0;b=i;jh();if((c[350659]|0)!=0){i=b;return}d=~~(+g[309708]*65536.0);e=yx(d<<1)|0;c[335656]=e;if((e|0)==0){e=c[350134]|0;f=(e|0)!=0?e:c[p>>2]|0;en(f|0,67440,(j=i,i=i+16|0,c[j>>2]=58944,c[j+8>>2]=497,j)|0)|0;i=j;f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0;ck(2)}c[335650]=512;c[335649]=2048;c[335648]=512;e=yx(8192)|0;c[335657]=e;if((e|0)==0){e=c[350134]|0;f=(e|0)!=0?e:c[p>>2]|0;en(f|0,67440,(j=i,i=i+16|0,c[j>>2]=58944,c[j+8>>2]=504,j)|0)|0;i=j;f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0;ck(2)}c[335659]=4096;if((a[1157148]&1)==0){a[1243489]=0;i=b;return}e=fA[c[c[350656]>>2]&63]((a[1157164]|0)!=0?1157164:0,c[289288]|0,c[290315]|0)|0;c[350659]=e;do{if((e|0)==0){f=c[350134]|0;k=(f|0)!=0?f:c[p>>2]|0;a5(53064,85,1,k|0)|0;k=c[350134]|0;f=(k|0)!=0?k:c[p>>2]|0;a_(f|0)|0;a[1243489]=0}else{if((a[1243489]&1)==0){break}f=c[(c[350656]|0)+24>>2]|0;if((f|0)==0){break}if(!(fv[f&127](c[350659]|0)|0)){break}a[1342616]=1}}while(0);do{if((a[1161264]&1)==0){if((a[1243489]&1)==0){break}ft[c[(c[350656]|0)+16>>2]&127](c[350659]|0,1);c[335648]=c[335649]}}while(0);l=+((c[289288]|0)>>>0>>>0)/+g[289290];h[167826]=l;h[167832]=l;e=(a[1165372]|0)!=0;if(!(kp(1342576,1342580,e?1165372:0,l)|0)){f=c[350134]|0;k=(f|0)!=0?f:c[p>>2]|0;f=e?1165372:45176;en(k|0,49336,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;f=c[350134]|0;k=(f|0)!=0?f:c[p>>2]|0;a_(k|0)|0;a[1243489]=0}k=yx(16384)|0;c[335646]=k;if((k|0)==0){k=c[350134]|0;f=(k|0)!=0?k:c[p>>2]|0;en(f|0,67440,(j=i,i=i+16|0,c[j>>2]=58944,c[j+8>>2]=561,j)|0)|0;i=j;f=c[350134]|0;k=(f|0)!=0?f:c[p>>2]|0;a_(k|0)|0;ck(2)}c[335647]=0;if(+((c[289288]|0)>>>0>>>0)>=+g[289290]*16.0){k=c[350134]|0;f=(k|0)!=0?k:c[p>>2]|0;en(f|0,67440,(j=i,i=i+16|0,c[j>>2]=58944,c[j+8>>2]=565,j)|0)|0;i=j;f=c[350134]|0;k=(f|0)!=0?f:c[p>>2]|0;a_(k|0)|0;ck(2)}k=yx(d<<2)|0;c[335655]=k;if((k|0)==0){k=c[350134]|0;d=(k|0)!=0?k:c[p>>2]|0;en(d|0,67440,(j=i,i=i+16|0,c[j>>2]=58944,c[j+8>>2]=566,j)|0)|0;i=j;j=c[350134]|0;d=(j|0)!=0?j:c[p>>2]|0;a_(d|0)|0;ck(2)}a[1342652]=0;L1733:do{if((c[335617]|0)==0){if((a[1243489]&1)==0){break}if((a[1165361]&1)==0){break}d=c[350656]|0;j=c[d+36>>2]|0;do{if((j|0)!=0){if((c[d+32>>2]|0)==0){break}c[335666]=fv[j&127](c[350659]|0)|0;a[1342652]=1;break L1733}}while(0);j=c[350134]|0;d=(j|0)!=0?j:c[p>>2]|0;a5(41008,97,1,d|0)|0;d=c[350134]|0;j=(d|0)!=0?d:c[p>>2]|0;a_(j|0)|0}}while(0);l=+g[291342];g[335667]=l;g[335668]=+S(10.0,+(l/20.0));j=1375448;c[j>>2]=0;c[j+4>>2]=0;if((a[1243489]&1)==0){i=b;return}if(!((a[1342617]&1)==0&(c[335617]|0)!=0)){i=b;return}fv[c[(c[350656]|0)+12>>2]&127](c[350659]|0)|0;i=b;return}function ho(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,q=0,r=0,s=0,t=0,u=0.0,v=0;b=i;d=c[350659]|0;e=c[350656]|0;if((d|0)!=0&(e|0)!=0){fs[c[e+20>>2]&255](d)}yz(c[335656]|0);c[335656]=0;c[335647]=0;yz(c[335657]|0);c[335657]=0;if((a[1157148]&1)==0){a[1243489]=0;i=b;return}d=c[335645]|0;e=c[335644]|0;if((d|0)!=0&(e|0)!=0){fs[c[d+8>>2]&255](e)}c[335645]=0;c[335644]=0;yz(c[335646]|0);c[335646]=0;yz(c[335655]|0);c[335655]=0;e=1375448;d=c[e>>2]|0;f=c[e+4>>2]|0;e=0;g=f>>>0<e>>>0|f>>>0==e>>>0&d>>>0<8192>>>0?d:8192;if(g>>>0<3){i=b;return}else{j=1;k=0;l=0}do{l=yT(c[1342680+(j<<2)>>2]|0,0,l,k)|0;k=F;j=j+1|0;}while(j>>>0<g>>>0);j=g-1|0;d=y1(l,k,j,0)|0;k=d;d=1;l=0;e=0;do{f=k-(c[1342680+(d<<2)>>2]|0)|0;e=yT(ab(f,f)|0,0,e,l)|0;l=F;d=d+1|0;}while(d>>>0<g>>>0);d=~~+R(+((+(e>>>0)+ +(l>>>0)*4294967296.0)/+((g-2|0)>>>0>>>0)));l=c[335666]|0;m=+(l>>>0>>>0);n=+(k|0)/m;o=+(d>>>0>>>0);d=(l*3|0)>>>2;k=l>>>2;l=0;e=0;f=1;while(1){q=c[1342680+(f<<2)>>2]|0;if(q>>>0<d>>>0){r=(q>>>0<=k>>>0)+e|0;s=l}else{r=e;s=l+1|0}q=f+1|0;if(q>>>0<g>>>0){l=s;e=r;f=q}else{break}}f=a[1243488]|0;if((f&1)==0){t=f}else{f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;u=(1.0-n)*100.0;n=o/m*100.0;en(e|0,77048,(v=i,i=i+16|0,h[v>>3]=u,h[v+8>>3]=n,v)|0)|0;i=v;e=c[350134]|0;f=(e|0)!=0?e:c[p>>2]|0;a_(f|0)|0;t=a[1243488]|0}if((t&1)==0){i=b;return}t=c[350134]|0;n=+(j>>>0>>>0);en(((t|0)!=0?t:c[p>>2]|0)|0,75616,(v=i,i=i+16|0,h[v>>3]=+(s>>>0>>>0)*100.0/n,h[v+8>>3]=+(r>>>0>>>0)*100.0/n,v)|0)|0;i=v;v=c[350134]|0;a_(((v|0)!=0?v:c[p>>2]|0)|0)|0;i=b;return}function hp(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0.0,q=0.0;b=i;d=c[350702]|0;if((d|0)!=0){jB(d);c[350702]=0;yG(1402816,0,16)}d=c[350661]|0;e=c[350660]|0;f=c[350658]|0;if((d|0)!=(e|0)&(f|0)!=0){fs[c[f+16>>2]&255](d);g=c[350660]|0}else{g=e}e=c[350657]|0;if((g|0)!=0&(e|0)!=0){fs[c[e+24>>2]&255](g)}jM(1402672);yG(1402672,0,128);yz(c[350700]|0);c[350700]=0;gZ(c[350091]|0);c[350091]=0;c[350092]=0;if((a[1148884]&1)!=0){if((a[1243488]&1)==0){i=b;return}g=c[350134]|0;e=(g|0)!=0?g:c[p>>2]|0;a5(89944,66,1,e|0)|0;e=c[350134]|0;g=(e|0)!=0?e:c[p>>2]|0;a_(g|0)|0;i=b;return}g=1391840;e=c[g+4>>2]|0;d=0;if(e>>>0<d>>>0|e>>>0==d>>>0&(c[g>>2]|0)>>>0<4096>>>0){if((a[1243488]&1)==0){i=b;return}g=c[350134]|0;d=(g|0)!=0?g:c[p>>2]|0;en(d|0,88144,(j=i,i=i+8|0,c[j>>2]=4096,j)|0)|0;i=j;d=c[350134]|0;g=(d|0)!=0?d:c[p>>2]|0;a_(g|0)|0;i=b;return}else{k=0;l=0;m=0}do{g=1375456+(k<<3)|0;m=yT(c[g>>2]|0,c[g+4>>2]|0,m,l)|0;l=F;k=k+1|0;}while(k>>>0<2048);k=y_(m,l,2048,0)|0;l=F;m=0;g=0;d=0;do{e=1375456+(d<<3)|0;f=yU(c[e>>2]|0,c[e+4>>2]|0,k,l)|0;e=F;n=y0(f,e,f,e)|0;g=yT(n,F,g,m)|0;m=F;d=d+1|0;}while(d>>>0<2048);o=+(k>>>0)+ +(l|0)*4294967296.0;if((a[1243488]&1)==0){i=b;return}q=+R(+((+(g>>>0)+ +(m|0)*4294967296.0)/2047.0))/o;m=c[350134]|0;en(((m|0)!=0?m:c[p>>2]|0)|0,86464,(j=i,i=i+24|0,h[j>>3]=1.0e6/o,h[j+8>>3]=q*100.0,c[j+16>>2]=2048,j)|0)|0;i=j;j=c[350134]|0;a_(((j|0)!=0?j:c[p>>2]|0)|0)|0;i=b;return}function hq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0;if((a[1148884]&1)!=0){f=0;return f|0}g=1391840;i=c[g>>2]|0;j=c[g+4>>2]|0;g=0;k=j>>>0>g>>>0|j>>>0==g>>>0&i>>>0>2048>>>0?2048:i;if(k>>>0<2){f=0;return f|0}else{l=0;m=0;n=0}do{i=1375456+(l<<3)|0;n=yT(c[i>>2]|0,c[i+4>>2]|0,n,m)|0;m=F;l=l+1|0;}while(l>>>0<k>>>0);l=y_(n,m,k,0)|0;m=F;n=0;i=0;g=0;do{j=1375456+(g<<3)|0;o=yU(c[j>>2]|0,c[j+4>>2]|0,l,m)|0;j=F;p=y0(o,j,o,j)|0;i=yT(p,F,i,n)|0;n=F;g=g+1|0;}while(g>>>0<k>>>0);q=+(l>>>0)+ +(m|0)*4294967296.0;h[d>>3]=+R(+((+(i>>>0)+ +(n|0)*4294967296.0)/+((k-1|0)>>>0>>>0)))/q;h[b>>3]=1.0e6/q;c[e>>2]=k;f=1;return f|0}function hr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=hw(b,0)|0;if((d|0)==0){e=0;return e|0}b=c[d+8>>2]|0;if((b|0)!=0){f=a+4|0;c[b+12>>2]=c[f>>2];b=d+4|0;c[f>>2]=c[b>>2];c[b>>2]=0}ht(d);e=1;return e|0}function hs(a){a=a|0;return hw(a,0)|0}function ht(a){a=a|0;var b=0,d=0;if((a|0)==0){return}b=c[a+4>>2]|0;if((b|0)!=0){d=b;while(1){yz(c[d+4>>2]|0);yz(c[d+8>>2]|0);b=c[d+12>>2]|0;yz(d|0);if((b|0)==0){break}else{d=b}}}d=c[a+16>>2]|0;if((d|0)!=0){b=d;while(1){yz(c[b>>2]|0);d=c[b+4>>2]|0;yz(b);if((d|0)==0){break}else{b=d}}}yz(c[a>>2]|0);yz(a);return}function hu(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+4112|0;g=f|0;h=f+8|0;j=f+4104|0;k=b7(e|0,35)|0;if((k|0)!=0){a[k]=0}l=b+12|0;m=c[l>>2]|0;do{if((k|0)==(e|0)){if(m>>>0>=16){n=1455;break}if((bN(e+1|0,86408,8)|0)!=0){o=e;break}q=h|0;r=e+9|0;while(1){s=r+1|0;if((bf(a[r]|0)|0)==0){break}else{r=s}}t=a[r]|0;do{if((t<<24>>24|0)==34){u=ej(s|0,81784,g|0)|0;if((u|0)==0){v=0;i=f;return v|0}else{w=dy(u|0)|0;break}}else if((t<<24>>24|0)==0){v=0;i=f;return v|0}else{u=ej(r|0,79984,g|0)|0;if((u|0)==0){v=0;i=f;return v|0}else{w=dy(u|0)|0;break}}}while(0);if((w|0)==0){v=0;i=f;return v|0}r=b+16|0;t=c[r>>2]|0;u=yy(1,8)|0;x=u;c[u>>2]=dy(w|0)|0;if((t|0)==0){c[r>>2]=x}else{r=t;do{y=r+4|0;r=c[y>>2]|0;}while((r|0)!=0);c[y>>2]=x}if((a[w]|0)==126){r=dM(98408)|0;t=(r|0)!=0?r:2659304;i5(q,t,4096)|0;t=w+1|0;i7(q,t,4096)|0}else{hd(q,c[b>>2]|0,w,4096)}t=hw(q,(c[l>>2]|0)+1|0)|0;if((t|0)==0){yz(w);v=0;i=f;return v|0}r=b+4|0;u=c[r>>2]|0;if((u|0)==0){z=t+4|0;A=c[z>>2]|0;if((A|0)==0){B=0}else{C=A;do{a[C|0]=1;C=c[C+12>>2]|0;}while((C|0)!=0);B=c[z>>2]|0}c[r>>2]=B;D=B}else{C=u;do{E=C+12|0;C=c[E>>2]|0;}while((C|0)!=0);C=t+4|0;u=c[C>>2]|0;if((u|0)==0){F=0}else{z=u;do{a[z|0]=1;z=c[z+12>>2]|0;}while((z|0)!=0);F=c[C>>2]|0}c[E>>2]=F;D=c[r>>2]|0}c[t+4>>2]=0;if((D|0)==0){c[b+8>>2]=0}else{z=D;while(1){u=c[z+12>>2]|0;if((u|0)==0){break}else{z=u}}c[b+8>>2]=z}ht(t);yz(w);v=0;i=f;return v|0}else{if(m>>>0>15){n=1455}else{o=e}}}while(0);if((n|0)==1455){m=c[p>>2]|0;a5(84328,58,1,m|0)|0;o=e}while(1){if((bf(a[o]|0)|0)==0){break}else{o=o+1|0}}e=yx(9)|0;if((eX(a[o]|0)|0)==0){G=o;H=e;I=0}else{m=o;o=e;e=8;w=0;while(1){if((w|0)==(e|0)){b=w<<1;J=b;K=yA(o,b|1)|0}else{J=e;K=o}b=m+1|0;D=w+1|0;a[K+w|0]=a[m]|0;if((eX(a[b]|0)|0)==0){G=b;H=K;I=D;break}else{m=b;o=K;e=J;w=D}}}a[H+I|0]=0;I=d+4|0;c[I>>2]=H;w=G;while(1){L=w+1|0;if((bf(a[w]|0)|0)==0){break}else{w=L}}do{if((a[w]|0)==61){G=L;while(1){M=G+1|0;if((bf(a[G]|0)|0)==0){break}else{G=M}}t=a[G]|0;if((t<<24>>24|0)==34){z=ej(M|0,81784,j|0)|0;if((z|0)==0){n=1470;break}N=dy(z|0)|0}else if((t<<24>>24|0)==0){n=1470;break}else{t=ej(G|0,79984,j|0)|0;if((t|0)==0){n=1470;break}N=dy(t|0)|0}c[d+8>>2]=N;if((N|0)==0){break}else{v=1}i=f;return v|0}else{n=1470}}while(0);if((n|0)==1470){c[d+8>>2]=0}c[I>>2]=0;yz(H);v=0;i=f;return v|0}function hv(b){b=b|0;var d=0,e=0;if((a[1400541]&1)==0){d=c[350134]|0;e=(d|0)!=0?d:c[p>>2]|0;en(e|0,67440,(e=i,i=i+16|0,c[e>>2]=84552,c[e+8>>2]=832,e)|0)|0;i=e;e=c[350134]|0;d=(e|0)!=0?e:c[p>>2]|0;a_(d|0)|0;ck(2)}else{i5(1400543,b,1024)|0;eQ(1401568,1)}}function hw(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=yy(1,20)|0;f=e;if((e|0)==0){g=0;return g|0}if((b|0)==0){g=f;return g|0}h=dy(b|0)|0;c[e>>2]=h;if((h|0)==0){yz(e);g=0;return g|0}c[e+12>>2]=d;d=dc(b|0,88096)|0;if((d|0)==0){yz(h);yz(e);g=0;return g|0}if((et(d|0)|0)==0){h=e+8|0;b=e+4|0;do{e=yy(1,16)|0;i=e;j=yx(9)|0;k=bT(d|0)|0;l=0;m=8;n=j;while(1){if((k|0)==(-1|0)|(k|0)==10){break}if((l|0)==(m|0)){j=m<<1;o=j;p=yA(n,j|1)|0}else{o=m;p=n}a[p+l|0]=k&255;k=bT(d|0)|0;l=l+1|0;m=o;n=p}a[n+l|0]=0;if((n|0)!=0){do{if(hu(f,i,n)|0){if((c[b>>2]|0)==0){c[b>>2]=i;c[h>>2]=i;break}else{c[(c[h>>2]|0)+12>>2]=i;c[h>>2]=i;break}}}while(0);yz(n)}if((i|0)!=(c[h>>2]|0)){yz(e)}}while((et(d|0)|0)==0)}aS(d|0)|0;g=f;return g|0}function hx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,i=0;e=a+4|0;while(1){f=c[e>>2]|0;if((f|0)==0){h=0;i=1519;break}if((cS(b|0,c[f+4>>2]|0)|0)==0){break}else{e=f+12|0}}if((i|0)==1519){return h|0}g[d>>2]=+yD(c[f+8>>2]|0,0);h=1;return h|0}function hy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+4|0;while(1){f=c[e>>2]|0;if((f|0)==0){g=0;h=1529;break}if((cS(b|0,c[f+4>>2]|0)|0)==0){break}else{e=f+12|0}}if((h|0)==1529){return g|0}c[(d0()|0)>>2]=0;h=a1(c[f+8>>2]|0,0,0)|0;if((c[(d0()|0)>>2]|0)!=0){g=0;return g|0}c[d>>2]=h;g=1;return g|0}function hz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+4|0;while(1){f=c[e>>2]|0;if((f|0)==0){g=0;h=1536;break}if((cS(b|0,c[f+4>>2]|0)|0)==0){break}else{e=f+12|0}}if((h|0)==1536){return g|0}c[(d0()|0)>>2]=0;h=aX(c[f+8>>2]|0,0,0)|0;if((c[(d0()|0)>>2]|0)!=0){g=0;return g|0}c[d>>2]=h;g=1;return g|0}function hA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+4|0;while(1){f=c[e>>2]|0;if((f|0)==0){g=0;h=1547;break}if((cS(b|0,c[f+4>>2]|0)|0)==0){break}else{e=f+12|0}}if((h|0)==1547){return g|0}c[(d0()|0)>>2]=0;h=aX(c[f+8>>2]|0,0,16)|0;if((c[(d0()|0)>>2]|0)!=0){g=0;return g|0}c[d>>2]=h;g=1;return g|0}function hB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+4|0;while(1){f=c[e>>2]|0;if((f|0)==0){g=0;h=1554;break}if((cS(b|0,c[f+4>>2]|0)|0)==0){break}else{e=f+12|0}}if((h|0)==1554){return g|0}c[d>>2]=dy(c[f+8>>2]|0)|0;g=1;return g|0}function hC(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=a+4|0;while(1){g=c[f>>2]|0;if((g|0)==0){h=0;i=1561;break}if((cS(b|0,c[g+4>>2]|0)|0)==0){break}else{f=g+12|0}}if((i|0)==1561){return h|0}h=(i5(d,c[g+8>>2]|0,e)|0)>>>0<e>>>0;return h|0}function hD(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=i;i=i+4096|0;h=g|0;j=b+4|0;while(1){k=c[j>>2]|0;if((k|0)==0){l=0;m=1576;break}if((cS(d|0,c[k+4>>2]|0)|0)==0){break}else{j=k+12|0}}if((m|0)==1576){i=g;return l|0}m=c[k+8>>2]|0;k=a[m]|0;do{if((k<<24>>24|0)==58){if((a[m+1|0]|0)!=47){n=e;o=f;q=m;break}j=h|0;g3(j,4096);if((a[1243488]&1)!=0){d=c[350134]|0;b=(d|0)!=0?d:c[p>>2]|0;en(b|0,79e3,(b=i,i=i+8|0,c[b>>2]=j,b)|0)|0;i=b;b=c[350134]|0;d=(b|0)!=0?b:c[p>>2]|0;a_(d|0)|0}g1(j);d=i5(e,j,f)|0;if(d>>>0<f>>>0){n=e+d|0;o=f-d|0;q=m+2|0;break}else{l=0;i=g;return l|0}}else if((k<<24>>24|0)==126){d=dM(98408)|0;if((d|0)==0){n=e;o=f;q=m;break}j=i5(e,d,f)|0;if(j>>>0<f>>>0){n=e+j|0;o=f-j|0;q=m+1|0;break}else{l=0;i=g;return l|0}}else{n=e;o=f;q=m}}while(0);l=(i5(n,q,o)|0)>>>0<o>>>0;i=g;return l|0}function hE(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;while(1){g=c[f>>2]|0;if((g|0)==0){h=0;i=1596;break}if((cS(d|0,c[g+4>>2]|0)|0)==0){break}else{f=g+12|0}}if((i|0)==1596){return h|0}i=c[g+8>>2]|0;if((yM(i|0,67096)|0)==0){a[e]=1;h=1;return h|0}if((yM(i|0,58752)|0)==0){a[e]=1;h=1;return h|0}if((yM(i|0,52896)|0)==0){a[e]=0;h=1;return h|0}if((yM(i|0,49152)|0)!=0){h=0;return h|0}a[e]=0;h=1;return h|0}function hF(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;b=c[f>>2]|0;L2091:do{if((b|0)==0){g=0}else{h=b;while(1){if((a[h|0]&1)==0){if((cS(d|0,c[h+4>>2]|0)|0)==0){break}}i=c[h+12>>2]|0;if((i|0)==0){g=h;break L2091}else{h=i}}i=h+8|0;yz(c[i>>2]|0);c[i>>2]=dy(e|0)|0;return}}while(0);b=yy(1,16)|0;i=b;c[b+4>>2]=dy(d|0)|0;c[b+8>>2]=dy(e|0)|0;if((g|0)==0){c[f>>2]=i;return}else{c[g+12>>2]=i;return}}function hG(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=i;i=i+128|0;e=d|0;bR(e|0,128,40760,(f=i,i=i+8|0,h[f>>3]=c,f)|0)|0;i=f;hF(a,b,e);i=d;return}function hH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+128|0;f=e|0;bR(f|0,128,37296,(g=i,i=i+8|0,c[g>>2]=d,g)|0)|0;i=g;hF(a,b,f);i=e;return}function hI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+128|0;f=e|0;bR(f|0,128,107552,(g=i,i=i+8|0,c[g>>2]=d,g)|0)|0;i=g;hF(a,b,f);i=e;return}function hJ(a,b,c){a=a|0;b=b|0;c=c|0;hF(a,b,c?67096:52896);return}function hK(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=(d|0)!=0;do{if(f){g=dc(d|0,99216)|0;if((g|0)==0){h=0}else{j=g;break}i=e;return h|0}else{j=c[o>>2]|0}}while(0);d=c[b+16>>2]|0;if((d|0)!=0){g=d;do{en(j|0,97448,(k=i,i=i+8|0,c[k>>2]=c[g>>2],k)|0)|0;i=k;g=c[g+4>>2]|0;}while((g|0)!=0)}g=c[b+4>>2]|0;if((g|0)!=0){b=g;do{if((a[b|0]&1)==0){g=c[b+4>>2]|0;d=c[b+8>>2]|0;en(j|0,95056,(k=i,i=i+16|0,c[k>>2]=g,c[k+8>>2]=d,k)|0)|0;i=k}b=c[b+12>>2]|0;}while((b|0)!=0)}if(!f){h=1;i=e;return h|0}aS(j|0)|0;h=1;i=e;return h|0}function hL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=c[b+16>>2]|0;if((f|0)!=0){g=f;do{en(d|0,97448,(h=i,i=i+8|0,c[h>>2]=c[g>>2],h)|0)|0;i=h;g=c[g+4>>2]|0;}while((g|0)!=0)}g=c[b+4>>2]|0;if((g|0)==0){i=e;return}else{j=g}do{g=c[j+8>>2]|0;b=(a[j|0]&1)!=0?91592:2659304;en(d|0,93360,(h=i,i=i+24|0,c[h>>2]=c[j+4>>2],c[h+8>>2]=g,c[h+16>>2]=b,h)|0)|0;i=h;j=c[j+12>>2]|0;}while((j|0)!=0);i=e;return}function hM(){var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i5(1140568,97672,32)|0;i5(1157116,58992,32)|0;i5(1165408,78416,32)|0;g[285158]=3.0;g[285159]=3.0;a[1140640]=a[1243491]&1;a[1140641]=1;c[285161]=0;c[285162]=0;c[285163]=0;a[1157108]=0;a[1140656]=1;a[1140657]=0;c[285166]=0;a[1140658]=0;c[285165]=1;a[1148884]=0;a[1140668]=1;a[1140669]=1;a[1140677]=0;a[1140670]=1;g[285168]=-1.0;a[1140676]=0;c[285170]=4;a[1144780]=0;a[1157112]=1;a[1157084]=1;g[289270]=48.0;a[1157085]=1;g[289272]=.05000000074505806;g[289273]=.05000000074505806;g[289274]=1.0;g[289275]=1.0;g[289276]=0.0;g[287220]=59.95000076293945;a[1157109]=0;a[1157110]=0;a[1157111]=1;a[1157148]=1;c[289288]=48e3;c[289289]=0;g[289290]=48.0e3;c[290315]=64;a[1161264]=1;a[1165361]=1;g[291341]=.004999999888241291;g[291342]=0.0;a[1238820]=0;c[309706]=20971520;c[309707]=1;g[309708]=3.0;g[309709]=-1.0;a[1238840]=0;yG(1238844,0,7);a[1238851]=1;a[1238852]=0;b[619427]=-10181;a[1238856]=0;c[304584]=100;yJ(1165472,6928,2240)|0;yJ(1167712,5928,1e3)|0;yJ(1169952,5928,1e3)|0;yJ(1172192,5928,1e3)|0;yJ(1174432,5928,1e3)|0;yJ(1176672,5928,1e3)|0;yJ(1178912,5928,1e3)|0;yJ(1181152,5928,1e3)|0;e=0;while(1){f=1183408+(e*40|0)|0;c[f>>2]=65535;c[f+4>>2]=0;c[1183424+(e*40|0)>>2]=-1;f=e+1|0;if(f>>>0<56){e=f}else{h=0;break}}while(1){e=1185648+(h*40|0)|0;c[e>>2]=65535;c[e+4>>2]=0;c[1185664+(h*40|0)>>2]=-1;e=h+1|0;if(e>>>0<56){h=e}else{j=0;break}}while(1){h=1187888+(j*40|0)|0;c[h>>2]=65535;c[h+4>>2]=0;c[1187904+(j*40|0)>>2]=-1;h=j+1|0;if(h>>>0<56){j=h}else{k=0;break}}while(1){j=1190128+(k*40|0)|0;c[j>>2]=65535;c[j+4>>2]=0;c[1190144+(k*40|0)>>2]=-1;j=k+1|0;if(j>>>0<56){k=j}else{l=0;break}}while(1){k=1192368+(l*40|0)|0;c[k>>2]=65535;c[k+4>>2]=0;c[1192384+(l*40|0)>>2]=-1;k=l+1|0;if(k>>>0<56){l=k}else{m=0;break}}while(1){l=1194608+(m*40|0)|0;c[l>>2]=65535;c[l+4>>2]=0;c[1194624+(m*40|0)>>2]=-1;l=m+1|0;if(l>>>0<56){m=l}else{n=0;break}}while(1){m=1196848+(n*40|0)|0;c[m>>2]=65535;c[m+4>>2]=0;c[1196864+(n*40|0)>>2]=-1;m=n+1|0;if(m>>>0<56){n=m}else{o=0;break}}while(1){n=1199088+(o*40|0)|0;c[n>>2]=65535;c[n+4>>2]=0;c[1199104+(o*40|0)>>2]=-1;n=o+1|0;if(n>>>0<56){o=n}else{q=0;break}}while(1){if((a[1165472+(q*40|0)|0]&1)!=0){if((q|0)!=(c[1165476+(q*40|0)>>2]|0)){break}}o=q+1|0;if((o|0)<56){q=o}else{r=0;s=1642;break}}L2162:do{if((s|0)==1642){while(1){s=0;if((a[1167712+(r*40|0)|0]&1)!=0){if((r|0)!=(c[1167716+(r*40|0)>>2]|0)){break L2162}}q=r+1|0;if((q|0)<56){r=q;s=1642}else{t=0;break}}while(1){if((a[1169952+(t*40|0)|0]&1)!=0){if((t|0)!=(c[1169956+(t*40|0)>>2]|0)){break L2162}}q=t+1|0;if((q|0)<56){t=q}else{u=0;break}}while(1){if((a[1172192+(u*40|0)|0]&1)!=0){if((u|0)!=(c[1172196+(u*40|0)>>2]|0)){break L2162}}q=u+1|0;if((q|0)<56){u=q}else{v=0;break}}while(1){if((a[1174432+(v*40|0)|0]&1)!=0){if((v|0)!=(c[1174436+(v*40|0)>>2]|0)){break L2162}}q=v+1|0;if((q|0)<56){v=q}else{w=0;break}}while(1){if((a[1176672+(w*40|0)|0]&1)!=0){if((w|0)!=(c[1176676+(w*40|0)>>2]|0)){break L2162}}q=w+1|0;if((q|0)<56){w=q}else{x=0;break}}while(1){if((a[1178912+(x*40|0)|0]&1)!=0){if((x|0)!=(c[1178916+(x*40|0)>>2]|0)){break L2162}}q=x+1|0;if((q|0)<56){x=q}else{y=0;break}}do{if((a[1181152+(y*40|0)|0]&1)!=0){if((y|0)!=(c[1181156+(y*40|0)>>2]|0)){break L2162}}y=y+1|0;}while((y|0)<56);g[300330]=.5;a[1201934]=1;c[300484]=6;c[300485]=3;g[301510]=1.0;g[301511]=1.0;a[1201932]=0;a[1201933]=1;c[300331]=0;c[300332]=1;c[300333]=2;c[300334]=3;c[300335]=4;c[300336]=5;c[300337]=6;c[300338]=7;a[1400542]=0;yG(1400476,0,16);a[1400444]=1;gj();i=d;return}}while(0);d=c[350134]|0;en(((d|0)!=0?d:c[p>>2]|0)|0,66552,(d=i,i=i+16|0,c[d>>2]=58512,c[d+8>>2]=251,d)|0)|0;i=d;d=c[350134]|0;a_(((d|0)!=0?d:c[p>>2]|0)|0)|0;ck(2)}function hN(){var b=0,d=0,e=0,f=0,g=0,h=0;b=i;if((a[1400444]&1)!=0){i=b;return}hM();d=(a[1243488]&1)!=0;L2204:do{if((a[1264018]|0)==0){if(d){e=c[350134]|0;f=(e|0)!=0?e:c[p>>2]|0;a5(97088,35,1,f|0)|0;f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0}e=hO(0)|0;do{if((a[1264018]|0)!=0){if((a[1243488]&1)==0){break}f=c[350134]|0;g=(f|0)!=0?f:c[p>>2]|0;en(g|0,96896,(h=i,i=i+8|0,c[h>>2]=1264018,h)|0)|0;i=h;g=c[350134]|0;f=(g|0)!=0?g:c[p>>2]|0;a_(f|0)|0;if(!e){break L2204}i=b;return}}while(0);if(!e){break}i=b;return}else{if(d){f=c[350134]|0;g=(f|0)!=0?f:c[p>>2]|0;en(g|0,97288,(h=i,i=i+8|0,c[h>>2]=1264018,h)|0)|0;i=h;g=c[350134]|0;f=(g|0)!=0?g:c[p>>2]|0;a_(f|0)|0}if(!(hO(1264018)|0)){break}i=b;return}}while(0);b=c[350134]|0;en(((b|0)!=0?b:c[p>>2]|0)|0,96704,(h=i,i=i+8|0,c[h>>2]=1264018,h)|0)|0;i=h;b=c[350134]|0;a_(((b|0)!=0?b:c[p>>2]|0)|0)|0;if((a[1400541]&1)==0){b=c[350134]|0;d=(b|0)!=0?b:c[p>>2]|0;en(d|0,66552,(h=i,i=i+16|0,c[h>>2]=96432,c[h+8>>2]=832,h)|0)|0;i=h;h=c[350134]|0;d=(h|0)!=0?h:c[p>>2]|0;a_(d|0)|0;ck(2)}else{i5(1400543,96552,1024)|0;eQ(1401568,1)}}function hO(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0.0,aQ=0.0;e=i;i=i+12920|0;f=e+4096|0;h=e+4104|0;j=e+8200|0;k=e+12296|0;l=e+12304|0;m=e+12312|0;n=e+12320|0;o=e+12328|0;q=e+12336|0;r=e+12344|0;s=e+12352|0;t=e+12360|0;u=e+12368|0;v=e+12376|0;w=e+12384|0;x=e+12392|0;y=e+12400|0;z=e+12408|0;A=e+12416|0;B=e+12424|0;C=e+12432|0;D=e+12440|0;E=e+12448|0;F=e+12456|0;G=e+12464|0;H=e+12472|0;I=e+12480|0;J=e+12488|0;K=e+12496|0;L=e+12504|0;M=e+12512|0;N=e+12520|0;O=e+12528|0;P=e+12536|0;Q=e+12544|0;R=e+12552|0;S=e+12560|0;T=e+12568|0;U=e+12576|0;V=e+12584|0;W=e+12592|0;X=e+12600|0;Y=e+12608|0;Z=e+12672|0;_=e+12680|0;$=e+12688|0;aa=e+12696|0;ab=e+12704|0;ac=e+12712|0;ad=e+12720|0;ae=e+12728|0;af=e+12736|0;ag=e+12744|0;ah=e+12752|0;ai=e+12760|0;aj=e+12768|0;ak=e+12776|0;al=e+12784|0;am=e+12792|0;an=e+12800|0;ao=e+12808|0;ap=e+12816|0;aq=e+12824|0;ar=e+12832|0;as=e+12840|0;at=e+12848|0;au=e+12856|0;av=e+12864|0;aw=e+12872|0;ax=e+12880|0;ay=e+12888|0;az=e+12896|0;aA=e+12904|0;aB=e+12912|0;do{if((d|0)==0){aC=e|0;aD=dM(98896)|0;aE=dM(98824)|0;do{if((aD|0)==0){if((aE|0)==0){aF=1703;break}bR(aC|0,4096,98640,(aG=i,i=i+8|0,c[aG>>2]=aE,aG)|0)|0;i=aG;aF=1696}else{bR(aC|0,4096,98736,(aG=i,i=i+8|0,c[aG>>2]=aD,aG)|0)|0;i=aG;aF=1696}}while(0);if((aF|0)==1696){if((a[1243488]&1)!=0){aD=c[350134]|0;aH=(aD|0)!=0?aD:c[p>>2]|0;en(aH|0,98224,(aG=i,i=i+8|0,c[aG>>2]=aC,aG)|0)|0;i=aG;aH=c[350134]|0;aD=(aH|0)!=0?aH:c[p>>2]|0;a_(aD|0)|0}aD=hs(aC)|0;if((aD|0)!=0|(aE|0)==0){aI=aD}else{bR(aC|0,4096,97816,(aG=i,i=i+8|0,c[aG>>2]=aE,aG)|0)|0;i=aG;if((a[1243488]&1)!=0){aD=c[350134]|0;aH=(aD|0)!=0?aD:c[p>>2]|0;en(aH|0,98224,(aG=i,i=i+8|0,c[aG>>2]=aC,aG)|0)|0;i=aG;aH=c[350134]|0;aD=(aH|0)!=0?aH:c[p>>2]|0;a_(aD|0)|0}aI=hs(aC)|0}if((aI|0)==0){aF=1703}else{aJ=aI}}do{if((aF|0)==1703){g5(aC,97680,97408,4096);if((a[1243488]&1)!=0){aD=c[350134]|0;aH=(aD|0)!=0?aD:c[p>>2]|0;en(aH|0,98224,(aG=i,i=i+8|0,c[aG>>2]=aC,aG)|0)|0;i=aG;aH=c[350134]|0;aD=(aH|0)!=0?aH:c[p>>2]|0;a_(aD|0)|0}aD=hs(aC)|0;if((aD|0)==0){aK=1}else{aJ=aD;break}i=e;return aK|0}}while(0);i5(1264018,aC,4096)|0;if((aJ|0)==0){aK=1}else{aL=aJ;break}i=e;return aK|0}else{aE=hs(d)|0;if((aE|0)==0){aK=0}else{aL=aE;break}i=e;return aK|0}}while(0);d=h|0;i5(d,1268114,4096)|0;h=ej(d|0,52824,f|0)|0;d=(a[1243488]&1)!=0;if((h|0)==0){aM=d}else{aJ=h;h=d;while(1){if(h){d=c[350134]|0;aF=(d|0)!=0?d:c[p>>2]|0;en(aF|0,49080,(aG=i,i=i+8|0,c[aG>>2]=aJ,aG)|0)|0;i=aG;aF=c[350134]|0;d=(aF|0)!=0?aF:c[p>>2]|0;a_(d|0)|0}if(!(hr(aL,aJ)|0)){d=c[350134]|0;aF=(d|0)!=0?d:c[p>>2]|0;en(aF|0,44832,(aG=i,i=i+8|0,c[aG>>2]=aJ,aG)|0)|0;i=aG;aF=c[350134]|0;d=(aF|0)!=0?aF:c[p>>2]|0;a_(d|0)|0}d=ej(0,40728,f|0)|0;aF=(a[1243488]&1)!=0;if((d|0)==0){aM=aF;break}else{aJ=d;h=aF}}}do{if(aM){h=c[350134]|0;aJ=(h|0)!=0?h:c[p>>2]|0;a5(37280,15,1,aJ|0)|0;aJ=c[350134]|0;h=(aJ|0)!=0?aJ:c[p>>2]|0;a_(h|0)|0;hL(aL,c[p>>2]|0);if((a[1243488]&1)==0){break}h=c[350134]|0;aJ=(h|0)!=0?h:c[p>>2]|0;a5(107528,19,1,aJ|0)|0;aJ=c[350134]|0;h=(aJ|0)!=0?aJ:c[p>>2]|0;a_(h|0)|0}}while(0);g[k>>2]=0.0;if(hx(aL,103928,k)|0){g[285158]=+g[k>>2]}g[l>>2]=0.0;if(hx(aL,100912,l)|0){g[285159]=+g[l>>2]}c[m>>2]=0;if(hy(aL,99192,m)|0){c[285162]=c[m>>2]}c[n>>2]=0;if(hy(aL,97424,n)|0){c[285163]=c[n>>2]}do{if((a[1243491]&1)==0){a[o]=0;if(!(hE(aL,95032,o)|0)){break}a[1140640]=a[o]&1}}while(0);a[q]=0;if(hE(aL,93328,q)|0){a[1140641]=a[q]&1}c[r>>2]=0;if(hy(aL,91568,r)|0){c[285161]=c[r>>2]}a[s]=0;if(hE(aL,89816,s)|0){a[1157108]=a[s]&1}a[t]=0;if(hE(aL,88080,t)|0){a[1140656]=a[t]&1}a[u]=0;if(hE(aL,86392,u)|0){a[1140657]=a[u]&1}c[v>>2]=0;if(hy(aL,84240,v)|0){u=c[v>>2]|0;c[285166]=u;aN=u}else{aN=c[285166]|0}if(aN>>>0>3){c[285166]=3}a[w]=0;if(hE(aL,81736,w)|0){a[1140658]=a[w]&1}c[x>>2]=0;if(hy(aL,79960,x)|0){w=c[x>>2]|0;c[285165]=w;aO=w}else{aO=c[285165]|0}w=aO>>>0>1?aO:1;c[285165]=w>>>0<4?w:4;a[y]=0;if(hE(aL,78208,y)|0){a[1148884]=a[y]&1}a[z]=0;if(hE(aL,77008,z)|0){a[1140668]=a[z]&1}a[A]=0;if(hE(aL,75488,A)|0){a[1140669]=a[A]&1}a[B]=0;if(hE(aL,74536,B)|0){a[1140677]=a[B]&1}a[C]=0;if(hE(aL,73552,C)|0){a[1140670]=a[C]&1}g[D>>2]=0.0;if(hx(aL,72592,D)|0){g[285168]=+g[D>>2]}c[E>>2]=0;if(hy(aL,71648,E)|0){c[285170]=c[E>>2]}a[F]=0;if(hE(aL,70248,F)|0){a[1140676]=a[F]&1}g[G>>2]=0.0;if(hx(aL,68696,G)|0){g[287220]=+g[G>>2]}hD(aL,67616,1140684,4096)|0;a[H]=0;if(hE(aL,66504,H)|0){a[1144780]=a[H]&1}a[I]=0;if(hE(aL,65616,I)|0){a[1157112]=a[I]&1}hD(aL,64712,1152981,4096)|0;g[J>>2]=0.0;if(hx(aL,63936,J)|0){g[289270]=+g[J>>2]}a[K]=0;if(hE(aL,63040,K)|0){a[1157084]=a[K]&1}a[L]=0;if(hE(aL,62512,L)|0){a[1157085]=a[L]&1}g[M>>2]=0.0;if(hx(aL,61736,M)|0){g[289272]=+g[M>>2]}g[N>>2]=0.0;if(hx(aL,60592,N)|0){g[289273]=+g[N>>2]}c[O>>2]=0;if(hy(aL,59472,O)|0){c[350119]=c[O>>2]}c[P>>2]=0;if(hy(aL,59008,P)|0){c[350120]=c[P>>2]}c[Q>>2]=0;if(hy(aL,58480,Q)|0){c[350121]=c[Q>>2]}c[R>>2]=0;if(hy(aL,57936,R)|0){c[350122]=c[R>>2]}c[S>>2]=0;if(hA(aL,57408,S)|0){R=c[S>>2]|0;g[289274]=+((R>>>16&255)>>>0>>>0)/255.0;g[289275]=+((R>>>8&255)>>>0>>>0)/255.0;g[289276]=+((R&255)>>>0>>>0)/255.0}a[T]=0;if(hE(aL,56936,T)|0){a[1157109]=a[T]&1}a[U]=0;if(hE(aL,56488,U)|0){a[1157110]=a[U]&1}a[V]=0;if(hE(aL,56096,V)|0){a[1157111]=a[V]&1}hD(aL,55536,1148885,4096)|0;if((cS(1148885,54696)|0)==0){a[1148885]=0}g[W>>2]=0.0;if(hx(aL,53704,W)|0){g[300330]=+g[W>>2]}a[X]=0;if(hE(aL,53176,X)|0){a[1201934]=a[X]&1}X=Y|0;bR(X|0,64,52784,(aG=i,i=i+8|0,c[aG>>2]=1,aG)|0)|0;i=aG;c[Z>>2]=0;if(hy(aL,X,Z)|0){c[300331]=c[Z>>2]}bR(X|0,64,52784,(aG=i,i=i+8|0,c[aG>>2]=2,aG)|0)|0;i=aG;c[Z>>2]=0;if(hy(aL,X,Z)|0){c[300332]=c[Z>>2]}bR(X|0,64,52784,(aG=i,i=i+8|0,c[aG>>2]=3,aG)|0)|0;i=aG;c[Z>>2]=0;if(hy(aL,X,Z)|0){c[300333]=c[Z>>2]}bR(X|0,64,52784,(aG=i,i=i+8|0,c[aG>>2]=4,aG)|0)|0;i=aG;c[Z>>2]=0;if(hy(aL,X,Z)|0){c[300334]=c[Z>>2]}bR(X|0,64,52784,(aG=i,i=i+8|0,c[aG>>2]=5,aG)|0)|0;i=aG;c[Z>>2]=0;if(hy(aL,X,Z)|0){c[300335]=c[Z>>2]}bR(X|0,64,52784,(aG=i,i=i+8|0,c[aG>>2]=6,aG)|0)|0;i=aG;c[Z>>2]=0;if(hy(aL,X,Z)|0){c[300336]=c[Z>>2]}bR(X|0,64,52784,(aG=i,i=i+8|0,c[aG>>2]=7,aG)|0)|0;i=aG;c[Z>>2]=0;if(hy(aL,X,Z)|0){c[300337]=c[Z>>2]}bR(X|0,64,52784,(aG=i,i=i+8|0,c[aG>>2]=8,aG)|0)|0;i=aG;c[Z>>2]=0;if(hy(aL,X,Z)|0){c[300338]=c[Z>>2]}a[_]=0;if(hE(aL,52456,_)|0){a[1157148]=a[_]&1}c[$>>2]=0;if(hy(aL,52224,$)|0){c[289288]=c[$>>2]}c[aa>>2]=0;if(hy(aL,51888,aa)|0){c[289289]=c[aa>>2]}hC(aL,51528,1157164,4096)|0;c[ab>>2]=0;if(hy(aL,51264,ab)|0){c[290315]=c[ab>>2]}a[ac]=0;if(hE(aL,51048,ac)|0){a[1161264]=a[ac]&1}a[ad]=0;if(hE(aL,50408,ad)|0){a[1165361]=a[ad]&1}g[ae>>2]=0.0;if(hx(aL,49752,ae)|0){g[291341]=+g[ae>>2]}g[af>>2]=0.0;if(hx(aL,49448,af)|0){g[291342]=+g[af>>2]}hC(aL,49040,1140568,32)|0;hC(aL,48744,1140600,32)|0;hC(aL,48496,1157116,32)|0;hD(aL,48176,1161265,4096)|0;hC(aL,47752,1165408,32)|0;hC(aL,47520,1165440,32)|0;if((a[1218340]|0)==0){hD(aL,47208,1218340,4096)|0}hD(aL,46536,1210144,4096)|0;hD(aL,45680,1230628,4096)|0;do{if((a[1230628]|0)!=0){if(g_(1230628)|0){break}af=c[350134]|0;ae=(af|0)!=0?af:c[p>>2]|0;a5(45200,84,1,ae|0)|0;ae=c[350134]|0;af=(ae|0)!=0?ae:c[p>>2]|0;a_(af|0)|0;a[1230628]=0}}while(0);hD(aL,44800,1238857,4096)|0;if((cS(1238857,54696)|0)==0){a[1238857]=0}hD(aL,44568,1321362,4096)|0;if((cS(1321362,54696)|0)==0){a[1321362]=0}hD(aL,44272,1201944,4096)|0;g[ag>>2]=0.0;if(hx(aL,43928,ag)|0){g[301510]=+g[ag>>2]}g[ah>>2]=0.0;if(hx(aL,43640,ah)|0){g[301511]=+g[ah>>2]}a[ai]=0;if(hE(aL,43272,ai)|0){a[1238820]=a[ai]&1}c[aj>>2]=0;if(hy(aL,42872,aj)|0){c[309706]=(c[aj>>2]|0)*1e6|0}c[ak>>2]=0;if(hy(aL,42296,ak)|0){c[309707]=c[ak>>2]}g[al>>2]=0.0;if(hx(aL,41488,al)|0){aP=+g[al>>2];g[309708]=aP;aQ=aP}else{aQ=+g[309708]}if(aQ<1.0){g[309708]=1.0}g[am>>2]=0.0;if(hx(aL,41120,am)|0){g[309709]=+g[am>>2]}a[an]=0;if(hE(aL,40664,an)|0){a[1238840]=a[an]&1}c[ao>>2]=0;if(hy(aL,40384,ao)|0){c[309711]=c[ao>>2]}hD(aL,40160,1222436,4096)|0;hD(aL,39904,1226532,4096)|0;a[ap]=0;if(hE(aL,39568,ap)|0){a[1238848]=a[ap]&1}a[aq]=0;if(hE(aL,39272,aq)|0){a[1238849]=a[aq]&1}a[ar]=0;if(hE(aL,39024,ar)|0){a[1238850]=a[ar]&1}a[as]=0;if(hE(aL,38584,as)|0){a[1238851]=a[as]&1}a[at]=0;if(hE(aL,37832,at)|0){a[1238852]=a[at]&1}c[au>>2]=0;if(hy(aL,37576,au)|0){b[619427]=c[au>>2]&65535}a[av]=0;if(hE(aL,37216,av)|0){a[1238856]=a[av]&1}hD(aL,37e3,1214240,4096)|0;c[aw>>2]=0;if(hy(aL,36840,aw)|0){c[304584]=c[aw>>2]}c[ax>>2]=0;if(hy(aL,36616,ax)|0){c[300484]=c[ax>>2]}c[ay>>2]=0;if(hy(aL,36384,ay)|0){c[300485]=c[ay>>2]}a[az]=0;if(hE(aL,36128,az)|0){a[1201932]=a[az]&1}a[aA]=0;if(hE(aL,109048,aA)|0){a[1201933]=a[aA]&1}hD(aL,108608,1206048,4096)|0;a[aB]=0;if(hE(aL,107960,aB)|0){a[1400542]=a[aB]&1}do{if((a[1264016]&1)==0){aB=j|0;if(!(hD(aL,107736,aB,4096)|0)){break}if((cS(aB|0,54696)|0)==0){a[1313170]=0;break}if(g_(aB)|0){i5(1313170,aB,4096)|0;i5(1284498,aB,4096)|0;g8(1284498,1276306,107504,4096);break}else{aB=c[350134]|0;aA=(aB|0)!=0?aB:c[p>>2]|0;a5(107272,72,1,aA|0)|0;aA=c[350134]|0;aB=(aA|0)!=0?aA:c[p>>2]|0;a_(aB|0)|0;break}}}while(0);do{if((a[1264017]&1)==0){aB=j|0;if(!(hD(aL,107104,aB,4096)|0)){break}if((cS(aB|0,54696)|0)==0){a[1317266]=0;break}if(g_(aB)|0){i5(1317266,aB,4096)|0;i5(1304978,aB,4096)|0;g8(1304978,1276306,106904,4096);break}else{aB=c[350134]|0;aA=(aB|0)!=0?aB:c[p>>2]|0;a5(106592,73,1,aA|0)|0;aA=c[350134]|0;aB=(aA|0)!=0?aA:c[p>>2]|0;a_(aB|0)|0;break}}}while(0);if(!(hD(aL,106200,1234724,4096)|0)){j=c[350134]|0;aB=(j|0)!=0?j:c[p>>2]|0;en(aB|0,105800,(aG=i,i=i+8|0,c[aG>>2]=1234724,aG)|0)|0;i=aG;aG=c[350134]|0;aB=(aG|0)!=0?aG:c[p>>2]|0;a_(aB|0)|0}if((cS(1234724,54696)|0)==0){a[1234724]=0}hQ(aL);ht(aL);aK=1;i=e;return aK|0}function hP(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,i=0.0,j=0.0,k=0.0,l=0,m=0,n=0;e=c[285170]|0;if(((b&1|0)!=0|(d&0|0)!=0)&(e|0)!=0){f=e-1|0;c[285170]=f;h=f}else{h=e}if(((b&2|0)!=0|(d&0|0)!=0)&h>>>0<7){c[285170]=h+1}if(!((b&4|0)==0&(d&0|0)==0)){a[1140677]=a[1140677]&1^1}if(!((b&8|0)==0&(d&0|0)==0)){a[1342617]=a[1342617]&1^1}do{if(!((b&16|0)==0&(d&0|0)==0)){i=+g[291341];if(i>0.0){j=i+-.001;g[291341]=j;k=j}else{k=i}if(k<5.0e-4){a[1165361]=0;g[291341]=0.0;break}else{a[1165361]=1;break}}}while(0);if(!((b&32|0)==0&(d&0|0)==0)){k=+g[291341];if(k<.2){g[291341]=k+.001}a[1165361]=1}if(!((b&64|0)==0&(d&0|0)==0)){h=1400520;e=c[h+4>>2]|16;f=1400520;c[f>>2]=c[h>>2];c[f+4>>2]=e;e=1400528;f=c[e+4>>2]|0;h=1400528;c[h>>2]=c[e>>2]|1;c[h+4>>2]=f}if(!((b&128|0)==0&(d&0|0)==0)){a[1140668]=a[1140668]&1^1}f=c[350112]|0;if(((b&256|0)!=0|(d&0|0)!=0)&(f|0)!=0){h=f-1|0;c[350112]=h;c[350113]=c[(c[350116]|0)+(h<<2)>>2];l=h}else{l=f}do{if(!((b&512|0)==0&(d&0|0)==0)){f=l+1|0;if(f>>>0>=(c[350117]|0)>>>0){break}c[350112]=f;c[350113]=c[(c[350116]|0)+(f<<2)>>2]}}while(0);l=c[350125]|0;if(((b&1024|0)!=0|(d&0|0)!=0)&(l|0)!=0){f=l-1|0;c[350125]=f;m=f}else{m=l}if(((b&2048|0)!=0|(d&0|0)!=0)&m>>>0<3){c[350125]=m+1}if(!((b&4096|0)==0&(d&0|0)==0)){a[1238820]=a[1238820]&1^1}m=c[334438]|0;if(((b&8192|0)!=0|(d&0|0)!=0)&(m|0)!=0){l=m-1|0;c[334438]=l;n=l}else{n=m}if(!((b&16384|0)==0&(d&0|0)==0)){c[334438]=n+1}do{if(!((b&32768|0)==0&(d&0|0)==0)){n=1400528;m=c[n>>2]|0;l=c[n+4>>2]|0;if((m&16384|0)==0&(l&0|0)==0){n=1400528;c[n>>2]=m|16384;c[n+4>>2]=l;break}else{n=1400528;c[n>>2]=m&-16385;c[n+4>>2]=l|0;break}}}while(0);if(!((b&65536|0)==0&(d&0|0)==0)){g[287220]=+g[287220]+-.009999999776482582}if(!((b&131072|0)==0&(d&0|0)==0)){g[287220]=+g[287220]+.009999999776482582}do{if(!((b&262144|0)==0&(d&0|0)==0)){l=1400528;n=c[l>>2]|0;m=c[l+4>>2]|0;if((n&256|0)==0&(m&0|0)==0){l=1400528;c[l>>2]=n|256;c[l+4>>2]=m;break}else{l=1400528;c[l>>2]=n&-257;c[l+4>>2]=m|0;break}}}while(0);do{if(!((b&524288|0)==0&(d&0|0)==0)){m=1400528;l=c[m>>2]|0;n=c[m+4>>2]|0;if((l&128|0)==0&(n&0|0)==0){m=1400528;c[m>>2]=l|128;c[m+4>>2]=n;break}else{m=1400528;c[m>>2]=l&-129;c[m+4>>2]=n|0;break}}}while(0);if(!((b&1048576|0)==0&(d&0|0)==0)){c[285170]=4}if(!((b&2097152|0)==0&(d&0|0)==0)){a[1140677]=0}if(!((b&4194304|0)==0&(d&0|0)==0)){a[1342617]=0}if(!((b&8388608|0)==0&(d&0|0)==0)){g[291341]=.004999999888241291;a[1165361]=1}if(!((b&16777216|0)==0&(d&0|0)==0)){a[1140668]=1}if(!((b&33554432|0)==0&(d&0|0)==0)){c[350125]=0}if(!((b&67108864|0)==0&(d&0|0)==0)){n=1400528;m=c[n+4>>2]|0;l=1400528;c[l>>2]=c[n>>2]|16384;c[l+4>>2]=m}if(!((b&134217728|0)==0&(d&0|0)==0)){c[334438]=0}if(!((b&268435456|0)==0&(d&0|0)==0)){g[287220]=59.95000076293945}if(!((b&536870912|0)==0&(d&0|0)==0)){m=1400528;l=c[m+4>>2]|0;n=1400528;c[n>>2]=c[m>>2]&-257;c[n+4>>2]=l}if((b&1073741824|0)==0&(d&0|0)==0){return}d=1400528;b=c[d+4>>2]|0;l=1400528;c[l>>2]=c[d>>2]|128;c[l+4>>2]=b;return}function hQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[17344]&1)==0){return}else{d=0}do{e=0;f=17344;do{g=1165472+(d*2240|0)+(e*40|0)|0;do{if((a[g|0]&1)!=0){h=c[17352+(e*20|0)>>2]|0;if((h|0)==0){break}i=(c[17348+(e*20|0)>>2]|0)!=0;j=iF(d,i)|0;if((j|0)!=0){iM(b,j,h,g)}j=(a[f]&1)==0;do{if(j){k=j?h:0}else{l=iF(d,i)|0;if((l|0)==0){k=h;break}iN(b,l,h,g);k=h}}while(0);if((a[f]&1)==0|(k|0)==0){break}h=iF(d,(c[17348+(e*20|0)>>2]|0)!=0)|0;if((h|0)==0){break}iO(b,h,k,g)}}while(0);e=e+1|0;f=17344+(e*20|0)|0;}while((a[f]&1)!=0);d=d+1|0;}while(d>>>0<8);return}function hR(b){b=b|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+64|0;f=e|0;h=hs(b)|0;do{if((h|0)==0){j=hs(0)|0;if((j|0)==0){k=0}else{l=j;break}i=e;return k|0}else{l=h}}while(0);if((a[1243488]&1)!=0){h=c[350134]|0;j=(h|0)!=0?h:c[p>>2]|0;en(j|0,105336,(m=i,i=i+8|0,c[m>>2]=b,m)|0)|0;i=m;j=c[350134]|0;h=(j|0)!=0?j:c[p>>2]|0;a_(h|0)|0}hF(l,47208,1218340);hF(l,40160,1222436);hJ(l,43272,(a[1238820]&1)!=0);hH(l,42296,c[309707]|0);hF(l,67616,1140684);hJ(l,66504,(a[1144780]&1)!=0);hG(l,72592,+g[285168]);hG(l,103928,+g[285158]);hG(l,100912,+g[285159]);hJ(l,73552,(a[1140670]&1)!=0);hJ(l,74536,(a[1140677]&1)!=0);hJ(l,77008,(a[1140668]&1)!=0);hG(l,68696,+g[287220]);hJ(l,88080,(a[1140656]&1)!=0);hJ(l,86392,(a[1140657]&1)!=0);hH(l,84240,c[285166]|0);hJ(l,81736,(a[1140658]&1)!=0);hH(l,79960,c[285165]|0);hH(l,71648,c[285170]|0);hF(l,51528,1157164);hJ(l,50408,(a[1165361]&1)!=0);hG(l,49752,+g[291341]);if((a[1234724]|0)==0){hF(l,106200,54696)}else{hF(l,106200,1234724)}if((a[1313170]|0)==0){hF(l,107736,54696)}else{hF(l,107736,1313170)}if((a[1317266]|0)==0){hF(l,107104,54696)}else{hF(l,107104,1317266)}if((a[1148885]|0)==0){hF(l,55536,54696)}else{hF(l,55536,1148885)}if((a[1238857]|0)==0){hF(l,44800,54696)}else{hF(l,44800,1238857)}if((a[1321362]|0)==0){hF(l,44568,54696)}else{hF(l,44568,1321362)}hF(l,44272,1201944);hG(l,43928,+g[301510]);hG(l,43640,+g[301511]);hJ(l,104608,(c[350126]|0)!=0);h=1400528;if((c[h>>2]&16384|0)==0&(c[h+4>>2]&0|0)==0){hJ(l,104320,0)}else{hJ(l,104320,1)}h=1400528;if((c[h>>2]&128|0)==0&(c[h+4>>2]&0|0)==0){hJ(l,103896,0)}else{hJ(l,103896,1)}h=1400528;if((c[h>>2]&65536|0)==0&(c[h+4>>2]&0|0)==0){hJ(l,103744,0)}else{hJ(l,103744,1)}h=1400528;if((c[h>>2]&32768|0)==0&(c[h+4>>2]&0|0)==0){hJ(l,103512,0)}else{hJ(l,103512,1)}hH(l,103128,d[1400508]|0);hH(l,102896,d[1400509]|0);hH(l,102720,c[350113]|0);hH(l,58480,c[350121]|0);hH(l,57936,c[350122]|0);hH(l,59472,c[350119]|0);hH(l,59008,c[350120]|0);hG(l,63936,+g[289270]);hJ(l,107960,(a[1400542]&1)!=0);hH(l,102520,c[350128]|0);hH(l,102064,c[334438]|0);hH(l,101624,a[1342617]&1);hH(l,101192,c[350125]|0);h=1400528;if((c[h>>2]&524288|0)==0&(c[h+4>>2]&0|0)==0){hJ(l,100888,0)}else{hJ(l,100888,1)}h=f|0;f=0;while(1){j=f+1|0;bR(h|0,64,100800,(m=i,i=i+8|0,c[m>>2]=j,m)|0)|0;i=m;hH(l,h,c[1201900+(f<<2)>>2]|0);bR(h|0,64,100680,(m=i,i=i+8|0,c[m>>2]=j,m)|0)|0;i=m;hH(l,h,c[1201356+(f<<2)>>2]|0);bR(h|0,64,52784,(m=i,i=i+8|0,c[m>>2]=j,m)|0)|0;i=m;hH(l,h,c[1201324+(f<<2)>>2]|0);if(j>>>0<8){f=j}else{break}}hK(l,b)|0;ht(l);k=1;i=e;return k|0}function hS(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+400|0;h=g|0;j=g+368|0;k=h;yG(k|0,0,360);l=h+324|0;yJ(l|0,112200,32)|0;l=h+360|0;c[l>>2]=f;c[l+4>>2]=0;m=h+64|0;if((f|0)==0){n=0}else{o=f;f=e;e=0;while(1){p=64-e|0;q=o>>>0<p>>>0?o:p;p=k+e|0;yJ(p|0,f|0,q)|0;p=q+(c[m>>2]|0)|0;c[m>>2]=p;if((p|0)==64){hT(h)}p=c[m>>2]|0;if((o|0)==(q|0)){n=p;break}else{o=o-q|0;f=f+q|0;e=p}}}c[m>>2]=n+1;a[h+n|0]=-128;n=c[m>>2]|0;if(n>>>0>56){yG(k+n|0,0,64-n|0);hT(h);r=c[m>>2]|0}else{r=n}yG(k+r|0,0,56-r|0);r=c[l>>2]|0;c[h+56>>2]=d5(r>>>29|c[l+4>>2]<<3|0)|0;c[h+60>>2]=d5(r<<3|0>>>29|0)|0;hT(h);c[j>>2]=d5(c[h+324>>2]|0)|0;c[j+4>>2]=d5(c[h+328>>2]|0)|0;c[j+8>>2]=d5(c[h+332>>2]|0)|0;c[j+12>>2]=d5(c[h+336>>2]|0)|0;c[j+16>>2]=d5(c[h+340>>2]|0)|0;c[j+20>>2]=d5(c[h+344>>2]|0)|0;c[j+24>>2]=d5(c[h+348>>2]|0)|0;c[j+28>>2]=d5(c[h+352>>2]|0)|0;h=j;j=0;do{bR(b+(j<<1)|0,3,49056,(r=i,i=i+8|0,c[r>>2]=d[h+j|0]|0,r)|0)|0;i=r;j=j+1|0;}while(j>>>0<32);i=g;return}function hT(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=d5(c[a>>2]|0)|0;c[a+68>>2]=b;c[a+72>>2]=d5(c[a+4>>2]|0)|0;c[a+76>>2]=d5(c[a+8>>2]|0)|0;c[a+80>>2]=d5(c[a+12>>2]|0)|0;c[a+84>>2]=d5(c[a+16>>2]|0)|0;c[a+88>>2]=d5(c[a+20>>2]|0)|0;c[a+92>>2]=d5(c[a+24>>2]|0)|0;c[a+96>>2]=d5(c[a+28>>2]|0)|0;c[a+100>>2]=d5(c[a+32>>2]|0)|0;c[a+104>>2]=d5(c[a+36>>2]|0)|0;c[a+108>>2]=d5(c[a+40>>2]|0)|0;c[a+112>>2]=d5(c[a+44>>2]|0)|0;c[a+116>>2]=d5(c[a+48>>2]|0)|0;c[a+120>>2]=d5(c[a+52>>2]|0)|0;c[a+124>>2]=d5(c[a+56>>2]|0)|0;c[a+128>>2]=d5(c[a+60>>2]|0)|0;d=16;e=b;while(1){b=c[a+68+(d-15<<2)>>2]|0;f=c[a+68+(d-2<<2)>>2]|0;c[a+68+(d<<2)>>2]=(c[a+68+(d-7<<2)>>2]|0)+e+((b>>>18|b<<14)^b>>>3^(b>>>7|b<<25))+((f>>>19|f<<13)^f>>>10^(f>>>17|f<<15));f=d+1|0;if(f>>>0<64){d=f;e=b}else{break}}e=a+324|0;d=c[e>>2]|0;b=a+328|0;f=c[b>>2]|0;g=a+332|0;h=c[g>>2]|0;i=a+336|0;j=c[i>>2]|0;k=a+340|0;l=c[k>>2]|0;m=a+344|0;n=c[m>>2]|0;o=a+348|0;p=c[o>>2]|0;q=a+352|0;r=c[q>>2]|0;s=f;t=h;u=j;v=l;w=n;x=p;y=r;z=d;A=0;while(1){B=((v>>>6|v<<26)^(v>>>11|v<<21)^(v>>>25|v<<7))+y+(x&~v^w&v)+(c[111944+(A<<2)>>2]|0)+(c[a+68+(A<<2)>>2]|0)|0;C=B+u|0;D=((z>>>2|z<<30)^(z>>>13|z<<19)^(z>>>22|z<<10))+(z&(t^s)^t&s)+B|0;B=A+1|0;if(B>>>0<64){u=t;t=s;s=z;y=x;x=w;w=v;v=C;z=D;A=B}else{break}}c[e>>2]=d+D;c[b>>2]=f+z;c[g>>2]=h+s;c[i>>2]=j+t;c[k>>2]=l+C;c[m>>2]=n+v;c[o>>2]=p+w;c[q>>2]=r+x;c[a+64>>2]=0;return}function hU(a){a=a|0;var b=0;b=a?18:66;c[157576]=a?144:398;c[157588]=a?470:124;c[157594]=a?42:18;c[157578]=a?110:128;c[157580]=a?14:70;c[157556]=b;c[157550]=a?84:96;c[157562]=a?58:52;c[157560]=a?36:68;c[157554]=a?60:120;c[157552]=a?122:44;c[157558]=a?4:14;c[157570]=a?8:290;c[157568]=a?258:268;c[157564]=a?6:46;c[157566]=a?16:2;c[157546]=a?12:22;c[157592]=a?196:154;c[157590]=a?54:68;c[157574]=a?14:28;c[157572]=a?16:30;c[157548]=a?246:166;c[157582]=a?50:16;c[157586]=a?16:2;c[157584]=a?40:12;fs[b&255](32);return}function hV(){return 1}function hW(a,b){a=a|0;b=b|0;return}function hX(a){a=a|0;c[350652]=a;return}function hY(a){a=a|0;c[350654]=a;return}function hZ(a){a=a|0;c[350648]=a;return}function h_(a){a=a|0;c[350646]=a;return}function h$(a){a=a|0;c[350644]=a;return}function h0(){return}function h1(a){a=a|0;return 0}function h2(){return}function h3(){return 0}function h4(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function h5(){return 0}function h6(a,b){a=a|0;b=b|0;return 0}function h7(a){a=a|0;h[a+24>>3]=60.0;h[a+32>>3]=3.0e4;c[a>>2]=320;c[a+4>>2]=240;c[a+8>>2]=320;c[a+12>>2]=240;g[a+16>>2]=1.3333333730697632;return}function h8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=i;i=i+4096|0;f=e|0;if((b|0)==9){c[d>>2]=(a[1234724]|0)!=0?1234724:0;if((a[1243488]&1)==0){g=1;i=e;return g|0}h=c[350134]|0;j=(h|0)!=0?h:c[p>>2]|0;en(j|0,100608,(k=i,i=i+8|0,c[k>>2]=1234724,k)|0)|0;i=k;j=c[350134]|0;h=(j|0)!=0?j:c[p>>2]|0;a_(h|0)|0;g=1;i=e;return g|0}else if((b|0)==2){a[d]=a[1140670]&1^1;if((a[1243488]&1)==0){g=1;i=e;return g|0}h=c[350134]|0;en(((h|0)!=0?h:c[p>>2]|0)|0,93232,(k=i,i=i+8|0,c[k>>2]=(a[1140670]&1^1)&255,k)|0)|0;i=k;h=c[350134]|0;a_(((h|0)!=0?h:c[p>>2]|0)|0)|0;g=1;i=e;return g|0}else if((b|0)==6){if((a[1243488]&1)!=0){h=c[350134]|0;j=(h|0)!=0?h:c[p>>2]|0;h=c[d>>2]|0;en(j|0,40112,(k=i,i=i+8|0,c[k>>2]=h,k)|0)|0;i=k;h=c[350134]|0;j=(h|0)!=0?h:c[p>>2]|0;a_(j|0)|0}j=c[348003]|0;if((j|0)==0){g=1;i=e;return g|0}ip(j);iq(c[348003]|0,c[d>>2]|0,1,c[d+4>>2]|0);g=1;i=e;return g|0}else if((b|0)==11){yG(1337856,0,512);j=c[d+16>>2]|0;if((j|0)!=0){h=d;l=j;while(1){j=c[h>>2]|0;do{if(j>>>0<=7){if((c[h+4>>2]|0)!=1){break}m=c[h+12>>2]|0;if(m>>>0>15){break}c[1337856+(j<<6)+(m<<2)>>2]=l}}while(0);j=c[h+36>>2]|0;if((j|0)==0){break}else{h=h+20|0;l=j}}}if((a[1243488]&1)==0){n=0}else{l=c[350134]|0;h=(l|0)!=0?l:c[p>>2]|0;a5(68448,42,1,h|0)|0;h=c[350134]|0;l=(h|0)!=0?h:c[p>>2]|0;a_(l|0)|0;n=0}while(1){l=n+1|0;h=0;do{j=c[1337856+(n<<6)+(h<<2)>>2]|0;do{if((j|0)!=0){if((a[1243488]&1)==0){break}m=c[350134]|0;o=(m|0)!=0?m:c[p>>2]|0;m=c[9912+(h<<2)>>2]|0;en(o|0,67352,(k=i,i=i+24|0,c[k>>2]=l,c[k+8>>2]=m,c[k+16>>2]=j,k)|0)|0;i=k;m=c[350134]|0;o=(m|0)!=0?m:c[p>>2]|0;a_(o|0)|0}}while(0);h=h+1|0;}while(h>>>0<16);if(l>>>0<8){n=l}else{g=1;break}}i=e;return g|0}else if((b|0)==17){n=c[335642]|0;if((n|0)==0){q=0}else{q=(iW(n)|0)&1}a[d]=q;g=1;i=e;return g|0}else if((b|0)==18){q=a[d]|0;if((a[1243488]&1)==0){r=q&1}else{n=c[350134]|0;h=(n|0)!=0?n:c[p>>2]|0;n=q&1;q=n<<24>>24!=0?59408:58928;en(h|0,60376,(k=i,i=i+8|0,c[k>>2]=q,k)|0)|0;i=k;q=c[350134]|0;h=(q|0)!=0?q:c[p>>2]|0;a_(h|0)|0;r=n}a[1337854]=r;g=1;i=e;return g|0}else if((b|0)==19){c[d>>2]=0;g=1;i=e;return g|0}else if((b|0)==21){if((a[1243488]&1)!=0){r=c[350134]|0;n=(r|0)!=0?r:c[p>>2]|0;a5(58392,44,1,n|0)|0;n=c[350134]|0;r=(n|0)!=0?n:c[p>>2]|0;a_(r|0)|0}c[335636]=c[d>>2];c[1342548>>2]=c[d+4>>2];c[1342552>>2]=c[d+8>>2];c[1342556>>2]=c[d+12>>2];g=1;i=e;return g|0}else if((b|0)==7){if((a[1243488]&1)!=0){r=c[350134]|0;n=(r|0)!=0?r:c[p>>2]|0;a5(107056,29,1,n|0)|0;n=c[350134]|0;r=(n|0)!=0?n:c[p>>2]|0;a_(r|0)|0}a[1337840]=1;g=1;i=e;return g|0}else if((b|0)==14|(b|0)==65550){if((a[1243488]&1)!=0){r=c[350134]|0;n=(r|0)!=0?r:c[p>>2]|0;a5(64568,34,1,n|0)|0;n=c[350134]|0;r=(n|0)!=0?n:c[p>>2]|0;a_(r|0)|0}r=c[d>>2]|0;do{if((r|0)==0){if((a[1243488]&1)==0){break}n=c[350134]|0;h=(n|0)!=0?n:c[p>>2]|0;a5(63784,37,1,h|0)|0;h=c[350134]|0;n=(h|0)!=0?h:c[p>>2]|0;a_(n|0)|0}else if((r|0)==2){if((a[1243488]&1)!=0){n=c[350134]|0;h=(n|0)!=0?n:c[p>>2]|0;a5(62960,41,1,h|0)|0;h=c[350134]|0;n=(h|0)!=0?h:c[p>>2]|0;a_(n|0)|0}c[350657]=224}else if((r|0)==1|(r|0)==3){n=c[350134]|0;a5(62336,116,1,((n|0)!=0?n:c[p>>2]|0)|0)|0;n=c[350134]|0;a_(((n|0)!=0?n:c[p>>2]|0)|0)|0;g=0;i=e;return g|0}else{if((a[1243488]&1)==0){g=0;i=e;return g|0}n=c[350134]|0;a5(61664,39,1,((n|0)!=0?n:c[p>>2]|0)|0)|0;n=c[350134]|0;a_(((n|0)!=0?n:c[p>>2]|0)|0)|0;g=0;i=e;return g|0}}while(0);c[d+8>>2]=34;c[d+12>>2]=32;if((b&65536|0)==0){yJ(1342500,d|0,40)|0;g=1;i=e;return g|0}else{c[335625]=c[d>>2];c[1342504>>2]=c[d+4>>2];c[1342508>>2]=c[d+8>>2];c[1342512>>2]=c[d+12>>2];a[1342516|0]=a[d+16|0]|0;g=1;i=e;return g|0}}else if((b|0)==1){r=c[d>>2]|0;if((a[1243488]&1)!=0){n=c[350134]|0;h=(n|0)!=0?n:c[p>>2]|0;en(h|0,36784,(k=i,i=i+8|0,c[k>>2]=r,k)|0)|0;i=k;h=c[350134]|0;n=(h|0)!=0?h:c[p>>2]|0;a_(n|0)|0}if((a[1157112]&1)==0){g=1;i=e;return g|0}c[334459]=r;n=c[350657]|0;if((n|0)==0){g=0;i=e;return g|0}h=c[n+40>>2]|0;if((h|0)==0){g=0;i=e;return g|0}n=c[350660]|0;if((n|0)==0){g=1;i=e;return g|0}ft[h&127](n,r);g=1;i=e;return g|0}else if((b|0)==16){if((a[1243488]&1)!=0){r=c[350134]|0;n=(r|0)!=0?r:c[p>>2]|0;a5(48424,34,1,n|0)|0;n=c[350134]|0;r=(n|0)!=0?n:c[p>>2]|0;a_(r|0)|0}r=c[335642]|0;if((r|0)!=0){i1(r);iU(c[335642]|0)}if((a[1210144]|0)!=0|(a[1264018]|0)==0){s=1210144}else{r=f|0;hd(r,1264018,44200,4096);s=r}c[335642]=i0(s,d)|0;g=1;i=e;return g|0}else if((b|0)==8){s=c[d>>2]|0;c[334461]=s;if((a[1243488]&1)==0){g=1;i=e;return g|0}r=c[350134]|0;en(((r|0)!=0?r:c[p>>2]|0)|0,103448,(k=i,i=i+8|0,c[k>>2]=s,k)|0)|0;i=k;s=c[350134]|0;a_(((s|0)!=0?s:c[p>>2]|0)|0)|0;g=1;i=e;return g|0}else if((b|0)==131072){if((a[1243488]&1)!=0){s=c[350134]|0;r=(s|0)!=0?s:c[p>>2]|0;a5(57816,48,1,r|0)|0;r=c[350134]|0;s=(r|0)!=0?r:c[p>>2]|0;a_(s|0)|0}if(!(g$(d)|0)){g=0;i=e;return g|0}i5(1218340,d,4096)|0;g=1;i=e;return g|0}else if((b|0)==10){s=c[d>>2]|0;do{if((s|0)==1){if((a[1243488]&1)==0){break}r=c[350134]|0;f=(r|0)!=0?r:c[p>>2]|0;a5(94696,47,1,f|0)|0;f=c[350134]|0;r=(f|0)!=0?f:c[p>>2]|0;a_(r|0)|0}else if((s|0)==2){if((a[1243488]&1)==0){break}r=c[350134]|0;a5(97024,45,1,((r|0)!=0?r:c[p>>2]|0)|0)|0;r=c[350134]|0;a_(((r|0)!=0?r:c[p>>2]|0)|0)|0}else if((s|0)==0){if((a[1243488]&1)==0){break}r=c[350134]|0;a5(98968,47,1,((r|0)!=0?r:c[p>>2]|0)|0)|0;r=c[350134]|0;a_(((r|0)!=0?r:c[p>>2]|0)|0)|0}else{g=0;i=e;return g|0}}while(0);c[334462]=s;g=1;i=e;return g|0}else if((b|0)==15){if((a[1243488]&1)!=0){s=c[350134]|0;r=(s|0)!=0?s:c[p>>2]|0;s=c[d>>2]|0;en(r|0,64664,(k=i,i=i+8|0,c[k>>2]=s,k)|0)|0;i=k;s=c[350134]|0;r=(s|0)!=0?s:c[p>>2]|0;a_(r|0)|0}r=c[335642]|0;if((r|0)==0){c[d+4>>2]=0}else{iV(r,d)}if((a[1243488]&1)==0){g=1;i=e;return g|0}r=c[350134]|0;s=c[d+4>>2]|0;en(((r|0)!=0?r:c[p>>2]|0)|0,57376,(k=i,i=i+8|0,c[k>>2]=(s|0)==0?52200:s,k)|0)|0;i=k;s=c[350134]|0;a_(((s|0)!=0?s:c[p>>2]|0)|0)|0;g=1;i=e;return g|0}else if((b|0)==13){if((a[1243488]&1)!=0){s=c[350134]|0;r=(s|0)!=0?s:c[p>>2]|0;a5(65440,47,1,r|0)|0;r=c[350134]|0;s=(r|0)!=0?r:c[p>>2]|0;a_(s|0)|0}c[335618]=c[d>>2];c[1342476>>2]=c[d+4>>2];c[1342480>>2]=c[d+8>>2];c[1342484>>2]=c[d+12>>2];c[1342488>>2]=c[d+16>>2];c[1342492>>2]=c[d+20>>2];c[1342496>>2]=c[d+24>>2];g=1;i=e;return g|0}else if((b|0)==131073|(b|0)==131074){if((d|0)==0){a[1280402]=0}else{i5(1280402,d,4096)|0}s=(a[1243488]&1)!=0;if((b|0)==131074){if(s){r=c[350134]|0;f=(r|0)!=0?r:c[p>>2]|0;a5(57280,42,1,f|0)|0;f=c[350134]|0;r=(f|0)!=0?f:c[p>>2]|0;a_(r|0)|0}a[1392016]=1;g=1;i=e;return g|0}else{if(!s){g=1;i=e;return g|0}s=c[350134]|0;r=(s|0)!=0?s:c[p>>2]|0;a5(56872,35,1,r|0)|0;r=c[350134]|0;s=(r|0)!=0?r:c[p>>2]|0;a_(s|0)|0;g=1;i=e;return g|0}}else if((b|0)==3){a[d]=1;if((a[1243488]&1)==0){g=1;i=e;return g|0}s=c[350134]|0;a5(75416,38,1,((s|0)!=0?s:c[p>>2]|0)|0)|0;s=c[350134]|0;a_(((s|0)!=0?s:c[p>>2]|0)|0)|0;g=1;i=e;return g|0}else if((b|0)==12){if((a[1243488]&1)!=0){s=c[350134]|0;r=(s|0)!=0?s:c[p>>2]|0;a5(66392,42,1,r|0)|0;r=c[350134]|0;s=(r|0)!=0?r:c[p>>2]|0;a_(s|0)|0}c[335616]=c[d>>2];g=1;i=e;return g|0}else{if((a[1243488]&1)==0){g=0;i=e;return g|0}d=c[350134]|0;en(((d|0)!=0?d:c[p>>2]|0)|0,56416,(k=i,i=i+8|0,c[k>>2]=b,k)|0)|0;i=k;k=c[350134]|0;a_(((k|0)!=0?k:c[p>>2]|0)|0)|0;g=0;i=e;return g|0}return 0}function h9(){var a=0;a=c[335642]|0;if((a|0)!=0){i1(a);iU(c[335642]|0)}yG(1337776,0,4800);return}function ia(){c[350542]=yy(76800,2)|0;return}function ib(){yz(c[350542]|0);c[350542]=0;return}function ic(b){b=b|0;yG(b|0,0,16);c[b>>2]=44888;c[b+4>>2]=2659320;a[b+12|0]=0;c[b+8>>2]=2659320;return}function id(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[350650]=a;c[d>>2]=2;fL[a&63](10,d)|0;i=b;return}function ie(){var a=0;fQ[c[350648]&1023]();a=0;do{b[(c[350542]|0)+(a<<1)>>1]=128;a=a+1|0;}while(a>>>0<76800);fR[c[350644]&63](c[350542]|0,320,240,640);return}function ig(a,b){a=a|0;b=b|0;return 0}function ih(a){a=a|0;return 0}function ii(a){a=a|0;return 0}function ij(){return}function ik(a,b,c){a=a|0;b=b|0;c=c|0;return}function il(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b+12|0;c[d>>2]=c[e>>2];d=b+28|0;if((a[d]&1)!=0){a[d]=0;f=1;return f|0}d=b+16|0;g=b+8|0;h=c[g>>2]|0;i=(c[d>>2]|0)-1&h;c[d>>2]=i;j=b+20|0;k=c[j>>2]|0;if((i|0)==(k|0)){c[d>>2]=h&i+1;f=0;return f|0}l=b|0;b=(c[l>>2]|0)+(i<<3)|0;m=c[b>>2]|0;n=c[b+4>>2]|0;if((m|0)==0&(n|0)==0){o=i;p=k;q=h}else{h=n;n=m;do{m=(c[e>>2]|0)+(h<<2)|0;c[m>>2]=c[m>>2]^n;r=c[g>>2]|0;s=(c[d>>2]|0)-1&r;c[d>>2]=s;m=(c[l>>2]|0)+(s<<3)|0;n=c[m>>2]|0;h=c[m+4>>2]|0;}while(!((n|0)==0&(h|0)==0));o=s;p=c[j>>2]|0;q=r}if((o|0)!=(p|0)){f=1;return f|0}c[d>>2]=q&p+1;f=1;return f|0}function im(a){a=a|0;var b=0,d=0,e=0;b=yy(1,16)|0;if((b|0)==0){d=0;return d|0}e=a+1|0;c[b+8>>2]=e;a=yy(e,4)|0;c[b>>2]=a;if((a|0)==0){yz(b);d=0;return d|0}else{c[b+4>>2]=1;d=b;return d|0}return 0}function io(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+4|0;d=c[b>>2]|0;e=a|0;if(d>>>0>1){f=1;g=d;while(1){d=c[(c[e>>2]|0)+(f<<2)>>2]|0;if((d|0)==0){h=g}else{yz(c[d+8>>2]|0);yz(c[(c[e>>2]|0)+(f<<2)>>2]|0);c[(c[e>>2]|0)+(f<<2)>>2]=0;h=c[b>>2]|0}d=f+1|0;if(d>>>0<h>>>0){f=d;g=h}else{break}}}c[b>>2]=1;b=a+12|0;yz(c[b>>2]|0);c[b>>2]=0;yz(c[e>>2]|0);yz(a);return}function ip(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a+4|0;d=c[b>>2]|0;if(d>>>0<=1){c[b>>2]=1;e=a+12|0;f=c[e>>2]|0;yz(f);c[e>>2]=0;return}g=a|0;h=1;i=d;while(1){d=c[(c[g>>2]|0)+(h<<2)>>2]|0;if((d|0)==0){j=i}else{yz(c[d+8>>2]|0);yz(c[(c[g>>2]|0)+(h<<2)>>2]|0);c[(c[g>>2]|0)+(h<<2)>>2]=0;j=c[b>>2]|0}d=h+1|0;if(d>>>0<j>>>0){h=d;i=j}else{break}}c[b>>2]=1;e=a+12|0;f=c[e>>2]|0;yz(f);c[e>>2]=0;return}function iq(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=a+4|0;g=c[f>>2]|0;if(g>>>0>=(c[a+8>>2]|0)>>>0){return}h=yy(1,12)|0;c[h+4>>2]=d;c[h>>2]=e;if((b|0)==0){i=0;j=g}else{g=dy(b|0)|0;i=g;j=c[f>>2]|0}c[h+8>>2]=i;i=a|0;c[(c[i>>2]|0)+(j<<2)>>2]=h;h=c[f>>2]|0;c[f>>2]=h+1;if(h>>>0>1){k=h}else{return}while(1){h=k>>>1;f=c[i>>2]|0;j=f+(h<<2)|0;a=c[j>>2]|0;g=c[f+(k<<2)>>2]|0;if((c[g+4>>2]|0)>>>0<=(c[a+4>>2]|0)>>>0){l=2287;break}c[j>>2]=g;c[(c[i>>2]|0)+(k<<2)>>2]=a;if(k>>>0>3){k=h}else{l=2288;break}}if((l|0)==2287){return}else if((l|0)==2288){return}}function ir(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+4|0;if((c[b>>2]|0)==1){d=0;return d|0}e=a|0;f=c[(c[e>>2]|0)+4>>2]|0;g=f|0;h=(c[g>>2]|0)-1|0;c[g>>2]=h;if((h|0)!=0){d=c[f+8>>2]|0;return d|0}h=a+12|0;yz(c[h>>2]|0);a=f+8|0;c[h>>2]=c[a>>2];c[a>>2]=0;a=c[e>>2]|0;f=a+4|0;g=c[f>>2]|0;i=(c[b>>2]|0)-1|0;c[b>>2]=i;c[f>>2]=c[a+(i<<2)>>2];yz(g);g=1;while(1){i=g<<1;a=c[b>>2]|0;if(i>>>0>a>>>0){j=0}else{f=c[e>>2]|0;j=(c[f+(g<<2)>>2]|0)>>>0<(c[f+(i<<2)>>2]|0)>>>0}f=i|1;if(f>>>0>a>>>0){k=0}else{a=c[e>>2]|0;k=(c[a+(g<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0}if(!(j|k)){break}do{if(k|j^1){if(!(j|k^1)){l=f;break}a=c[e>>2]|0;l=(c[a+(i<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0?f:i}else{l=i}}while(0);i=c[e>>2]|0;f=i+(g<<2)|0;a=c[f>>2]|0;c[f>>2]=c[i+(l<<2)>>2];c[(c[e>>2]|0)+(l<<2)>>2]=a;g=l}d=c[h>>2]|0;return d|0}function is(a){a=a|0;yz(c[a>>2]|0);yz(c[a+12>>2]|0);yz(a);return}function it(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0;e=b+12|0;f=c[e>>2]|0;g=d;h=b+16|0;i=c[h>>2]|0;c[h>>2]=i+1;j=b|0;k=(c[j>>2]|0)+(i<<3)|0;c[k>>2]=0;c[k+4>>2]=0;k=b+8|0;i=c[k>>2]|0;l=c[h>>2]&i;c[h>>2]=l;m=b+20|0;n=(l|0)==(c[m>>2]|0);o=b+24|0;p=c[o>>2]|0;if((p|0)==0){q=n;r=l;s=i;t=0}else{u=0;v=0;w=n;n=l;l=i;i=p;while(1){p=v;x=c[f+(p<<2)>>2]|0;y=c[g+(p<<2)>>2]|0;if((x|0)==(y|0)){z=w;A=n;B=l;C=i}else{p=(c[j>>2]|0)+(n<<3)|0;c[p>>2]=y^x;c[p+4>>2]=v;p=c[k>>2]|0;x=(c[h>>2]|0)+1&p;c[h>>2]=x;z=(x|0)==(c[m>>2]|0)|w;A=x;B=p;C=c[o>>2]|0}p=yT(v,u,1,0)|0;x=F;y=0;if(x>>>0<y>>>0|x>>>0==y>>>0&p>>>0<C>>>0){u=x;v=p;w=z;n=A;l=B;i=C}else{q=z;r=A;s=B;t=C;break}}}if(!q){D=c[e>>2]|0;E=D;G=t<<2;yJ(E|0,d|0,G)|0;H=b+28|0;a[H]=1;return 1}q=r+1&s;c[m>>2]=q;r=c[j>>2]|0;j=r+(q<<3)|0;if((c[j>>2]|0)==0&(c[j+4>>2]|0)==0){D=c[e>>2]|0;E=D;G=t<<2;yJ(E|0,d|0,G)|0;H=b+28|0;a[H]=1;return 1}else{I=q}do{I=I+1&s;c[m>>2]=I;q=r+(I<<3)|0;}while(!((c[q>>2]|0)==0&(c[q+4>>2]|0)==0));D=c[e>>2]|0;E=D;G=t<<2;yJ(E|0,d|0,G)|0;H=b+28|0;a[H]=1;return 1}function iu(a){a=a|0;var b=0;if((a|0)==0){return}b=c[a>>2]|0;if((b|0)!=0){aS(b|0)|0}yz(c[a+4>>2]|0);yz(c[a+12>>2]|0);yz(a);return}function iv(a,b){a=a|0;b=b|0;return(eh(b|0,2,1,c[a>>2]|0)|0)==1|0}function iw(a,d){a=a|0;d=d|0;var e=0,f=0;e=i;i=i+8|0;f=e|0;b[f>>1]=d;a5(f|0,2,1,c[a>>2]|0)|0;i=e;return}function ix(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+16|0;f=e|0;g=f|0;h=f;j=yy(1,36)|0;k=j;if((j|0)==0){l=0;i=e;return l|0}m=f;L3102:do{if((d|0)==0){a[j+24|0]=1;n=dc(b|0,73952)|0;c[j>>2]=n;if((n|0)==0){o=c[350134]|0;q=(o|0)!=0?o:c[p>>2]|0;en(q|0,63368,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;q=c[350134]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;break}yG(m|0,0,16);if((eh(m|0,4,4,n|0)|0)!=4){o=c[350134]|0;q=(o|0)!=0?o:c[p>>2]|0;a5(56584,49,1,q|0)|0;q=c[350134]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;s=n;t=2355;break}o=c[f>>2]|0;if(!((o|0)==1112757809|(o|0)==827740994)){o=c[350134]|0;q=(o|0)!=0?o:c[p>>2]|0;a5(51632,58,1,q|0)|0;q=c[350134]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;u=n;t=2354;break}if((c[f+8>>2]|0)!=(c[311907]|0)){o=c[350134]|0;q=(o|0)!=0?o:c[p>>2]|0;a5(47816,151,1,q|0)|0;q=c[350134]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0}o=c[h+12>>2]|0;do{if((o|0)!=0){q=yx(o)|0;c[j+4>>2]=q;c[j+8>>2]=o;if((q|0)==0){u=n;t=2354;break L3102}if((eh(q|0,1,o|0,n|0)|0)!=(o|0)){v=c[350134]|0;w=(v|0)!=0?v:c[p>>2]|0;a5(43672,53,1,w|0)|0;w=c[350134]|0;v=(w|0)!=0?w:c[p>>2]|0;a_(v|0)|0;u=n;t=2354;break L3102}if((fN[c[157564]&63]()|0)==(o|0)){v=c[157546]|0;fL[v&63](q,o)|0;break}else{q=c[350134]|0;v=(q|0)!=0?q:c[p>>2]|0;a5(39608,102,1,v|0)|0;v=c[350134]|0;q=(v|0)!=0?v:c[p>>2]|0;a_(q|0)|0;break}}}while(0);q=o+16|0;c[j+28>>2]=q;x=n;y=q;t=2352}else{q=dc(b|0,42288)|0;c[j>>2]=q;if((q|0)==0){v=c[350134]|0;w=(v|0)!=0?v:c[p>>2]|0;en(w|0,90520,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;w=c[350134]|0;v=(w|0)!=0?w:c[p>>2]|0;a_(v|0)|0;break}c[g>>2]=0;c[g+4>>2]=0;c[f>>2]=827740994;c[f+8>>2]=c[311907];v=fN[c[157564]&63]()|0;c[h+12>>2]=v;a5(m|0,4,4,q|0)|0;w=v+16|0;c[j+28>>2]=w;c[j+8>>2]=v;if((v|0)==0){x=q;y=w;t=2352;break}z=yx(v)|0;c[j+4>>2]=z;if((z|0)==0){u=q;t=2354;break}A=c[157566]|0;fL[A&63](z,v)|0;a5(z|0,1,v|0,q|0)|0;x=q;y=w;t=2352}}while(0);do{if((t|0)==2352){m=yy(1048576,4)|0;h=m;c[j+12>>2]=h;if((m|0)==0){u=x;t=2354;break}c[h>>2]=y;c[j+16>>2]=1048575;l=k;i=e;return l|0}}while(0);if((t|0)==2354){if((u|0)!=0){s=u;t=2355}}if((t|0)==2355){aS(s|0)|0}yz(c[j+4>>2]|0);yz(c[j+12>>2]|0);yz(j);l=0;i=e;return l|0}function iy(a){a=a|0;var b=0;b=ci(c[a>>2]|0)|0;c[(c[a+12>>2]|0)+(c[a+20>>2]<<2)>>2]=b;return}function iz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;if(b<<2>>>0>=d>>>0){g=0;i=f;return g|0}h=yy(1,32)|0;j=h;if((h|0)==0){g=0;i=f;return g|0}if((b&3|0)!=0){k=c[350134]|0;l=(k|0)!=0?k:c[p>>2]|0;en(l|0,42896,(m=i,i=i+16|0,c[m>>2]=91032,c[m+8>>2]=73,m)|0)|0;i=m;l=c[350134]|0;k=(l|0)!=0?l:c[p>>2]|0;a_(k|0)|0;ck(2);return 0}c[h+16>>2]=1;k=b>>>2;c[h+24>>2]=k;l=d-1|0;n=l>>>1|l;l=n>>>2|n;n=l>>>4|l;l=n>>>8|n;n=(l>>>16|l)+1|0;l=n>>>1;o=(n-d|0)>>>0<(d-l|0)>>>0?n:l;l=o>>>3;c[h+4>>2]=l;c[h+8>>2]=l-1;if((a[1243488]&1)!=0){n=c[350134]|0;d=(n|0)!=0?n:c[p>>2]|0;n=o>>>23<<3;en(d|0,74264,(m=i,i=i+8|0,c[m>>2]=n,m)|0)|0;i=m;m=c[350134]|0;n=(m|0)!=0?m:c[p>>2]|0;a_(n|0)|0}n=yy(1,l<<3)|0;c[h>>2]=n;do{if((n|0)!=0){l=yy(1,k<<2)|0;c[h+12>>2]=l;if((l|0)==0){break}yJ(l|0,e|0,b)|0;g=j;i=f;return g|0}}while(0);yz(n);yz(c[h+12>>2]|0);yz(h);g=0;i=f;return g|0}function iA(a,b){a=a|0;b=b|0;return}function iB(){var b=0.0;if((a[1400540]&1)==0){return}b=+g[334452];if(b>0.0){g[6896]=b;return}else{g[6896]=+((c[334448]|0)>>>0>>>0)/+((c[334449]|0)>>>0>>>0);return}}function iC(){var b=0.0;b=+g[285168];if(b>=0.0){g[6862]=b;return}b=+g[334452];do{if(b>0.0){if((a[1140676]&1)==0){break}g[6862]=b;return}}while(0);g[6862]=+((c[334448]|0)>>>0>>>0)/+((c[334449]|0)>>>0>>>0);return}function iD(b){b=b|0;var d=0;d=b+20|0;c[d>>2]=(c[d>>2]|0)+1&c[b+16>>2];d=b+33|0;a[b+32|0]=a[d]&1^1;a[d]=0;return}function iE(a){a=a|0;return c[627440+(a<<2)>>2]|0}function iF(a,b){a=a|0;b=b|0;var d=0;if((a|0)==0){return(b?91368:89632)|0}if(b){d=0;return d|0}d=c[26864+(a<<2)>>2]|0;return d|0}function iG(a,b){a=a|0;b=b|0;var d=0;d=c[a+4100>>2]|0;return c[(c[c[d+(b<<4)+8>>2]>>2]|0)+(c[d+(b<<4)+12>>2]<<3)>>2]|0}function iH(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a[b+33|0]=1;d=b+20|0;e=c[d>>2]|0;f=c[b+12>>2]|0;do{if(e>>>0<2){g=c[f>>2]|0;h=b+28|0;if((g|0)!=(c[h>>2]|0)){i=h;j=2410;break}c[d>>2]=0;k=c[b>>2]|0;eC(k|0,g|0,0)|0;l=h}else{i=b+28|0;j=2410}}while(0);if((j|0)==2410){j=e-((a[b+32|0]&1)!=0?1:2)&c[b+16>>2];c[d>>2]=j;d=c[b>>2]|0;e=c[f+(j<<2)>>2]|0;eC(d|0,e|0,0)|0;l=i}i=b|0;e=ci(c[i>>2]|0)|0;d=c[l>>2]|0;if((e|0)>(d|0)){return}e=c[i>>2]|0;if((a[b+24|0]&1)==0){eC(e|0,16,0)|0;l=c[157566]|0;j=b+4|0;f=c[j>>2]|0;h=b+8|0;b=c[h>>2]|0;fL[l&63](f,b)|0;b=c[j>>2]|0;j=c[h>>2]|0;h=c[i>>2]|0;a5(b|0,1,j|0,h|0)|0;return}else{eC(e|0,d|0,0)|0;return}}function iI(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0;f=i;a[b]=0;j=ks()|0;k=F;if((c[350074]|0)==0){c[285040]=j;c[285041]=k;c[285038]=j;c[285039]=k;bR(b|0,d|0,89896,(l=i,i=i+8|0,c[l>>2]=1400300,l)|0)|0;i=l;m=1;i=f;return m|0}n=1391840;o=c[n>>2]|0;p=yT(o,c[n+4>>2]|0,1,0)|0;n=1391840;c[n>>2]=p;c[n+4>>2]=F;n=yU(j,k,c[285040]|0,c[285041]|0)|0;p=1375456+((o&2047)<<3)|0;c[p>>2]=n;c[p+4>>2]=F;c[285040]=j;c[285041]=k;p=c[350074]|0;if((p&255|0)==0){n=yU(j,k,c[285038]|0,c[285039]|0)|0;q=256.0e6/(+(n>>>0)+ +(F|0)*4294967296.0);g[4780]=q;c[285038]=j;c[285039]=k;r=q;bR(b|0,d|0,40960,(l=i,i=i+24|0,c[l>>2]=1400300,h[l+8>>3]=r,c[l+16>>2]=p,l)|0)|0;i=l;m=1;i=f;return m|0}if(!e){m=0;i=f;return m|0}r=+g[4780];bR(b|0,d|0,40960,(l=i,i=i+24|0,c[l>>2]=1400300,h[l+8>>3]=r,c[l+16>>2]=p,l)|0)|0;i=l;m=0;i=f;return m|0}function iJ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=+e;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((c[285170]|0)==7){g=c[350121]|0;h=c[350122]|0;i=g;j=h;k=b-g|0;l=d-h|0}else{h=c[334449]|0;g=~~+bL(+(+(h>>>0>>>0)*e));do{if(g>>>0>b>>>0|h>>>0>d>>>0){m=0;n=0}else{if(f){o=(b>>>0)/(g>>>0)|0;p=(d>>>0)/(h>>>0)|0;q=o>>>0<p>>>0?o:p;p=b-(ab(q,g)|0)|0;m=p;n=d-(ab(q,h)|0)|0;break}else{m=(b>>>0)%(g>>>0)|0;n=(d>>>0)%(h>>>0)|0;break}}}while(0);i=b-m|0;j=d-n|0;k=m;l=n}c[a+8>>2]=i;c[a+12>>2]=j;c[a>>2]=(k|0)/2|0;c[a+4>>2]=(l|0)/2|0;return}function iK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0;d=i;if((a|0)==0|(b|0)==0){i=d;return}e=a>>>0<b>>>0?a:b;if(e>>>0>1){f=1;h=1;while(1){if(((a>>>0)%(f>>>0)|0|0)==0){j=((b>>>0)%(f>>>0)|0|0)==0?f:h}else{j=h}k=f+1|0;if(k>>>0<e>>>0){f=k;h=j}else{l=j;break}}}else{l=1}j=(a>>>0)/(l>>>0)|0;a=(b>>>0)/(l>>>0)|0;bR(27452|0,64,73592|0,(l=i,i=i+16|0,c[l>>2]=j,c[l+8>>2]=a,l)|0)|0;i=l;g[6879]=+(j>>>0>>>0)/+(a>>>0>>>0);i=d;return}function iL(a){a=a|0;var b=0,d=0,e=0;yG(627440,0,1292);b=c[a+4>>2]|0;if((b|0)==0){return}else{d=a;e=b}while(1){c[627440+(e<<2)>>2]=c[d>>2];b=c[d+12>>2]|0;if((b|0)==0){break}else{d=d+8|0;e=b}}return}function iM(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+128|0;h=g+64|0;bR(h|0,64,91464,(j=i,i=i+16|0,c[j>>2]=d,c[j+8>>2]=e,j)|0)|0;i=j;j=g|0;if(!(hC(b,h,j,64)|0)){i=g;return}do{if((yF(j|0)|0)==1){if((dt(a[j]|0)|0)==0){k=0;l=2456;break}m=yK(a[j]|0)|0}else{k=0;l=2456}}while(0);L3259:do{if((l|0)==2456){while(1){l=0;if((k|0)==67){m=0;break L3259}if((yM(c[16800+(k<<3)>>2]|0,j|0)|0)==0){break}else{k=k+1|0;l=2456}}m=c[16804+(k<<3)>>2]|0}}while(0);c[f+12>>2]=m;i=g;return}function iN(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+136|0;h=g|0;j=g+8|0;k=g+72|0;bR(k|0,64,91304,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;l=j|0;if(!(hC(b,k,l,64)|0)){i=g;return}if((cS(l|0,91520)|0)==0){k=f+16|0;c[k>>2]=65535;c[k+4>>2]=0;i=g;return}if((a[l]|0)!=104){k=aY(l|0,0,0)|0;l=f+16|0;c[l>>2]=k;c[l+4>>2]=F;i=g;return}l=j+1|0;if(((a[l]|0)-48|0)>>>0>=10){i=g;return}c[h>>2]=0;j=aX(l|0,h|0,0)|0;l=c[h>>2]|0;if((l|0)==0){h=c[350134]|0;k=(h|0)!=0?h:c[p>>2]|0;a5(89744,49,1,k|0)|0;k=c[350134]|0;h=(k|0)!=0?k:c[p>>2]|0;a_(h|0)|0;i=g;return}do{if((yM(l|0,36408)|0)==0){m=-32768}else{if((yM(l|0,102920)|0)==0){m=16384;break}if((yM(l|0,98832)|0)==0){m=8192;break}h=(yM(l|0,94576)|0)==0;if(h){m=h?4096:0;break}i=g;return}}while(0);l=f+16|0;c[l>>2]=m&65535|j&4095;c[l+4>>2]=0;i=g;return}function iO(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+128|0;h=g|0;j=g+64|0;bR(j|0,64,91192,(k=i,i=i+16|0,c[k>>2]=d,c[k+8>>2]=e,k)|0)|0;i=k;k=h|0;if(!(hC(b,j,k,64)|0)){i=g;return}if((cS(k|0,91520)|0)==0){c[f+32>>2]=-1;i=g;return}if((yF(k|0)|0)>>>0<=1){i=g;return}j=a[k]|0;if(!((j<<24>>24|0)==43|(j<<24>>24|0)==45)){i=g;return}j=a1(h+1|0,0,0)|0;if((a[k]|0)==43){c[f+32>>2]=j|-65536;i=g;return}else{c[f+32>>2]=j<<16|65535;i=g;return}}function iP(){var a=0,b=0,d=0;a=yy(1,48)|0;do{if((a|0)==0){b=0}else{d=bo()|0;c[a+44>>2]=d;if((d|0)==0){yz(a);b=0;break}else{iL(9232);b=a;break}}}while(0);return b|0}function iQ(a){a=a|0;var b=0;b=cp(c[a+44>>2]|0)|0;yJ(a|0,b|0,44)|0;return}function iR(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;g=b;do{if((f|0)==2){if((h|0)==2){i=a[b+40|0]|0;break}else if((h|0)==0){i=c[b+32>>2]&65535;break}else if((h|0)==1){i=c[b+36>>2]&65535;break}else if((h|0)==3){i=a[b+41|0]|0;break}else{i=0;break}}else if((f|0)==3){if((h|0)>322){i=0;break}j=iE(h)|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else if((f|0)==1){j=c[d+(e<<2)>>2]|0;if(h>>>0>=56){i=0;break}if((a[j+(h*40|0)|0]&1)==0){i=0;break}k=c[j+(h*40|0)+12>>2]|0;if((k|0)>322){i=0;break}j=iE(k)|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else{i=0}}while(0);return i|0}function iS(b,d){b=b|0;d=d|0;var e=0,f=0;if(d>>>0>=56){e=0;return e|0}if((a[1165472+(d*40|0)|0]&1)==0){e=0;return e|0}f=c[1165484+(d*40|0)>>2]|0;if((f|0)>322){e=0;return e|0}d=iE(f)|0;e=(a[b+(d>>>3)|0]&1<<(d&7)|0)!=0;return e|0}function iT(a){a=a|0;aM(c[a+44>>2]|0);yz(a);return}function iU(a){a=a|0;var b=0,d=0,e=0;if((a|0)==0){return}b=a+4104|0;if((c[b>>2]|0)!=0){d=a+4100|0;e=0;do{yz(c[(c[d>>2]|0)+(e<<4)>>2]|0);yz(c[(c[d>>2]|0)+(e<<4)+4>>2]|0);gS(c[(c[d>>2]|0)+(e<<4)+8>>2]|0);e=e+1|0;}while(e>>>0<(c[b>>2]|0)>>>0)}b=c[a>>2]|0;if((b|0)!=0){ht(b)}yz(c[a+4100>>2]|0);yz(a);return}function iV(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;a[b+4108|0]=0;e=c[b+4104>>2]|0;f=b+4100|0;b=d|0;g=0;while(1){if(g>>>0>=e>>>0){h=2542;break}i=c[f>>2]|0;if((cS(c[i+(g<<4)+4>>2]|0,c[b>>2]|0)|0)==0){h=2541;break}else{g=g+1|0}}if((h|0)==2542){c[d+4>>2]=0;return}else if((h|0)==2541){c[d+4>>2]=c[(c[c[i+(g<<4)+8>>2]>>2]|0)+(c[i+(g<<4)+12>>2]<<3)>>2];return}}function iW(b){b=b|0;return(a[b+4108|0]&1)!=0|0}function iX(a){a=a|0;return c[a+4104>>2]|0}function iY(a,b){a=a|0;b=b|0;return c[(c[a+4100>>2]|0)+(b<<4)>>2]|0}function iZ(b,d){b=b|0;d=d|0;var e=0,f=0;e=c[b+4100>>2]|0;f=e+(d<<4)+12|0;c[f>>2]=(((c[f>>2]|0)+1|0)>>>0)%((c[(c[e+(d<<4)+8>>2]|0)+4>>2]|0)>>>0)|0;a[b+4108|0]=1;return}function i_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=c[b+4100>>2]|0;f=e+(d<<4)+12|0;g=c[(c[e+(d<<4)+8>>2]|0)+4>>2]|0;c[f>>2]=(((c[f>>2]|0)-1+g|0)>>>0)%(g>>>0)|0;a[b+4108|0]=1;return}function i$(b,d){b=b|0;d=d|0;c[(c[b+4100>>2]|0)+(d<<4)+12>>2]=0;a[b+4108|0]=1;return}function i0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=i;i=i+8|0;f=e|0;g=yy(1,4112)|0;h=g;if((g|0)==0){j=0;i=e;return j|0}if((a[b]|0)==0){k=c[g>>2]|0}else{l=hs(b)|0;c[g>>2]=l;k=l}l=g;if((k|0)==0){c[l>>2]=hs(0)|0}i5(g+4|0,b,4096)|0;do{if((c[l>>2]|0)!=0){b=d|0;k=c[b>>2]|0;m=(k|0)==0;L3387:do{if(m){n=0}else{o=0;q=d;while(1){if((c[q+4>>2]|0)==0){n=o;break L3387}r=o+1|0;s=q+8|0;if((c[s>>2]|0)==0){n=r;break}else{o=r;q=s}}}}while(0);q=yy(n,16)|0;o=g+4100|0;c[o>>2]=q;if((q|0)==0){break}c[g+4104>>2]=n;if(m){j=h;i=e;return j|0}q=0;s=b;r=k;while(1){t=s+4|0;if((c[t>>2]|0)==0){j=h;u=2595;break}v=c[o>>2]|0;w=v+(q<<4)+4|0;c[w>>2]=dy(r|0)|0;x=dy(c[t>>2]|0)|0;t=bw(x|0,107400)|0;if((t|0)==0){u=2567;break}a[t]=0;y=v+(q<<4)|0;c[y>>2]=dy(x|0)|0;z=gY(t+2|0,105920)|0;t=v+(q<<4)+8|0;c[t>>2]=z;if((z|0)==0){u=2569;break}c[f>>2]=0;if(hB(c[l>>2]|0,c[w>>2]|0,f)|0){z=c[t>>2]|0;A=c[z+4>>2]|0;B=z|0;z=c[f>>2]|0;C=0;while(1){if(C>>>0>=A>>>0){D=z;break}if((cS(c[(c[B>>2]|0)+(C<<3)>>2]|0,z|0)|0)==0){u=2574;break}else{C=C+1|0}}if((u|0)==2574){u=0;c[v+(q<<4)+12>>2]=C;D=c[f>>2]|0}yz(D)}yz(x);z=a[1243488]|0;if((z&1)==0){E=z}else{z=c[350134]|0;B=(z|0)!=0?z:c[p>>2]|0;a5(85704,24,1,B|0)|0;B=c[350134]|0;z=(B|0)!=0?B:c[p>>2]|0;a_(z|0)|0;E=a[1243488]|0}if((E&1)==0){F=E}else{z=c[350134]|0;B=(z|0)!=0?z:c[p>>2]|0;z=c[y>>2]|0;en(B|0,71240,(G=i,i=i+8|0,c[G>>2]=z,G)|0)|0;i=G;z=c[350134]|0;B=(z|0)!=0?z:c[p>>2]|0;a_(B|0)|0;F=a[1243488]|0}if((F&1)==0){H=F}else{B=c[350134]|0;z=(B|0)!=0?B:c[p>>2]|0;B=c[w>>2]|0;en(z|0,61456,(G=i,i=i+8|0,c[G>>2]=B,G)|0)|0;i=G;B=c[350134]|0;z=(B|0)!=0?B:c[p>>2]|0;a_(z|0)|0;H=a[1243488]|0}if((H&1)==0){I=H}else{z=c[350134]|0;B=(z|0)!=0?z:c[p>>2]|0;z=c[o>>2]|0;A=c[(c[c[z+(q<<4)+8>>2]>>2]|0)+(c[z+(q<<4)+12>>2]<<3)>>2]|0;en(B|0,55408,(G=i,i=i+8|0,c[G>>2]=A,G)|0)|0;i=G;A=c[350134]|0;B=(A|0)!=0?A:c[p>>2]|0;a_(B|0)|0;I=a[1243488]|0}if((I&1)!=0){B=c[350134]|0;A=(B|0)!=0?B:c[p>>2]|0;a5(50840,29,1,A|0)|0;A=c[350134]|0;B=(A|0)!=0?A:c[p>>2]|0;a_(B|0)|0}B=c[t>>2]|0;if((c[B+4>>2]|0)!=0){A=0;z=B;while(1){if((a[1243488]&1)==0){J=z}else{B=c[350134]|0;K=(B|0)!=0?B:c[p>>2]|0;B=c[(c[z>>2]|0)+(A<<3)>>2]|0;en(K|0,46936,(G=i,i=i+8|0,c[G>>2]=B,G)|0)|0;i=G;B=c[350134]|0;K=(B|0)!=0?B:c[p>>2]|0;a_(K|0)|0;J=c[t>>2]|0}K=A+1|0;if(K>>>0<(c[J+4>>2]|0)>>>0){A=K;z=J}else{break}}}z=s+8|0;A=c[z>>2]|0;if((A|0)==0){j=h;u=2594;break}else{q=q+1|0;s=z;r=A}}if((u|0)==2567){yz(x);break}else if((u|0)==2595){i=e;return j|0}else if((u|0)==2594){i=e;return j|0}else if((u|0)==2569){yz(x);break}}}while(0);iU(h);j=0;i=e;return j|0}function i1(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a+4104|0;if((c[b>>2]|0)==0){d=a|0;e=c[d>>2]|0;f=a+4|0;g=hK(e,f)|0;return}h=a+4100|0;i=a|0;j=0;while(1){k=c[h>>2]|0;hF(c[i>>2]|0,c[k+(j<<4)+4>>2]|0,c[(c[c[k+(j<<4)+8>>2]>>2]|0)+(c[k+(j<<4)+12>>2]<<3)>>2]|0);k=j+1|0;if(k>>>0<(c[b>>2]|0)>>>0){j=k}else{d=i;break}}e=c[d>>2]|0;f=a+4|0;g=hK(e,f)|0;return}function i2(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0;j=i;i=i+144|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+40|0;q=j+48|0;r=j+56|0;s=j+64|0;t=j+72|0;u=j+80|0;v=j+88|0;w=j+96|0;x=j+104|0;y=j+112|0;z=j+120|0;A=j+128|0;B=j+136|0;if(d>>>0<19){C=2;i=j;return C|0}D=c[h>>2]|0;E=a[b]|0;a[B]=E;G=me(0,B,1)|0;if(E<<24>>24!=66){C=3;i=j;return C|0}E=a[b+1|0]|0;a[A]=E;B=me(G,A,1)|0;if(E<<24>>24!=80){C=3;i=j;return C|0}E=a[b+2|0]|0;a[z]=E;A=me(B,z,1)|0;if(E<<24>>24!=83){C=3;i=j;return C|0}E=a[b+3|0]|0;a[y]=E;z=me(A,y,1)|0;if(E<<24>>24!=49){C=3;i=j;return C|0}E=0;y=0;A=0;B=1;G=~z;z=4;H=7;while(1){I=z+1|0;J=a[b+z|0]|0;a[x]=J;K=~(me(~G,x,1)|0);L=J&255;J=y0(L&127,0,B,A)|0;M=yT(J,F,y,E)|0;if((L&128|0)!=0){N=0;O=0;P=0;Q=1;R=K;S=I;T=H;break}L=B<<7|0>>>25;J=A<<7|B>>>25;U=yT(M,F,L,J)|0;E=F;y=U;A=J;B=L;G=K;z=I;H=H+1|0}while(1){V=S+1|0;H=a[b+S|0]|0;a[w]=H;W=~(me(~R,w,1)|0);z=H&255;H=y0(z&127,0,Q,P)|0;X=yT(H,F,O,N)|0;if((z&128|0)!=0){break}z=Q<<7|0>>>25;H=P<<7|Q>>>25;G=yT(X,F,z,H)|0;N=F;O=G;P=H;Q=z;R=W;S=V;T=T+1|0}S=M;M=0;R=0;Q=0;P=1;O=W;W=V;V=T;while(1){Y=W+1|0;Z=a[b+W|0]|0;a[v]=Z;_=~(me(~O,v,1)|0);T=Z&255;N=y0(T&127,0,P,Q)|0;$=yT(N,F,R,M)|0;if((T&128|0)!=0){break}T=P<<7|0>>>25;N=Q<<7|P>>>25;w=yT($,F,T,N)|0;M=F;R=w;Q=N;P=T;O=_;W=Y;V=V+1|0}W=X;X=$;if((X|0)==0){aa=_;ab=Y}else{$=y0(P,Q,Z&127,0)|0;Z=yT(R,M,$,F)|0;$=Z;Z=_;_=Y;Y=0;while(1){a[u]=a[b+_|0]|0;ac=~(me(~Z,u,1)|0);M=Y+1|0;if(M>>>0<X>>>0){Z=ac;_=_+1|0;Y=M}else{break}}aa=ac;ab=V+$|0}if(S>>>0>f>>>0){C=5;i=j;return C|0}if(W>>>0>D>>>0){C=6;i=j;return C|0}D=d-12|0;d=ab;ab=0;S=0;$=aa;aa=-1;V=0;L3486:while(1){ac=d;Y=ab;_=$;Z=aa;X=V;while(1){u=ac;M=_;ad=Z;ae=X;L3490:while(1){af=u;ag=M;while(1){if(af>>>0<D>>>0){ah=0;ai=0;aj=0;ak=1;al=ag;am=af}else{break L3486}while(1){an=am+1|0;R=a[b+am|0]|0;a[t]=R;ao=~(me(~al,t,1)|0);Q=R&255;R=y0(Q&127,0,ak,aj)|0;ap=yT(R,F,ai,ah)|0;if((Q&128|0)!=0){break}Q=ak<<7|0>>>25;R=aj<<7|ak>>>25;P=yT(ap,F,Q,R)|0;ah=F;ai=P;aj=R;ak=Q;al=ao;am=an}Q=ap;aq=Q&3;ar=(Q>>>2)+1|0;if((aq|0)==0){as=ae;at=ad;au=ar;av=2637;break}else if((aq|0)==1){aw=ae;ax=ad;ay=ao;az=an;aA=ar;av=2638;break}else if((aq|0)==2|(aq|0)==3){aB=0;aC=0;aD=0;aE=1;aF=ao;aG=an;break L3490}else{af=an;ag=ao}}if((av|0)==2637){while(1){av=0;Q=au-1|0;R=a[e+as|0]|0;a[g+as|0]=R;a[s]=R;R=~(me(~at,s,1)|0);if((Q|0)==0){aH=an;aI=ao;aJ=R;break}else{as=as+1|0;at=R;au=Q;av=2637}}}else if((av|0)==2638){while(1){av=0;Q=aA-1|0;R=a[b+az|0]|0;a[r]=R;aK=~(me(~ay,r,1)|0);a[g+aw|0]=R;a[q]=R;aL=~(me(~ax,q,1)|0);if((Q|0)==0){break}else{aw=aw+1|0;ax=aL;ay=aK;az=az+1|0;aA=Q;av=2638}}aH=ar+an|0;aI=aK;aJ=aL}u=aH;M=aI;ad=aJ;ae=ae+ar|0}while(1){aM=aG+1|0;M=a[b+aG|0]|0;a[p]=M;aN=~(me(~aF,p,1)|0);u=M&255;M=y0(u&127,0,aE,aD)|0;aO=yT(M,F,aC,aB)|0;if((u&128|0)!=0){break}u=aE<<7|0>>>25;M=aD<<7|aE>>>25;Q=yT(aO,F,u,M)|0;aB=F;aC=Q;aD=M;aE=u;aF=aN;aG=aM}u=aO;M=u>>1;aP=(u&1|0)==0?M:-M|0;if((aq|0)!=2){break}M=aP+ar|0;u=ae;Q=ad;R=aP+Y|0;P=ar;while(1){O=P-1|0;v=a[e+R|0]|0;a[g+u|0]=v;a[o]=v;aQ=~(me(~Q,o,1)|0);if((O|0)==0){break}else{u=u+1|0;Q=aQ;R=R+1|0;P=O}}ac=aM;Y=M+Y|0;_=aN;Z=aQ;X=ar+ae|0}X=S+ar|0;Z=ae;_=ad;ac=aP+S|0;P=ar;while(1){R=P-1|0;Q=a[g+ac|0]|0;a[g+Z|0]=Q;a[n]=Q;aR=~(me(~_,n,1)|0);if((R|0)==0){break}else{Z=Z+1|0;_=aR;ac=ac+1|0;P=R}}d=aM;ab=Y;S=X+aP|0;$=aN;aa=aR;V=ar+ae|0}ae=a[b+af|0]|0;a[m]=ae;ar=me(~ag,m,1)|0;ag=a[b+(af+1)|0]|0;a[m]=ag;V=me(ar,m,1)|0;ar=a[b+(af+2)|0]|0;a[m]=ar;aR=me(V,m,1)|0;V=a[b+(af+3)|0]|0;a[m]=V;aa=me(aR,m,1)|0;m=a[b+(af+4)|0]|0;a[l]=m;aR=me(aa,l,1)|0;aa=a[b+(af+5)|0]|0;a[l]=aa;aN=me(aR,l,1)|0;aR=a[b+(af+6)|0]|0;a[l]=aR;$=me(aN,l,1)|0;aN=a[b+(af+7)|0]|0;a[l]=aN;aP=me($,l,1)|0;l=a[b+(af+8)|0]|0;a[k]=l;$=me(aP,k,1)|0;S=a[b+(af+9)|0]|0;a[k]=S;ab=me($,k,1)|0;$=a[b+(af+10)|0]|0;a[k]=$;aM=me(ab,k,1)|0;ab=a[b+(af+11)|0]|0;a[k]=ab;me(aM,k,1)|0;if((me(0,e,f)|0)!=((V&255)<<24|((ar&255)<<16|((ag&255)<<8|ae&255))|0)){C=9;i=j;return C|0}if(((aN&255)<<24|((aR&255)<<16|((aa&255)<<8|m&255))|0)!=(~ad|0)){C=10;i=j;return C|0}if(((ab&255)<<24|(($&255)<<16|((S&255)<<8|l&255))|0)!=(aP|0)){C=11;i=j;return C|0}c[h>>2]=W;C=1;i=j;return C|0}function i3(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0;j=i;i=i+152|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+40|0;q=j+48|0;r=j+56|0;s=j+64|0;t=j+72|0;u=j+80|0;v=j+88|0;w=j+96|0;x=j+104|0;y=j+112|0;z=j+120|0;A=j+128|0;B=j+136|0;C=j+144|0;D=c[h>>2]|0;if(d>>>0<=17){E=4;i=j;return E|0}G=a[b]|0;a[C]=G;H=me(0,C,1)|0;if(G<<24>>24!=85){E=4;i=j;return E|0}G=a[b+1|0]|0;a[B]=G;C=me(H,B,1)|0;if(G<<24>>24!=80){E=4;i=j;return E|0}G=a[b+2|0]|0;a[A]=G;B=me(C,A,1)|0;if(G<<24>>24!=83){E=4;i=j;return E|0}G=a[b+3|0]|0;a[z]=G;A=me(B,z,1)|0;if(G<<24>>24!=49){E=4;i=j;return E|0}G=0;z=0;B=0;C=1;H=4;I=~A;while(1){if(H>>>0<d>>>0){A=H+1|0;J=a[b+H|0]|0;a[y]=J;K=~(me(~I,y,1)|0);L=J&255;J=y0(L&127,0,C,B)|0;M=yT(J,F,z,G)|0;if((L&128|0)==0){N=F;O=M;P=A;Q=K}else{R=0;S=0;T=0;U=1;V=A;W=K;break}}else{N=G;O=z;P=H;Q=I}K=C<<7|0>>>25;A=B<<7|C>>>25;L=yT(O,N,K,A)|0;G=F;z=L;B=A;C=K;H=P;I=Q}while(1){if(V>>>0<d>>>0){X=V+1|0;Q=a[b+V|0]|0;a[x]=Q;Y=~(me(~W,x,1)|0);I=Q&255;Q=y0(I&127,0,U,T)|0;Z=yT(Q,F,S,R)|0;if((I&128|0)==0){_=F;$=Z;aa=X;ab=Y}else{break}}else{_=R;$=S;aa=V;ab=W}I=U<<7|0>>>25;Q=T<<7|U>>>25;P=yT($,_,I,Q)|0;R=F;S=P;T=Q;U=I;V=aa;W=ab}ab=M;M=Z;Z=(ab|0)==(f|0);W=(M|0)==(f|0);if(!(Z|W)){E=7;i=j;return E|0}aa=Z?M:ab;c[h>>2]=aa;if(D>>>0<aa>>>0){E=6;i=j;return E|0}D=d-12|0;if(X>>>0<D>>>0){h=-1;V=-1;U=Y;T=0;S=0;R=X;while(1){_=0;$=0;x=0;I=1;Q=R;P=U;while(1){if(Q>>>0<d>>>0){ac=Q+1|0;H=a[b+Q|0]|0;a[w]=H;ad=~(me(~P,w,1)|0);C=H&255;H=y0(C&127,0,I,x)|0;ae=yT(H,F,$,_)|0;if((C&128|0)==0){af=F;ag=ae;ah=ac;ai=ad}else{break}}else{af=_;ag=$;ah=Q;ai=P}C=I<<7|0>>>25;H=x<<7|I>>>25;B=yT(ag,af,C,H)|0;_=F;$=B;x=H;I=C;Q=ah;P=ai}P=ae;if((P|0)==0){aj=ac;ak=S;al=T;am=ad;an=V;ao=h}else{Q=h;I=V;x=T;$=S;_=P;while(1){C=_-1|0;if($>>>0<f>>>0){H=a[e+$|0]|0;a[v]=H;ap=H;aq=$+1|0;ar=~(me(~I,v,1)|0)}else{ap=0;aq=$;ar=I}if(x>>>0<aa>>>0){a[g+x|0]=ap;a[u]=ap;as=~(me(~Q,u,1)|0)}else{as=Q}if((C|0)==0){break}else{Q=as;I=ar;x=x+1|0;$=aq;_=C}}aj=ac;ak=aq;al=T+P|0;am=ad;an=ar;ao=as}while(1){if(aj>>>0<d>>>0){_=a[b+aj|0]|0;a[t]=_;at=_;au=aj+1|0;av=~(me(~am,t,1)|0)}else{at=0;au=aj;av=am}if(ak>>>0<f>>>0){_=a[e+ak|0]|0;a[s]=_;aw=_;ax=ak+1|0;ay=~(me(~an,s,1)|0)}else{aw=0;ax=ak;ay=an}_=aw^at;if(al>>>0<aa>>>0){a[g+al|0]=_;a[r]=_;az=~(me(~ao,r,1)|0)}else{az=ao}aA=al+1|0;if(at<<24>>24==0){break}else{aj=au;ak=ax;al=aA;am=av;an=ay;ao=az}}if(au>>>0<D>>>0){h=az;V=ay;U=av;T=aA;S=ax;R=au}else{aB=az;aC=ay;aD=av;aE=aA;aF=ax;aG=au;break}}}else{aB=-1;aC=-1;aD=Y;aE=0;aF=0;aG=X}if(aF>>>0<f>>>0){X=aE+f|0;Y=aB;au=aC;ax=aE;aA=aF;while(1){av=aA+1|0;ay=a[e+aA|0]|0;a[q]=ay;aH=~(me(~au,q,1)|0);if(ax>>>0<aa>>>0){a[g+ax|0]=ay;a[p]=ay;aI=~(me(~Y,p,1)|0)}else{aI=Y}if(av>>>0<f>>>0){Y=aI;au=aH;ax=ax+1|0;aA=av}else{break}}aJ=aI;aK=aH;aL=X-aF|0;aM=f}else{aJ=aB;aK=aC;aL=aE;aM=aF}if(aL>>>0<aa>>>0){aF=aJ;aE=aK;aC=aL;aL=aM;while(1){if(aL>>>0<f>>>0){aM=a[e+aL|0]|0;a[o]=aM;aN=aM;aO=aL+1|0;aP=~(me(~aE,o,1)|0)}else{aN=0;aO=aL;aP=aE}a[g+aC|0]=aN;a[n]=aN;aM=~(me(~aF,n,1)|0);aB=aC+1|0;if(aB>>>0<aa>>>0){aF=aM;aE=aP;aC=aB;aL=aO}else{aQ=aM;aR=aP;break}}}else{aQ=aJ;aR=aK}if(aG>>>0<d>>>0){aK=a[b+aG|0]|0;a[m]=aK;aS=aK&255;aT=aG+1|0;aU=~(me(~aD,m,1)|0)}else{aS=0;aT=aG;aU=aD}if(aT>>>0<d>>>0){aD=a[b+aT|0]|0;a[m]=aD;aV=(aD&255)<<8;aW=aT+1|0;aX=~(me(~aU,m,1)|0)}else{aV=0;aW=aT;aX=aU}if(aW>>>0<d>>>0){aU=a[b+aW|0]|0;a[m]=aU;aY=(aU&255)<<16;aZ=aW+1|0;a_=~(me(~aX,m,1)|0)}else{aY=0;aZ=aW;a_=aX}if(aZ>>>0<d>>>0){aX=a[b+aZ|0]|0;a[m]=aX;a$=(aX&255)<<24;a0=aZ+1|0;a1=~(me(~a_,m,1)|0)}else{a$=0;a0=aZ;a1=a_}a_=a$|(aY|(aV|aS));if(a0>>>0<d>>>0){aS=a[b+a0|0]|0;a[l]=aS;a2=aS&255;a3=a0+1|0;a4=~(me(~a1,l,1)|0)}else{a2=0;a3=a0;a4=a1}if(a3>>>0<d>>>0){a1=a[b+a3|0]|0;a[l]=a1;a5=(a1&255)<<8;a6=a3+1|0;a7=~(me(~a4,l,1)|0)}else{a5=0;a6=a3;a7=a4}if(a6>>>0<d>>>0){a4=a[b+a6|0]|0;a[l]=a4;a8=(a4&255)<<16;a9=a6+1|0;ba=~(me(~a7,l,1)|0)}else{a8=0;a9=a6;ba=a7}if(a9>>>0<d>>>0){a7=a[b+a9|0]|0;a[l]=a7;bb=(a7&255)<<24;bc=a9+1|0;bd=~(me(~ba,l,1)|0)}else{bb=0;bc=a9;bd=ba}ba=bb|(a8|(a5|a2));a2=~aR;if(bc>>>0<d>>>0){aR=a[b+bc|0]|0;a[k]=aR;be=aR&255;bf=bc+1|0;bg=~(me(~bd,k,1)|0)}else{be=0;bf=bc;bg=bd}if(bf>>>0<d>>>0){bc=a[b+bf|0]|0;a[k]=bc;bh=(bc&255)<<8;bi=bf+1|0;bj=~(me(~bg,k,1)|0)}else{bh=0;bi=bf;bj=bg}if(bi>>>0<d>>>0){bg=a[b+bi|0]|0;a[k]=bg;bk=(bg&255)<<16;bl=bi+1|0;bm=~(me(~bj,k,1)|0)}else{bk=0;bl=bi;bm=bj}if(bl>>>0<d>>>0){d=a[b+bl|0]|0;a[k]=d;bl=~bm;me(bl,k,1)|0;bn=(d&255)<<24}else{bn=0}d=~aQ;if((bn|(bk|(bh|be))|0)!=(~bd|0)){E=4;i=j;return E|0}if(!((a_|0)!=(a2|0)|Z^1)){i=j;return((ba|0)==(d|0)&(aa|0)==(M|0)?1:8)|0}if((ba|0)!=(a2|0)|W^1){E=7;i=j;return E|0}E=(a_|0)==(d|0)&(aa|0)==(ab|0)?1:8;i=j;return E|0}function i4(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if(e>>>0<8){j=4;return j|0}if((a[b]|0)!=80){j=4;return j|0}if((a[b+1|0]|0)!=65){j=4;return j|0}if((a[b+2|0]|0)!=84){j=4;return j|0}if((a[b+3|0]|0)!=67){j=4;return j|0}if((a[b+4|0]|0)!=72){j=4;return j|0}yJ(h|0,f|0,g)|0;c[i>>2]=g;g=e-3|0;if(g>>>0<5){j=4;return j|0}f=e-2|0;k=5;while(1){l=k+3|0;m=d[b+(k+1)|0]<<8|d[b+k|0]<<16|d[b+(k+2)|0];if((m|0)==4542278){if((l|0)==(e|0)){j=1;n=2780;break}if((l|0)==(g|0)){n=2756;break}}if(l>>>0>f>>>0){j=4;n=2781;break}o=k+5|0;p=d[b+l|0]<<8|d[b+(k+4)|0];if((p|0)==0){if(o>>>0>g>>>0){j=4;n=2783;break}l=d[b+o|0]<<8|d[b+(k+6)|0];if((l|0)==0){j=4;n=2778;break}q=b+(k+7)|0;r=m;s=l;while(1){t=s-1|0;a[h+r|0]=a[q]|0;if((t|0)==0){break}else{r=r+1|0;s=t}}u=l;v=k+8|0}else{if(o>>>0>(e-p|0)>>>0){j=4;n=2776;break}else{w=o;x=m;y=p}while(1){s=y-1|0;a[h+x|0]=a[b+w|0]|0;if((s|0)==0){break}else{w=w+1|0;x=x+1|0;y=s}}u=p;v=o+p|0}l=u+m|0;if(l>>>0>(c[i>>2]|0)>>>0){c[i>>2]=l}if(v>>>0>g>>>0){j=4;n=2779;break}else{k=v}}if((n|0)==2783){return j|0}else if((n|0)==2778){return j|0}else if((n|0)==2776){return j|0}else if((n|0)==2780){return j|0}else if((n|0)==2779){return j|0}else if((n|0)==2756){c[i>>2]=d[b+(k+4)|0]<<8|d[b+g|0]<<16|d[b+(k+5)|0];j=1;return j|0}else if((n|0)==2781){return j|0}return 0}function i5(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;do{if((d|0)==0){e=0;f=c}else{g=d;h=0;i=b;j=c;while(1){k=g-1|0;if((k|0)==0){l=2788;break}m=a[j]|0;a[i]=m;if(m<<24>>24==0){n=h;l=2794;break}else{g=k;h=h+1|0;i=i+1|0;j=j+1|0}}if((l|0)==2794){return n|0}else if((l|0)==2788){a[i]=0;e=h;f=j;break}}}while(0);if((a[f]|0)==0){n=e;return n|0}else{o=f;p=e}while(1){e=o+1|0;f=p+1|0;if((a[e]|0)==0){n=f;break}else{o=e;p=f}}return n|0}function i6(a){a=a|0;return c[a>>2]|0}function i7(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=yF(b|0)|0;f=e>>>0>d>>>0?0:d-e|0;do{if((f|0)==0){g=0;h=c}else{d=f;i=0;j=b+e|0;k=c;while(1){l=d-1|0;if((l|0)==0){m=2800;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=i;m=2805;break}else{d=l;i=i+1|0;j=j+1|0;k=k+1|0}}if((m|0)==2800){a[j]=0;g=i;h=k;break}else if((m|0)==2805){p=o+e|0;return p|0}}}while(0);if((a[h]|0)==0){o=g;p=o+e|0;return p|0}else{q=h;r=g}while(1){g=q+1|0;h=r+1|0;if((a[g]|0)==0){o=h;break}else{q=g;r=h}}p=o+e|0;return p|0}function i8(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=c[350134]|0;a5(106504,85,1,((f|0)!=0?f:c[p>>2]|0)|0)|0;f=c[350134]|0;a_(((f|0)!=0?f:c[p>>2]|0)|0)|0;c[e>>2]=0;f=dc(b|0,105768)|0;if((f|0)==0){g=0;i=d;return g|0}b=yy(1,4)|0;h=b;j=(b|0)==0;L3742:do{if(j){k=2821}else{eC(f|0,0,2)|0;l=ci(f|0)|0;eK(f|0);m=yx(l+1|0)|0;do{if((m|0)==0){n=0}else{a[m+l|0]=0;if((eh(m|0,1,l|0,f|0)|0)!=(l|0)){n=m;break}aS(f|0)|0;c[e>>2]=m;do{if((yO(m|0,105648,5)|0)==0){o=bw(m|0,102432)|0;if((o|0)==0){q=m;break}r=o+3|0;c[e>>2]=r;s=r;k=2814}else{s=m;k=2814}}while(0);do{if((k|0)==2814){r=yF(s|0)|0;o=yx(r+1|0)|0;if((o|0)==0){q=m;break}a[o+r|0]=0;r=bw(s|0,38832)|0;t=bw(s|0,108888)|0;if((r|0)==0|(t|0)==0){u=s;v=o}else{w=s;x=o;y=r;r=t;while(1){t=y-w|0;yJ(x|0,w|0,t)|0;z=x+t|0;t=r+3|0;A=bw(t|0,38832)|0;B=bw(t|0,108888)|0;if((A|0)==0|(B|0)==0){u=t;v=z;break}else{w=t;x=z;y=A;r=B}}}r=yF(u|0)|0;yJ(v|0,u|0,r)|0;a[v+r|0]=0;yz(m);c[e>>2]=o;r=i9(e)|0;c[b>>2]=r;if((r|0)==0){q=o;break}yz(o);g=h;i=d;return g|0}}while(0);yz(q);break L3742}}while(0);yz(n);k=2821}}while(0);if((k|0)==2821){aS(f|0)|0}if(j){g=0;i=d;return g|0}j=c[b>>2]|0;if((j|0)!=0){jd(j)}yz(b);g=0;i=d;return g|0}function i9(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=yy(1,24)|0;h=g;if((g|0)==0){j=0;i=d;return j|0}k=c[b>>2]|0;while(1){l=k+1|0;if((bf(a[k]|0)|0)==0){break}else{k=l}}c[b>>2]=k;L3778:do{if((a[k]|0)==60){m=b7(k|0,62)|0;if((m|0)==0){n=0;break}o=m-l|0;p=yx(o+1|0)|0;if((p|0)==0){n=0;break}yJ(p|0,l|0,o)|0;a[p+o|0]=0;o=p;while(1){if((bf(a[o]|0)|0)==0){q=o;break}else{o=o+1|0}}while(1){r=a[q]|0;if(r<<24>>24==0){s=0;break}if((bf(r<<24>>24|0)|0)==0){q=q+1|0}else{t=2841;break}}if((t|0)==2841){s=a[q]|0}r=(bf(s|0)|0)!=0?q:0;if((r|0)==0){u=dy(o|0)|0;c[g>>2]=u;if((u|0)==0){n=p;break}if((a[u]|0)==0){n=p;break}}else{u=r-o|0;v=yx(u+1|0)|0;if((v|0)==0){c[g>>2]=0;n=p;break}yJ(v|0,o|0,u)|0;a[v+u|0]=0;c[g>>2]=v;if((a[v]|0)==0){n=p;break}v=dy(r|0)|0;if((v|0)==0){w=0}else{r=v+((yF(v|0)|0)-1)|0;if((a[r]|0)==47){a[r]=0}r=ej(v|0,46928,e|0)|0;L3801:do{if((r|0)==0){x=0}else{u=r;y=0;z=0;while(1){A=bw(u|0,42680)|0;if((A|0)==0){x=z;break L3801}B=A+2|0;C=cn(B|0,34)|0;if((C|0)==0){x=z;break L3801}if((C|0)!=(u+((yF(u|0)|0)-1)|0)){x=z;break L3801}D=A-u|0;A=yx(D+1|0)|0;if((A|0)==0){E=0}else{yJ(A|0,u|0,D)|0;a[A+D|0]=0;E=A}A=C-B|0;C=yx(A+1|0)|0;if((C|0)==0){x=z;break L3801}yJ(C|0,B|0,A)|0;a[C+A|0]=0;if((E|0)==0){x=z;break L3801}A=yy(1,12)|0;B=A;if((A|0)==0){x=z;break L3801}c[A>>2]=E;c[A+4>>2]=C;if((y|0)==0){F=B}else{c[y+8>>2]=B;F=z}C=ej(0,46928,e|0)|0;if((C|0)==0){x=F;break}else{u=C;y=B;z=F}}}}while(0);yz(v);w=x}c[g+8>>2]=w}if(((bw(k|0,85640)|0)+1|0)==(m|0)){c[b>>2]=m+1}else{r=c[g>>2]|0;o=(yF(r|0)|0)+4|0;z=yx(o)|0;if((z|0)==0){n=p;break}bR(z|0,o|0,71216,(o=i,i=i+8|0,c[o>>2]=r,o)|0)|0;i=o;o=m+1|0;r=bw(o|0,61432)|0;y=b7(o|0,60)|0;u=bw(o|0,z|0)|0;if((u|0)==0){yz(z);n=p;break}L3828:do{if((r|0)==0){t=2877}else{B=o;while(1){if(B>>>0>=r>>>0){break}if((bf(a[B]|0)|0)==0){t=2877;break L3828}else{B=B+1|0}}B=bw(r|0,55384)|0;if((B|0)==0){yz(z);n=p;break L3778}C=r+9|0;A=B-C|0;B=yx(A+1|0)|0;if((B|0)==0){G=0}else{yJ(B|0,C|0,A)|0;a[B+A|0]=0;G=B}c[g+4>>2]=G;H=u}}while(0);do{if((t|0)==2877){if((u|0)==(y|0)){r=y-o|0;m=yx(r+1|0)|0;if((m|0)==0){I=0}else{yJ(m|0,o|0,r)|0;a[m+r|0]=0;I=m}c[g+4>>2]=I;H=y;break}c[f>>2]=y;m=b7(y|0,60)|0;r=bw(y|0,50832)|0;L3847:do{if((r|0)!=0&(m|0)!=0&m>>>0<r>>>0){v=0;B=0;while(1){A=i9(f)|0;if((A|0)==0){break}if((B|0)==0){J=A}else{c[B+16>>2]=A;J=v}C=c[f>>2]|0;D=b7(C|0,60)|0;K=bw(C|0,50832)|0;if((K|0)!=0&(D|0)!=0&D>>>0<K>>>0){v=J;B=A}else{L=J;M=C;break L3847}}yz(z);n=p;break L3778}else{L=0;M=y}}while(0);c[g+12>>2]=L;r=bw(M|0,z|0)|0;if((r|0)!=0){H=r;break}yz(z);n=p;break L3778}}while(0);c[b>>2]=H+(yF(z|0)|0);yz(z)}yz(p);j=h;i=d;return j|0}else{n=0}}while(0);yz(n);jd(h);j=0;i=d;return j|0}function ja(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;h=c[3718]|0;if((h|0)==0){c[3718]=1;j=1}else{j=h}if((b|0)==1){k=-1;i=g;return k|0}h=d+(j<<2)|0;l=c[h>>2]|0;m=(l|0)==0;L3869:do{if(m){n=-1;o=-1}else{q=0;r=l;while(1){if((a[r]|0)==45){if((a[r+1|0]|0)!=45){s=q;break}}t=q+1|0;u=c[d+(t+j<<2)>>2]|0;if((u|0)==0){s=-1;break}else{q=t;r=u}}if(m){n=-1;o=s;break}else{v=0;w=l}while(1){if((a[w]|0)==45){if((a[w+1|0]|0)==45){n=v;o=s;break L3869}}r=v+1|0;q=c[d+(r+j<<2)>>2]|0;if((q|0)==0){n=-1;o=s;break}else{v=r;w=q}}}}while(0);w=(o|0)==-1;v=(n|0)==-1;if(w&v){k=-1;i=g;return k|0}do{if((o|0)>0){if(!((o|0)<(n|0)|v)){x=2912;break}jb(h,d+(j+o<<2)|0,d+(b<<2)|0)}else{x=2912}}while(0);L3888:do{if((x|0)==2912){do{if((n|0)>0){if(!((n|0)<(o|0)|w)){x=2916;break}jb(h,d+(j+n<<2)|0,d+(b<<2)|0);if((o|0)==0){break L3888}y=c[3718]|0}else{x=2916}}while(0);do{if((x|0)==2916){v=(o|0)==0;s=(n|0)==0;if(!(v|s)){l=c[350134]|0;m=(l|0)!=0?l:c[p>>2]|0;en(m|0,106848,(m=i,i=i+16|0,c[m>>2]=105776,c[m+8>>2]=190,m)|0)|0;i=m;m=c[350134]|0;l=(m|0)!=0?m:c[p>>2]|0;a_(l|0)|0;ck(2);return 0}if(v){break L3888}if(s){y=j;break}else{k=63}i=g;return k|0}}while(0);s=d+(y<<2)|0;v=0;while(1){z=f+(v<<4)|0;l=c[z>>2]|0;if((l|0)==0){k=63;x=2944;break}if((cS(l|0,(c[s>>2]|0)+2|0)|0)==0){break}else{v=v+1|0}}if((x|0)==2944){i=g;return k|0}if((z|0)==0){k=63;i=g;return k|0}s=y+1|0;do{if((c[f+(v<<4)+4>>2]|0)==0){A=s}else{l=c[d+(s<<2)>>2]|0;if((l|0)==0){k=63;i=g;return k|0}else{c[159936]=l;A=y+2|0;break}}}while(0);c[3718]=A;s=c[f+(v<<4)+8>>2]|0;l=c[f+(v<<4)+12>>2]|0;if((s|0)==0){k=l;i=g;return k|0}c[s>>2]=l;k=0;i=g;return k|0}}while(0);f=c[3718]|0;A=c[d+(f<<2)>>2]|0;y=A+1|0;z=a[y]|0;if(z<<24>>24==58){k=63;i=g;return k|0}x=b7(e|0,z<<24>>24|0)|0;if((x|0)==0){k=63;i=g;return k|0}z=A+2|0;A=(a[x+1|0]|0)==58;e=A&(a[z]|0)!=0;if(!A){if(e){yN(y|0,z|0,(yF(z|0)|0)+1|0);k=a[x]|0;i=g;return k|0}else{c[3718]=f+1;k=a[x]|0;i=g;return k|0}}if(e){c[159936]=z;B=f+1|0;C=z}else{z=c[d+(f+1<<2)>>2]|0;c[159936]=z;B=f+2|0;C=z}c[3718]=B;if((C|0)==0){k=63;i=g;return k|0}k=a[x]|0;i=g;return k|0}function jb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b;g=f-a|0;h=g>>2;j=yy(h,4)|0;if((j|0)==0){k=c[350134]|0;l=(k|0)!=0?k:c[p>>2]|0;en(l|0,106848,(l=i,i=i+16|0,c[l>>2]=105776,c[l+8>>2]=150,l)|0)|0;i=l;l=c[350134]|0;k=(l|0)!=0?l:c[p>>2]|0;a_(k|0)|0;ck(2)}else{k=a;yJ(j|0,k|0,g)|0;yN(k|0,b|0,d-f|0);f=d+(-h<<2)|0;yJ(f|0,j|0,g)|0;yz(j);i=e;return}}function jc(a){a=a|0;var b=0;if((a|0)==0){return}b=c[a>>2]|0;if((b|0)!=0){jd(b)}yz(a);return}function jd(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((b|0)!=0){d=b;while(1){b=c[d+16>>2]|0;jd(d);if((b|0)==0){break}else{d=b}}}d=c[a+8>>2]|0;if((d|0)!=0){b=d;while(1){d=c[b+8>>2]|0;yz(c[b>>2]|0);yz(c[b+4>>2]|0);yz(b);if((d|0)==0){break}else{b=d}}}yz(c[a>>2]|0);yz(c[a+4>>2]|0);yz(a);return}function je(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+8|0;while(1){e=c[d>>2]|0;if((e|0)==0){f=0;g=2976;break}if((cS(b|0,c[e>>2]|0)|0)==0){break}else{d=e+8|0}}if((g|0)==2976){return f|0}f=c[e+4>>2]|0;return f|0}function jf(d,e,f,g,h,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;k=i;i=i+8248|0;l=k|0;m=k+4152|0;g2(m,106192,4096);n=k+56|0;g5(n,d,m,4096);m=dc(n|0,105688)|0;if((m|0)==0){d=c[350134]|0;o=(d|0)!=0?d:c[p>>2]|0;en(o|0,85464,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;o=c[350134]|0;n=(o|0)!=0?o:c[p>>2]|0;a_(n|0)|0;q=0;i=k;return q|0}n=l|0;o=f*3|0;d=o+3&-4;r=ab(d,g)|0;s=r+54|0;a[n]=66;a[l+1|0]=77;a[l+2|0]=s&255;a[l+3|0]=s>>>8&255;a[l+4|0]=s>>>16&255;a[l+5|0]=s>>>24&255;s=l+6|0;x=0;a[s]=x&255;x=x>>8;a[s+1|0]=x&255;x=x>>8;a[s+2|0]=x&255;x=x>>8;a[s+3|0]=x&255;a[l+10|0]=54;a[l+11|0]=0;a[l+12|0]=0;a[l+13|0]=0;a[l+14|0]=40;a[l+15|0]=0;a[l+16|0]=0;a[l+17|0]=0;a[l+18|0]=f&255;a[l+19|0]=f>>>8&255;a[l+20|0]=f>>>16&255;a[l+21|0]=f>>>24&255;a[l+22|0]=g&255;a[l+23|0]=g>>>8&255;a[l+24|0]=g>>>16&255;a[l+25|0]=g>>>24&255;a[l+26|0]=1;a[l+27|0]=0;a[l+28|0]=24;yG(l+29|0,0,5);a[l+34|0]=r&255;a[l+35|0]=r>>>8&255;a[l+36|0]=r>>>16&255;a[l+37|0]=r>>>24&255;a[l+38|0]=19;a[l+39|0]=11;a[l+40|0]=0;a[l+41|0]=0;a[l+42|0]=19;a[l+43|0]=11;yG(l+44|0,0,10);l=(a5(n|0,1,54,m|0)|0)==54;do{if(l){n=yy(g,4)|0;r=n;if((n|0)==0){break}else{t=0}while(1){if((t|0)>=(g|0)){u=2983;break}s=yy(1,d)|0;c[r+(t<<2)>>2]=s;if((s|0)==0){u=2999;break}else{t=t+1|0}}do{if((u|0)==2983){do{if(j){if((g|0)>0){v=e;w=0}else{u=2997;break}while(1){s=c[r+(w<<2)>>2]|0;yJ(s|0,v|0,o)|0;s=w+1|0;if((s|0)<(g|0)){v=v+h|0;w=s}else{u=2997;break}}}else{s=(g|0)>0;if((c[334462]|0)==1){if(!s){u=2997;break}if((f|0)==0){y=0;break}else{z=e;A=0}while(1){B=z;C=0;D=c[r+(A<<2)>>2]|0;while(1){E=c[B>>2]|0;a[D]=E&255;a[D+1|0]=E>>>8&255;a[D+2|0]=E>>>16&255;E=C+1|0;if(E>>>0<f>>>0){B=B+4|0;C=E;D=D+3|0}else{break}}D=A+1|0;if((D|0)<(g|0)){z=z+h|0;A=D}else{u=2997;break}}}else{if(!s){u=2997;break}if((f|0)==0){y=0;break}else{F=e;G=0}while(1){D=0;C=F;B=c[r+(G<<2)>>2]|0;while(1){E=b[C>>1]|0;H=E&255;a[B]=(H&255)>>>2&7|H<<3;a[B+1|0]=(E&65535)>>>5<<2&255|(E&65535)>>>9&3;H=(E&65535)>>>11&65535;a[B+2|0]=(H<<3|H>>>2)&255;H=D+1|0;if(H>>>0<f>>>0){D=H;C=C+2|0;B=B+3|0}else{break}}B=G+1|0;if((B|0)<(g|0)){F=F+h|0;G=B}else{u=2997;break}}}}}while(0);if((u|0)==2997){if((g|0)==0){break}else{y=0}}while(1){a5(c[r+(y<<2)>>2]|0,1,d|0,m|0)|0;s=y+1|0;if(s>>>0<g>>>0){y=s}else{u=2999;break}}}}while(0);do{if((u|0)==2999){if((g|0)>0){I=0}else{break}do{yz(c[r+(I<<2)>>2]|0);I=I+1|0;}while((I|0)<(g|0))}}while(0);yz(n)}else{r=c[350134]|0;a5(71120,51,1,((r|0)!=0?r:c[p>>2]|0)|0)|0;r=c[350134]|0;a_(((r|0)!=0?r:c[p>>2]|0)|0)|0}}while(0);aS(m|0)|0;q=l;i=k;return q|0}function jg(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=i;i=i+16|0;e=d|0;f=d+8|0;fQ[c[157592]&1023]();g=yy(1,16)|0;h=g;if((g|0)==0){j=0;i=d;return j|0}k=g+12|0;c[k>>2]=1;l=yy(1,12)|0;m=g;c[m>>2]=l;do{if((l|0)==0){c[k>>2]=0}else{n=i8(b)|0;if((n|0)==0){o=c[350134]|0;q=(o|0)!=0?o:c[p>>2]|0;en(q|0,105928,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;q=c[350134]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;break}o=i6(n)|0;L4026:do{if((o|0)!=0){q=o;while(1){if((c[q+20>>2]|0)==0){if((cS(c[q>>2]|0,105664)|0)==0){break}}s=c[q+16>>2]|0;if((s|0)==0){break L4026}else{q=s}}s=c[q+12>>2]|0;if((s|0)==0){break}else{t=s}L4033:while(1){do{if((c[t+20>>2]|0)==0){if((cS(c[t>>2]|0,85416)|0)!=0){break}s=je(t,71112)|0;if((s|0)==0|(a[1400372]|0)==0){break}if((cS(s|0,1400372)|0)==0){break L4033}}}while(0);s=c[t+16>>2]|0;if((s|0)==0){break L4026}else{t=s}}q=c[t+12>>2]|0;s=g+8|0;L4041:do{if((q|0)!=0){u=q;L4042:while(1){v=c[u>>2]|0;L4044:do{if((cS(v|0,98488)|0)==0){w=c[u+4>>2]|0;if((w|0)==0){break}if((a[1243488]&1)==0){break}x=c[350134]|0;y=(x|0)!=0?x:c[p>>2]|0;en(y|0,96288,(r=i,i=i+8|0,c[r>>2]=w,r)|0)|0;i=r;w=c[350134]|0;y=(w|0)!=0?w:c[p>>2]|0;a_(y|0)|0}else{if((cS(v|0,94304)|0)!=0){break}y=c[s>>2]|0;if((y|0)==(c[k>>2]|0)){c[k>>2]=y<<1;w=yA(c[m>>2]|0,y*24|0)|0;x=w;c[m>>2]=x;if((w|0)==0){break L4042}z=c[s>>2]|0;A=x}else{z=y;A=c[m>>2]|0}y=A+(z*12|0)|0;x=c[u+12>>2]|0;if((x|0)==0){break}yG(y|0,0,12);w=y|0;y=A+(z*12|0)+8|0;B=x;x=1;C=0;D=0;L4056:while(1){E=c[B>>2]|0;do{if((cS(E|0,92568)|0)==0){c[w>>2]=c[B+4>>2];F=x;G=C;H=D}else{if((cS(E|0,90952)|0)!=0){F=x;G=C;H=D;break}do{if(x){I=C}else{J=(D|0)!=0;if(J){K=(yF(D|0)|0)+2|0}else{K=2}L=yA(D,K)|0;if((L|0)==0){M=3041;break L4056}if(J){i7(L,89024,K)|0;c[y>>2]=L;I=L;break}else{i5(L,89024,K)|0;c[y>>2]=L;I=L;break}}}while(0);L=c[B+4>>2]|0;if((L|0)==0){break L4044}J=(I|0)!=0;if(J){N=(yF(I|0)|0)+1|0}else{N=1}O=(yF(L|0)|0)+N|0;P=yA(I,O)|0;if((P|0)==0){M=3049;break L4056}if(J){i7(P,L,O)|0;c[y>>2]=P;F=0;G=P;H=P;break}else{i5(P,L,O)|0;c[y>>2]=P;F=0;G=P;H=P;break}}}while(0);E=c[B+16>>2]|0;if((E|0)==0){M=3054;break}else{B=E;x=F;C=G;D=H}}if((M|0)==3041){M=0;c[y>>2]=0;break}else if((M|0)==3049){M=0;c[y>>2]=0;break}else if((M|0)==3054){M=0;c[s>>2]=(c[s>>2]|0)+1;break}}}while(0);u=c[u+16>>2]|0;if((u|0)==0){break L4041}}u=c[350134]|0;a5(61360,68,1,((u|0)!=0?u:c[p>>2]|0)|0)|0;u=c[350134]|0;a_(((u|0)!=0?u:c[p>>2]|0)|0)|0;break L4026}}while(0);if((c[s>>2]|0)==0){q=c[350134]|0;u=(q|0)!=0?q:c[p>>2]|0;en(u|0,55304,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;u=c[350134]|0;q=(u|0)!=0?u:c[p>>2]|0;a_(q|0)|0;break}do{if((a[1226532]|0)!=0){q=hs(1226532)|0;if((q|0)==0){break}c[e>>2]=0;if(!(hB(q,1400372,e)|0)){ht(q);break}u=ej(c[e>>2]|0,100080,f|0)|0;if((u|0)!=0){v=u;do{u=aX(v|0,0,0)|0;if(u>>>0<(c[s>>2]|0)>>>0){a[(c[m>>2]|0)+(u*12|0)+4|0]=1}v=ej(0,100080,f|0)|0;}while((v|0)!=0)}yz(c[e>>2]|0);ht(q);fQ[c[157592]&1023]();v=c[s>>2]|0;if((v|0)==0){break}else{Q=0;R=0;S=v}while(1){v=c[m>>2]|0;if((a[v+(R*12|0)+4|0]&1)==0){T=Q;U=S}else{fP[c[157590]&127](Q,1,c[v+(R*12|0)+8>>2]|0);T=Q+1|0;U=c[s>>2]|0}v=R+1|0;if(v>>>0<U>>>0){Q=T;R=v;S=U}else{break}}}}while(0);jc(n);j=h;i=d;return j|0}}while(0);jl(h);jc(n);j=0;i=d;return j|0}}while(0);jl(h);j=0;i=d;return j|0}function jh(){return}function ji(a){a=a|0;return 1}function jj(a,c,d,e){a=a|0;c=c|0;d=d|0;e=+e;var f=0.0,h=0;f=e*30517578125.0e-15;if((d|0)==0){return}else{h=0}do{g[a+(h<<2)>>2]=f*+(b[c+(h<<1)>>1]|0);h=h+1|0;}while(h>>>0<d>>>0);return}function jk(a,c,d){a=a|0;c=c|0;d=d|0;var e=0,f=0,h=0;if((d|0)==0){return}else{e=0}do{f=~~(+g[c+(e<<2)>>2]*32768.0);if((f|0)>32767){h=32767}else{h=(f|0)<-32768?-32768:f&65535}b[a+(e<<1)>>1]=h;e=e+1|0;}while(e>>>0<d>>>0);return}function jl(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;d=i;i=i+544|0;e=d|0;if((b|0)==0){i=d;return}f=b|0;if((c[f>>2]|0)!=0){g=e|0;h=d+512|0;L4139:do{if((a[1226532]|0)!=0){j=hs(1226532)|0;do{if((j|0)==0){k=hs(0)|0;if((k|0)!=0){l=k;break}k=c[350134]|0;m=(k|0)!=0?k:c[p>>2]|0;a5(108824,53,1,m|0)|0;m=c[350134]|0;k=(m|0)!=0?m:c[p>>2]|0;a_(k|0)|0;break L4139}else{l=j}}while(0);yG(g|0,0,512);yG(h|0,0,32);j=b+8|0;k=c[j>>2]|0;do{if((k|0)!=0){m=0;n=k;while(1){if((a[(c[f>>2]|0)+(m*12|0)+4|0]&1)==0){o=n}else{bR(h|0,32,105608,(q=i,i=i+8|0,c[q>>2]=m,q)|0)|0;i=q;i7(g,h,512)|0;o=c[j>>2]|0}r=m+1|0;if(r>>>0<o>>>0){m=r;n=o}else{break}}if((a[g]|0)==0){break}a[e+((yF(g|0)|0)-1)|0]=0}}while(0);hF(l,1400372,g);if(!(hK(l,1226532)|0)){j=c[350134]|0;k=(j|0)!=0?j:c[p>>2]|0;en(k|0,102304,(q=i,i=i+8|0,c[q>>2]=1226532,q)|0)|0;i=q;k=c[350134]|0;j=(k|0)!=0?k:c[p>>2]|0;a_(j|0)|0}ht(l)}}while(0);l=b+8|0;q=c[f>>2]|0;if((c[l>>2]|0)==0){s=q}else{g=0;e=q;while(1){yz(c[e+(g*12|0)+8>>2]|0);q=g+1|0;o=c[f>>2]|0;if(q>>>0<(c[l>>2]|0)>>>0){g=q;e=o}else{s=o;break}}}yz(s)}yz(b);i=d;return}function jm(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b|0;e=(c[d>>2]|0)+((c[b+4>>2]|0)*12|0)+4|0;a[e]=a[e]&1^1;fQ[c[157592]&1023]();e=b+8|0;f=c[e>>2]|0;if((f|0)==0){jn(b);return}else{g=0;h=0;i=f}while(1){f=c[d>>2]|0;if((a[f+(h*12|0)+4|0]&1)==0){j=g;k=i}else{fP[c[157590]&127](g,1,c[f+(h*12|0)+8>>2]|0);j=g+1|0;k=c[e>>2]|0}f=h+1|0;if(f>>>0<k>>>0){g=j;h=f;i=k}else{break}}jn(b);return}function jn(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+256|0;ip(c[348003]|0);e=d|0;f=c[b+4>>2]|0;g=c[b>>2]|0;b=(a[g+(f*12|0)+4|0]&1)!=0?46888:42664;h=c[g+(f*12|0)>>2]|0;bR(e|0,256,50792,(g=i,i=i+24|0,c[g>>2]=f,c[g+8>>2]=b,c[g+16>>2]=h,g)|0)|0;i=g;iq(c[348003]|0,e,1,180);if((a[1243488]&1)==0){i=d;return}h=c[350134]|0;en(((h|0)!=0?h:c[p>>2]|0)|0,38784,(g=i,i=i+8|0,c[g>>2]=e,g)|0)|0;i=g;g=c[350134]|0;a_(((g|0)!=0?g:c[p>>2]|0)|0)|0;i=d;return}function jo(a){a=a|0;var b=0;b=a+4|0;c[b>>2]=(((c[b>>2]|0)+1|0)>>>0)%((c[a+8>>2]|0)>>>0)|0;jn(a);return}function jp(a){a=a|0;var b=0,d=0,e=0;b=a+4|0;d=c[b>>2]|0;if((d|0)==0){e=c[a+8>>2]|0}else{e=d}c[b>>2]=e-1;jn(a);return}function jq(a,b,d){a=a|0;b=b|0;d=d|0;b=aT(d|0)|0;if((b|0)==0){return b|0}c[289288]=c2()|0;return b|0}function jr(a,b,c){a=a|0;b=b|0;c=c|0;return bI(b|0,c|0)|0}function js(a){a=a|0;return aN()|0}function jt(a){a=a|0;return e9()|0}function ju(a,b){a=a|0;b=b|0;d9(b|0);return}function jv(a){a=a|0;d2();return}function jw(a){a=a|0;return cU()|0}function jx(a){a=a|0;return bm()|0}function jy(b,d){b=b|0;d=+d;var e=0,f=0,h=0,i=0,j=0.0;e=b+24|0;if((c[e>>2]|0)!=0){f=b+12|0;h=0;do{i=c[f>>2]|0;if((a[i+(h*136|0)+20|0]&1)==0){g[i+(h*136|0)+56>>2]=d;g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2]*d;g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]*d;j=+g[i+(h*136|0)+60>>2];g[i+(h*136|0)+24>>2]=j+(+g[i+(h*136|0)+40>>2]-j)*d;j=+g[i+(h*136|0)+64>>2];g[i+(h*136|0)+28>>2]=j+(+g[i+(h*136|0)+44>>2]-j)*d}else{g[i+(h*136|0)+24>>2]=+g[i+(h*136|0)+40>>2];g[i+(h*136|0)+28>>2]=+g[i+(h*136|0)+44>>2];g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2];g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]}h=h+1|0;}while(h>>>0<(c[e>>2]|0)>>>0)}e=c[b+16>>2]|0;fx[c[(c[b+4>>2]|0)+12>>2]&7](c[b>>2]|0,+g[e+24>>2],+g[e+28>>2],+g[e+32>>2],+g[e+36>>2]);return}function jz(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0.0,aC=0.0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0;d=i;i=i+9256|0;e=d|0;f=d+64|0;h=d+320|0;j=d+328|0;k=d+392|0;l=d+456|0;m=d+520|0;n=d+584|0;o=d+4680|0;q=d+8776|0;r=d+8792|0;s=d+8856|0;t=d+9112|0;u=d+9176|0;v=d+9240|0;w=d+9248|0;x=yy(1,32)|0;y=x;if((x|0)==0){z=0;i=d;return z|0}A=c[(c[350657]|0)+52>>2]|0;do{if((A|0)==0){B=c[350134]|0;C=(B|0)!=0?B:c[p>>2]|0;a5(103952,71,1,C|0)|0;C=c[350134]|0;B=(C|0)!=0?C:c[p>>2]|0;a_(B|0)|0}else{B=x+4|0;ft[A&127](c[350660]|0,B);C=x;c[C>>2]=c[350660];if((c[B>>2]|0)==0){break}D=hs(b)|0;if((D|0)==0){E=c[350134]|0;G=(E|0)!=0?E:c[p>>2]|0;en(G|0,105408,(H=i,i=i+8|0,c[H>>2]=b,H)|0)|0;i=H;G=c[350134]|0;E=(G|0)!=0?G:c[p>>2]|0;a_(E|0)|0;break}c[w>>2]=0;L4216:do{if(hz(D,85168,w)|0){E=c[w>>2]|0;if((E|0)==0){break}G=yy(E,136)|0;I=G;J=x+12|0;c[J>>2]=I;if((G|0)==0){break}G=x+24|0;c[G>>2]=E;E=l|0;K=m|0;L=n|0;M=o|0;N=q;O=r|0;P=s|0;Q=t|0;R=u|0;S=q+8|0;T=q|0;U=q+4|0;V=e|0;W=f|0;X=j|0;Y=k|0;bR(E|0,64,46824,(H=i,i=i+8|0,c[H>>2]=0,H)|0)|0;i=H;L4221:do{if(hD(D,E,L,4096)|0){Z=I;_=0;L4222:while(1){bR(K|0,64,38760,(H=i,i=i+8|0,c[H>>2]=_,H)|0)|0;i=H;hC(D,K,Z+(_*136|0)+69|0,64)|0;hd(M,b,L,4096);yG(N|0,0,12);if(!(ko(M,q)|0)){$=3164;break}c[Z+(_*136|0)+8>>2]=c[S>>2];c[Z+(_*136|0)+12>>2]=c[T>>2];c[Z+(_*136|0)+16>>2]=c[U>>2];aa=Z+(_*136|0)+44|0;g[aa>>2]=0.0;ab=Z+(_*136|0)+40|0;g[ab>>2]=0.0;ac=Z+(_*136|0)+52|0;g[ac>>2]=1.0;ad=Z+(_*136|0)+48|0;g[ad>>2]=1.0;bR(O|0,64,105552,(H=i,i=i+8|0,c[H>>2]=_,H)|0)|0;i=H;if(hC(D,O,P,256)|0){ae=gY(P,102240)|0;if((c[ae+4>>2]|0)>>>0<4){$=3167;break}af=ae|0;g[ab>>2]=+yD(c[c[af>>2]>>2]|0,0);g[aa>>2]=+yD(c[(c[af>>2]|0)+8>>2]|0,0);g[ad>>2]=+yD(c[(c[af>>2]|0)+16>>2]|0,0);g[ac>>2]=+yD(c[(c[af>>2]|0)+24>>2]|0,0);gS(ae)}bR(Q|0,64,98456,(H=i,i=i+8|0,c[H>>2]=_,H)|0)|0;i=H;ae=Z+(_*136|0)+68|0;a[ae]=0;hE(D,Q,ae)|0;bR(R|0,64,96272,(H=i,i=i+8|0,c[H>>2]=_,H)|0)|0;i=H;c[v>>2]=0;if(!(hz(D,R,v)|0)){$=3170;break}ae=c[v>>2]|0;af=yy(ae,104)|0;ag=af;ah=Z+(_*136|0)|0;c[ah>>2]=ag;if((af|0)==0){$=3172;break}af=Z+(_*136|0)+4|0;c[af>>2]=ae;L4231:do{if((ae|0)!=0){ai=c[T>>2]|0;aj=c[U>>2]|0;bR(V|0,64,88960,(H=i,i=i+16|0,c[H>>2]=_,c[H+8>>2]=0,H)|0)|0;i=H;if(hC(D,V,W,256)|0){ak=ag;al=0;am=ai;an=aj}else{ao=0;$=3175;break L4222}while(1){ap=gY(W,102240)|0;if((ap|0)==0){$=3177;break L4222}if((c[ap+4>>2]|0)>>>0<6){$=3179;break L4222}aj=ap|0;ai=c[aj>>2]|0;aq=c[ai+8>>2]|0;ar=c[ai+16>>2]|0;as=c[ai+24>>2]|0;at=c[ai>>2]|0;ai=ak+(al*104|0)+24|0;c[ai>>2]=0;c[ai+4>>2]=0;do{if((cS(at|0,80864)|0)==0){c[ak+(al*104|0)+20>>2]=1}else{au=ak+(al*104|0)+20|0;if((cS(at|0,79128)|0)==0){c[au>>2]=2;break}c[au>>2]=0;au=ej(at|0,77720,h|0)|0;if((au|0)!=0){av=au;do{au=0;while(1){if(au>>>0>=56){aw=0;ax=56;break}if((cS(c[2864+(au<<3)>>2]|0,av|0)|0)==0){$=3188;break}else{au=au+1|0}}if(($|0)==3188){$=0;aw=0;ax=c[2868+(au<<3)>>2]|0}ay=yV(1,0,ax|0)|0;az=F;aA=c[ai+4>>2]|az;c[ai>>2]=c[ai>>2]|ay;c[ai+4>>2]=aA;av=ej(0,77720,h|0)|0;}while((av|0)!=0)}if((c[ai>>2]&0|0)==0&(c[ai+4>>2]&524288|0)==0){break}bR(X|0,64,76352,(H=i,i=i+16|0,c[H>>2]=_,c[H+8>>2]=al,H)|0)|0;i=H;av=ak+(al*104|0)+40|0;hC(D,X,av,64)|0}}while(0);aB=+(am>>>0>>>0);g[ak+(al*104|0)>>2]=+yD(aq,0)/aB;aC=+(an>>>0>>>0);g[ak+(al*104|0)+4>>2]=+yD(ar,0)/aC;if((cS(as|0,75104)|0)==0){c[ak+(al*104|0)+8>>2]=0;aD=0}else{if((cS(as|0,74176)|0)!=0){$=3196;break L4222}c[ak+(al*104|0)+8>>2]=1;aD=1}do{if((c[ak+(al*104|0)+20>>2]|0)!=0){if((aD|0)!=0){$=3199;break L4222}bR(Y|0,64,71064,(H=i,i=i+16|0,c[H>>2]=_,c[H+8>>2]=al,H)|0)|0;i=H;ai=ak+(al*104|0)+32|0;if(hx(D,Y,ai)|0){break}g[ai>>2]=1.0}}while(0);g[ak+(al*104|0)+12>>2]=+yD(c[(c[aj>>2]|0)+32>>2]|0,0)/aB;g[ak+(al*104|0)+16>>2]=+yD(c[(c[aj>>2]|0)+40>>2]|0,0)/aC;gS(ap);ar=al+1|0;if(ar>>>0>=(c[af>>2]|0)>>>0){break L4231}aq=c[ah>>2]|0;ai=c[T>>2]|0;at=c[U>>2]|0;bR(V|0,64,88960,(H=i,i=i+16|0,c[H>>2]=_,c[H+8>>2]=ar,H)|0)|0;i=H;if(hC(D,V,W,256)|0){ak=aq;al=ar;am=ai;an=at}else{ao=ar;$=3175;break L4222}}}}while(0);a[Z+(_*136|0)+20|0]=0;g[Z+(_*136|0)+60>>2]=+g[ab>>2]+ +g[ad>>2]*.5;g[Z+(_*136|0)+64>>2]=+g[aa>>2]+ +g[ac>>2]*.5;ah=_+1|0;aE=c[G>>2]|0;if(ah>>>0>=aE>>>0){$=3161;break}af=c[J>>2]|0;bR(E|0,64,46824,(H=i,i=i+8|0,c[H>>2]=ah,H)|0)|0;i=H;if(hD(D,E,L,4096)|0){Z=af;_=ah}else{aF=ah;$=3162;break L4221}}if(($|0)==3177){Z=c[350134]|0;ah=(Z|0)!=0?Z:c[p>>2]|0;a5(85344,62,1,ah|0)|0;ah=c[350134]|0;Z=(ah|0)!=0?ah:c[p>>2]|0;a_(Z|0)|0;aG=al}else if(($|0)==3196){Z=c[350134]|0;en(((Z|0)!=0?Z:c[p>>2]|0)|0,73080,(H=i,i=i+8|0,c[H>>2]=as,H)|0)|0;i=H;Z=c[350134]|0;a_(((Z|0)!=0?Z:c[p>>2]|0)|0)|0;gS(ap);aG=al}else if(($|0)==3164){Z=c[350134]|0;en(((Z|0)!=0?Z:c[p>>2]|0)|0,108768,(H=i,i=i+8|0,c[H>>2]=L,H)|0)|0;i=H;Z=c[350134]|0;a_(((Z|0)!=0?Z:c[p>>2]|0)|0)|0;aH=_;break}else if(($|0)==3161){L4273:do{if((aE|0)!=0){Z=0;ah=aE;L4274:while(1){af=c[J>>2]|0;ag=af+(Z*136|0)+4|0;if((c[ag>>2]|0)==0){aI=ah;aJ=Z+1|0}else{ae=af+(Z*136|0)|0;ar=Z+1|0;at=0;do{ai=c[ae>>2]|0;aK=ai+(at*104|0)+40|0;if((a[aK]|0)==0){c[ai+(at*104|0)+36>>2]=(ar>>>0)%(ah>>>0)|0}else{aq=0;while(1){if(aq>>>0>=ah>>>0){break L4274}if((cS(af+(aq*136|0)+69|0,aK|0)|0)==0){break}else{aq=aq+1|0}}if((aq|0)<0){break L4274}c[ai+(at*104|0)+36>>2]=aq}at=at+1|0;}while(at>>>0<(c[ag>>2]|0)>>>0);aI=c[G>>2]|0;aJ=ar}if(aJ>>>0<aI>>>0){Z=aJ;ah=aI}else{break L4273}}ah=c[350134]|0;en(((ah|0)!=0?ah:c[p>>2]|0)|0,50664,(H=i,i=i+8|0,c[H>>2]=aK,H)|0)|0;i=H;ah=c[350134]|0;a_(((ah|0)!=0?ah:c[p>>2]|0)|0)|0;ah=c[350134]|0;a5(55176,64,1,((ah|0)!=0?ah:c[p>>2]|0)|0)|0;ah=c[350134]|0;a_(((ah|0)!=0?ah:c[p>>2]|0)|0)|0;break L4216}}while(0);ht(D);ah=c[J>>2]|0;Z=x+16|0;c[Z>>2]=ah;fO[c[(c[B>>2]|0)+4>>2]&15](c[C>>2]|0,c[ah+8>>2]|0,c[ah+12>>2]|0,c[ah+16>>2]|0)|0;ah=c[Z>>2]|0;fx[c[(c[B>>2]|0)+12>>2]&7](c[C>>2]|0,+g[ah+24>>2],+g[ah+28>>2],+g[ah+32>>2],+g[ah+36>>2]);ft[c[(c[B>>2]|0)+16>>2]&127](c[C>>2]|0,(a[(c[Z>>2]|0)+68|0]&1)!=0);ft[c[c[B>>2]>>2]&127](c[C>>2]|0,1);a[x+8|0]=1;fq[c[(c[B>>2]|0)+20>>2]&7](c[C>>2]|0,+g[301510]);jy(y,1.0);c[x+28>>2]=(((c[x+20>>2]|0)+1|0)>>>0)%((c[G>>2]|0)>>>0)|0;z=y;i=d;return z|0}else if(($|0)==3170){Z=c[350134]|0;en(((Z|0)!=0?Z:c[p>>2]|0)|0,94184,(H=i,i=i+8|0,c[H>>2]=R,H)|0)|0;i=H;Z=c[350134]|0;a_(((Z|0)!=0?Z:c[p>>2]|0)|0)|0;aH=_;break}else if(($|0)==3172){Z=c[350134]|0;a5(92480,58,1,((Z|0)!=0?Z:c[p>>2]|0)|0)|0;Z=c[350134]|0;a_(((Z|0)!=0?Z:c[p>>2]|0)|0)|0;aH=_;break}else if(($|0)==3175){Z=c[350134]|0;en(((Z|0)!=0?Z:c[p>>2]|0)|0,87296,(H=i,i=i+8|0,c[H>>2]=V,H)|0)|0;i=H;Z=c[350134]|0;a_(((Z|0)!=0?Z:c[p>>2]|0)|0)|0;aG=ao}else if(($|0)==3199){Z=c[350134]|0;a5(72232,69,1,((Z|0)!=0?Z:c[p>>2]|0)|0)|0;Z=c[350134]|0;a_(((Z|0)!=0?Z:c[p>>2]|0)|0)|0;gS(ap);aG=al}else if(($|0)==3167){Z=c[350134]|0;en(((Z|0)!=0?Z:c[p>>2]|0)|0,99976,(H=i,i=i+8|0,c[H>>2]=P,H)|0)|0;i=H;Z=c[350134]|0;a_(((Z|0)!=0?Z:c[p>>2]|0)|0)|0;aH=_;break}else if(($|0)==3179){gS(ap);Z=c[350134]|0;a5(82752,85,1,((Z|0)!=0?Z:c[p>>2]|0)|0)|0;Z=c[350134]|0;a_(((Z|0)!=0?Z:c[p>>2]|0)|0)|0;aG=al}Z=c[350134]|0;en(((Z|0)!=0?Z:c[p>>2]|0)|0,90872,(H=i,i=i+8|0,c[H>>2]=aG,H)|0)|0;i=H;Z=c[350134]|0;a_(((Z|0)!=0?Z:c[p>>2]|0)|0)|0;aH=_}else{aF=0;$=3162}}while(0);if(($|0)==3162){P=c[350134]|0;V=(P|0)!=0?P:c[p>>2]|0;en(V|0,42504,(H=i,i=i+8|0,c[H>>2]=E,H)|0)|0;i=H;V=c[350134]|0;P=(V|0)!=0?V:c[p>>2]|0;a_(P|0)|0;aH=aF}P=c[350134]|0;V=(P|0)!=0?P:c[p>>2]|0;en(V|0,61208,(H=i,i=i+8|0,c[H>>2]=aH,H)|0)|0;i=H;V=c[350134]|0;P=(V|0)!=0?V:c[p>>2]|0;a_(P|0)|0}else{P=c[350134]|0;V=(P|0)!=0?P:c[p>>2]|0;a5(70936,62,1,V|0)|0;V=c[350134]|0;P=(V|0)!=0?V:c[p>>2]|0;a_(P|0)|0}}while(0);ht(D)}}while(0);H=x+24|0;aH=x+12|0;aF=c[aH>>2]|0;if((c[H>>2]|0)==0){aL=aF}else{$=0;aG=aF;while(1){yz(c[aG+($*136|0)>>2]|0);yz(c[aG+($*136|0)+8>>2]|0);aF=$+1|0;al=c[aH>>2]|0;if(aF>>>0<(c[H>>2]|0)>>>0){$=aF;aG=al}else{aL=al;break}}}yz(aL);aL=c[x+4>>2]|0;if((aL|0)!=0){ft[c[aL>>2]&127](c[x>>2]|0,0)}yz(x);z=0;i=d;return z|0}function jA(a,b){a=a|0;b=+b;fq[c[(c[a+4>>2]|0)+20>>2]&7](c[a>>2]|0,b);return}function jB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)==0){return}b=a+24|0;d=a+12|0;e=c[d>>2]|0;if((c[b>>2]|0)==0){f=e}else{g=0;h=e;while(1){yz(c[h+(g*136|0)>>2]|0);yz(c[h+(g*136|0)+8>>2]|0);e=g+1|0;i=c[d>>2]|0;if(e>>>0<(c[b>>2]|0)>>>0){g=e;h=i}else{f=i;break}}}yz(f);f=c[a+4>>2]|0;if((f|0)!=0){ft[c[f>>2]&127](c[a>>2]|0,0)}yz(a);return}function jC(b){b=b|0;a[b+9|0]=0;return}function jD(b){b=b|0;return(a[(c[b+16>>2]|0)+68|0]&1)!=0|0}function jE(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)>0){i=0;j=a;k=c}else{return}while(1){c=0;do{a=b[k+(c<<1)>>1]|0;b[j+(c<<1)>>1]=(a&65535)>>>1&32736|a&31;c=c+1|0;}while((c|0)<(d|0));c=i+1|0;if((c|0)<(e|0)){i=c;j=j+(h<<1)|0;k=k+(f<<1)|0}else{break}}return}function jF(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)>0){i=0;j=a;k=c}else{return}while(1){c=0;do{a=b[k+(c<<1)>>1]|0;b[j+(c<<1)>>1]=a<<1&-64|a&31|(a&65535)>>>4&32;c=c+1|0;}while((c|0)<(d|0));c=i+1|0;if((c|0)<(e|0)){i=c;j=j+(h<<1)|0;k=k+(f<<1)|0}else{break}}return}function jG(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)>0){j=0;k=a;l=b}else{return}while(1){b=0;do{a=e[l+(b<<1)>>1]|0;h=a>>>10&31;m=a>>>5&31;n=a&31;c[k+(b<<2)>>2]=n>>>2|n<<3|(m<<3|m>>>2)<<8|(h<<3|h>>>2)<<16|-16777216;b=b+1|0;}while((b|0)<(d|0));b=j+1|0;if((b|0)<(f|0)){j=b;k=k+(i<<2)|0;l=l+(g<<1)|0}else{break}}return}function jH(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)>0){j=0;k=a;l=b}else{return}while(1){b=0;do{a=e[l+(b<<1)>>1]|0;h=a>>>5&63;m=a&31;c[k+(b<<2)>>2]=m>>>2|m<<3|(a>>>11<<3|a>>>13)<<16|(h<<2|h>>>4)<<8|-16777216;b=b+1|0;}while((b|0)<(d|0));b=j+1|0;if((b|0)<(f|0)){j=b;k=k+(i<<2)|0;l=l+(g<<1)|0}else{break}}return}function jI(d,e,f,h){d=d|0;e=e|0;f=f|0;h=h|0;var i=0,j=0,k=0,l=0.0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0,E=0,F=0,G=0.0,H=0.0;i=e;yG(i|0,0,16);if((a[d+8|0]&1)==0){a[d+9|0]=0;return}j=d+16|0;k=c[j>>2]|0;l=(+((f<<16>>16)+32767|0)/65535.0- +g[k+24>>2])/+g[k+32>>2];m=(+((h<<16>>16)+32767|0)/65535.0- +g[k+28>>2])/+g[k+36>>2];do{if((c[k+4>>2]|0)==0){n=d+9|0}else{h=e|0;f=d+28|0;o=0;p=k;do{q=c[p>>2]|0;r=q+(o*104|0)|0;s=c[q+(o*104|0)+8>>2]|0;do{if((s|0)==0){t=+g[r>>2];u=+g[q+(o*104|0)+12>>2];v=(l-t)/u;w=+g[q+(o*104|0)+4>>2];x=+g[q+(o*104|0)+16>>2];y=(m-w)/x;if(v*v+y*y<=1.0){z=t;A=u;B=w;C=x;D=3289}}else if((s|0)==1){x=+g[r>>2];w=+Q(+(l-x));u=+g[q+(o*104|0)+12>>2];if(w>u){break}w=+g[q+(o*104|0)+4>>2];t=+Q(+(m-w));y=+g[q+(o*104|0)+16>>2];if(t<=y){z=x;A=u;B=w;C=y;D=3289}}}while(0);do{if((D|0)==3289){D=0;r=c[q+(o*104|0)+20>>2]|0;if((r|0)==0){s=q+(o*104|0)+24|0;E=c[s>>2]|0;F=c[s+4>>2]|0;s=c[h+4>>2]|F;c[h>>2]=c[h>>2]|E;c[h+4>>2]=s;if((E&0|0)==0&(F&524288|0)==0){break}c[f>>2]=c[(c[c[j>>2]>>2]|0)+(o*104|0)+36>>2];break}y=+g[q+(o*104|0)+32>>2];w=(l-z)/A/y;u=(m-B)/C/y;if(+Q(+w)>1.0){G=w>0.0?1.0:-1.0}else{G=w}if(+Q(+u)>1.0){H=u>0.0?1.0:-1.0}else{H=u}F=(r|0)==2?2:0;b[e+8+(F<<1)>>1]=~~(G*32767.0);b[e+8+((F|1)<<1)>>1]=~~(H*32767.0)}}while(0);o=o+1|0;p=c[j>>2]|0;}while(o>>>0<(c[p+4>>2]|0)>>>0);p=d+9|0;if((c[h>>2]|0)==0&(c[h+4>>2]|0)==0){n=p;break}if((a[p]&1)==0){return}yG(i|0,0,16);return}}while(0);a[n]=0;return}function jJ(b){b=b|0;var d=0,e=0,f=0,h=0,i=0,j=0,k=0;d=b+28|0;e=c[d>>2]|0;f=b+20|0;c[f>>2]=e;h=c[b+12>>2]|0;i=b+16|0;c[i>>2]=h+(e*136|0);j=b+4|0;k=b|0;fO[c[(c[j>>2]|0)+4>>2]&15](c[k>>2]|0,c[h+(e*136|0)+8>>2]|0,c[h+(e*136|0)+12>>2]|0,c[h+(e*136|0)+16>>2]|0)|0;e=c[i>>2]|0;fx[c[(c[j>>2]|0)+12>>2]&7](c[k>>2]|0,+g[e+24>>2],+g[e+28>>2],+g[e+32>>2],+g[e+36>>2]);ft[c[(c[j>>2]|0)+16>>2]&127](c[k>>2]|0,(a[(c[i>>2]|0)+68|0]&1)!=0);a[b+9|0]=1;c[d>>2]=(((c[f>>2]|0)+1|0)>>>0)%((c[b+24>>2]|0)>>>0)|0;return}function jK(a,b){a=a|0;b=b|0;return yy(a,b)|0}function jL(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b+64|0;yz(c[d>>2]|0);yz(c[b+76>>2]|0);yz(c[b+80>>2]|0);yz(c[b+92>>2]|0);e=b+104|0;yz(c[e>>2]|0);f=b+96|0;yz(c[f>>2]|0);g=b+120|0;yz(c[g>>2]|0);yG(d|0,0,64);d=c[b>>2]|0;h=c[b+12>>2]|0;i=c[b+4>>2]|0;do{if((d|0)==(h|0)){if((i|0)!=(c[b+16>>2]|0)){j=3312;break}a[b+60|0]=1;k=1}else{j=3312}}while(0);if((j|0)==3312){c[b+36>>2]=76;c[b+40>>2]=62;a[b+60|0]=0;k=0}c[b+44>>2]=0;l=(h<<3)+56&-64;c[b+116>>2]=l;c[b+108>>2]=h;c[b+112>>2]=i;m=yy(8,(ab(l,i)|0)>>3)|0;c[e>>2]=m;if((m|0)==0){n=0;return n|0}m=c[b+24>>2]|0;do{if((m|0)!=0){e=(d<<2)+28&-32;c[b+100>>2]=e;l=yy(4,(ab(e,i)|0)>>2)|0;c[f>>2]=l;if((l|0)==0){n=0}else{break}return n|0}}while(0);f=c[b+28>>2]|0;i=(f|0)==0;do{if(!i){d=(h<<2)+28&-32;c[b+124>>2]=d;l=yy(4,(ab(c[b+16>>2]|0,d)|0)>>2)|0;c[g>>2]=l;if((l|0)==0){n=0}else{break}return n|0}}while(0);g=k<<24>>24==0;L4432:do{if(g){if((m|0)==2){c[b+48>>2]=4}else if((m|0)==3){c[b+48>>2]=24}else if((m|0)==4){c[b+48>>2]=2}else if((m|0)!=0){n=0;return n|0}if((f|0)==2){c[b+52>>2]=22;j=3349;break}else if((f|0)==4){c[b+52>>2]=8;j=3349;break}else if((f|0)==0){j=3349;break}else{n=0;return n|0}}else{if((m|0)==(f|0)){c[b+56>>2]=16;j=3349;break}k=(m|0)==2;if(k&i){c[b+56>>2]=4;break}if(!((m|0)!=3|i^1)){c[b+56>>2]=24;j=3349;break}h=(m|0)==3;l=(f|0)==4;if(h&l){c[b+56>>2]=12;j=3349;break}if(k&(f|0)==3){c[b+56>>2]=10;j=3349;break}do{if(h){if((f|0)!=2){o=0;break}c[b+56>>2]=20;j=3349;break L4432}else{if((m|0)==4){if(!i){o=0;break}c[b+56>>2]=2;j=3349;break L4432}else if((m|0)!=0){o=0;break}if((f|0)==4){c[b+56>>2]=8;j=3349;break L4432}else if((f|0)==2){c[b+56>>2]=22;j=3349;break L4432}else{o=1;break}}}while(0);if(k&l){c[b+56>>2]=18;j=3349;break}if(o&(f|0)==1){c[b+56>>2]=6;j=3349;break}else{n=0;return n|0}}}while(0);do{if((j|0)==3349){if(!g){break}if(jY(b)|0){break}else{n=0}return n|0}}while(0);n=1;return n|0}function jM(a){a=a|0;var b=0;b=a+64|0;yz(c[b>>2]|0);yz(c[a+76>>2]|0);yz(c[a+80>>2]|0);yz(c[a+92>>2]|0);yz(c[a+104>>2]|0);yz(c[a+96>>2]|0);yz(c[a+120>>2]|0);yG(b|0,0,64);return}function jN(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[b+60|0]&1)!=0){fM[c[b+56>>2]&31](d,e,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[b+8>>2]|0);return}f=b+44|0;if((c[f>>2]|0)==0){if((c[b+24>>2]|0)==0){fP[c[b+36>>2]&127](b,e,c[b+8>>2]|0)}else{g=b+96|0;h=b+100|0;fM[c[b+48>>2]&31](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,c[b+8>>2]|0);fP[c[b+36>>2]&127](b,c[g>>2]|0,c[h>>2]|0)}h=c[b+40>>2]|0;if((c[b+28>>2]|0)==0){fP[h&127](b,d,c[b+20>>2]|0);return}else{g=b+120|0;i=b+124|0;fP[h&127](b,c[g>>2]|0,c[i>>2]|0);fM[c[b+52>>2]&31](d,c[g>>2]|0,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[i>>2]|0);return}}else{i=c[b+8>>2]|0;if((c[b+24>>2]|0)==0){j=e;k=i}else{g=b+96|0;h=b+100|0;fM[c[b+48>>2]&31](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,i);j=c[g>>2]|0;k=c[h>>2]|0}h=(c[b+28>>2]|0)!=0;g=b+20|0;if(h){l=b+124|0;m=c[b+120>>2]|0}else{l=g;m=d}i=b+12|0;e=b+16|0;fK[c[f>>2]&15](b,m,j,c[i>>2]|0,c[e>>2]|0,c[b>>2]|0,c[b+4>>2]|0,c[l>>2]|0,k);if(!h){return}fM[c[b+52>>2]&31](d,c[b+120>>2]|0,c[i>>2]|0,c[e>>2]|0,c[g>>2]|0,c[b+124>>2]|0);return}}function jO(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<3|m>>>7&7)&255;a[l+2|0]=(m>>>10<<3|m>>>12&7)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function jP(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<2|m>>>9&3)&255;a[l+2|0]=(m>>>11<<3|m>>>13)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function jQ(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>2;g=0;k=a;a=b;while(1){if(i){b=a;l=0;while(1){c[k+(l<<2)>>2]=d[b]|0|(d[b+1|0]|0)<<8|(d[b+2|0]|0)<<16|-16777216;m=l+1|0;if((m|0)<(e|0)){b=b+3|0;l=m}else{break}}}l=g+1|0;if((l|0)<(f|0)){g=l;k=k+(j<<2)|0;a=a+h|0}else{break}}return}function jR(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>1;g=h>>2;h=0;k=a;a=d;while(1){if(i){d=0;do{l=c[a+(d<<2)>>2]|0;b[k+(d<<1)>>1]=(l>>>11<<5&992|l>>>3&31|l>>>19<<10&31744)&65535;d=d+1|0;}while((d|0)<(e|0))}d=h+1|0;if((d|0)<(f|0)){h=d;k=k+(j<<1)|0;a=a+(g<<2)|0}else{break}}return}function jS(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=h>>2;h=b;b=0;k=d;while(1){if(i){d=h;l=0;while(1){m=c[k+(l<<2)>>2]|0;a[d]=m&255;a[d+1|0]=m>>>8&255;a[d+2|0]=m>>>16&255;m=l+1|0;if((m|0)<(e|0)){d=d+3|0;l=m}else{break}}}l=b+1|0;if((l|0)<(f|0)){h=h+g|0;b=l;k=k+(j<<2)|0}else{break}}return}function jT(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((e|0)<=0){return}h=(d|0)>0;i=f>>2;f=g>>2;g=a;a=0;j=b;while(1){if(h){b=0;do{k=c[j+(b<<2)>>2]|0;c[g+(b<<2)>>2]=k>>>16&255|k&-16711936|k<<16&16711680;b=b+1|0;}while((b|0)<(d|0))}b=a+1|0;if((b|0)<(e|0)){g=g+(i<<2)|0;a=b;j=j+(f<<2)|0}else{break}}return}function jU(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[a+104>>2]|0;g=a+16|0;h=c[g>>2]|0;if((h|0)<=0){return}i=a+92|0;j=a+116|0;k=a+12|0;l=a+88|0;m=e>>2;e=a+84|0;n=0;o=c[a+80>>2]|0;a=d;d=c[k>>2]|0;p=h;while(1){h=ab(c[j>>2]>>3,c[(c[i>>2]|0)+(n<<2)>>2]|0)|0;if((d|0)>0){q=0;do{r=c[e>>2]|0;if((r|0)==0){s=0;t=0;u=0;v=0}else{w=c[j>>2]>>3;x=0;y=0;z=f+(q+h<<3)|0;A=0;B=0;C=0;while(1){D=c[z>>2]|0;E=c[z+4>>2]|0;F=b[o+(A<<1)>>1]|0;G=ab(((E>>>16|0<<16)&65535)<<16>>16,F)|0;H=ab((E&65535)<<16>>16,F)|0;I=ab(((D>>>16|E<<16)&65535)<<16>>16,F)|0;E=A+1|0;J=G+(C<<16)>>16;K=H+(B<<16)>>16;L=I+(x<<16)>>16;M=(ab((D&65535)<<16>>16,F)|0)+(y<<16)>>16;if(E>>>0<r>>>0){x=L;y=M;z=z+(w<<3)|0;A=E;B=K;C=J}else{break}}s=L>>>3;t=M>>>3;u=K>>>3;v=J>>>3}C=v&65535;B=u&65535;A=s&65535;w=t&65535;if(C<<16>>16>255){N=-16777216}else{N=C<<16>>16<0?0:v<<24}if(B<<16>>16>255){O=16711680}else{O=B<<16>>16<0?0:u<<16&16711680}if(A<<16>>16>255){P=65280}else{P=A<<16>>16<0?0:s<<8&65280}if(w<<16>>16>255){Q=255}else{Q=w<<16>>16<0?0:t&255}c[a+(q<<2)>>2]=O|N|P|Q;q=q+1|0;R=c[k>>2]|0;}while((q|0)<(R|0));S=R;T=c[g>>2]|0}else{S=d;T=p}q=n+1|0;if((q|0)>=(T|0)){break}n=q;o=o+(c[l>>2]<<1)|0;a=a+(m<<2)|0;d=S;p=T}return}function jV(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=a+112|0;g=c[f>>2]|0;if((g|0)<=0){return}h=a+64|0;i=a+108|0;j=e>>2;e=a+116|0;k=a+76|0;l=a+68|0;m=a+72|0;n=0;o=c[a+104>>2]|0;a=d;d=c[i>>2]|0;p=g;while(1){if((d|0)>0){g=0;q=c[h>>2]|0;while(1){r=c[(c[k>>2]|0)+(g<<2)>>2]|0;s=c[l>>2]|0;if((s|0)==0){t=0;u=0;v=0;w=0;x=0;y=0;z=0;A=0}else{B=0;C=0;D=0;E=0;F=0;while(1){G=c[a+(E+r<<2)>>2]|0;H=b[q+(E<<1)>>1]|0;I=((ab(G>>>17&32640,H)|0)>>>16)+(F&65535)|0;J=((ab(G>>>9&32640,H)|0)>>>16)+(B&65535)|0;K=((ab(G>>>1&32640,H)|0)>>>16)+(C&65535)|0;L=((ab(G<<7&32640,H)|0)>>>16)+(D&65535)|0;H=E+1|0;if(H>>>0<s>>>0){B=J&65535;C=K&65535;D=L&65535;E=H;F=I&65535}else{break}}F=K&65535;t=J&65535;u=0;v=0<<16|F>>>16;w=F<<16|0>>>16;x=0;y=L&65535;z=I<<16|0>>>16;A=0<<16|0>>>16}F=o+(g<<3)|0;c[F>>2]=w|u|y|A;c[F+4>>2]=v|t|x|z;F=g+1|0;M=c[i>>2]|0;if((F|0)<(M|0)){g=F;q=q+(c[m>>2]<<1)|0}else{break}}N=M;O=c[f>>2]|0}else{N=d;O=p}q=n+1|0;if((q|0)<(O|0)){n=q;o=o+(c[e>>2]>>3<<3)|0;a=a+(j<<2)|0;d=N;p=O}else{break}}return}function jW(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;a=((g<<15|0)/(e|0)|0)-32768|0;k=(g<<16|0)/(e|0)|0;g=((h<<15|0)/(f|0)|0)-32768|0;l=(h<<16|0)/(f|0)|0;h=(a|0)<0?0:a;a=d;if((f|0)<=0){return}d=j>>2;j=i>>2;if((e|0)>0){m=(g|0)<0?0:g;n=b;o=0}else{return}while(1){b=ab(m>>16,d)|0;g=h;i=0;while(1){c[n+(i<<2)>>2]=c[a+((g>>16)+b<<2)>>2];p=i+1|0;if((p|0)<(e|0)){g=g+k|0;i=p}else{break}}i=o+1|0;if((i|0)<(f|0)){m=m+l|0;n=n+(j<<2)|0;o=i}else{break}}return}function jX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;c=(e|0)>-1?e:-e|0;g=(f|0)>-1?f:-f|0;h=(g|0)<(c|0)?g:c;if((d|0)>0){i=b;j=a;k=0}else{return}while(1){yJ(j|0,i|0,h)|0;a=k+1|0;if((a|0)<(d|0)){i=i+f|0;j=j+e|0;k=a}else{break}}return}function jY(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0.0,E=0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0.0,R=0.0,S=0,T=0,V=0,W=0,X=0;d=i;e=c[a+32>>2]|0;L4646:do{if((e|0)==2){c[a+68>>2]=2;c[a+72>>2]=2;c[a+84>>2]=2;f=a+88|0;c[f>>2]=2;g=a+12|0;h=a+64|0;c[h>>2]=jK(2,c[g>>2]<<1)|0;j=a+76|0;c[j>>2]=jK(4,c[g>>2]|0)|0;k=a+16|0;l=a+80|0;c[l>>2]=jK(2,ab(c[k>>2]|0,c[f>>2]|0)|0)|0;f=a+92|0;c[f>>2]=jK(4,c[k>>2]|0)|0;if((c[h>>2]|0)==0){m=0;i=d;return m|0}if((c[l>>2]|0)==0){m=0;i=d;return m|0}n=c[a>>2]|0;o=c[g>>2]|0;g=(n<<16|0)/(o|0)|0;q=c[a+4>>2]|0;r=c[k>>2]|0;s=((q<<15|0)/(r|0)|0)-32768|0;t=(q<<16|0)/(r|0)|0;if((o|0)>0){q=((n<<15|0)/(o|0)|0)-32768|0;n=0;while(1){c[(c[j>>2]|0)+(n<<2)>>2]=q>>16;u=n<<1;v=u|1;b[(c[h>>2]|0)+(v<<1)>>1]=q>>>2&16383;w=c[h>>2]|0;b[w+(u<<1)>>1]=16384-(b[w+(v<<1)>>1]|0)&65535;v=n+1|0;if((v|0)<(o|0)){q=q+g|0;n=v}else{break}}x=c[k>>2]|0}else{x=r}if((x|0)>0){y=s;z=0}else{break}while(1){c[(c[f>>2]|0)+(z<<2)>>2]=y>>16;n=z<<1;g=n|1;b[(c[l>>2]|0)+(g<<1)>>1]=y>>>2&16383;q=c[l>>2]|0;b[q+(n<<1)>>1]=16384-(b[q+(g<<1)>>1]|0)&65535;g=z+1|0;if((g|0)>=(x|0)){break L4646}y=y+t|0;z=g}}else if((e|0)==3){t=a|0;l=c[t>>2]|0;f=a+12|0;s=c[f>>2]|0;if((l|0)>(s|0)){r=((l|0)/(s|0)|0)-1|0;l=r>>>1|r;r=l>>>2|l;l=r>>>4|r;r=l>>>8|l;A=((r>>>16|r)<<3)+8|0}else{A=8}r=a+68|0;c[r>>2]=A;c[a+72>>2]=A;l=a+84|0;c[l>>2]=A;k=a+88|0;c[k>>2]=A;g=a+64|0;c[g>>2]=jK(2,ab(A,s)|0)|0;s=a+76|0;c[s>>2]=jK(4,c[f>>2]|0)|0;q=a+16|0;n=a+80|0;c[n>>2]=jK(2,ab(c[q>>2]|0,c[k>>2]|0)|0)|0;k=a+92|0;c[k>>2]=jK(4,c[q>>2]|0)|0;if((c[g>>2]|0)==0){m=0;i=d;return m|0}if((c[n>>2]|0)==0){m=0;i=d;return m|0}o=c[t>>2]|0;t=c[f>>2]|0;f=-32768-(A<<15)|0;h=((o<<15|0)/(t|0)|0)+f|0;j=(o<<16|0)/(t|0)|0;v=c[a+4>>2]|0;w=c[q>>2]|0;u=((v<<15|0)/(w|0)|0)+f|0;f=(v<<16|0)/(w|0)|0;if((o|0)>(t|0)){B=+(t|0)/+(o|0)}else{B=1.0}if((v|0)>(w|0)){C=+(w|0)/+(v|0)}else{C=1.0}v=c[r>>2]|0;L4679:do{if((t|0)>0){r=v<<15;D=+(v>>1|0);if((v|0)>0){E=0;F=h}else{w=0;o=h;while(1){c[(c[s>>2]|0)+(w<<2)>>2]=o>>16;G=w+1|0;if((G|0)<(t|0)){w=G;o=o+j|0}else{break L4679}}}while(1){c[(c[s>>2]|0)+(E<<2)>>2]=F>>16;H=+((F&65535)+r|0)*152587890625.0e-16;o=ab(E,v)|0;w=0;do{I=(H- +(w|0))*3.141592653589793;J=I/D;K=B*I;if(+Q(+K)<1.0e-4){L=16384.0}else{L=+U(+K)/K*16384.0}if(+Q(+J)<1.0e-4){M=1.0}else{M=+U(+J)/J}b[(c[g>>2]|0)+(w+o<<1)>>1]=~~(B*L*M);w=w+1|0;}while((w|0)<(v|0));w=E+1|0;if((w|0)<(t|0)){E=w;F=F+j|0}else{break}}}}while(0);j=c[q>>2]|0;t=c[l>>2]|0;if((j|0)<=0){break}v=t<<15;D=+(t>>1|0);if((t|0)>0){N=0;O=u}else{g=0;s=u;while(1){c[(c[k>>2]|0)+(g<<2)>>2]=s>>16;h=g+1|0;if((h|0)>=(j|0)){break L4646}g=h;s=s+f|0}}while(1){c[(c[k>>2]|0)+(N<<2)>>2]=O>>16;H=+((O&65535)+v|0)*152587890625.0e-16;s=ab(N,t)|0;g=0;do{J=(H- +(g|0))*3.141592653589793;K=J/D;I=C*J;if(+Q(+I)<1.0e-4){P=16384.0}else{P=+U(+I)/I*16384.0}if(+Q(+K)<1.0e-4){R=1.0}else{R=+U(+K)/K}b[(c[n>>2]|0)+(g+s<<1)>>1]=~~(C*P*R);g=g+1|0;}while((g|0)<(t|0));g=N+1|0;if((g|0)>=(j|0)){break L4646}N=g;O=O+f|0}}else if((e|0)==1){c[a+68>>2]=1;c[a+72>>2]=1;c[a+84>>2]=1;f=a+88|0;c[f>>2]=1;j=a+12|0;t=a+64|0;c[t>>2]=jK(2,c[j>>2]|0)|0;n=a+76|0;c[n>>2]=jK(4,c[j>>2]|0)|0;v=a+16|0;k=a+80|0;c[k>>2]=jK(2,ab(c[v>>2]|0,c[f>>2]|0)|0)|0;f=a+92|0;c[f>>2]=jK(4,c[v>>2]|0)|0;if((c[t>>2]|0)==0){m=0;i=d;return m|0}if((c[k>>2]|0)==0){m=0;i=d;return m|0}g=c[a>>2]|0;s=c[j>>2]|0;j=(g<<16|0)/(s|0)|0;u=c[a+4>>2]|0;l=c[v>>2]|0;q=((u<<15|0)/(l|0)|0)-32768|0;h=(u<<16|0)/(l|0)|0;if((s|0)>0){u=((g<<15|0)/(s|0)|0)-32768|0;g=0;while(1){c[(c[n>>2]|0)+(g<<2)>>2]=u>>16;b[(c[t>>2]|0)+(g<<1)>>1]=16384;r=g+1|0;if((r|0)<(s|0)){u=u+j|0;g=r}else{break}}S=c[v>>2]|0}else{S=l}L4726:do{if((S|0)>0){g=q;j=0;while(1){c[(c[f>>2]|0)+(j<<2)>>2]=g>>16;b[(c[k>>2]|0)+(j<<1)>>1]=16384;u=j+1|0;if((u|0)>=(S|0)){break L4726}g=g+h|0;j=u}}}while(0);c[a+44>>2]=2}else{m=0;i=d;return m|0}}while(0);S=a+12|0;e=a|0;jZ(a+64|0,c[S>>2]|0,c[e>>2]|0);O=a+16|0;N=a+4|0;jZ(a+80|0,c[O>>2]|0,c[N>>2]|0);F=(c[e>>2]|0)-(c[a+68>>2]|0)|0;e=c[S>>2]|0;S=a+76|0;E=0;while(1){if((E|0)>=(e|0)){break}T=c[(c[S>>2]|0)+(E<<2)>>2]|0;if((T|0)>(F|0)|(T|0)<0){V=3533;break}else{E=E+1|0}}if((V|0)==3533){F=c[p>>2]|0;en(F|0,100496,(W=i,i=i+16|0,c[W>>2]=E,c[W+8>>2]=T,W)|0)|0;i=W;m=0;i=d;return m|0}T=(c[N>>2]|0)-(c[a+84>>2]|0)|0;N=c[O>>2]|0;O=a+92|0;a=0;while(1){if((a|0)>=(N|0)){m=1;V=3546;break}X=c[(c[O>>2]|0)+(a<<2)>>2]|0;if((X|0)>(T|0)|(X|0)<0){break}else{a=a+1|0}}if((V|0)==3546){i=d;return m|0}en(c[p>>2]|0,104528,(W=i,i=i+16|0,c[W>>2]=a,c[W+8>>2]=X,W)|0)|0;i=W;m=0;i=d;return m|0}function jZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=a+4|0;f=d-(c[e>>2]|0)|0;if((b|0)<=0){return}d=a+12|0;g=a|0;h=a+8|0;a=0;do{i=(c[d>>2]|0)+(a<<2)|0;j=c[i>>2]|0;k=j-f|0;l=-j|0;do{if((k|0)>0){c[i>>2]=f;m=c[g>>2]|0;n=ab(c[h>>2]|0,a)|0;o=m+(n<<1)|0;p=c[e>>2]|0;if((k|0)>(p|0)){yG(o|0,0,p<<1|0);break}else{q=o;yN(m+(n+k<<1)|0,q|0,p-k<<1|0);yG(q|0,0,k<<1|0);break}}}while(0);do{if((j|0)<0){k=(c[d>>2]|0)+(a<<2)|0;c[k>>2]=(c[k>>2]|0)-j;k=c[g>>2]|0;i=ab(c[h>>2]|0,a)|0;q=c[e>>2]|0;p=k+(i<<1)|0;if((q|0)<(l|0)){yG(p|0,0,q<<1|0);break}else{yN(p|0,k+(i-j<<1)|0,q+j<<1|0);yG(k+(i+j+(c[e>>2]|0)<<1)|0,0,l<<1|0);break}}}while(0);a=a+1|0;}while((a|0)<(b|0));return}function j_(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=yy(1,12)|0;f=e;if((e|0)==0){g=0;return g|0}h=d+8|0;i=c[h>>2]|0;j=yy(i,112)|0;k=e;c[k>>2]=j;c[e+4>>2]=i;if((i|0)==0){g=f;return g|0}i=d+4|0;l=d|0;d=e+8|0;m=e+10|0;e=0;n=j;while(1){i5(n+(e*112|0)|0,(c[i>>2]|0)+(e*80|0)|0,64)|0;c[(c[k>>2]|0)+(e*112|0)+76>>2]=c[(c[i>>2]|0)+(e*80|0)+64>>2];c[(c[k>>2]|0)+(e*112|0)+84>>2]=c[(c[i>>2]|0)+(e*80|0)+68>>2];j=b[(c[i>>2]|0)+(e*80|0)+76>>1]|0;b[(c[k>>2]|0)+(e*112|0)+80>>1]=j<<16>>16==0?-1:j;b[(c[k>>2]|0)+(e*112|0)+82>>1]=b[(c[i>>2]|0)+(e*80|0)+78>>1]|0;j=c[(c[i>>2]|0)+(e*80|0)+72>>2]|0;if((j|0)==3){c[(c[k>>2]|0)+(e*112|0)+68>>2]=m;a[(c[k>>2]|0)+(e*112|0)+64|0]=1}else if((j|0)==2){c[(c[k>>2]|0)+(e*112|0)+68>>2]=d;a[(c[k>>2]|0)+(e*112|0)+64|0]=1}else if((j|0)==1){j=c[l>>2]|0;c[(c[k>>2]|0)+(e*112|0)+72>>2]=(j|0)==0?582416:j}else{c[(c[k>>2]|0)+(e*112|0)+72>>2]=582416}j=e+1|0;if(j>>>0>=(c[h>>2]|0)>>>0){g=f;break}e=j;n=c[k>>2]|0}return g|0}function j$(a){a=a|0;yz(c[a>>2]|0);yz(a);return}function j0(e,f,h,i){e=e|0;f=f|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;j=c[e+4>>2]|0;k=j>>>0<h>>>0?j:h;h=c[350658]|0;if((h|0)!=0){j=4;l=0;m=0;n=h;while(1){h=c[1112+(j-4<<2)>>2]|0;o=((fu[c[n+8>>2]&15](c[350661]|0,1160,0,1,0,h)|0)<<16>>16!=0)<<j|l;p=((fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,1160,1,1,0,h)|0)<<16>>16!=0)<<j|m;h=j+1|0;if(h>>>0>=16){break}j=h;l=o&65535;m=p&65535;n=c[350658]|0}n=e+8|0;x=p<<16|o&65535;b[n>>1]=x&65535;b[n+2>>1]=x>>16}if((k|0)==0){return k|0}n=e|0;e=0;do{o=c[n>>2]|0;c[f+(e<<3)>>2]=o+(e*112|0);switch(c[o+(e*112|0)+84>>2]|0){case 1:{p=o+(e*112|0)+88|0;m=c[p>>2]|0;l=(a[o+(e*112|0)+64|0]&1)==0;if(l){q=d[(c[o+(e*112|0)+72>>2]|0)+(c[o+(e*112|0)+76>>2]|0)|0]|0}else{q=b[c[o+(e*112|0)+68>>2]>>1]|0}j=b[o+(e*112|0)+80>>1]|0;h=j&q;r=b[o+(e*112|0)+82>>1]|0;s=r<<16>>16==0;t=o+(e*112|0)+92|0;if((m|0)==((s|h<<16>>16==r<<16>>16?h&65535:0)|0)){u=c[t>>2]|0}else{c[t>>2]=m;if(l){v=d[(c[o+(e*112|0)+72>>2]|0)+(c[o+(e*112|0)+76>>2]|0)|0]|0}else{v=b[c[o+(e*112|0)+68>>2]>>1]|0}l=v&j;c[p>>2]=s|l<<16>>16==r<<16>>16?l&65535:0;u=m}g[f+(e<<3)+4>>2]=+(u>>>0>>>0);break};case 0:{if((a[o+(e*112|0)+64|0]&1)==0){w=d[(c[o+(e*112|0)+72>>2]|0)+(c[o+(e*112|0)+76>>2]|0)|0]|0}else{w=b[c[o+(e*112|0)+68>>2]>>1]|0}m=b[o+(e*112|0)+80>>1]&w;l=b[o+(e*112|0)+82>>1]|0;g[f+(e<<3)+4>>2]=l<<16>>16==0|m<<16>>16==l<<16>>16?+((m&65535)>>>0):0.0;break};case 3:{m=o+(e*112|0)+104|0;l=(a[o+(e*112|0)+64|0]&1)==0;if(l){y=d[(c[o+(e*112|0)+72>>2]|0)+(c[o+(e*112|0)+76>>2]|0)|0]|0}else{y=b[c[o+(e*112|0)+68>>2]>>1]|0}r=b[o+(e*112|0)+80>>1]|0;s=r&y;p=b[o+(e*112|0)+82>>1]|0;j=p<<16>>16==0;if((c[m>>2]|0)==((j|s<<16>>16==p<<16>>16?s&65535:0)|0)){z=c[o+(e*112|0)+108>>2]|0}else{if(l){A=d[(c[o+(e*112|0)+72>>2]|0)+(c[o+(e*112|0)+76>>2]|0)|0]|0}else{A=b[c[o+(e*112|0)+68>>2]>>1]|0}l=A&r;c[m>>2]=j|l<<16>>16==p<<16>>16?l&65535:0;l=o+(e*112|0)+108|0;p=(c[l>>2]|0)+1|0;c[l>>2]=p;z=p}g[f+(e<<3)+4>>2]=+(z|0);break};case 4:{p=o+(e*112|0)+104|0;l=(a[o+(e*112|0)+64|0]&1)==0;if(l){B=d[(c[o+(e*112|0)+72>>2]|0)+(c[o+(e*112|0)+76>>2]|0)|0]|0}else{B=b[c[o+(e*112|0)+68>>2]>>1]|0}j=b[o+(e*112|0)+80>>1]|0;m=j&B;r=b[o+(e*112|0)+82>>1]|0;s=r<<16>>16==0;if((c[p>>2]|0)==((s|m<<16>>16==r<<16>>16?m&65535:0)|0)){C=c[o+(e*112|0)+100>>2]|0}else{if(l){D=d[(c[o+(e*112|0)+72>>2]|0)+(c[o+(e*112|0)+76>>2]|0)|0]|0}else{D=b[c[o+(e*112|0)+68>>2]>>1]|0}l=D&j;c[p>>2]=s|l<<16>>16==r<<16>>16?l&65535:0;l=o+(e*112|0)+96|0;r=c[l>>2]|0;c[o+(e*112|0)+100>>2]=r;c[l>>2]=i;C=r}g[f+(e<<3)+4>>2]=+(C|0);break};case 2:{r=o+(e*112|0)+104|0;l=(a[o+(e*112|0)+64|0]&1)==0;if(l){E=d[(c[o+(e*112|0)+72>>2]|0)+(c[o+(e*112|0)+76>>2]|0)|0]|0}else{E=b[c[o+(e*112|0)+68>>2]>>1]|0}s=b[o+(e*112|0)+80>>1]|0;p=s&E;j=b[o+(e*112|0)+82>>1]|0;m=j<<16>>16==0;if((c[r>>2]|0)==((m|p<<16>>16==j<<16>>16?p&65535:0)|0)){F=c[o+(e*112|0)+96>>2]|0}else{if(l){G=d[(c[o+(e*112|0)+72>>2]|0)+(c[o+(e*112|0)+76>>2]|0)|0]|0}else{G=b[c[o+(e*112|0)+68>>2]>>1]|0}l=G&s;c[r>>2]=m|l<<16>>16==j<<16>>16?l&65535:0;c[o+(e*112|0)+96>>2]=i;F=i}g[f+(e<<3)+4>>2]=+(F|0);break};default:{}}e=e+1|0;}while(e>>>0<k>>>0);return k|0}function j1(d,e){d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+1880|0;h=f|0;j=f+8|0;k=f+16|0;l=f+24|0;m=f+32|0;n=f+40|0;o=f+1064|0;q=f+1072|0;r=f+1208|0;s=f+1792|0;t=f+1800|0;u=f+1872|0;yG(e|0,0,109528);c[e>>2]=0;c[u>>2]=0;if(!(hz(d,100456,u)|0)){v=c[350134]|0;w=(v|0)!=0?v:c[p>>2]|0;a5(104472,50,1,w|0)|0;w=c[350134]|0;v=(w|0)!=0?w:c[p>>2]|0;a_(v|0)|0;x=0;i=f;return x|0}v=c[u>>2]|0;if((v|0)==0){u=c[350134]|0;w=(u|0)!=0?u:c[p>>2]|0;a5(84680,55,1,w|0)|0;w=c[350134]|0;u=(w|0)!=0?w:c[p>>2]|0;a_(u|0)|0;x=0;i=f;return x|0}u=v>>>0<16?v:16;v=e+72|0;c[v>>2]=u;w=f+1080|0;y=f+1144|0;z=f+1216|0;A=f+1280|0;B=f+1344|0;C=f+1408|0;D=f+1472|0;E=f+1536|0;F=f+1600|0;G=f+1664|0;H=f+1728|0;I=f+1808|0;J=0;K=u;while(1){if(J>>>0>=K>>>0){break}bR(w|0,64,72200,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;L4868:do{if(hD(d,w,e+76+(J*4148|0)|0,4096)|0){bR(y|0,64,71032,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;a[r]=0;if(hE(d,y,r)|0){c[e+76+(J*4148|0)+4136>>2]=(a[r]&1)!=0?1:2}else{c[e+76+(J*4148|0)+4136>>2]=0}bR(z|0,64,69384,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;if(hC(d,z,A,64)|0){c[e+76+(J*4148|0)+4140>>2]=j8(A)|0}yG(B|0,0,64);bR(C|0,64,68144,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;if(hC(d,C,B,64)|0){c[e+76+(J*4148|0)+4144>>2]=aX(B|0,0,0)|0}yG(D|0,0,64);yG(E|0,0,64);yG(F|0,0,64);bR(G|0,64,100848,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;hC(d,G,D,64)|0;bR(G|0,64,100736,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;hC(d,G,E,64)|0;bR(G|0,64,100560,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;hC(d,G,F,64)|0;do{if((a[D]|0)==0){if((a[E]|0)!=0){break}if((a[F]|0)==0){M=1;break L4868}}else{i5(E,D,64)|0;i5(F,D,64)|0}}while(0);g[s>>2]=0.0;c[t>>2]=0;a[e+76+(J*4148|0)+4104|0]=1;u=e+76+(J*4148|0)+4108|0;c[u>>2]=0;N=e+76+(J*4148|0)+4112|0;c[N>>2]=0;O=e+76+(J*4148|0)+4116|0;g[O>>2]=1.0;P=e+76+(J*4148|0)+4120|0;g[P>>2]=1.0;bR(I|0,64,52040,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;Q=e+76+(J*4148|0)+4132|0;hE(d,I,Q)|0;do{if((a[E]|0)!=0){if((cS(E|0,49944)|0)==0){c[u>>2]=0;break}if((cS(E|0,49520)|0)==0){c[u>>2]=2;break}if((cS(E|0,49184)|0)==0){c[u>>2]=1;break}else{Q=c[350134]|0;R=(Q|0)!=0?Q:c[p>>2]|0;a5(100384,40,1,R|0)|0;R=c[350134]|0;Q=(R|0)!=0?R:c[p>>2]|0;a_(Q|0)|0;M=0;break L4868}}}while(0);do{if((a[F]|0)!=0){if((cS(F|0,49944)|0)==0){c[N>>2]=0;break}if((cS(F|0,49520)|0)==0){c[N>>2]=2;break}if((cS(F|0,49184)|0)==0){c[N>>2]=1;break}else{Q=c[350134]|0;R=(Q|0)!=0?Q:c[p>>2]|0;a5(100384,40,1,R|0)|0;R=c[350134]|0;Q=(R|0)!=0?R:c[p>>2]|0;a_(Q|0)|0;M=0;break L4868}}}while(0);Q=(c[u>>2]|0)==1;bR(H|0,64,100288,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;do{if(Q){if(hy(d,H,t)|0){c[e+76+(J*4148|0)+4124>>2]=c[t>>2];break}bR(H|0,64,100184,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;if(!(hy(d,H,t)|0)){break}c[e+76+(J*4148|0)+4124>>2]=c[t>>2]}else{if(hx(d,H,s)|0){g[O>>2]=+g[s>>2];break}bR(H|0,64,100184,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;if(!(hx(d,H,s)|0)){break}g[O>>2]=+g[s>>2]}}while(0);O=(c[N>>2]|0)==1;bR(H|0,64,100288,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;if(O){if(hy(d,H,t)|0){c[e+76+(J*4148|0)+4128>>2]=c[t>>2];M=1;break}bR(H|0,64,100064,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;if(!(hy(d,H,t)|0)){M=1;break}c[e+76+(J*4148|0)+4128>>2]=c[t>>2];M=1;break}else{if(hx(d,H,s)|0){g[P>>2]=+g[s>>2];M=1;break}bR(H|0,64,100064,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;if(!(hx(d,H,s)|0)){M=1;break}g[P>>2]=+g[s>>2];M=1;break}}else{O=c[350134]|0;Q=(O|0)!=0?O:c[p>>2]|0;en(Q|0,100984,(L=i,i=i+8|0,c[L>>2]=w,L)|0)|0;i=L;Q=c[350134]|0;O=(Q|0)!=0?Q:c[p>>2]|0;a_(O|0)|0;M=0}}while(0);if(!M){x=0;S=3735;break}J=J+1|0;K=c[v>>2]|0}if((S|0)==3735){i=f;return x|0}v=n|0;L4938:do{if(hC(d,66120,v,1024)|0){n=ej(v|0,67176,o|0)|0;if((n|0)==0){break}K=e+66444|0;J=n;while(1){n=c[K>>2]|0;if(n>>>0>=8){break L4938}if(!(hC(d,J,e+66448+(n*4168|0)+64|0,4096)|0)){break}i5(e+66448+((c[K>>2]|0)*4168|0)|0,J,64)|0;bR(w|0,64,65224,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;a[q]=0;if(hE(d,w,q)|0){c[e+66448+((c[K>>2]|0)*4168|0)+4160>>2]=(a[q]&1)!=0?1:2}else{c[e+66448+((c[K>>2]|0)*4168|0)+4160>>2]=0}bR(y|0,64,64352,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;if(hC(d,y,z,64)|0){n=j8(z)|0;c[e+66448+((c[K>>2]|0)*4168|0)+4164>>2]=n}c[K>>2]=(c[K>>2]|0)+1;n=ej(0,67176,o|0)|0;if((n|0)==0){break L4938}else{J=n}}K=c[350134]|0;en(((K|0)!=0?K:c[p>>2]|0)|0,101760,(L=i,i=i+8|0,c[L>>2]=J,L)|0)|0;i=L;K=c[350134]|0;a_(((K|0)!=0?K:c[p>>2]|0)|0)|0;x=0;i=f;return x|0}}while(0);if(!(hC(d,62152,v,1024)|0)){x=1;i=f;return x|0}o=ej(v|0,67176,h|0)|0;L4958:do{if((o|0)!=0){v=e+99792|0;q=o;L4960:while(1){K=c[v>>2]|0;if(K>>>0>=64){break L4958}i5(e+99796+(K*80|0)|0,q,64)|0;bR(w|0,64,58200,(L=i,i=i+8|0,c[L>>2]=q,L)|0)|0;i=L;bR(y|0,64,57736,(L=i,i=i+8|0,c[L>>2]=q,L)|0)|0;i=L;bR(z|0,64,57160,(L=i,i=i+8|0,c[L>>2]=q,L)|0)|0;i=L;bR(A|0,64,56768,(L=i,i=i+8|0,c[L>>2]=q,L)|0)|0;i=L;bR(B|0,64,56280,(L=i,i=i+8|0,c[L>>2]=q,L)|0)|0;i=L;if(!(hC(d,w,C,64)|0)){S=3705;break}do{if((cS(C|0,55920)|0)==0){c[e+99796+(K*80|0)+68>>2]=0;S=3719}else{if((cS(C|0,55264)|0)==0){c[e+99796+(K*80|0)+68>>2]=2;S=3719;break}if((cS(C|0,54144)|0)==0){c[e+99796+(K*80|0)+68>>2]=3;S=3719;break}if((cS(C|0,53552)|0)==0){c[e+99796+(K*80|0)+68>>2]=1;S=3719;break}if((cS(C|0,52944)|0)==0){c[e+99796+(K*80|0)+68>>2]=4;S=3719;break}if((cS(C|0,52552)|0)!=0){S=3717;break L4960}c[e+99796+(K*80|0)+68>>2]=5;c[j>>2]=0;c[k>>2]=0;c[l>>2]=0}}while(0);do{if((S|0)==3719){S=0;c[j>>2]=0;c[k>>2]=0;c[l>>2]=0;c[m>>2]=0;if(!(hz(d,z,m)|0)){if(!(hA(d,y,j)|0)){S=3726;break L4960}c[e+99796+(K*80|0)+72>>2]=1;c[e+99796+(K*80|0)+64>>2]=c[j>>2];break}P=c[m>>2]|0;if((P|0)==1){c[e+99796+(K*80|0)+72>>2]=2;break}else if((P|0)==2){c[e+99796+(K*80|0)+72>>2]=3;break}else{S=3723;break L4960}}}while(0);if(hA(d,A,k)|0){b[e+99796+(K*80|0)+76>>1]=c[k>>2]&65535}if(hA(d,B,l)|0){b[e+99796+(K*80|0)+78>>1]=c[l>>2]&65535}c[v>>2]=(c[v>>2]|0)+1;q=ej(0,67176,h|0)|0;if((q|0)==0){break L4958}}if((S|0)==3723){q=c[350134]|0;v=(q|0)!=0?q:c[p>>2]|0;a5(41200,52,1,v|0)|0;v=c[350134]|0;q=(v|0)!=0?v:c[p>>2]|0;a_(q|0)|0;x=0;i=f;return x|0}else if((S|0)==3705){q=c[350134]|0;a5(102760,54,1,((q|0)!=0?q:c[p>>2]|0)|0)|0;q=c[350134]|0;a_(((q|0)!=0?q:c[p>>2]|0)|0)|0;x=0;i=f;return x|0}else if((S|0)==3726){q=c[350134]|0;a5(102248,54,1,((q|0)!=0?q:c[p>>2]|0)|0)|0;q=c[350134]|0;a_(((q|0)!=0?q:c[p>>2]|0)|0)|0;x=0;i=f;return x|0}else if((S|0)==3717){q=c[350134]|0;a5(102552,39,1,((q|0)!=0?q:c[p>>2]|0)|0)|0;q=c[350134]|0;a_(((q|0)!=0?q:c[p>>2]|0)|0)|0;x=0;i=f;return x|0}}}while(0);hD(d,63584,e+104916|0,4096)|0;hC(d,62776,e+109016|0,512)|0;x=1;i=f;return x|0}function j2(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0.0,al=0.0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0;f=i;i=i+832|0;j=f|0;k=f+64|0;l=f+128|0;m=f+192|0;n=f+256|0;o=f+320|0;q=f+384|0;r=f+448|0;s=f+512|0;t=f+576|0;u=f+640|0;v=f+704|0;w=f+768|0;if((a[1243488]&1)!=0){x=c[350134]|0;y=(x|0)!=0?x:c[p>>2]|0;en(y|0,60816,(z=i,i=i+8|0,c[z>>2]=d,z)|0)|0;i=z;y=c[350134]|0;x=(y|0)!=0?y:c[p>>2]|0;a_(x|0)|0}x=i8(d)|0;y=(x|0)!=0;L5011:do{if(y){A=i6(x)|0;if((A|0)==0){break}B=w|0;C=A;L5014:while(1){do{if((c[C+20>>2]|0)==0){if((cS(c[C>>2]|0,50552)|0)!=0){break}A=je(C,46704)|0;if((A|0)==0){a[B]=0}else{i5(B,A,64)|0}if((cS(B|0,42368)|0)==0){break L5014}}}while(0);A=c[C+16>>2]|0;if((A|0)==0){break L5011}else{C=A}}c[e>>2]=2;A=je(C,38664)|0;if((A|0)==0){a[B]=0}else{i5(B,A,64)|0}A=e+4|0;a[A]=(cS(B|0,108696)|0)==0|0;D=e+5|0;E=je(C,105480)|0;do{if((E|0)==0){a[D]=0}else{if((i5(D,E,64)|0)>>>0>=64){break}if((a[1243488]&1)==0){break}F=c[350134]|0;G=(F|0)!=0?F:c[p>>2]|0;en(G|0,102144,(z=i,i=i+8|0,c[z>>2]=D,z)|0)|0;i=z;G=c[350134]|0;F=(G|0)!=0?G:c[p>>2]|0;a_(F|0)|0}}while(0);do{if((a[A]&1)==0){D=c[350134]|0;E=(D|0)!=0?D:c[p>>2]|0;a5(98328,57,1,E|0)|0;E=c[350134]|0;D=(E|0)!=0?E:c[p>>2]|0;a_(D|0)|0}else{if((a[1243488]&1)==0){break}D=c[350134]|0;E=(D|0)!=0?D:c[p>>2]|0;a5(99880,54,1,E|0)|0;E=c[350134]|0;D=(E|0)!=0?E:c[p>>2]|0;a_(D|0)|0}}while(0);D=c[C+12>>2]|0;E=e+72|0;L5040:do{if((D|0)!=0){B=j|0;F=k|0;G=l|0;H=m|0;I=n|0;J=o|0;K=q|0;L=r|0;M=s|0;N=t|0;O=u|0;P=v|0;Q=e+66444|0;R=e+99792|0;S=e+109012|0;T=e+109016|0;U=D;L5042:while(1){if((c[E>>2]|0)>>>0>=16){break L5040}do{if((c[U+20>>2]|0)==0){V=U+4|0;W=c[V>>2]|0;if((W|0)==0){break}X=dy(W|0)|0;if((X|0)==0){break}W=c[E>>2]|0;Y=c[U>>2]|0;if((cS(Y|0,96176)|0)==0){Z=e+76+(W*4148|0)+4096|0;if((c[Z>>2]|0)!=0){_=3777;break L5042}$=j4(X,d,U)|0;if(($|0)==0){_=3779;break L5042}c[Z>>2]=$;break}if((cS(Y|0,88896)|0)!=0){if((cS(Y|0,82712)|0)==0){yz(X);$=c[Q>>2]|0;if($>>>0>7){Z=c[350134]|0;aa=(Z|0)!=0?Z:c[p>>2]|0;a5(40456,58,1,aa|0)|0;aa=c[350134]|0;Z=(aa|0)!=0?aa:c[p>>2]|0;a_(Z|0)|0;break}Z=e+66448+($*4168|0)|0;aa=je(U,44656)|0;if((aa|0)==0){a[Z]=0}else{i5(Z,aa,64)|0}aa=e+66448+($*4168|0)+64|0;ab=je(U,40240)|0;if((ab|0)==0){a[aa]=0}else{i5(aa,ab,4096)|0}yG(B|0,0,64);ab=je(U,39992)|0;if((ab|0)==0){a[B]=0}else{i5(B,ab,64)|0}if((a[Z]|0)==0){_=3886;break L5042}if((a[aa]|0)==0){_=3888;break L5042}do{if((cS(B|0,39112)|0)==0){c[e+66448+($*4168|0)+4160>>2]=1}else{if((cS(B|0,38776)|0)==0){c[e+66448+($*4168|0)+4160>>2]=2;break}if((a[B]|0)!=0){_=3895;break L5042}c[e+66448+($*4168|0)+4160>>2]=0}}while(0);c[Q>>2]=(c[Q>>2]|0)+1;break}if((cS(Y|0,78992)|0)!=0){if((cS(Y|0,76288)|0)!=0){break}yz(X);if((c[S>>2]|0)!=0){_=3951;break L5042}$=je(U,46856)|0;if(($|0)==0){a[T]=0}else{i5(T,$,512)|0}$=je(U,46704)|0;if(($|0)==0){a[B]=0}else{i5(B,$,64)|0}if((cS(B|0,52552)|0)!=0){_=3959;break L5042}$=c[V>>2]|0;if(($|0)==0){_=3961;break L5042}aa=dy($|0)|0;c[S>>2]=aa;if((aa|0)==0){_=3965;break L5042}$=j4(aa,d,U)|0;c[S>>2]=$;if(($|0)==0){_=3964;break L5042}else{break}}yz(X);$=c[R>>2]|0;if($>>>0>63){_=3900;break L5042}aa=e+99796+($*80|0)|0;Z=je(U,44656)|0;if((Z|0)==0){a[aa]=0}else{i5(aa,Z,64)|0}Z=je(U,44344)|0;if((Z|0)==0){a[B]=0}else{i5(B,Z,64)|0}Z=je(U,44032)|0;if((Z|0)==0){a[F]=0}else{i5(F,Z,64)|0}Z=je(U,43784)|0;if((Z|0)==0){a[G]=0}else{i5(G,Z,64)|0}Z=je(U,43400)|0;if((Z|0)==0){a[H]=0}else{i5(H,Z,64)|0}Z=je(U,43e3)|0;if((Z|0)==0){a[I]=0}else{i5(I,Z,64)|0}if((a[B]|0)==0){_=3921;break L5042}if((a[aa]|0)==0){_=3921;break L5042}do{if((cS(B|0,55920)|0)==0){c[e+99796+($*80|0)+68>>2]=0;_=3935}else{if((cS(B|0,53552)|0)==0){c[e+99796+($*80|0)+68>>2]=1;_=3935;break}if((cS(B|0,55264)|0)==0){c[e+99796+($*80|0)+68>>2]=2;_=3935;break}if((cS(B|0,54144)|0)==0){c[e+99796+($*80|0)+68>>2]=3;_=3935;break}if((cS(B|0,52944)|0)==0){c[e+99796+($*80|0)+68>>2]=4;_=3935;break}if((cS(B|0,52552)|0)!=0){_=3933;break L5042}c[e+99796+($*80|0)+68>>2]=5}}while(0);do{if((_|0)==3935){_=0;if((a[G]|0)==0){if((a[F]|0)==0){_=3942;break L5042}c[e+99796+($*80|0)+64>>2]=aX(F|0,0,16)|0;c[e+99796+($*80|0)+72>>2]=1;break}V=aX(G|0,0,0)|0;if((V|0)==1){c[e+99796+($*80|0)+72>>2]=2;break}else if((V|0)==2){c[e+99796+($*80|0)+72>>2]=3;break}else{_=3939;break L5042}}}while(0);if((a[H]|0)!=0){b[e+99796+($*80|0)+76>>1]=(aX(H|0,0,16)|0)&65535}if((a[I]|0)!=0){b[e+99796+($*80|0)+78>>1]=(aX(I|0,0,16)|0)&65535}c[R>>2]=(c[R>>2]|0)+1;break}if((a[A]&1)!=0){if((c[e+76+(W*4148|0)+4096>>2]|0)==0){_=3784;break L5042}}V=j4(X,d,U)|0;if((V|0)==0){_=3786;break L5042}c[e+76+(W*4148|0)+4100>>2]=V;V=e+76+(W*4148|0)+4144|0;c[V>>2]=0;Y=e+76+(W*4148|0)+4136|0;c[Y>>2]=0;aa=e+76+(W*4148|0)+4132|0;a[aa]=0;Z=e+76+(W*4148|0)+4116|0;g[Z>>2]=1.0;ab=e+76+(W*4148|0)+4120|0;g[ab>>2]=1.0;ac=e+76+(W*4148|0)+4112|0;c[ac>>2]=0;ad=e+76+(W*4148|0)+4108|0;c[ad>>2]=0;ae=e+76+(W*4148|0)+4104|0;a[ae]=0;af=je(U,39992)|0;do{if((af|0)==0){a[B]=0;_=3797}else{if((i5(B,af,64)|0)>>>0>=64){_=3797;break}if((cS(B|0,38776)|0)==0){c[Y>>2]=2;if((a[1243488]&1)==0){_=3797;break}ag=c[350134]|0;ah=(ag|0)!=0?ag:c[p>>2]|0;a5(37664,42,1,ah|0)|0;ah=c[350134]|0;ag=(ah|0)!=0?ah:c[p>>2]|0;a_(ag|0)|0;_=3797;break}if((cS(B|0,39112)|0)!=0){ag=c[350134]|0;ah=(ag|0)!=0?ag:c[p>>2]|0;a5(37088,54,1,ah|0)|0;ah=c[350134]|0;ag=(ah|0)!=0?ah:c[p>>2]|0;a_(ag|0)|0;ai=0;break}c[Y>>2]=1;if((a[1243488]&1)==0){_=3797;break}ag=c[350134]|0;ah=(ag|0)!=0?ag:c[p>>2]|0;a5(37376,41,1,ah|0)|0;ah=c[350134]|0;ag=(ah|0)!=0?ah:c[p>>2]|0;a_(ag|0)|0;_=3797}}while(0);do{if((_|0)==3797){_=0;Y=je(U,36920)|0;if((Y|0)==0){a[F]=0}else{i5(F,Y,64)|0}Y=je(U,36704)|0;if((Y|0)==0){a[G]=0}else{i5(G,Y,64)|0}Y=je(U,36488)|0;if((Y|0)==0){a[H]=0}else{i5(H,Y,64)|0}Y=je(U,36216)|0;if((Y|0)==0){a[I]=0}else{i5(I,Y,64)|0}Y=je(U,109120)|0;if((Y|0)==0){a[J]=0}else{i5(J,Y,64)|0}Y=je(U,108816)|0;if((Y|0)==0){a[K]=0}else{i5(K,Y,64)|0}Y=je(U,108056)|0;if((Y|0)==0){a[L]=0}else{i5(L,Y,64)|0}Y=je(U,107824)|0;if((Y|0)==0){a[M]=0}else{i5(M,Y,64)|0}Y=je(U,107592)|0;if((Y|0)==0){a[N]=0}else{i5(N,Y,64)|0}Y=je(U,107384)|0;if((Y|0)==0){a[O]=0}else{i5(O,Y,64)|0}Y=je(U,107160)|0;if((Y|0)==0){a[P]=0}else{i5(P,Y,64)|0}a[aa]=(cS(P|0,106968)|0)==0|0;do{if((a[O]|0)!=0){Y=aX(O|0,0,0)|0;c[V>>2]=Y;if((a[1243488]&1)==0){break}af=c[350134]|0;$=(af|0)!=0?af:c[p>>2]|0;en($|0,106720,(z=i,i=i+8|0,c[z>>2]=Y,z)|0)|0;i=z;Y=c[350134]|0;$=(Y|0)!=0?Y:c[p>>2]|0;a_($|0)|0}}while(0);do{if((a[F]|0)==0){aj=0}else{ak=+yD(F,0);g[Z>>2]=ak;g[ab>>2]=ak;a[ae]=1;if((a[1243488]&1)==0){aj=1;break}$=c[350134]|0;Y=($|0)!=0?$:c[p>>2]|0;al=ak;en(Y|0,106264,(z=i,i=i+8|0,h[z>>3]=al,z)|0)|0;i=z;Y=c[350134]|0;$=(Y|0)!=0?Y:c[p>>2]|0;a_($|0)|0;aj=1}}while(0);if((a[G]|0)==0){am=aj}else{al=+yD(G,0);g[Z>>2]=al;a[ae]=1;if((a[1243488]&1)!=0){$=c[350134]|0;Y=($|0)!=0?$:c[p>>2]|0;ak=al;en(Y|0,106032,(z=i,i=i+8|0,h[z>>3]=ak,z)|0)|0;i=z;Y=c[350134]|0;$=(Y|0)!=0?Y:c[p>>2]|0;a_($|0)|0}am=aj+1|0}if((a[H]|0)==0){an=aj}else{ak=+yD(H,0);g[ab>>2]=ak;a[ae]=1;if((a[1243488]&1)!=0){$=c[350134]|0;Y=($|0)!=0?$:c[p>>2]|0;al=ak;en(Y|0,105568,(z=i,i=i+8|0,h[z>>3]=al,z)|0)|0;i=z;Y=c[350134]|0;$=(Y|0)!=0?Y:c[p>>2]|0;a_($|0)|0}an=aj+1|0}if((a[I]|0)==0){ao=am;ap=an}else{$=aX(I|0,0,0)|0;c[e+76+(W*4148|0)+4128>>2]=$;c[e+76+(W*4148|0)+4124>>2]=$;a[ae]=1;c[ac>>2]=1;c[ad>>2]=1;if((a[1243488]&1)!=0){Y=c[350134]|0;af=(Y|0)!=0?Y:c[p>>2]|0;en(af|0,104712,(z=i,i=i+8|0,c[z>>2]=$,z)|0)|0;i=z;$=c[350134]|0;af=($|0)!=0?$:c[p>>2]|0;a_(af|0)|0}ao=am+1|0;ap=an+1|0}if((a[J]|0)==0){aq=ao}else{af=aX(J|0,0,0)|0;c[e+76+(W*4148|0)+4124>>2]=af;a[ae]=1;c[ad>>2]=1;if((a[1243488]&1)!=0){$=c[350134]|0;Y=($|0)!=0?$:c[p>>2]|0;en(Y|0,104376,(z=i,i=i+8|0,c[z>>2]=af,z)|0)|0;i=z;af=c[350134]|0;Y=(af|0)!=0?af:c[p>>2]|0;a_(Y|0)|0}aq=ao+1|0}if((a[K]|0)==0){ar=ap}else{Y=aX(K|0,0,0)|0;c[e+76+(W*4148|0)+4128>>2]=Y;a[ae]=1;c[ac>>2]=1;if((a[1243488]&1)!=0){af=c[350134]|0;$=(af|0)!=0?af:c[p>>2]|0;en($|0,104112,(z=i,i=i+8|0,c[z>>2]=Y,z)|0)|0;i=z;Y=c[350134]|0;$=(Y|0)!=0?Y:c[p>>2]|0;a_($|0)|0}ar=ap+1|0}if((a[L]|0)==0){as=aq;at=ar}else{al=+yD(L,0);g[ab>>2]=al;g[Z>>2]=al;a[ae]=1;c[ac>>2]=2;c[ad>>2]=2;if((a[1243488]&1)!=0){$=c[350134]|0;Y=($|0)!=0?$:c[p>>2]|0;ak=al;en(Y|0,103784,(z=i,i=i+8|0,h[z>>3]=ak,z)|0)|0;i=z;Y=c[350134]|0;$=(Y|0)!=0?Y:c[p>>2]|0;a_($|0)|0}as=aq+1|0;at=ar+1|0}if((a[M]|0)==0){au=as}else{ak=+yD(M,0);g[Z>>2]=ak;a[ae]=1;c[ad>>2]=2;if((a[1243488]&1)!=0){$=c[350134]|0;Y=($|0)!=0?$:c[p>>2]|0;al=ak;en(Y|0,103664,(z=i,i=i+8|0,h[z>>3]=al,z)|0)|0;i=z;Y=c[350134]|0;$=(Y|0)!=0?Y:c[p>>2]|0;a_($|0)|0}au=as+1|0}if((a[N]|0)==0){av=at}else{al=+yD(N,0);g[ab>>2]=al;a[ae]=1;c[ac>>2]=2;if((a[1243488]&1)!=0){$=c[350134]|0;Y=($|0)!=0?$:c[p>>2]|0;ak=al;en(Y|0,103272,(z=i,i=i+8|0,h[z>>3]=ak,z)|0)|0;i=z;Y=c[350134]|0;$=(Y|0)!=0?Y:c[p>>2]|0;a_($|0)|0}av=at+1|0}if(au>>>0>1){ai=0;break}ai=av>>>0<2}}while(0);if(!ai){_=3871;break L5042}c[E>>2]=(c[E>>2]|0)+1}}while(0);U=c[U+16>>2]|0;if((U|0)==0){break L5040}}if((_|0)==3895){U=c[350134]|0;N=(U|0)!=0?U:c[p>>2]|0;a5(38056,46,1,N|0)|0;N=c[350134]|0;U=(N|0)!=0?N:c[p>>2]|0;a_(U|0)|0;_=3897}else if((_|0)==3886){U=c[350134]|0;a5(39752,51,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;_=3897}else if((_|0)==3933){U=c[350134]|0;a5(41640,56,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;_=3948}else if((_|0)==3939){U=c[350134]|0;a5(41200,52,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;_=3948}else if((_|0)==3942){U=c[350134]|0;a5(40792,65,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;_=3948}else if((_|0)==3921){U=c[350134]|0;a5(42568,57,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;_=3948}else if((_|0)==3951){U=c[350134]|0;a5(47296,46,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;_=3965}else if((_|0)==3959){U=c[350134]|0;a5(46032,52,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;_=3965}else if((_|0)==3961){c[S>>2]=0;_=3965}else if((_|0)==3964){U=c[350134]|0;a5(45392,48,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;_=3965}else if((_|0)==3888){U=c[350134]|0;a5(39344,57,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;_=3897}else if((_|0)==3777){U=c[350134]|0;a5(94064,75,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;yz(X);break L5011}else if((_|0)==3779){U=c[350134]|0;a5(90752,74,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;break L5011}else if((_|0)==3784){U=c[350134]|0;a5(87112,98,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;yz(X);break L5011}else if((_|0)==3786){U=c[350134]|0;a5(90752,74,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;break L5011}else if((_|0)==3871){U=c[350134]|0;a5(85208,78,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;break L5011}else if((_|0)==3900){U=c[350134]|0;a5(44952,51,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;_=3948}if((_|0)==3897){U=c[350134]|0;N=(U|0)!=0?U:c[p>>2]|0;a5(80768,51,1,N|0)|0;N=c[350134]|0;U=(N|0)!=0?N:c[p>>2]|0;a_(U|0)|0;break L5011}else if((_|0)==3948){U=c[350134]|0;a5(77624,46,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;break L5011}else if((_|0)==3965){U=c[350134]|0;a5(75024,40,1,((U|0)!=0?U:c[p>>2]|0)|0)|0;U=c[350134]|0;a_(((U|0)!=0?U:c[p>>2]|0)|0)|0;break L5011}}}while(0);if((c[E>>2]|0)==0){A=c[350134]|0;D=(A|0)!=0?A:c[p>>2]|0;a5(74080,82,1,D|0)|0;D=c[350134]|0;A=(D|0)!=0?D:c[p>>2]|0;a_(A|0)|0;break}jc(x);aw=1;i=f;return aw|0}else{A=c[350134]|0;en(((A|0)!=0?A:c[p>>2]|0)|0,54840,(z=i,i=i+8|0,c[z>>2]=d,z)|0)|0;i=z;A=c[350134]|0;a_(((A|0)!=0?A:c[p>>2]|0)|0)|0}}while(0);z=c[350134]|0;a5(73008,51,1,((z|0)!=0?z:c[p>>2]|0)|0)|0;z=c[350134]|0;a_(((z|0)!=0?z:c[p>>2]|0)|0)|0;if(!y){aw=0;i=f;return aw|0}jc(x);aw=0;i=f;return aw|0}function j3(){return 2659368|0}function j4(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+8200|0;g=f|0;c[g>>2]=b;h=f+8|0;j=je(e,92440)|0;if((j|0)==0){a[h]=0;i=f;return b|0}if((i5(h,j,4096)|0)>>>0>=4096){i=f;return b|0}yz(b);c[g>>2]=0;b=f+4104|0;hd(b,d,h,4096);if((a[1243488]&1)==0){k=gJ(b,g)|0;l=(k|0)>-1;m=c[g>>2]|0;n=l?m:0;i=f;return n|0}h=c[350134]|0;en(((h|0)!=0?h:c[p>>2]|0)|0,103e3,(h=i,i=i+8|0,c[h>>2]=b,h)|0)|0;i=h;h=c[350134]|0;a_(((h|0)!=0?h:c[p>>2]|0)|0)|0;k=gJ(b,g)|0;l=(k|0)>-1;m=c[g>>2]|0;n=l?m:0;i=f;return n|0}function j5(b,d){b=b|0;d=d|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+8640|0;h=f|0;j=f+64|0;k=f+128|0;l=f+192|0;m=f+256|0;n=f+384|0;o=f+4480|0;p=f+4544|0;q=d+72|0;hH(b,100456,c[q>>2]|0);if((c[q>>2]|0)!=0){r=f+320|0;s=j|0;t=h|0;u=0;do{bR(r|0,64,72200,(v=i,i=i+8|0,c[v>>2]=u,v)|0)|0;i=v;hF(b,r,d+76+(u*4148|0)|0);w=d+76+(u*4148|0)+4136|0;if((c[w>>2]|0)!=0){bR(r|0,64,71032,(v=i,i=i+8|0,c[v>>2]=u,v)|0)|0;i=v;hJ(b,r,(c[w>>2]|0)==1)}bR(r|0,64,69384,(v=i,i=i+8|0,c[v>>2]=u,v)|0)|0;i=v;w=c[d+76+(u*4148|0)+4140>>2]|0;if((w|0)==3){x=48032}else if((w|0)==2){x=48304}else if((w|0)==1){x=48568}else if((w|0)==0){x=48848}else{x=47648}hF(b,r,x);w=d+76+(u*4148|0)+4144|0;if((c[w>>2]|0)!=0){bR(r|0,64,68144,(v=i,i=i+8|0,c[v>>2]=u,v)|0)|0;i=v;hH(b,r,c[w>>2]|0)}bR(s|0,64,52040,(v=i,i=i+8|0,c[v>>2]=u,v)|0)|0;i=v;hJ(b,s,(a[d+76+(u*4148|0)+4132|0]&1)!=0);do{if((a[d+76+(u*4148|0)+4104|0]&1)!=0){w=c[d+76+(u*4148|0)+4108>>2]|0;y=+g[d+76+(u*4148|0)+4116>>2];z=c[d+76+(u*4148|0)+4124>>2]|0;bR(t|0,64,51128,(v=i,i=i+16|0,c[v>>2]=51768,c[v+8>>2]=u,v)|0)|0;i=v;if((w|0)==0){A=49944}else if((w|0)==1){A=49184}else if((w|0)==2){A=49520}else{A=52320}hF(b,t,A);bR(t|0,64,50744,(v=i,i=i+16|0,c[v>>2]=51768,c[v+8>>2]=u,v)|0)|0;i=v;if((w|0)==1){hH(b,t,z)}else{hG(b,t,y)}z=c[d+76+(u*4148|0)+4112>>2]|0;y=+g[d+76+(u*4148|0)+4120>>2];w=c[d+76+(u*4148|0)+4128>>2]|0;bR(t|0,64,51128,(v=i,i=i+16|0,c[v>>2]=51392,c[v+8>>2]=u,v)|0)|0;i=v;if((z|0)==2){B=49520}else if((z|0)==0){B=49944}else if((z|0)==1){B=49184}else{B=52320}hF(b,t,B);bR(t|0,64,50744,(v=i,i=i+16|0,c[v>>2]=51392,c[v+8>>2]=u,v)|0)|0;i=v;if((z|0)==1){hH(b,t,w);break}else{hG(b,t,y);break}}}while(0);u=u+1|0;}while(u>>>0<(c[q>>2]|0)>>>0)}q=d+66444|0;do{if((c[q>>2]|0)!=0){u=n|0;yG(u|0,0,4096);t=d+66448|0;i5(u,t,4096)|0;if((c[q>>2]|0)>>>0>1){t=1;do{i7(u,67176,4096)|0;i7(u,d+66448+(t*4168|0)|0,4096)|0;t=t+1|0;}while(t>>>0<(c[q>>2]|0)>>>0)}hF(b,66120,u);if((c[q>>2]|0)==0){break}t=o|0;B=0;do{A=d+66448+(B*4168|0)|0;hF(b,A,d+66448+(B*4168|0)+64|0);s=d+66448+(B*4168|0)+4160|0;if((c[s>>2]|0)!=0){bR(t|0,64,65224,(v=i,i=i+8|0,c[v>>2]=A,v)|0)|0;i=v;hJ(b,t,(c[s>>2]|0)!=1)}bR(t|0,64,64352,(v=i,i=i+8|0,c[v>>2]=A,v)|0)|0;i=v;A=c[d+66448+(B*4168|0)+4164>>2]|0;if((A|0)==1){C=48568}else if((A|0)==0){C=48848}else if((A|0)==3){C=48032}else if((A|0)==2){C=48304}else{C=47648}hF(b,t,C);B=B+1|0;}while(B>>>0<(c[q>>2]|0)>>>0)}}while(0);q=d+104916|0;if((a[q]|0)!=0){hF(b,63584,q)}q=d+109016|0;if((a[q]|0)!=0){hF(b,62776,q)}q=d+99792|0;if((c[q>>2]|0)==0){i=f;return}C=p|0;yG(C|0,0,4096);i5(C,d+99796|0,4096)|0;if((c[q>>2]|0)>>>0>1){p=1;do{i7(C,67176,4096)|0;i7(C,d+99796+(p*80|0)|0,4096)|0;p=p+1|0;}while(p>>>0<(c[q>>2]|0)>>>0)}hF(b,62152,C);if((c[q>>2]|0)==0){i=f;return}C=h|0;h=j|0;j=k|0;k=l|0;l=m|0;m=0;do{p=d+99796+(m*80|0)|0;bR(C|0,64,58200,(v=i,i=i+8|0,c[v>>2]=p,v)|0)|0;i=v;bR(h|0,64,57736,(v=i,i=i+8|0,c[v>>2]=p,v)|0)|0;i=v;bR(j|0,64,57160,(v=i,i=i+8|0,c[v>>2]=p,v)|0)|0;i=v;bR(k|0,64,56768,(v=i,i=i+8|0,c[v>>2]=p,v)|0)|0;i=v;bR(l|0,64,56280,(v=i,i=i+8|0,c[v>>2]=p,v)|0)|0;i=v;switch(c[d+99796+(m*80|0)+68>>2]|0){case 1:{D=53552;break};case 4:{D=52944;break};case 5:{D=52552;break};case 2:{D=55264;break};case 3:{D=54144;break};case 0:{D=55920;break};default:{D=52320}}hF(b,C,D);hI(b,k,e[d+99796+(m*80|0)+76>>1]|0);hI(b,l,e[d+99796+(m*80|0)+78>>1]|0);p=c[d+99796+(m*80|0)+72>>2]|0;if((p|0)==3){hH(b,j,2)}else if((p|0)==1){hI(b,h,c[d+99796+(m*80|0)+64>>2]|0)}else if((p|0)==2){hH(b,j,1)}m=m+1|0;}while(m>>>0<(c[q>>2]|0)>>>0);i=f;return}function j6(a,b){a=a|0;b=b|0;var c=0,d=0;if((a|0)==0){c=b;return c|0}d=gU(a)|0;if((cS(d|0,61296)|0)==0){c=0;return c|0}if((cS(d|0,59840)|0)==0){c=0;return c|0}if((cS(d|0,50552)|0)==0){c=2;return c|0}if((cS(d|0,59296)|0)==0){c=2;return c|0}else{return((cS(d|0,58768)|0)==0?2:b)|0}return 0}
function j7(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+4096|0;f=e|0;g=b+72|0;h=c[g>>2]|0;if((h|0)!=0){j=f|0;k=0;l=h;while(1){h=b+76+(k*4148|0)|0;if((a[h]|0)==0){m=l}else{i5(j,h,4096)|0;hd(h,d,j,4096);m=c[g>>2]|0}h=k+1|0;if(h>>>0<m>>>0){k=h;l=m}else{break}}}m=b+66444|0;if((c[m>>2]|0)!=0){l=f|0;k=0;do{g=b+66448+(k*4168|0)+64|0;i5(l,g,4096)|0;hd(g,d,l,4096);k=k+1|0;}while(k>>>0<(c[m>>2]|0)>>>0)}m=b+104916|0;if((a[m]|0)==0){i=e;return}b=f|0;i5(b,m,4096)|0;hd(m,d,b,4096);i=e;return}function j8(a){a=a|0;var b=0,d=0,e=0;b=i;if((cS(a|0,48848)|0)==0){d=0;i=b;return d|0}if((cS(a|0,48568)|0)==0){d=1;i=b;return d|0}if((cS(a|0,48304)|0)==0){d=2;i=b;return d|0}if((cS(a|0,48032)|0)==0){d=3;i=b;return d|0}e=c[350134]|0;en(((e|0)!=0?e:c[p>>2]|0)|0,101288,(e=i,i=i+8|0,c[e>>2]=a,e)|0)|0;i=e;e=c[350134]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;d=0;i=b;return d|0}function j9(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0;e=i;f=(a[1152981]|0)!=0;if(f){h=f?1152981:0}else{h=fN[c[5780]&63]()|0}do{if((h|0)!=0){f=fH[c[5776]&3](h,+g[289270])|0;c[d>>2]=f;if((f|0)==0){f=c[350134]|0;j=(f|0)!=0?f:c[p>>2]|0;f=c[5781]|0;en(j|0,104144,(k=i,i=i+8|0,c[k>>2]=f,k)|0)|0;i=k;f=c[350134]|0;j=(f|0)!=0?f:c[p>>2]|0;a_(j|0)|0;break}if((a[1243488]&1)!=0){j=c[350134]|0;f=(j|0)!=0?j:c[p>>2]|0;j=c[5781]|0;en(f|0,98536,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;j=c[350134]|0;f=(j|0)!=0?j:c[p>>2]|0;a_(f|0)|0}c[b>>2]=23104;l=1;i=e;return l|0}}while(0);c[b>>2]=0;c[d>>2]=0;l=0;i=e;return l|0}function ka(b,e){b=b|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=yy(1,1032)|0;f=b;if((b|0)==0){g=0;return g|0}h=~~+bL(+(e/10.0));i=b;j=(h|0)==0?1:h;c[i>>2]=j;h=yx(ab(j*12800|0,j)|0)|0;k=b+1028|0;c[k>>2]=h;if((h|0)==0){yz(b);g=0;return g|0}else{l=0;m=j;n=h}while(1){h=ab(ab(l*50|0,m)|0,m)|0;c[f+4+(l<<2)>>2]=n+h;j=l*7|0;o=c[i>>2]|0;p=0;q=o;while(1){r=p*5|0;s=0;t=q;u=q;while(1){v=s+r|0;w=((1<<(v&7)&(d[24920+((v>>>3)+j)|0]|0)|0)!=0)<<31>>31;if((t|0)==0){x=0;y=u}else{v=0;z=u;while(1){if((z|0)==0){A=0}else{B=0;C=z;while(1){a[n+(h+((ab((((ab(C,p)|0)+B|0)*5|0)+s|0,C)|0)+v))|0]=w;D=B+1|0;if(D>>>0<o>>>0){B=D;C=o}else{A=o;break}}}C=v+1|0;if(C>>>0<A>>>0){v=C;z=A}else{x=A;y=A;break}}}z=s+1|0;if(z>>>0<5){s=z;t=x;u=y}else{break}}u=p+1|0;if(u>>>0<10){p=u;q=y}else{break}}q=l+1|0;if(q>>>0>=256){g=b;break}l=q;m=o;n=c[k>>2]|0}return g|0}function kb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=e|0;c[f>>2]=0;e=yF(d|0)|0;if((e|0)==0){return}g=b+4|0;h=b;b=0;i=0;j=0;while(1){k=yy(1,52)|0;l=k;if((k|0)==0){m=4126;break}c[k>>2]=c[g+(a[d+i|0]<<2)>>2];n=c[h>>2]|0;o=n*5|0;c[k+4>>2]=o;p=n*10|0;c[k+8>>2]=p;c[k+12>>2]=o;c[k+32>>2]=o;c[k+36>>2]=p;c[k+40>>2]=0;c[k+44>>2]=p;c[k+24>>2]=b;c[k+28>>2]=0;c[k+48>>2]=0;if((i|0)==0){c[f>>2]=l;q=c[h>>2]|0}else{c[j+48>>2]=l;q=n}n=i+1|0;if(n>>>0<e>>>0){b=(q*6|0)+b|0;i=n;j=l}else{m=4128;break}}if((m|0)==4128){return}else if((m|0)==4126){return}}function kc(a,b){a=a|0;b=b|0;var d=0;a=b|0;b=c[a>>2]|0;if((b|0)==0){c[a>>2]=0;return}else{d=b}while(1){b=c[d+48>>2]|0;yz(d);if((b|0)==0){break}else{d=b}}c[a>>2]=0;return}function kd(a){a=a|0;yz(c[a+1028>>2]|0);yz(a);return}function ke(a,b,c){a=a|0;b=b|0;c=c|0;return-1|0}function kf(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function kg(a){a=a|0;return 1}function kh(a){a=a|0;return 1}function ki(a,b){a=a|0;b=b|0;return}function kj(a){a=a|0;return}function kk(a){a=a|0;return 1}function kl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0,N=0.0,O=0.0,P=0,Q=0.0,R=0.0;d=~~(16777216.0/+h[b+16>>3]);e=c[b+8>>2]|0;if((e|0)==0){f=0;i=b+12|0;c[i>>2]=f;return}j=a+20|0;k=a+4|0;l=a+16|0;m=a+8|0;n=a+12|0;o=a;a=c[b>>2]|0;p=c[b+4>>2]|0;q=e;e=0;while(1){r=c[j>>2]|0;L5539:do{if((q|0)==0){s=a;t=r;u=4150}else{v=a;w=q;x=r;while(1){if(x>>>0<=16777215){y=x;z=w;A=v;break L5539}B=c[l>>2]|0;if((B|0)==0){C=c[n>>2]|0;c[l>>2]=C;D=C}else{D=B}B=D-1|0;c[l>>2]=B;E=+g[v>>2];g[(c[k>>2]|0)+(B<<2)>>2]=E;g[(c[k>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;B=v+8|0;E=+g[v+4>>2];g[(c[m>>2]|0)+(c[l>>2]<<2)>>2]=E;g[(c[m>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;C=(c[j>>2]|0)-16777216|0;c[j>>2]=C;F=w-1|0;if((F|0)==0){s=B;t=C;u=4150;break}else{v=B;w=F;x=C}}}}while(0);if((u|0)==4150){u=0;if(t>>>0<16777216){y=t;z=0;A=s}else{f=e;u=4157;break}}r=p;x=e;w=y;do{v=c[k>>2]|0;C=c[l>>2]|0;F=c[m>>2]|0;B=c[n>>2]|0;G=c[o>>2]|0;H=ab(w>>>16,B<<1)|0;I=H+B|0;E=+((w&65535)>>>0>>>0)*152587890625.0e-16;if((B|0)==0){J=0.0;K=0.0}else{L=0.0;M=0;N=0.0;while(1){O=+g[G+(M+H<<2)>>2]+E*+g[G+(I+M<<2)>>2];P=M+C|0;Q=N+ +g[v+(P<<2)>>2]*O;R=L+ +g[F+(P<<2)>>2]*O;P=M+1|0;if(P>>>0<B>>>0){L=R;M=P;N=Q}else{J=R;K=Q;break}}}g[r>>2]=K;g[r+4>>2]=J;r=r+8|0;x=x+1|0;w=(c[j>>2]|0)+d|0;c[j>>2]=w;}while(w>>>0<16777216);if((z|0)==0){f=x;u=4156;break}else{a=A;p=r;q=z;e=x}}if((u|0)==4157){i=b+12|0;c[i>>2]=f;return}else if((u|0)==4156){i=b+12|0;c[i>>2]=f;return}}function km(a){a=a|0;c[a>>2]=0;return}function kn(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;k=i;i=i+8|0;l=k|0;if((bw(b|0,98200)|0)==0){if((bw(b|0,104088)|0)==0){m=0;i=k;return m|0}if((a[1243488]&1)!=0){n=c[350134]|0;o=(n|0)!=0?n:c[p>>2]|0;a5(84432,38,1,o|0)|0;o=c[350134]|0;n=(o|0)!=0?o:c[p>>2]|0;a_(n|0)|0}n=e+8|0;o=e|0;q=e+4|0;if(!(mb(b,n,o,q)|0)){m=0;i=k;return m|0}if((f|0)==24&(g|0)==16&(h|0)==8&(j|0)==0){m=1;i=k;return m|0}r=ab(c[q>>2]|0,c[o>>2]|0)|0;o=c[n>>2]|0;if((r|0)==0){m=1;i=k;return m|0}else{s=0}while(1){n=o+(s<<2)|0;q=c[n>>2]|0;c[n>>2]=(q&255)<<j|q>>>24<<f|(q>>>16&255)<<g|(q>>>8&255)<<h;q=s+1|0;if(q>>>0<r>>>0){s=q}else{m=1;break}}i=k;return m|0}c[l>>2]=0;if((gJ(b,l)|0)<0){s=c[350134]|0;r=(s|0)!=0?s:c[p>>2]|0;en(r|0,70304,(t=i,i=i+8|0,c[t>>2]=b,t)|0)|0;i=t;b=c[350134]|0;r=(b|0)!=0?b:c[p>>2]|0;a_(r|0)|0;m=0;i=k;return m|0}r=c[l>>2]|0;if((a[r+2|0]|0)!=2){l=c[350134]|0;b=(l|0)!=0?l:c[p>>2]|0;a5(60656,56,1,b|0)|0;b=c[350134]|0;l=(b|0)!=0?b:c[p>>2]|0;a_(l|0)|0;yz(r);m=0;i=k;return m|0}l=a[r+16|0]|0;b=d[r+13|0]<<8|d[r+12|0];s=d[r+15|0]<<8|d[r+14|0];if((a[1243488]&1)!=0){o=l&255;q=c[350134]|0;n=(q|0)!=0?q:c[p>>2]|0;en(n|0,54776,(t=i,i=i+24|0,c[t>>2]=b,c[t+8>>2]=s,c[t+16>>2]=o,t)|0)|0;i=t;t=c[350134]|0;o=(t|0)!=0?t:c[p>>2]|0;a_(o|0)|0}o=ab(s,b)|0;t=yx(o<<2)|0;n=t;q=e+8|0;c[q>>2]=n;c[e>>2]=b;c[e+4>>2]=s;if((t|0)==0){t=c[350134]|0;s=(t|0)!=0?t:c[p>>2]|0;a5(50488,52,1,s|0)|0;s=c[350134]|0;t=(s|0)!=0?s:c[p>>2]|0;a_(t|0)|0;yz(r);m=0;i=k;return m|0}L5596:do{if((l<<24>>24|0)==24){if((o|0)==0){break}t=255<<f;s=0;e=n;while(1){b=s*3|0;c[e+(s<<2)>>2]=d[r+(b+18)|0]<<j|t|d[r+(b+19)|0]<<h|d[r+(b+20)|0]<<g;b=s+1|0;if(b>>>0>=o>>>0){break L5596}s=b;e=c[q>>2]|0}}else if((l<<24>>24|0)==32){if((o|0)==0){break}else{u=0;v=n}while(1){e=u<<2;c[v+(u<<2)>>2]=d[r+((e|1)+18)|0]<<h|d[r+(e+18)|0]<<j|d[r+((e|2)+18)|0]<<g|d[r+((e|3)+18)|0]<<f;e=u+1|0;if(e>>>0>=o>>>0){break L5596}u=e;v=c[q>>2]|0}}else{e=c[350134]|0;a5(46600,88,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[350134]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;yz(r);yz(c[q>>2]|0);c[q>>2]=0;m=0;i=k;return m|0}}while(0);yz(r);m=1;i=k;return m|0}function ko(b,c){b=b|0;c=c|0;var d=0;if((a[1402804]&1)==0){d=kn(b,c,24,16,8,0)|0;return d|0}else{d=kn(b,c,24,0,8,16)|0;return d|0}return 0}function kp(a,b,d,e){a=a|0;b=b|0;d=d|0;e=+e;var f=0,g=0;d=c[a>>2]|0;do{if((d|0)!=0){f=c[b>>2]|0;if((f|0)==0){break}fs[c[f+8>>2]&255](d)}}while(0);c[b>>2]=3640;d=fy[c[910]&3](e)|0;c[a>>2]=d;if((d|0)!=0){g=1;return g|0}c[b>>2]=0;g=0;return g|0}function kq(b){b=+b;var d=0,e=0,f=0,h=0,j=0.0,k=0,l=0,m=0,n=0,o=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0,E=0,F=0.0,G=0.0,H=0;d=i;e=yy(1,28)|0;if((e|0)==0){f=0;i=d;return f|0}yG(e|0,0,28);h=e+12|0;if(b<1.0){j=b*.825;k=~~+aa(+(16.0/b))+3&-4}else{j=.825;k=16}c[h>>2]=k;l=k<<9;m=yx((l+(k<<2)<<2)+132|0)|0;k=m+132&-128;c[k-4>>2]=m;m=k;c[e+24>>2]=m;if((k|0)==0){yz(c[m-4>>2]|0);yz(e);f=0;i=d;return f|0}c[e>>2]=m;c[e+4>>2]=m+(l<<2);k=c[h>>2]|0;n=k<<1;c[e+8>>2]=m+(n+l<<2);b=1.0;o=0.0;q=1.0;r=1.0;s=0.0;l=0;while(1){t=s+r*q/(b*b);u=o+1.0;v=l+1|0;if(v>>>0<18){b=b*u;o=u;q=q*30.25;r=r*.25;s=t;l=v}else{break}}s=+(k|0)*.5;r=+(k<<8|0);if((k|0)>0){l=0;while(1){v=ab(l,n)|0;w=0;do{q=+((w<<8)+l|0)/r*2.0+-1.0;o=j*s*q*3.141592653589793;if(+Q(+o)<1.0e-5){x=1.0}else{x=+U(+o)/o}o=+R(+(1.0-q*q))*5.5;q=o*o;o=1.0;b=0.0;u=1.0;y=1.0;z=0.0;A=0;while(1){B=z+y*u/(o*o);C=b+1.0;D=A+1|0;if(D>>>0<18){o=o*C;b=C;u=q*u;y=y*.25;z=B;A=D}else{break}}g[m+(w+v<<2)>>2]=j*x*B/t;w=w+1|0;}while((w|0)<(k|0));w=l+1|0;if((w|0)<256){l=w}else{E=0;break}}while(1){l=E+1|0;w=ab(l,n)|0;v=E<<1;A=ab(v,k)|0;D=ab(v|1,k)|0;v=0;do{g[m+(v+D<<2)>>2]=+g[m+(v+w<<2)>>2]- +g[m+(v+A<<2)>>2];v=v+1|0;}while((v|0)<(k|0));if((l|0)<255){E=l}else{break}}E=k*510|0;n=k*511|0;v=0;do{B=+((v<<8)+256|0)/r*2.0+-1.0;x=j*s*B*3.141592653589793;if(+Q(+x)<1.0e-5){F=1.0}else{F=+U(+x)/x}x=+R(+(1.0-B*B))*5.5;B=x*x;x=1.0;z=0.0;y=1.0;u=1.0;q=0.0;A=0;while(1){G=q+u*y/(x*x);b=z+1.0;w=A+1|0;if(w>>>0<18){x=x*b;z=b;y=B*y;u=u*.25;q=G;A=w}else{break}}g[m+(v+n<<2)>>2]=j*F*G/t- +g[m+(v+E<<2)>>2];v=v+1|0;}while((v|0)<(k|0))}k=a[1243488]|0;if((k&1)==0){H=k}else{k=c[350134]|0;v=(k|0)!=0?k:c[p>>2]|0;a5(104024,30,1,v|0)|0;v=c[350134]|0;k=(v|0)!=0?v:c[p>>2]|0;a_(k|0)|0;H=a[1243488]|0}if((H&1)==0){f=e;i=d;return f|0}H=c[350134]|0;k=c[h>>2]|0;en(((H|0)!=0?H:c[p>>2]|0)|0,84272,(H=i,i=i+16|0,c[H>>2]=8,c[H+8>>2]=k,H)|0)|0;i=H;H=c[350134]|0;a_(((H|0)!=0?H:c[p>>2]|0)|0)|0;f=e;i=d;return f|0}function kr(a){a=a|0;if((a|0)==0){yz(a);return}yz(c[(c[a+24>>2]|0)-4>>2]|0);yz(a);return}function ks(){var a=0.0;a=+bb()*1.0e3;return(F=+Q(a)>=1.0?a>0.0?(ag(+P(a/4294967296.0),4294967295.0)|0)>>>0:~~+aa((a- +(~~a>>>0))/4294967296.0)>>>0:0,~~a>>>0)|0}function kt(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+4096|0;e=d|0;f=gU(1140684)|0;do{if((cS(f|0,97504)|0)!=0){if((cS(f|0,103944)|0)==0){break}do{if((cS(f|0,84264)|0)!=0){if((cS(f|0,70272)|0)==0){break}g=(a[1148885]|0)!=0?1148885:1234724;h=e|0;g5(h,g,60616,4096);j=hs(h)|0;do{if((j|0)==0){g5(h,g,54736,4096);k=hs(h)|0;if((k|0)!=0){l=k;break}i=d;return}else{l=j}}while(0);j=b+4180|0;if(j1(l,j)|0){j7(j,h)}ht(l);i=d;return}}while(0);j=b+4256|0;i5(j,1140684,4096)|0;c[b+4252>>2]=1;i=d;return}}while(0);l=hs(1140684)|0;if((l|0)==0){i=d;return}e=b+4180|0;if(j1(l,e)|0){j7(e,1140684)}ht(l);i=d;return}function ku(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;if((d|0)!=0){c[d>>2]=c[(c[a>>2]|0)+(b*12|0)>>2]}if((e|0)==0){return}c[e>>2]=c[(c[a>>2]|0)+(b*12|0)+4>>2];return}function kv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=c[a+8>>2]|0;if((e|0)==0){return}f=e-1|0;if((b|0)!=0){c[b>>2]=c[(c[a>>2]|0)+(f*12|0)>>2]}if((d|0)==0){return}c[d>>2]=c[(c[a>>2]|0)+(f*12|0)+4>>2];return}function kw(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0;h=i;if((f|0)==30){j=c[b+72>>2]|0;bR(d|0,e|0,50456,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;i=h;return}else if((f|0)==29){a[d]=0;i=h;return}else{j=f-31|0;f=(j>>>0)/3|0;l=(j>>>0)%3|0;if((l|0)==0){j=b+76+(f*4148|0)|0;if((a[j]|0)==0){i5(d,46592,e)|0;i=h;return}else{ha(d,j,e);i=h;return}}else if((l|0)==2){j=~~+g[b+76+(f*4148|0)+4116>>2];if((j|0)==0){i5(d,108664,e)|0;i=h;return}else{bR(d|0,e|0,105400,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;i=h;return}}else if((l|0)==1){l=c[b+76+(f*4148|0)+4136>>2]|0;if((l|0)==1){i5(d,42344,e)|0;i=h;return}else if((l|0)==0){i5(d,108664,e)|0;i=h;return}else if((l|0)==2){i5(d,38640,e)|0;i=h;return}else{i=h;return}}else{i=h;return}}}function kx(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((a|0)==0){return}f=a+8|0;g=a+4|0;h=c[g>>2]|0;if((c[f>>2]|0)>>>0<h>>>0){i=a}else{j=(h<<1)+2|0;c[g>>2]=j;g=a;c[g>>2]=yA(c[g>>2]|0,j*12|0)|0;i=g}g=dy(b|0)|0;c[(c[i>>2]|0)+((c[f>>2]|0)*12|0)>>2]=g;c[(c[i>>2]|0)+((c[f>>2]|0)*12|0)+4>>2]=d;c[(c[i>>2]|0)+((c[f>>2]|0)*12|0)+8>>2]=e;c[f>>2]=(c[f>>2]|0)+1;return}function ky(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a+8|0;e=c[d>>2]|0;if((e|0)!=0){f=e-1|0;c[d>>2]=f;yz(c[(c[a>>2]|0)+(f*12|0)>>2]|0)}if((b|0)==0){return}c[b>>2]=c[(c[a>>2]|0)+((c[d>>2]|0)*12|0)+8>>2];return}function kz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a+8|0;d=a|0;e=c[d>>2]|0;if((c[b>>2]|0)==0){f=e;g=f;yz(g);h=a;yz(h);return}else{i=0;j=e}while(1){yz(c[j+(i*12|0)>>2]|0);e=i+1|0;k=c[d>>2]|0;if(e>>>0<(c[b>>2]|0)>>>0){i=e;j=k}else{f=k;break}}g=f;yz(g);h=a;yz(h);return}function kA(a){a=a|0;var b=0,d=0;b=a+8|0;if((c[b>>2]|0)==0){c[b>>2]=0;return}d=a|0;a=0;do{yz(c[(c[d>>2]|0)+(a*12|0)>>2]|0);a=a+1|0;}while(a>>>0<(c[b>>2]|0)>>>0);c[b>>2]=0;return}function kB(){var b=0,d=0,e=0;b=i;i=i+4096|0;d=b|0;if((a[1243524]&1)==0){i5(d,1280402,4096)|0}else{bR(d|0,4096,102120,(e=i,i=i+8|0,c[e>>2]=1276306,e)|0)|0;i=e}if((a[d]|0)!=0){hc(d,4096)}e=c[(c[155632]|0)+113712>>2]|0;if((e|0)==0){i=b;return}kU(e,(a[d]|0)!=0?d:0,1218340,c[334444]|0);i=b;return}function kC(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+8192|0;d=b|0;e=b+4096|0;do{if((a[1280402]|0)==0){f=c[155632]|0;if((a[f+4176|0]&1)==0){g=f}else{h=4352}}else{f=1400528;if((c[f>>2]&128|0)==0&(c[f+4>>2]&0|0)==0){h=4352;break}f=d|0;ha(f,1280402,4096);j=e|0;bR(j|0,4096,99832,(k=i,i=i+8|0,c[k>>2]=f,k)|0)|0;i=k;iq(c[348003]|0,j,1,1);h=4352}}while(0);do{if((h|0)==4352){e=c[155632]|0;d=c[e+4160>>2]|0;j=c[e+113712>>2]|0;if((j|0)==0){g=e;break}kU(j,(a[1280402]|0)!=0?1280402:0,1218340,(d|0)==0?2659336:d);g=c[155632]|0}}while(0);h=g+8|0;c[h>>2]=0;c[h+4>>2]=0;h=c[155632]|0;c[h>>2]=0;c[h+4>>2]=0;a[(c[155632]|0)+16|0]=0;a[(c[155632]|0)+53|0]=1;kM(c[155632]|0)|0;h=c[350708]|0;do{if((h|0)!=0){g=c[h+24>>2]|0;if((g|0)==0){break}fP[g&127](c[350660]|0,(a[(c[155632]|0)+36|0]&1)!=0,0)}}while(0);if((c[350657]|0)!=0){ga()}h=c[350708]|0;if((h|0)==0){i=b;return}g=c[h+24>>2]|0;if((g|0)==0){i=b;return}fP[g&127](c[350660]|0,0,0);i=b;return}function kD(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;c[e>>2]=0;c[f>>2]=0;c[g>>2]=0;kR(c[(c[155632]|0)+113712>>2]|0,b,e,f,g);h8(131072,c[f>>2]|0)|0;a[(c[155632]|0)+4176|0]=(c[e>>2]|0)==0|0;h8(131073,c[e>>2]|0)|0;i=d;return}function kE(){var b=0,d=0,e=0,f=0,g=0;b=i;i=i+8216|0;d=b|0;if((a[1400540]&1)!=0){gC()}e=d;c[e>>2]=c[3922];c[e+4>>2]=c[3923];c[e+8>>2]=c[3924];c[e+12>>2]=c[3925];c[e+16>>2]=c[3926];c[e+20>>2]=c[3927];a[d+20|0]=a[1243488]&1;c[d+12>>2]=(a[1264018]|0)!=0?1264018:0;c[d+4>>2]=(a[1313170]|0)!=0?1313170:0;c[d+8>>2]=(a[1317266]|0)!=0?1317266:0;c[d>>2]=(a[1280402]|0)!=0?1280402:0;c[d+16>>2]=1218340;e=(c[155632]|0)+4176|0;a[d+21|0]=a[e]&1;a[e]=0;if((gD(d)|0)!=0){d=b+24|0;ha(d,1280402,4096);e=b+4120|0;bR(e|0,4096,94e3,(f=i,i=i+8|0,c[f>>2]=d,f)|0)|0;i=f;iq(c[348003]|0,e,1,90);a[(c[155632]|0)+53|0]=1;e=c[350134]|0;f=(e|0)!=0?e:c[p>>2]|0;a5(92312,52,1,f|0)|0;f=c[350134]|0;e=(f|0)!=0?f:c[p>>2]|0;a_(e|0)|0;g=0;i=b;return g|0}if((a[1243488]&1)==0){g=1;i=b;return g|0}e=c[350134]|0;a5(96104,45,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[350134]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;g=1;i=b;return g|0}function kF(){kL(c[155632]|0);kV(c[(c[155632]|0)+113712>>2]|0);yz(c[155632]|0);return}function kG(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=yF(d|0)|0;if(f>>>0<=b>>>0){g=b+1|0;i5(a,d,g)|0;return}if(!e){e=b+1|0;g=b-2|0;i5(a,d,g)|0;i7(a,82680,e)|0;return}e=f-b|0;f=(c>>>0)%(((e<<1)+4|0)>>>0)|0;c=e+4|0;if(f>>>0<2){g=b+1|0;i5(a,d,g)|0;return}if(f>>>0<(e+2|0)>>>0){g=d+(f-2)|0;h=b+1|0;i5(a,g,h)|0;return}if(f>>>0<c>>>0){h=d+e|0;g=b+1|0;i5(a,h,g)|0;return}else{g=d+(c+e-f)|0;f=b+1|0;i5(a,g,f)|0;return}}function kH(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;i=i+4096|0;d=b|0;e=kJ()|0;c[155632]=e;if((e|0)==0){f=c[350134]|0;g=(f|0)!=0?f:c[p>>2]|0;a5(90640,48,1,g|0)|0;g=c[350134]|0;f=(g|0)!=0?g:c[p>>2]|0;a_(f|0)|0;if((a[1400541]&1)==0){f=c[350134]|0;g=(f|0)!=0?f:c[p>>2]|0;en(g|0,80696,(h=i,i=i+16|0,c[h>>2]=78928,c[h+8>>2]=832,h)|0)|0;i=h;g=c[350134]|0;f=(g|0)!=0?g:c[p>>2]|0;a_(f|0)|0;ck(2)}else{i5(1400543,88816,1024)|0;eQ(1401568,1)}}f=e+8|0;c[f>>2]=0;c[f+4>>2]=0;f=c[155632]|0;c[f>>2]=0;c[f+4>>2]=0;a[(c[155632]|0)+16|0]=0;a[(c[155632]|0)+36|0]=1;c[(c[155632]|0)+113708>>2]=0;w_((c[155632]|0)+4160|0);kt(c[155632]|0);if((a[1264018]|0)==0){j=ks()|0;k=F;l=c[155632]|0;m=l+113720|0;n=m|0;c[n>>2]=j;o=m+4|0;c[o>>2]=k;i=b;return}f=d|0;if((a[1214240]|0)==0){hd(f,1264018,87048,4096)}else{i5(f,1214240,4096)|0}if((a[1243488]&1)!=0){d=c[350134]|0;e=(d|0)!=0?d:c[p>>2]|0;en(e|0,85120,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;h=c[350134]|0;e=(h|0)!=0?h:c[p>>2]|0;a_(e|0)|0}e=kW(f,c[304584]|0)|0;c[(c[155632]|0)+113712>>2]=e;j=ks()|0;k=F;l=c[155632]|0;m=l+113720|0;n=m|0;c[n>>2]=j;o=m+4|0;c[o>>2]=k;i=b;return}function kI(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0;b=i;i=i+8|0;d=b|0;e=1400528;if(!((c[e>>2]&32|0)==0&(c[e+4>>2]&0|0)==0)){a[(c[155632]|0)+52|0]=1;e=1400528;f=c[e+4>>2]|0;h=1400528;c[h>>2]=c[e>>2]&-33;c[h+4>>2]=f;f=c[155632]|0;h=c[f+4>>2]|0;c[f>>2]=c[f>>2]|256;c[f+4>>2]=h}ge();gw();if((a[1402655]&1)==0){h=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,30)|0;f=1402816;if((c[f>>2]&1073741824|h&1|0)==0&(c[f+4>>2]&0|0)==0){j=4414}else{j=4415}}else{j=4414}do{if((j|0)==4414){if(fv[c[(c[350657]|0)+12>>2]&127](c[350660]|0)|0){k=0;l=0;m=0}else{j=4415;break}do{f=c[5536+(m<<2)>>2]|0;if((fu[c[(c[350658]|0)+8>>2]&15](c[350661]|0,5600,0,1,0,f)|0)<<16>>16==0){n=0;o=0}else{h=yV(1,0,c[5536+((m|1)<<2)>>2]|0)|0;e=F;n=e;o=h}h=1402816;e=c[h>>2]|0;p=c[h+4>>2]|0;h=yV(1,0,f|0)|0;f=F;if((e&h|0)==0&(p&f|0)==0){q=0;r=0}else{f=yV(1,0,c[5536+((m|1)<<2)>>2]|0)|0;p=F;q=p;r=f}l=o|l|r;k=n|k|q;m=m+2|0;}while(m>>>0<16);if((a[1402655]&1)==0){f=fL[c[(c[350658]|0)+12>>2]&63](c[350661]|0,55)|0;p=1402816;h=(c[p>>2]&0|f&1|0)!=0|(c[p+4>>2]&8388608|0)!=0;s=h?0:0;t=h?256:0}else{s=0;t=0}h=t|l;p=s|k;f=c[155632]|0;e=f|0;u=p&~c[e+4>>2];v=f+8|0;c[v>>2]=h&~c[e>>2];c[v+4>>2]=u;if((l&15|0)==0&(k&0|0)==0){w=0}else{w=((h>>>8|p<<24)&1^1)&255}a[(c[155632]|0)+16|0]=w;u=c[155632]|0;do{if((a[u+16|0]&1)==0){a[15232]=0;x=0;y=u}else{if(a[15232]|0){z=u}else{a[15232]=1;c[u+20>>2]=a[15224]|0?6:12;c[(c[155632]|0)+24>>2]=0;z=c[155632]|0}if((c[z+24>>2]|0)>>>0<(c[z+20>>2]|0)>>>0){x=1;y=z;break}a[15232]=0;v=z+8|0;c[v>>2]=h;c[v+4>>2]=p;x=1;y=c[155632]|0}}while(0);a[15224]=x;u=y+24|0;c[u>>2]=(c[u>>2]|0)+1;u=c[155632]|0;c[u>>2]=h;c[u+4>>2]=p;u=kM(c[155632]|0)|0;v=c[350708]|0;do{if((v|0)!=0){e=c[v+24>>2]|0;if((e|0)==0){break}fP[e&127](c[350660]|0,(a[(c[155632]|0)+36|0]&1)!=0,0)}}while(0);ga();v=ks()|0;p=(c[155632]|0)+113720|0;h=yU(v,F,c[p>>2]|0,c[p+4>>2]|0)|0;p=y_(h,F,1e3,0)|0;h=F;A=750.0/+g[287220];v=yU(~~A>>>0,+Q(A)>=1.0?A>0.0?(ag(+P(A/4294967296.0),4294967295.0)|0)>>>0:~~+aa((A- +(~~A>>>0))/4294967296.0)>>>0:0,p,h)|0;h=F;p=0;if((h|0)>(p|0)|(h|0)==(p|0)&v>>>0>0>>>0){p=v;v=d;c[d>>2]=0;c[d+4>>2]=0;c[d>>2]=(p>>>0)/1e3|0;c[v+4>>2]=((p>>>0)%1e3|0)*1e6|0;dn(v|0,0)|0}v=ks()|0;p=(c[155632]|0)+113720|0;c[p>>2]=v;c[p+4>>2]=F;p=c[350708]|0;do{if((p|0)!=0){v=c[p+24>>2]|0;if((v|0)==0){break}fP[v&127](c[350660]|0,0,0)}}while(0);p=c[155632]|0;v=p|0;if((kT(p,c[v>>2]|0,c[v+4>>2]|0)|0|u|0)==0){B=1}else{break}i=b;return B|0}}while(0);if((j|0)==4415){j=1400528;d=c[j+4>>2]|0;y=1400528;c[y>>2]=c[j>>2]|1;c[y+4>>2]=d}B=0;i=b;return B|0}function kJ(){var a=0,b=0,d=0,e=0.0;a=c[28080]<<1;b=yy(1,113728)|0;d=b;c[b+28>>2]=881872;c[b+32>>2]=a;c[b+4152>>2]=23128;i5(b+54|0,1238857,4096)|0;a=yy(1,12)|0;c[b+40>>2]=a;c[b+44>>2]=yy(1,12)|0;kx(a,2659360,4,0);c[b+48>>2]=0;kK(d);b=c[350660]|0;if((b|0)==0){e=1.3333333730697632;g[6913]=e;return d|0}if(!((c[350121]|0)==0|(c[350122]|0)==0)){e=1.3333333730697632;g[6913]=e;return d|0}ft[c[(c[350657]|0)+44>>2]&127](b,1400476);e=+((c[350121]|0)>>>0>>>0)/+((c[350122]|0)>>>0>>>0);g[6913]=e;return d|0}function kK(b){b=b|0;var d=0;d=b+44|0;kA(c[d>>2]|0);if((c[b+113712>>2]|0)!=0){kx(c[d>>2]|0,98856,56,0)}kx(c[d>>2]|0,98776,55,0);kx(c[d>>2]|0,98696,58,0);kx(c[d>>2]|0,98440,5,0);kx(c[d>>2]|0,97912,59,0);kx(c[d>>2]|0,97720,60,0);kx(c[d>>2]|0,97488,61,0);kx(c[d>>2]|0,97336,62,0);do{if((a[1400540]&1)!=0){if((a[1401613]&1)!=0){break}if((c[335622]|0)!=0){kx(c[d>>2]|0,97184,69,0)}kx(c[d>>2]|0,96960,67,0);kx(c[d>>2]|0,96816,68,0);kx(c[d>>2]|0,96600,72,0);kx(c[d>>2]|0,96464,86,0);kx(c[d>>2]|0,96256,80,0)}}while(0);kx(c[d>>2]|0,95616,85,0);kx(c[d>>2]|0,95424,87,0);return}function kL(b){b=b|0;if((a[b+4156|0]&1)!=0){yz(c[b+4152>>2]|0)}kz(c[b+40>>2]|0);kz(c[b+44>>2]|0);return}function kM(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;e=i;i=i+21752|0;f=e|0;h=e+1024|0;j=e+1032|0;k=e+1040|0;l=e+1048|0;m=e+5144|0;n=e+9240|0;o=e+9248|0;q=e+9256|0;r=e+9264|0;s=e+9272|0;t=e+9280|0;u=e+9288|0;v=e+9296|0;w=e+9304|0;x=e+9312|0;y=e+9320|0;z=e+9328|0;A=e+9336|0;B=e+9344|0;C=e+9368|0;D=e+9432|0;E=e+9440|0;G=e+9448|0;H=e+9456|0;I=e+9464|0;J=e+13560|0;K=e+17656|0;L=d+8|0;M=c[L>>2]|0;N=c[L+4>>2]|0;do{if((M&1|0)==0&(N&0|0)==0){if(!((M&2|0)==0&(N&0|0)==0)){O=1;break}if(!((M&4|0)==0&(N&0|0)==0)){O=2;break}if(!((M&8|0)==0&(N&0|0)==0)){O=3;break}if(!((M&32|0)==0&(N&0|0)==0)){O=5;break}if(!((M&16|0)==0&(N&0|0)==0)){O=4;break}if(!((M&128|0)==0&(N&0|0)==0)){O=8;break}O=(M&64|0)==0&(N&0|0)==0?10:7}else{O=0}}while(0);c[D>>2]=0;c[E>>2]=0;N=d+40|0;kv(c[N>>2]|0,D,E);M=c[350708]|0;do{if((M|0)!=0){if((c[M+24>>2]|0)==0){break}fB[c[M+20>>2]&3](c[350660]|0,881872,0,c[28080]|0,c[28082]|0,1.0)}}while(0);M=c[E>>2]|0;switch(M|0){case 69:case 62:case 61:case 59:case 58:case 26:case 5:case 4:case 60:{P=kN(d,O)|0;i=e;return P|0};default:{}}if((M-12|0)>>>0<2){M=C|0;c[A>>2]=0;kv(c[N>>2]|0,0,A);C=(a[1140677]&1)==0;L=C?1:c[334448]|0;Q=C?1:c[334449]|0;L5962:do{switch(O|0){case 2:{do{if((c[A>>2]|0)==12){c[350119]=(c[350119]|0)-L;c[350121]=(c[350121]|0)+L}else{R=c[350121]|0;if(R>>>0<L>>>0){break}c[350121]=R-L}}while(0);R=c[(c[350708]|0)+16>>2]|0;if((R|0)==0){break L5962}fs[R&255](c[350660]|0);break};case 4:{R=d+48|0;ky(c[N>>2]|0,R);if((c[A>>2]|0)!=12){break L5962}if((a[1140677]&1)!=0){break L5962}kx(c[N>>2]|0,2659360,13,c[R>>2]|0);break};case 0:{do{if((c[A>>2]|0)==12){c[350120]=(c[350120]|0)-Q;c[350122]=(c[350122]|0)+Q}else{R=c[350122]|0;if(R>>>0<Q>>>0){break}c[350122]=R-Q}}while(0);R=c[(c[350708]|0)+16>>2]|0;if((R|0)==0){break L5962}fs[R&255](c[350660]|0);break};case 3:{do{if((c[A>>2]|0)==12){c[350119]=(c[350119]|0)+L;R=c[350121]|0;if(R>>>0<L>>>0){break}c[350121]=R-L}else{c[350121]=(c[350121]|0)+L}}while(0);R=c[(c[350708]|0)+16>>2]|0;if((R|0)==0){break L5962}fs[R&255](c[350660]|0);break};case 1:{do{if((c[A>>2]|0)==12){c[350120]=(c[350120]|0)+Q;R=c[350122]|0;if(R>>>0<Q>>>0){break}c[350122]=R-Q}else{c[350122]=(c[350122]|0)+Q}}while(0);R=c[(c[350708]|0)+16>>2]|0;if((R|0)==0){break L5962}fs[R&255](c[350660]|0);break};case 7:{ky(c[N>>2]|0,d+48|0);break};case 9:{a[d+53|0]=1;break};case 8:{if(!C){break L5962}ft[c[(c[350657]|0)+44>>2]&127](c[350660]|0,B);if((c[A>>2]|0)==12){c[350121]=(c[350121]|0)+(c[350119]|0);c[350122]=(c[350122]|0)+(c[350120]|0);c[350119]=0;c[350120]=0}else{c[350121]=(c[B+16>>2]|0)-(c[350119]|0);c[350122]=(c[B+20>>2]|0)-(c[350120]|0)}R=c[(c[350708]|0)+16>>2]|0;if((R|0)==0){break L5962}fs[R&255](c[350660]|0);break};case 5:{R=d+48|0;ky(c[N>>2]|0,R);if((c[A>>2]|0)!=13){break L5962}kx(c[N>>2]|0,2659360,12,c[R>>2]|0);break};default:{}}}while(0);kv(c[N>>2]|0,0,A);kP(d);if((a[1140677]&1)==0){B=c[A>>2]|0;if((B|0)==12){S=46008}else{S=(B|0)==13?45368:0}B=c[350119]|0;A=c[350120]|0;C=c[350121]|0;R=c[350122]|0;bR(M|0,64,44928,(T=i,i=i+40|0,c[T>>2]=S,c[T+8>>2]=B,c[T+16>>2]=A,c[T+24>>2]=C,c[T+32>>2]=R,T)|0)|0;i=T}else{c[350119]=0;c[350120]=0;R=c[334448]|0;C=(c[350121]|0)-1+R|0;A=C-((C>>>0)%(R>>>0)|0)|0;c[350121]=A;B=c[334449]|0;S=(c[350122]|0)-1+B|0;U=S-((S>>>0)%(B>>>0)|0)|0;c[350122]=U;V=(C>>>0)/(R>>>0)|0;R=(S>>>0)/(B>>>0)|0;bR(M|0,64,46792,(T=i,i=i+40|0,c[T>>2]=47256,c[T+8>>2]=A,c[T+16>>2]=U,c[T+24>>2]=V,c[T+32>>2]=R,T)|0)|0;i=T}if((a[M]|0)!=0){R=dy(M|0)|0;M=yF(R|0)|0;V=c[28080]|0;U=((V-30|0)>>>0)/6|0;if(M>>>0>U>>>0){a[R+(U-2)|0]=46;a[R+(U-1)|0]=46;a[R+U|0]=46;a[R+(U+1)|0]=0}U=(yF(R|0)|0)*6|0;M=U+15|0;A=(V-M|0)>>>1;V=((c[28082]|0)-26|0)>>>1;B=d+28|0;S=c[B>>2]|0;C=d+32|0;W=A+5|0;X=V+5|0;Y=V+21|0;do{if(Y>>>0>X>>>0){Z=U+5+W|0;_=(c[C>>2]|0)>>>1;if(Z>>>0>W>>>0){$=X}else{aa=S;break}do{ac=ab($,_)|0;ad=$>>>1;ae=W;do{af=((ae>>>1)+ad&1)+1|0;b[S+(ae+ac<<1)>>1]=(af<<9|af<<13|af<<5|12)&65535;ae=ae+1|0;}while(ae>>>0<Z>>>0);$=$+1|0;}while($>>>0<Y>>>0);aa=c[B>>2]|0}else{aa=S}}while(0);S=U+10|0;U=c[C>>2]|0;$=A+S|0;Z=U>>>1;if($>>>0>A>>>0){_=V;do{ae=ab(_,Z)|0;ac=_>>>1;ad=A;do{af=((ad>>>1)+ac&1)+1|0;b[aa+(ad+ae<<1)>>1]=(af<<10|af<<13|af<<5|12)&65535;ad=ad+1|0;}while(ad>>>0<$>>>0);_=_+1|0;}while(_>>>0<X>>>0);ag=c[B>>2]|0;ah=c[C>>2]|0}else{ag=aa;ah=U}U=A+M|0;M=cv(U|0,-5|0)|0;aa=M;M=ah>>>1;if(F){ah=V;do{_=ab(ah,M)|0;$=ah>>>1;Z=aa;do{ad=((Z>>>1)+$&1)+1|0;b[ag+(Z+_<<1)>>1]=(ad<<10|ad<<13|ad<<5|12)&65535;Z=Z+1|0;}while(Z>>>0<U>>>0);ah=ah+1|0;}while(ah>>>0<Y>>>0);ai=c[B>>2]|0}else{ai=ag}ag=V+26|0;do{if(ag>>>0>Y>>>0){ah=W+S|0;U=(c[C>>2]|0)>>>1;if(ah>>>0<=W>>>0){aj=ai;break}aa=ab(U,Y)|0;M=Y>>>1;Z=W;do{_=((Z>>>1)+M&1)+1|0;b[ai+(Z+aa<<1)>>1]=(_<<10|_<<13|_<<5|12)&65535;Z=Z+1|0;}while(Z>>>0<ah>>>0);Z=V+22|0;aa=ab(U,Z)|0;M=Z>>>1;Z=W;do{_=((Z>>>1)+M&1)+1|0;b[ai+(Z+aa<<1)>>1]=(_<<10|_<<13|_<<5|12)&65535;Z=Z+1|0;}while(Z>>>0<ah>>>0);Z=V+23|0;aa=ab(U,Z)|0;M=Z>>>1;Z=W;do{_=((Z>>>1)+M&1)+1|0;b[ai+(Z+aa<<1)>>1]=(_<<10|_<<13|_<<5|12)&65535;Z=Z+1|0;}while(Z>>>0<ah>>>0);Z=V+24|0;aa=ab(U,Z)|0;M=Z>>>1;Z=W;do{_=((Z>>>1)+M&1)+1|0;b[ai+(Z+aa<<1)>>1]=(_<<10|_<<13|_<<5|12)&65535;Z=Z+1|0;}while(Z>>>0<ah>>>0);Z=V+25|0;aa=ab(U,Z)|0;M=Z>>>1;Z=W;do{_=((Z>>>1)+M&1)+1|0;b[ai+(Z+aa<<1)>>1]=(_<<10|_<<13|_<<5|12)&65535;Z=Z+1|0;}while(Z>>>0<ah>>>0);aj=c[B>>2]|0}else{aj=ai}}while(0);if(ag>>>0>X>>>0){ai=(c[C>>2]|0)>>>1;C=X;do{X=ab(C,ai)|0;B=C>>>1;Y=A;do{S=((Y>>>1)+B&1)+1|0;b[aj+(Y+X<<1)>>1]=(S<<10|S<<13|S<<5|12)&65535;Y=Y+1|0;}while(Y>>>0<W>>>0);C=C+1|0;}while(C>>>0<ag>>>0)}kQ(d,A+8|0,V+8|0,R,0);yz(R)}R=c[350121]|0;if((R|0)==0){c[350121]=L;ak=L}else{ak=R}R=c[350122]|0;if((R|0)==0){c[350122]=Q;al=Q}else{al=R}g[6913]=+(ak>>>0>>>0)/+(al>>>0>>>0);al=c[(c[350708]|0)+16>>2]|0;if((al|0)==0){P=0;i=e;return P|0}fs[al&255](c[350660]|0);P=0;i=e;return P|0}al=d+52|0;L6082:do{switch(((a[al]&1)==0?O:10)|0){case 6:{c[d+48>>2]=0;a[al]=1;am=0;break};case 7:{a[al]=1;ak=c[N>>2]|0;if((c[ak+8>>2]|0)>>>0>1){R=d+48|0;Q=ak;do{ky(Q,R);Q=c[N>>2]|0;}while((c[Q+8>>2]|0)>>>0>1)}P=kN(d,6)|0;i=e;return P|0};case 9:{a[d+53|0]=1;am=0;break};case 0:{Q=d+48|0;R=c[Q>>2]|0;if((R|0)==0){c[Q>>2]=(c[(c[d+44>>2]|0)+8>>2]|0)-1;am=0;break L6082}else{c[Q>>2]=R-1;am=0;break L6082}break};case 5:{R=c[N>>2]|0;if((c[R+8>>2]|0)>>>0<=1){am=0;break L6082}a[al]=1;ky(R,d+48|0);am=0;break};case 4:{R=c[d+44>>2]|0;if((c[R+8>>2]|0)==0){P=0;i=e;return P|0}c[G>>2]=0;c[H>>2]=0;Q=d+48|0;ku(R,c[Q>>2]|0,G,H);R=c[H>>2]|0;ak=R-31|0;do{if(!(ak>>>0<24&((ak>>>0)%3|0|0)==0|(R|0)==28)){if((R-73|0)>>>0<4|(R|0)==78|(R|0)==79){break}if((R|0)==88|(R|0)==71|(R|0)==57|(R|0)==1){break}L=c[E>>2]|0;V=L-31|0;A=(L|0)==28;if(V>>>0<24&((V>>>0)%3|0|0)==0|A){if(A){A=J|0;g5(A,c[D>>2]|0,c[G>>2]|0,4096);kO(d+4180|0,j6(A,3)|0,A)}else{g5(d+4256+(((V>>>0)/3|0)*4148|0)|0,c[D>>2]|0,c[G>>2]|0,4096)}a[al]=1;c[z>>2]=0;kv(c[N>>2]|0,0,z);if((c[z>>2]|0)==26){am=0;break L6082}while(1){ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,z);if((c[z>>2]|0)==26){am=0;break L6082}}}switch(L|0){case 73:{i5(1238857,c[D>>2]|0,4096)|0;i5(d+54|0,c[D>>2]|0,4096)|0;a[al]=1;c[u>>2]=0;kv(c[N>>2]|0,0,u);if((c[u>>2]|0)==61){am=0;break L6082}while(1){ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,u);if((c[u>>2]|0)==61){am=0;break L6082}}break};case 76:{i5(1313170,c[D>>2]|0,4096)|0;a[al]=1;c[t>>2]=0;kv(c[N>>2]|0,0,t);if((c[t>>2]|0)==61){am=0;break L6082}while(1){ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,t);if((c[t>>2]|0)==61){am=0;break L6082}}break};case 78:{i5(1321362,c[D>>2]|0,4096)|0;a[al]=1;c[s>>2]=0;kv(c[N>>2]|0,0,s);if((c[s>>2]|0)==61){am=0;break L6082}while(1){ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,s);if((c[s>>2]|0)==61){am=0;break L6082}}break};case 75:{i5(1317266,c[D>>2]|0,4096)|0;a[al]=1;c[r>>2]=0;kv(c[N>>2]|0,0,r);if((c[r>>2]|0)==61){am=0;break L6082}while(1){ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,r);if((c[r>>2]|0)==61){am=0;break L6082}}break};case 74:{i5(1148885,c[D>>2]|0,4096)|0;a[al]=1;c[q>>2]=0;kv(c[N>>2]|0,0,q);if((c[q>>2]|0)==61){am=0;break L6082}while(1){ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,q);if((c[q>>2]|0)==61){am=0;break L6082}}break};case 56:{kD(c[Q>>2]|0);a[al]=1;c[v>>2]=0;kv(c[N>>2]|0,0,v);if((c[v>>2]|0)==4){am=-1;break L6082}while(1){ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,v);if((c[v>>2]|0)==4){am=-1;break L6082}}break};case 57:{a[al]=1;c[y>>2]=0;kv(c[N>>2]|0,0,y);if((c[y>>2]|0)==4){am=0;break L6082}while(1){ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,y);if((c[y>>2]|0)==4){am=0;break L6082}}break};case 88:{g5(1201944,c[D>>2]|0,c[G>>2]|0,4096);V=c[350702]|0;if((V|0)!=0){jB(V)}V=jz(1201944)|0;c[350702]=V;if((V|0)==0){V=c[350134]|0;A=(V|0)!=0?V:c[p>>2]|0;a5(84192,45,1,A|0)|0;A=c[350134]|0;V=(A|0)!=0?A:c[p>>2]|0;a_(V|0)|0}a[al]=1;c[x>>2]=0;kv(c[N>>2]|0,0,x);if((c[x>>2]|0)==60){am=0;break L6082}while(1){ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,x);if((c[x>>2]|0)==60){am=0;break L6082}}break};case 71:{V=K|0;g5(V,c[D>>2]|0,c[G>>2]|0,4096);gr(V);V=1400528;A=c[V+4>>2]|0;ag=1400528;c[ag>>2]=c[V>>2]|1;c[ag+4>>2]=A;a[al]=1;c[w>>2]=0;kv(c[N>>2]|0,0,w);if((c[w>>2]|0)==4){am=-1;break L6082}while(1){ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,w);if((c[w>>2]|0)==4){am=-1;break L6082}}break};default:{A=c[D>>2]|0;if((L|0)==79){i5(1234724,A,4096)|0;a[al]=1;c[o>>2]=0;kv(c[N>>2]|0,0,o);if((c[o>>2]|0)==61){am=0;break L6082}while(1){ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,o);if((c[o>>2]|0)==61){am=0;break L6082}}}g5(1280402,A,c[G>>2]|0,4096);L=1400528;ag=c[L+4>>2]|0;V=1400528;c[V>>2]=c[L>>2]|2;c[V+4>>2]=ag;a[al]=1;c[n>>2]=0;kv(c[N>>2]|0,0,n);if((c[n>>2]|0)!=4){do{ky(c[N>>2]|0,Q);kv(c[N>>2]|0,0,n);}while((c[n>>2]|0)!=4)}a[d+53|0]=1;am=-1;break L6082}}}}while(0);R=I|0;g5(R,c[D>>2]|0,c[G>>2]|0,4096);kx(c[N>>2]|0,R,c[H>>2]|0,c[Q>>2]|0);c[Q>>2]=0;a[al]=1;am=0;break};case 1:{R=d+48|0;ak=(c[R>>2]|0)+1|0;if(ak>>>0<(c[(c[d+44>>2]|0)+8>>2]|0)>>>0){c[R>>2]=ak;am=0;break L6082}else{c[R>>2]=0;am=0;break L6082}break};case 2:{R=d+48|0;ak=c[R>>2]|0;if(ak>>>0>8){c[R>>2]=ak-8;am=0;break L6082}else{c[R>>2]=0;am=0;break L6082}break};case 3:{R=d+48|0;ak=(c[R>>2]|0)+8|0;A=c[(c[d+44>>2]|0)+8>>2]|0;if(ak>>>0<A>>>0){c[R>>2]=ak;am=0;break L6082}else{c[R>>2]=A-1;am=0;break L6082}break};default:{am=0}}}while(0);kv(c[N>>2]|0,D,E);L6173:do{if((a[al]&1)!=0){N=c[E>>2]|0;do{if((N|0)!=1){H=N-31|0;if(H>>>0<24&((H>>>0)%3|0|0)==0|(N|0)==28){break}if((N-73|0)>>>0<4|(N|0)==78|(N|0)==79){break}if(!((N|0)==88|(N|0)==71|(N|0)==57|(N|0)==56)){break L6173}}}while(0);a[al]=0;N=d+44|0;kA(c[N>>2]|0);Q=c[E>>2]|0;do{if((Q|0)==56){H=l|0;G=m|0;I=d+113712|0;n=kS(c[I>>2]|0)|0;if((n|0)==0){break}else{an=0}do{c[h>>2]=0;c[j>>2]=0;c[k>>2]=0;kR(c[I>>2]|0,an,h,j,k);o=c[h>>2]|0;if((o|0)==0){w=c[k>>2]|0;i5(H,w,4096)|0}else{g6(G,g0(o)|0,2659360,4096);o=c[k>>2]|0;bR(H|0,4096,48544,(T=i,i=i+16|0,c[T>>2]=G,c[T+8>>2]=o,T)|0)|0;i=T}kx(c[N>>2]|0,H,0,0);an=an+1|0;}while(an>>>0<n>>>0)}else{n=c[D>>2]|0;H=c[N>>2]|0;G=f|0;if((a[n]|0)==0){kx(H,51096,Q,0);break}do{if((Q|0)==28){ao=50648}else if((Q|0)==57){ao=2659360}else{I=Q-31|0;if(I>>>0<24&((I>>>0)%3|0|0)==0){ao=49928;break}if((Q|0)==88){ao=49504;break}if((Q-73|0)>>>0<4|(Q|0)==78|(Q|0)==79){ao=2659360;break}I=c[d+4168>>2]|0;if((I|0)==0){ao=1338368;break}if((a[I]|0)==0){a[G]=0;ao=G;break}else{bR(G|0,1024,49160,(T=i,i=i+8|0,c[T>>2]=I,T)|0)|0;i=T;ao=G;break}}}while(0);G=g4(n,ao,1)|0;if((G|0)==0){break}gV(G,1);I=(Q-73|0)>>>0<4|(Q|0)==78|(Q|0)==79;if(I){kx(H,48808,3,0)}o=G+4|0;w=c[o>>2]|0;L6207:do{if((w|0)!=0){K=G|0;if(I){ap=0;aq=w}else{x=0;while(1){y=c[K>>2]|0;v=a[y+(x<<3)+4|0]|0;q=c[y+(x<<3)>>2]|0;if((a[n]|0)==0){ar=q}else{ar=g0(q)|0}kx(H,ar,(v&1)!=0?Q:0,0);x=x+1|0;if(x>>>0>=(c[o>>2]|0)>>>0){break L6207}}}while(1){x=c[K>>2]|0;if((a[x+(ap<<3)+4|0]&1)==0){as=aq}else{v=c[x+(ap<<3)>>2]|0;if((a[n]|0)==0){at=v}else{at=g0(v)|0}kx(H,at,Q,0);as=c[o>>2]|0}v=ap+1|0;if(v>>>0<as>>>0){ap=v;aq=as}else{break}}}}while(0);gS(G)}}while(0);Q=d+48|0;o=c[(c[N>>2]|0)+8>>2]|0;H=(o|0)==0;if(!((c[Q>>2]|0)>>>0<o>>>0|H)){c[Q>>2]=o-1;break}if(!H){break}c[Q>>2]=0}}while(0);kP(d);P=am;i=e;return P|0}function kN(b,d){b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0.0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0,aa=0,ab=0.0,ac=0,ad=0.0,ae=0,af=0.0,ag=0,ah=0;e=i;i=i+4216|0;f=e|0;j=e+64|0;k=e+4160|0;l=e+4168|0;m=e+4176|0;n=e+4184|0;o=e+4192|0;q=e+4200|0;r=e+4208|0;c[b+32>>2]=c[28080]<<1;c[n>>2]=0;c[o>>2]=0;do{if((d|0)!=6){ku(c[b+44>>2]|0,c[b+48>>2]|0,o,n);s=c[n>>2]|0;if((s|0)==57){c[o>>2]=2659360;break}else if((s|0)==71){c[o>>2]=b+54;break}else{break}}}while(0);c[q>>2]=0;c[r>>2]=0;s=b+40|0;kv(c[s>>2]|0,q,r);t=b+52|0;u=(a[t]&1)==0?d:10;L6238:do{switch(u|0){case 2:case 3:case 4:case 8:{d=c[n>>2]|0;v=(u|0)==4;if((d|0)==55&v){w=b+48|0;kx(c[s>>2]|0,b+54|0,1,c[w>>2]|0);c[w>>2]=0;a[t]=1;break L6238}do{if((d|0)==56){if(!v){break L6238}}else{if(((d-73|0)>>>0<4|(d|0)==78|(d|0)==79)&v){break}L6246:do{switch(d|0){case 69:case 62:case 61:case 59:case 58:case 26:case 5:case 4:case 60:case 71:case 57:{if(!v){break L6246}w=b+48|0;kx(c[s>>2]|0,c[o>>2]|0,d,c[w>>2]|0);c[w>>2]=0;a[t]=1;break L6238;break};default:{if(!((d|0)==12&v)){break L6246}kx(c[s>>2]|0,2659360,12,c[b+48>>2]|0);ft[c[(c[350657]|0)+44>>2]&127](c[350660]|0,1400476);g[6913]=+((c[350121]|0)>>>0>>>0)/+((c[350122]|0)>>>0>>>0);c[285170]=7;w=c[(c[350708]|0)+12>>2]|0;if((w|0)==0){break L6238}ft[w&127](c[350660]|0,7);break L6238}}}while(0);w=b+113708|0;x=c[w>>2]|0;if((d-6|0)>>>0<20){switch(d|0){case 23:{if((u|0)==8){a[1140670]=1;break L6238}else if((u|0)==2|(u|0)==3|(u|0)==4){a[1140670]=a[1140670]&1^1;break L6238}else{break L6238}break};case 21:case 22:{y=(d|0)==21?1140632:1140636;z=+g[y>>2];if((u|0)==8){g[y>>2]=3.0;A=3.0}else if((u|0)==2){B=z+-1.0;g[y>>2]=B;A=B}else if((u|0)==3){B=z+1.0;g[y>>2]=B;A=B}else{A=z}B=+bL(+A);C=B>1.0?B:1.0;g[y>>2]=C;if(z==C){break L6238}if((a[1140640]&1)!=0){break L6238}gm(0);break L6238;break};case 9:{if((u|0)==2){y=c[350126]|0;if((y|0)==0){break L6238}c[350126]=y-1;y=c[(c[350708]|0)+16>>2]|0;if((y|0)==0){break L6238}fs[y&255](c[350660]|0);break L6238}else if((u|0)==8){c[350126]=0;y=c[(c[350708]|0)+16>>2]|0;if((y|0)==0){break L6238}fs[y&255](c[350660]|0);break L6238}else{if(!((u|0)==3&(c[350126]|0)==0)){break L6238}c[350126]=1;y=c[(c[350708]|0)+16>>2]|0;if((y|0)==0){break L6238}fs[y&255](c[350660]|0);break L6238}break};case 17:{if((u|0)==8){a[1140657]=0;break L6238}else if((u|0)==2|(u|0)==3|(u|0)==4){a[1140657]=a[1140657]&1^1;break L6238}else{break L6238}break};case 15:{if((u|0)==8){hP(8388608,0);ft[c[(c[350657]|0)+40>>2]&127](c[350660]|0,c[350125]|0);break L6238}else if((u|0)==2){hP(1024,0);ft[c[(c[350657]|0)+40>>2]&127](c[350660]|0,c[350125]|0);break L6238}else if((u|0)==3){hP(2048,0);ft[c[(c[350657]|0)+40>>2]&127](c[350660]|0,c[350125]|0);break L6238}else{break L6238}break};case 7:{if((u|0)==8){hP(16777216,0)}else{hP(128,0)}y=c[c[350708]>>2]|0;if((y|0)==0){break L6238}fP[y&127](c[350660]|0,1,(a[1140668]&1)!=0);break L6238;break};case 19:{if((u|0)==8){a[1140658]=0;break L6238}else if((u|0)==2|(u|0)==3|(u|0)==4){a[1140658]=a[1140658]&1^1;break L6238}else{break L6238}break};case 24:{if((u|0)==8){y=1391840;c[y>>2]=0;c[y+4>>2]=0;break L6238}else if((u|0)!=4){break L6238}h[k>>3]=0.0;h[l>>3]=0.0;c[m>>2]=0;if(!(hq(k,l,m)|0)){break L6238}he(+h[k>>3]);ft[c[(c[350657]|0)+8>>2]&127](c[350660]|0,0);break L6238;break};case 11:{if((u|0)==3){hP(2,0)}else if((u|0)==8){hP(1048576,0)}else if((u|0)==2){hP(1,0)}y=c[(c[350708]|0)+12>>2]|0;if((y|0)==0){break L6238}ft[y&127](c[350660]|0,c[285170]|0);break L6238;break};case 18:{if((u|0)==3|(u|0)==4){y=c[285166]|0;if(y>>>0>=3){break L6238}c[285166]=y+1;break L6238}else if((u|0)==8){c[285166]=0;break L6238}else if((u|0)==2){y=c[285166]|0;if((y|0)==0){break L6238}c[285166]=y-1;break L6238}else{break L6238}break};case 14:{if(!v){break L6238}gm((a[1140640]&1)==0);break L6238;break};case 20:{y=c[285165]|0;if((u|0)==8){c[285165]=1;D=1}else if((u|0)==2){E=y-1|0;c[285165]=E;D=E}else if((u|0)==3|(u|0)==4){E=y+1|0;c[285165]=E;D=E}else{D=y}E=D>>>0<4?D:4;F=E>>>0>1?E:1;c[285165]=F;E=c[350657]|0;G=c[350660]|0;if(!((y|0)!=(F|0)&(E|0)!=0&(G|0)!=0)){break L6238}ft[c[E+8>>2]&127](G,0);break L6238;break};case 16:{if((u|0)==8){a[1140656]=1;break L6238}else if((u|0)==2|(u|0)==3|(u|0)==4){a[1140656]=a[1140656]&1^1;break L6238}else{break L6238}break};case 10:{do{if((u|0)==8){hP(2097152,0)}else{if((u-2|0)>>>0>=3){break}hP(4,0)}}while(0);G=c[(c[350708]|0)+16>>2]|0;if((G|0)==0){break L6238}fs[G&255](c[350660]|0);break L6238;break};default:{break L6238}}}if((d-27|0)>>>0<28){G=j|0;E=d-31|0;F=d-32|0;y=d-33|0;if((d|0)==29){if(!((c[(c[350657]|0)+20>>2]|0)!=0&v)){break L6238}if((a[1243488]&1)!=0){H=c[350134]|0;I=(H|0)!=0?H:c[p>>2]|0;a5(99136,31,1,I|0)|0;I=c[350134]|0;H=(I|0)!=0?I:c[p>>2]|0;a_(H|0)|0}H=b+4180|0;I=b+4252|0;L6345:do{if((c[I>>2]|0)!=0){J=3;K=0;while(1){L=j6(b+4256+(K*4148|0)|0,3)|0;if(!((L|0)==0|(L|0)==2)){break L6345}if((J|0)==3){M=L}else{if((J|0)==(L|0)){M=J}else{break L6345}}L=K+1|0;N=c[I>>2]|0;if(L>>>0<N>>>0){J=M;K=L}else{break}}if((N|0)==0|(M|0)==3){break}g5(G,(a[1148885]|0)!=0?1148885:1234724,(M|0)==2?99064:98928,4096);K=hs(0)|0;if((K|0)==0){break L6238}j5(K,H);hK(K,G)|0;ht(K);kO(0,M,G);break L6238}}while(0);G=j6(2659360,2)|0;kO(0,(G|0)==3?2:G,0);break L6238}else if((d|0)==30){do{if((u|0)==3|(u|0)==4){G=b+4252|0;H=c[G>>2]|0;if(H>>>0>=8){break}c[G>>2]=H+1}else if((u|0)==8){c[b+4252>>2]=0}else if((u|0)==2){H=b+4252|0;G=c[H>>2]|0;if((G|0)==0){break}c[H>>2]=G-1}}while(0);a[t]=1;break L6238}else if((d|0)==27){if((u|0)==8){a[1140668]=1;break L6238}else if((u|0)==2|(u|0)==3|(u|0)==4){a[1140668]=a[1140668]&1^1;break L6238}else{break L6238}}else{G=(d|0)==28;if(((E>>>0)%3|0|0)==0|G){if(G){O=b+4256+(((E>>>0)/3|0)*4148|0)|0}else{O=0}if((u|0)==4){G=b+48|0;kx(c[s>>2]|0,1148885,d,c[G>>2]|0);c[G>>2]=0;a[t]=1;break L6238}else if((u|0)!=8){break L6238}if((O|0)==0){break L6238}a[O|0]=0;break L6238}if(((F>>>0)%3|0|0)==0){G=(F>>>0)/3|0;if((u|0)==8){c[b+4256+(G*4148|0)+4136>>2]=0;break L6238}else if((u|0)==2|(u|0)==3|(u|0)==4){H=b+4256+(G*4148|0)+4136|0;c[H>>2]=(((c[H>>2]|0)+((u|0)==2?2:1)|0)>>>0)%3|0;break L6238}else{break L6238}}if(((y>>>0)%3|0|0)!=0){break L6238}H=(y>>>0)/3|0;if((u|0)==8){g[b+4256+(H*4148|0)+4120>>2]=0.0;g[b+4256+(H*4148|0)+4116>>2]=0.0;a[b+4256+(H*4148|0)+4104|0]=0;break L6238}else if((u|0)==2|(u|0)==3|(u|0)==4){G=b+4256+(H*4148|0)+4116|0;I=((~~+g[G>>2]+((u|0)==2?5:1)|0)>>>0)%6|0;a[b+4256+(H*4148|0)+4104|0]=(I|0)!=0|0;C=+(I>>>0>>>0);g[b+4256+(H*4148|0)+4120>>2]=C;g[G>>2]=C;break L6238}else{break L6238}}}if(d>>>0>65535){G=d-65536|0;if((u|0)==8){i$(c[335642]|0,G);break L6238}else if((u|0)==2){i_(c[335642]|0,G);break L6238}else if((u|0)==3|(u|0)==4){iZ(c[335642]|0,G);break L6238}else{break L6238}}L6397:do{switch(d|0){case 81:{if((u|0)==8){hP(4194304,0);break L6238}else{hP(8,0);break L6238}break};case 82:{if((u|0)==8){hP(8388608,0);break L6238}else if((u|0)==2){hP(16,0);break L6238}else if((u|0)==3){hP(32,0);break L6238}else{break L6238}break};case 91:{if((u|0)==8){c[w>>2]=0;break L6238}else if((u|0)==2){if((x|0)==0){break L6238}c[w>>2]=x-1;break L6238}else if((u|0)==3){if(x>>>0>=7){break L6238}c[w>>2]=x+1;break L6238}else{break L6238}break};case 92:{G=(c[350658]|0)+20|0;if((c[G>>2]|0)==0){H=1201324+(x<<2)|0;if((u|0)==8){c[H>>2]=x;P=x}else if((u|0)==2){I=(c[H>>2]|0)-1|0;c[H>>2]=I;P=I}else if((u|0)==3){I=(c[H>>2]|0)+1|0;c[H>>2]=I;P=I}else{P=c[H>>2]|0}if((P|0)<-1){c[H>>2]=-1;break L6238}if((P|0)<=7){break L6238}c[H>>2]=7;break L6238}else{H=1201356+(x<<2)|0;I=c[H>>2]|0;if((u|0)==8){c[H>>2]=0;Q=0}else if((u|0)==2){K=I-1|0;c[H>>2]=K;Q=K}else if((u|0)==3){K=I+1|0;c[H>>2]=K;Q=K}else{Q=I}I=c[1201900+(x<<2)>>2]|0;if((I|0)==1){R=80}else if((I|0)==2){R=144}else if((I|0)==0){R=48}else{R=16}fr[c[G>>2]&15](c[350661]|0,Q,x,0,R);break L6238}break};case 85:{if(!v){break L6238}G=1400528;I=c[G+4>>2]|0|0;K=1400528;c[K>>2]=c[G>>2]&-1026|1024;c[K+4>>2]=I;S=-1;i=e;return S|0};case 86:{if(!v){break L6238}if((a[1400540]&1)==0){break L6238}I=1400528;K=c[I+4>>2]|0;G=1400528;c[G>>2]=c[I>>2]|1;c[G+4>>2]=K;S=-1;i=e;return S|0};case 73:{break};case 76:{if((u|0)!=8){break L6238}a[1313170]=0;break L6238;break};case 78:{if((u|0)!=8){break L6238}a[1321362]=0;break L6238;break};case 75:{if((u|0)!=8){break L6238}a[1317266]=0;break L6238;break};case 74:{if((u|0)!=8){break L6238}a[1148885]=0;break L6238;break};case 79:{if((u|0)!=8){break L6238}a[1234724]=0;break L6238;break};case 84:{if((u|0)==8|(u|0)==2){K=1400528;G=c[K+4>>2]|0;I=1400528;c[I>>2]=c[K>>2]&-257;c[I+4>>2]=G;break L6238}else if((u|0)==3){G=1400528;I=c[G+4>>2]|0;K=1400528;c[K>>2]=c[G>>2]|256;c[K+4>>2]=I;break L6238}else{break L6238}break};case 70:{I=fN[c[335622]&63]()|0;K=fN[c[335620]&63]()|0;if((u-3|0)>>>0<2){T=1}else{G=(u|0)==2;if(G){T=G<<31>>31}else{break L6238}}G=I+1|0;gs(1,0);gt(((K+G+T|0)>>>0)%(G>>>0)|0);gs(0,0);break L6238;break};case 72:{if(!v){break L6238}do{if((a[1157111]&1)!=0|(c[335625]|0)!=0){G=c[350708]|0;do{if((G|0)!=0){K=c[G+24>>2]|0;if((K|0)==0){break}fP[K&127](c[350660]|0,0,0)}}while(0);if((c[350657]|0)==0){break}ga()}}while(0);f9();break L6238;break};case 65:{if((u-3|0)>>>0<2|(u|0)==2){a[1400542]=a[1400542]&1^1;break L6238}if((u|0)!=8){break L6238}a[1400542]=1;break L6238;break};case 67:case 68:{if((u|0)==2){hP(8192,0);break L6238}else if((u|0)==3){hP(16384,0);break L6238}else if((u|0)==4){if((d|0)==67){gl()}else{gk()}G=1400528;K=c[G+4>>2]|0;I=1400528;c[I>>2]=c[G>>2]|1;c[I+4>>2]=K;S=-1;i=e;return S|0}else if((u|0)==8){hP(134217728,0);break L6238}else{break L6238}break};case 64:{if((u-3|0)>>>0<2){c[309707]=(c[309707]|0)+1;break L6238}if((u|0)==8){c[309707]=1;break L6238}else if((u|0)!=2){break L6238}K=c[309707]|0;if(K>>>0<=1){break L6238}c[309707]=K-1;break L6238;break};case 63:{if((u|0)==8){a[1238820]=0;gh();break L6238}else if(!((u|0)==4|(u|0)==3|(u|0)==2)){break L6238}hP(4096,0);if((a[1238820]&1)==0){gh();break L6238}else{gg();break L6238}break};case 93:{K=1243492+(x<<2)|0;I=c[K>>2]|0;G=0;while(1){if(G>>>0>=8){U=0;break}if((I|0)==(c[5504+(G<<2)>>2]|0)){U=G;break}else{G=G+1|0}}if((u|0)==2){V=c[5504+((U+7&7)<<2)>>2]|0}else if((u|0)==3|(u|0)==4){V=c[5504+((U+1&7)<<2)>>2]|0}else if((u|0)==8){V=1}else{break L6238}c[K>>2]=V;ft[c[157558]&127](x,V);break L6238;break};case 94:{G=1201900+(x<<2)|0;I=c[G>>2]|0;H=I+4|0;c[G>>2]=H;if((u|0)==8){c[G>>2]=1;W=1}else if((u|0)==2){J=I+3|0;c[G>>2]=J;W=J}else if((u|0)==3){J=I+5|0;c[G>>2]=J;W=J}else{W=H}H=W&3;c[G>>2]=H;G=c[(c[350658]|0)+20>>2]|0;if((G|0)==0){break L6238}if((H|0)==2){X=128}else if((H|0)==0){X=32}else if((H|0)==1){X=64}else{break L6238}fr[G&15](c[350661]|0,c[1201356+(x<<2)>>2]|0,x,0,X);break L6238;break};case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:case 105:case 106:case 107:case 108:case 109:case 110:{G=c[(c[350658]|0)+20>>2]|0;if((G|0)==0){break L6397}if((u|0)==8){Y=8}else if((u|0)==2){Y=2}else{H=(u|0)==3;if(H){Y=H?4:0}else{break L6397}}H=d-95|0;fr[G&15](c[350661]|0,c[1201356+(H<<2)>>2]|0,x,c[5608+(H<<2)>>2]|0,Y);break};case 80:{if(!v){break L6238}gp();H=1400528;G=c[H+4>>2]|0;J=1400528;c[J>>2]=c[H>>2]|1;c[J+4>>2]=G;S=-1;i=e;return S|0};case 87:{if(!v){break L6238}G=1400528;J=c[G+4>>2]|0;H=1400528;c[H>>2]=c[G>>2]&-2;c[H+4>>2]=J;S=-1;i=e;return S|0};case 88:{if((u|0)==4){J=b+48|0;kx(c[s>>2]|0,1321362,88,c[J>>2]|0);c[J>>2]=0;a[t]=1;break L6238}else if((u|0)!=8){break L6238}J=c[350702]|0;if((J|0)!=0){jB(J)}c[350702]=0;a[1201944]=0;break L6238;break};case 89:{if((u|0)==2){C=+g[301510]+-.009999999776482582;g[301510]=C;Z=1;_=C;$=4874}else if((u|0)==3|(u|0)==4){C=+g[301510]+.009999999776482582;g[301510]=C;Z=1;_=C;$=4874}else if((u|0)==8){g[301510]=1.0;aa=1;ab=1.0}else{Z=0;_=+g[301510];$=4874}do{if(($|0)==4874){if(_<0.0){g[301510]=0.0;aa=Z;ab=0.0;break}if(_<=1.0){aa=Z;ab=_;break}g[301510]=1.0;aa=Z;ab=1.0}}while(0);K=c[350702]|0;if(!(aa&(K|0)!=0)){break L6238}jA(K,ab);break L6238;break};case 90:{if((u|0)==3|(u|0)==4){C=+g[301511]+.009999999776482582;g[301511]=C;ac=1;ad=C;$=4885}else if((u|0)==8){g[301511]=1.0;ae=1;af=1.0}else if((u|0)==2){C=+g[301511]+-.009999999776482582;g[301511]=C;ac=1;ad=C;$=4885}else{ac=0;ad=+g[301511];$=4885}do{if(($|0)==4885){if(ad<.009999999776482582){g[301511]=.009999999776482582;ae=ac;af=.009999999776482582;break}if(ad<=2.0){ae=ac;af=ad;break}g[301511]=2.0;ae=ac;af=2.0}}while(0);K=c[350702]|0;if(!(ae&(K|0)!=0)){break L6238}jy(K,af);break L6238;break};default:{break L6238}}}while(0);if((u|0)!=8){break L6238}a[1238857]=0;a[b+54|0]=0;break L6238}}while(0);v=b+48|0;kx(c[s>>2]|0,2659360,d,c[v>>2]|0);c[v>>2]=0;a[t]=1;break};case 1:{v=b+48|0;x=(c[v>>2]|0)+1|0;if(x>>>0<(c[(c[b+44>>2]|0)+8>>2]|0)>>>0){c[v>>2]=x;break L6238}else{c[v>>2]=0;break L6238}break};case 5:{v=c[s>>2]|0;if((c[v+8>>2]|0)>>>0<=1){break L6238}ky(v,b+48|0);a[t]=1;break};case 6:{c[b+48>>2]=0;a[t]=1;break};case 9:{a[b+53|0]=1;break};case 0:{v=b+48|0;x=c[v>>2]|0;if((x|0)==0){c[v>>2]=(c[(c[b+44>>2]|0)+8>>2]|0)-1;break L6238}else{c[v>>2]=x-1;break L6238}break};default:{}}}while(0);kv(c[s>>2]|0,q,r);L6588:do{if((a[t]&1)!=0){q=c[r>>2]|0;if((q|0)==1){break}s=q-31|0;if(s>>>0<24&((s>>>0)%3|0|0)==0|(q|0)==28){break}if((q-73|0)>>>0<4|(q|0)==78|(q|0)==79){break}if((q|0)==88|(q|0)==71|(q|0)==57|(q|0)==56){break}a[t]=0;switch(q|0){case 60:{q=b+44|0;kA(c[q>>2]|0);kx(c[q>>2]|0,104696,88,0);kx(c[q>>2]|0,104360,89,0);kx(c[q>>2]|0,104096,90,0);kx(c[q>>2]|0,103776,91,0);kx(c[q>>2]|0,103656,92,0);kx(c[q>>2]|0,103256,93,0);s=c[350658]|0;if((s|0)==0){break L6588}if((c[s+20>>2]|0)==0){break L6588}kx(c[q>>2]|0,102984,94,0);kx(c[q>>2]|0,102752,95,0);kx(c[q>>2]|0,102544,96,0);kx(c[q>>2]|0,102232,97,0);kx(c[q>>2]|0,101752,98,0);kx(c[q>>2]|0,101280,99,0);kx(c[q>>2]|0,100976,100,0);kx(c[q>>2]|0,100840,101,0);kx(c[q>>2]|0,100728,102,0);kx(c[q>>2]|0,100552,103,0);kx(c[q>>2]|0,100376,104,0);kx(c[q>>2]|0,100280,105,0);kx(c[q>>2]|0,100176,106,0);kx(c[q>>2]|0,99968,107,0);kx(c[q>>2]|0,99512,108,0);kx(c[q>>2]|0,99376,109,0);kx(c[q>>2]|0,99240,110,0);break L6588;break};case 61:{q=b+44|0;kA(c[q>>2]|0);kx(c[q>>2]|0,107136,73,0);kx(c[q>>2]|0,106944,74,0);kx(c[q>>2]|0,106696,75,0);kx(c[q>>2]|0,106240,76,0);kx(c[q>>2]|0,106008,78,0);kx(c[q>>2]|0,105528,79,0);break L6588;break};case 62:{q=b+44|0;kA(c[q>>2]|0);kx(c[q>>2]|0,108048,63,0);kx(c[q>>2]|0,107800,64,0);kx(c[q>>2]|0,107568,65,0);kx(c[q>>2]|0,107360,84,0);break L6588;break};case 58:{q=b+44|0;kA(c[q>>2]|0);s=c[335642]|0;if((s|0)==0){kx(c[q>>2]|0,108744,65535,0);break L6588}u=iX(s)|0;if((u|0)==0){break L6588}else{ag=0}do{s=c[q>>2]|0;kx(s,iY(c[335642]|0,ag)|0,ag+65536|0,0);ag=ag+1|0;}while(ag>>>0<u>>>0);break};case 59:{u=b+44|0;kA(c[u>>2]|0);kx(c[u>>2]|0,36200,81,0);kx(c[u>>2]|0,109096,82,0);break L6588;break};case 69:{u=b+44|0;kA(c[u>>2]|0);kx(c[u>>2]|0,36688,70,0);kx(c[u>>2]|0,36464,71,0);break L6588;break};case 5:{u=b+44|0;kA(c[u>>2]|0);kx(c[u>>2]|0,41624,26,0);kx(c[u>>2]|0,41184,10,0);kx(c[u>>2]|0,40776,11,0);kx(c[u>>2]|0,40440,12,0);kx(c[u>>2]|0,40216,14,0);kx(c[u>>2]|0,39976,15,0);kx(c[u>>2]|0,39744,16,0);kx(c[u>>2]|0,39328,17,0);kx(c[u>>2]|0,39088,18,0);kx(c[u>>2]|0,38736,19,0);kx(c[u>>2]|0,38032,20,0);kx(c[u>>2]|0,37640,21,0);kx(c[u>>2]|0,37352,22,0);kx(c[u>>2]|0,37064,23,0);kx(c[u>>2]|0,36896,24,0);break L6588;break};case 26:{u=f|0;q=b+44|0;kA(c[q>>2]|0);kx(c[q>>2]|0,44632,29,0);kx(c[q>>2]|0,44328,27,0);kx(c[q>>2]|0,44008,28,0);kx(c[q>>2]|0,43768,30,0);d=b+4252|0;if((c[d>>2]|0)==0){break L6588}else{ah=0}do{bR(u|0,64,43384,(s=i,i=i+8|0,c[s>>2]=ah,s)|0)|0;i=s;ae=ah*3|0;kx(c[q>>2]|0,u,ae+31|0,0);bR(u|0,64,42976,(s=i,i=i+8|0,c[s>>2]=ah,s)|0)|0;i=s;kx(c[q>>2]|0,u,ae+32|0,0);bR(u|0,64,42480,(s=i,i=i+8|0,c[s>>2]=ah,s)|0)|0;i=s;kx(c[q>>2]|0,u,ae+33|0,0);ah=ah+1|0;}while(ah>>>0<(c[d>>2]|0)>>>0);break};default:{kK(b);break L6588}}}}while(0);kP(b);S=0;i=e;return S|0}function kO(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;if((a[1243488]&1)!=0){g=c[350134]|0;h=(g|0)!=0?g:c[p>>2]|0;g=(e|0)!=0?e:48008;en(h|0,48256,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;h=c[350134]|0;g=(h|0)!=0?h:c[p>>2]|0;a_(g|0)|0}if(!(fA[c[(c[350657]|0)+20>>2]&63](c[350660]|0,d,e)|0)){d=c[350134]|0;g=(d|0)!=0?d:c[p>>2]|0;a5(47592,46,1,g|0)|0;g=c[350134]|0;d=(g|0)!=0?g:c[p>>2]|0;a_(d|0)|0;a[1144780]=0;i=f;return}d=(e|0)!=0;i5(1140684,d?e:2659360,4096)|0;a[1144780]=1;if((b|0)==0|d^1){i=f;return}d=hs(e)|0;if((d|0)!=0){j1(d,b)|0;j7(b,e);ht(d)}a[(c[155632]|0)+52|0]=1;i=f;return}function kP(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0.0,aa=0.0,ac=0,ad=0;e=i;i=i+1536|0;f=e|0;j=e+256|0;k=e+264|0;l=e+272|0;m=e+528|0;n=e+592|0;o=e+600|0;p=e+608|0;q=e+864|0;r=e+1120|0;s=e+1128|0;t=e+1136|0;u=e+1144|0;v=e+1216|0;w=e+1472|0;do{if((a[d+52|0]&1)!=0){x=1400528;if((c[x>>2]&4|0)==0&(c[x+4>>2]&0|0)==0){break}if((a[d+53|0]&1)!=0){break}i=e;return}}while(0);x=d+48|0;y=c[x>>2]|0;z=c[28082]|0;A=(((z-42|0)>>>0)/11|0)-1|0;B=A>>>1;C=A+y|0;D=d+44|0;E=c[(c[D>>2]|0)+8>>2]|0;F=C>>>0>E>>>0?E:C;C=E>>>0>A>>>0?y>>>0<B>>>0?0:y-B|0:0;B=(F-C|0)>>>0>A>>>0?C+A|0:F;F=d+28|0;A=c[F>>2]|0;y=d+32|0;E=c[28080]|0;do{if((z|0)==0){G=A;H=E;I=5001}else{J=c[y>>2]|0;K=J>>>1;if((E|0)==0){L=A;M=-5;N=J;I=5003;break}else{O=0}do{J=ab(O,K)|0;P=O>>>1;Q=0;do{R=((Q>>>1)+P&1)+1|0;b[A+(Q+J<<1)>>1]=(R<<13|R<<9|R<<5|12)&65535;Q=Q+1|0;}while(Q>>>0<E>>>0);O=O+1|0;}while(O>>>0<z>>>0);G=c[F>>2]|0;H=c[28080]|0;I=5001}}while(0);do{if((I|0)==5001){z=H-5|0;if(z>>>0<=5){S=G;break}L=G;M=z;N=c[y>>2]|0;I=5003}}while(0);if((I|0)==5003){I=N>>>1;N=I*5|0;G=5;do{H=(G>>>1&1)+1|0;b[L+(G+N<<1)>>1]=(H<<13|H<<10|H<<5|12)&65535;G=G+1|0;}while(G>>>0<M>>>0);G=I*6|0;N=5;do{H=2-(N>>>1&1)|0;b[L+(N+G<<1)>>1]=(H<<13|H<<10|H<<5|12)&65535;N=N+1|0;}while(N>>>0<M>>>0);N=I*7|0;G=5;do{H=2-(G>>>1&1)|0;b[L+(G+N<<1)>>1]=(H<<13|H<<10|H<<5|12)&65535;G=G+1|0;}while(G>>>0<M>>>0);G=I<<3;N=5;do{H=(N>>>1&1)+1|0;b[L+(N+G<<1)>>1]=(H<<13|H<<10|H<<5|12)&65535;N=N+1|0;}while(N>>>0<M>>>0);N=I*9|0;I=5;do{G=(I>>>1&1)+1|0;b[L+(I+N<<1)>>1]=(G<<13|G<<10|G<<5|12)&65535;I=I+1|0;}while(I>>>0<M>>>0);S=c[F>>2]|0}M=c[28082]|0;I=M-10|0;do{if((M-5|0)>>>0>I>>>0){N=(c[28080]|0)-5|0;L=(c[y>>2]|0)>>>1;if(N>>>0<=5){T=S;U=M;break}G=ab(L,I)|0;H=I>>>1;z=5;do{O=((z>>>1)+H&1)+1|0;b[S+(z+G<<1)>>1]=(O<<13|O<<10|O<<5|12)&65535;z=z+1|0;}while(z>>>0<N>>>0);z=M-9|0;G=ab(L,z)|0;H=z>>>1;z=5;do{O=((z>>>1)+H&1)+1|0;b[S+(z+G<<1)>>1]=(O<<13|O<<10|O<<5|12)&65535;z=z+1|0;}while(z>>>0<N>>>0);z=M-8|0;G=ab(L,z)|0;H=z>>>1;z=5;do{O=((z>>>1)+H&1)+1|0;b[S+(z+G<<1)>>1]=(O<<13|O<<10|O<<5|12)&65535;z=z+1|0;}while(z>>>0<N>>>0);z=M-7|0;G=ab(L,z)|0;H=z>>>1;z=5;do{O=((z>>>1)+H&1)+1|0;b[S+(z+G<<1)>>1]=(O<<13|O<<10|O<<5|12)&65535;z=z+1|0;}while(z>>>0<N>>>0);z=M-6|0;G=ab(L,z)|0;H=z>>>1;z=5;do{O=((z>>>1)+H&1)+1|0;b[S+(z+G<<1)>>1]=(O<<13|O<<10|O<<5|12)&65535;z=z+1|0;}while(z>>>0<N>>>0);T=c[F>>2]|0;U=c[28082]|0}else{T=S;U=M}}while(0);M=U-5|0;if(M>>>0>5){S=(c[y>>2]|0)>>>1;I=5;do{N=ab(I,S)|0;z=I>>>1&1;G=z+1|0;H=(G<<13|G<<10|G<<5|12)&65535;b[T+(N+5<<1)>>1]=H;G=2-z|0;z=(G<<13|G<<10|G<<5|12)&65535;b[T+(N+6<<1)>>1]=z;b[T+(N+7<<1)>>1]=z;b[T+(N+8<<1)>>1]=H;b[T+(N+9<<1)>>1]=H;I=I+1|0;}while(I>>>0<M>>>0);V=c[F>>2]|0;W=c[28082]|0}else{V=T;W=U}U=c[28080]|0;T=U-10|0;F=W-5|0;do{if(F>>>0>5){W=(c[y>>2]|0)>>>1;if((U-5|0)>>>0<=T>>>0){break}M=T>>>1;I=U-9|0;S=I>>>1;H=U-8|0;N=H>>>1;z=U-7|0;G=z>>>1;L=U-6|0;O=L>>>1;E=5;do{A=ab(E,W)|0;K=E>>>1;Q=(K+M&1)+1|0;b[V+(A+T<<1)>>1]=(Q<<13|Q<<10|Q<<5|12)&65535;Q=(K+S&1)+1|0;b[V+(A+I<<1)>>1]=(Q<<13|Q<<10|Q<<5|12)&65535;Q=(K+N&1)+1|0;b[V+(A+H<<1)>>1]=(Q<<13|Q<<10|Q<<5|12)&65535;Q=(K+G&1)+1|0;b[V+(A+z<<1)>>1]=(Q<<13|Q<<10|Q<<5|12)&65535;Q=(K+O&1)+1|0;b[V+(A+L<<1)>>1]=(Q<<13|Q<<10|Q<<5|12)&65535;E=E+1|0;}while(E>>>0<F>>>0)}}while(0);c[j>>2]=0;c[k>>2]=0;kv(c[d+40>>2]|0,j,k);F=c[k>>2]|0;L6696:do{switch(F|0){case 59:{i5(f|0,46576,256)|0;break};case 26:{i5(f|0,50440,256)|0;break};case 69:{i5(f|0,42328,256)|0;break};case 58:{i5(f|0,38624,256)|0;break};case 57:{bR(f|0,256,70224,(X=i,i=i+8|0,c[X>>2]=c[j>>2],X)|0)|0;i=X;break};case 71:{bR(f|0,256,60576,(X=i,i=i+8|0,c[X>>2]=c[j>>2],X)|0)|0;i=X;break};case 5:{i5(f|0,54720,256)|0;break};default:{V=F-31|0;if(V>>>0<24&((V>>>0)%3|0|0)==0|(F|0)==28){V=f|0;T=c[j>>2]|0;bR(V|0,256,108648,(X=i,i=i+8|0,c[X>>2]=T,X)|0)|0;i=X;break L6696}if((F-60|0)>>>0<3|(F|0)==12|(F|0)==13|(F|0)==4){T=f|0;V=c[j>>2]|0;bR(T|0,256,105392,(X=i,i=i+8|0,c[X>>2]=V,X)|0)|0;i=X;break L6696}switch(F|0){case 56:{i5(f|0,102104,256)|0;break L6696;break};case 88:{bR(f|0,256,99816,(X=i,i=i+8|0,c[X>>2]=c[j>>2],X)|0)|0;i=X;break L6696;break};case 73:{bR(f|0,256,98288,(X=i,i=i+8|0,c[X>>2]=c[j>>2],X)|0)|0;i=X;break L6696;break};case 75:{bR(f|0,256,93976,(X=i,i=i+8|0,c[X>>2]=c[j>>2],X)|0)|0;i=X;break L6696;break};case 78:{bR(f|0,256,90624,(X=i,i=i+8|0,c[X>>2]=c[j>>2],X)|0)|0;i=X;break L6696;break};case 74:{bR(f|0,256,96088,(X=i,i=i+8|0,c[X>>2]=c[j>>2],X)|0)|0;i=X;break L6696;break};case 79:{bR(f|0,256,88800,(X=i,i=i+8|0,c[X>>2]=c[j>>2],X)|0)|0;i=X;break L6696;break};case 76:{bR(f|0,256,92296,(X=i,i=i+8|0,c[X>>2]=c[j>>2],X)|0)|0;i=X;break L6696;break};default:{V=c[d+4160>>2]|0;T=(V|0)==0?c[334444]|0:V;V=c[j>>2]|0;bR(f|0,256,85104,(X=i,i=i+16|0,c[X>>2]=(T|0)==0?87040:T,c[X+8>>2]=V,X)|0)|0;i=X;break L6696}}}}}while(0);j=l|0;kG(j,((((c[28080]|0)-30|0)>>>0)/6|0)-3|0,((c[350074]|0)>>>0)/15|0,f|0,1);kQ(d,30,15,j,1);j=c[d+4160>>2]|0;f=(j|0)==0?c[334444]|0:j;j=c[d+4164>>2]|0;l=(j|0)==0?c[334445]|0:j;j=m|0;bR(j|0,64,82664,(X=i,i=i+24|0,c[X>>2]=80672,c[X+8>>2]=(f|0)==0?87040:f,c[X+16>>2]=(l|0)==0?2659360:l,X)|0)|0;i=X;l=(c[28082]|0)-42|0;kQ(d,30,18-((l>>>0)%11|0)+l|0,j,1);if(C>>>0>=B>>>0){i=e;return}j=d+113708|0;l=q|0;q=d+4180|0;f=v|0;v=w|0;w=p|0;p=u+8|0;m=u|0;F=u;u=C;C=27;while(1){c[n>>2]=0;c[o>>2]=0;ku(c[D>>2]|0,u,n,o);V=c[k>>2]|0;if((V|0)==60){Y=24;Z=60}else{Y=(V|0)==61?24:19;Z=V}V=c[j>>2]|0;T=c[o>>2]|0;L6730:do{if((T-27|0)>>>0<28){U=Z-31|0;do{if(U>>>0<24&((U>>>0)%3|0|0)==0|(Z|0)==28){y=T-31|0;if(!(y>>>0<24&((y>>>0)%3|0|0)==0|(T|0)==28)){break}c[o>>2]=1;i5(l,78904,256)|0;_=5;break L6730}}while(0);if((T|0)==27){U=(a[1140668]&1)!=0?74992:74048;bR(l|0,256,76208,(X=i,i=i+8|0,c[X>>2]=U,X)|0)|0;i=X;_=Y;break}else if((T|0)==28){i5(l,77600,256)|0;_=Y;break}else{kw(q,l,256,T);_=Y;break}}else{do{if(!((Z|0)==88|(Z|0)==71|(Z|0)==57)){if((Z-73|0)>>>0<4|(Z|0)==78|(Z|0)==79){break}if((Z|0)==56){a[l]=0;_=0;break L6730}if(T>>>0>65535){U=iG(c[335642]|0,T-65536|0)|0;i5(l,U,256)|0;_=Y;break L6730}switch(T|0){case 76:{i5(l,(a[1313170]|0)!=0?1313170:61192,256)|0;_=Y;break L6730;break};case 78:{i5(l,(a[1321362]|0)!=0?1321362:62128,256)|0;_=Y;break L6730;break};case 16:{i5(l,(a[1140656]&1)!=0?72176:70928,256)|0;_=Y;break L6730;break};case 17:{i5(l,(a[1140657]&1)!=0?72176:70928,256)|0;_=Y;break L6730;break};case 10:{i5(l,(a[1140677]&1)!=0?72176:70928,256)|0;_=Y;break L6730;break};case 19:{i5(l,(a[1140658]&1)!=0?72176:70928,256)|0;_=Y;break L6730;break};case 20:{bR(l|0,256,66064,(X=i,i=i+8|0,c[X>>2]=c[285165],X)|0)|0;i=X;_=Y;break L6730;break};case 15:{i5(l,5192+(c[350125]<<5)|0,256)|0;_=Y;break L6730;break};case 8:{U=1400528;bR(l|0,256,((c[U>>2]&65536|0)!=0|(c[U+4>>2]&0|0)!=0?72176:70928)|0,(X=i,i=i+1|0,i=i+7>>3<<3,c[X>>2]=0,X)|0)|0;i=X;_=Y;break L6730;break};case 7:{if((a[1140668]&1)==0){i5(l,68072,256)|0;_=Y;break L6730}else{i5(l,69336,256)|0;_=Y;break L6730}break};case 9:{bR(l|0,256,67088,(X=i,i=i+8|0,c[X>>2]=c[350126],X)|0)|0;i=X;_=Y;break L6730;break};case 64:{bR(l|0,256,66064,(X=i,i=i+8|0,c[X>>2]=c[309707],X)|0)|0;i=X;_=Y;break L6730;break};case 65:{i5(l,(a[1400542]&1)!=0?72176:70928,256)|0;_=Y;break L6730;break};case 66:{i5(l,(c[309711]|0)!=0?72176:70928,256)|0;_=Y;break L6730;break};case 67:case 68:{bR(l|0,256,67088,(X=i,i=i+8|0,c[X>>2]=c[334438],X)|0)|0;i=X;_=Y;break L6730;break};case 11:{i5(l,27112+((c[285170]|0)*68|0)|0,256)|0;_=Y;break L6730;break};case 0:{i5(l,72976,256)|0;_=6;break L6730;break};case 1:{i5(l,78904,256)|0;_=5;break L6730;break};case 63:{i5(l,(a[1238820]&1)!=0?72176:70928,256)|0;_=Y;break L6730;break};case 23:{i5(l,(a[1140670]&1)!=0?72176:70928,256)|0;_=Y;break L6730;break};case 18:{bR(l|0,256,66064,(X=i,i=i+8|0,c[X>>2]=c[285166],X)|0)|0;i=X;_=Y;break L6730;break};case 24:{h[r>>3]=0.0;h[s>>3]=0.0;c[t>>2]=0;if(hq(r,s,t)|0){$=+h[r>>3];aa=+h[s>>3]*100.0;U=c[t>>2]|0;bR(l|0,256,64304,(X=i,i=i+24|0,h[X>>3]=$,h[X+8>>3]=aa,c[X+16>>2]=U,X)|0)|0;i=X;_=Y;break L6730}else{i5(l,63568,256)|0;_=Y;break L6730}break};case 21:{bR(l|0,256,65168,(X=i,i=i+8|0,h[X>>3]=+g[285158],X)|0)|0;i=X;_=Y;break L6730;break};case 22:{bR(l|0,256,65168,(X=i,i=i+8|0,h[X>>3]=+g[285159],X)|0)|0;i=X;_=Y;break L6730;break};case 81:{i5(l,(a[1342617]&1)!=0?72176:70928,256)|0;_=Y;break L6730;break};case 82:{bR(l|0,256,62752,(X=i,i=i+8|0,h[X>>3]=+g[291341],X)|0)|0;i=X;_=Y;break L6730;break};case 84:{U=1400528;bR(l|0,256,((c[U>>2]&256|0)!=0|(c[U+4>>2]&0|0)!=0?72176:70928)|0,(X=i,i=i+1|0,i=i+7>>3<<3,c[X>>2]=0,X)|0)|0;i=X;_=Y;break L6730;break};case 73:{i5(l,(a[1238857]|0)!=0?1238857:62128,256)|0;_=Y;break L6730;break};case 93:{switch(c[1243492+(V<<2)>>2]|0){case 1:{ac=56744;break};case 5:{ac=56240;break};case 257:{ac=55888;break};case 2:{ac=55168;break};case 516:{ac=54120;break};case 772:{ac=53520;break};case 260:{ac=52904;break};case 0:{ac=57136;break};default:{ac=52528}}i5(l,ac,256)|0;_=Y;break L6730;break};case 94:{U=c[1201900+(V<<2)>>2]|0;if((U|0)==0){i5(l,57136,256)|0;_=Y;break L6730}else if((U|0)==1){i5(l,52288,256)|0;_=Y;break L6730}else if((U|0)==3){i5(l,52008,256)|0;_=Y;break L6730}else if((U|0)==2){i5(l,51728,256)|0;_=Y;break L6730}else{_=Y;break L6730}break};case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:case 105:case 106:case 107:case 108:case 109:case 110:{U=c[5608+(T-95<<2)>>2]|0;i5(p,52528,64)|0;y=1165472+(V*2240|0)+(U*40|0)+16|0;U=c[y+4>>2]|0;c[m>>2]=c[y>>2];c[m+4>>2]=U;U=c[(c[350658]|0)+20>>2]|0;if((U|0)!=0){fr[U&15](F,0,0,0,256)}i5(l,p,256)|0;_=Y;break L6730;break};case 75:{i5(l,(a[1317266]|0)!=0?1317266:61192,256)|0;_=Y;break L6730;break};case 74:{i5(l,(a[1148885]|0)!=0?1148885:62128,256)|0;_=Y;break L6730;break};case 79:{i5(l,(a[1234724]|0)!=0?1234724:61192,256)|0;_=Y;break L6730;break};case 70:{U=fN[c[335622]&63]()|0;y=fN[c[335620]&63]()|0;if(y>>>0<U>>>0){U=y+1|0;bR(l|0,256,66064,(X=i,i=i+8|0,c[X>>2]=U,X)|0)|0;i=X;_=Y;break L6730}else{i5(l,59816,256)|0;_=Y;break L6730}break};case 55:case 56:case 58:case 12:case 14:case 5:case 59:case 69:case 26:case 28:case 57:case 71:case 60:case 61:case 62:{i5(l,77600,256)|0;_=Y;break L6730;break};case 88:{i5(l,g0(1201944)|0,256)|0;_=Y;break L6730;break};case 89:{bR(l|0,256,59280,(X=i,i=i+8|0,h[X>>3]=+g[301510],X)|0)|0;i=X;_=Y;break L6730;break};case 90:{bR(l|0,256,59280,(X=i,i=i+8|0,h[X>>3]=+g[301511],X)|0)|0;i=X;_=Y;break L6730;break};case 91:{bR(l|0,256,58744,(X=i,i=i+8|0,c[X>>2]=V+1,X)|0)|0;i=X;_=Y;break L6730;break};case 92:{U=c[1201324+(V<<2)>>2]|0;if(U>>>0>=8){i5(l,57712,256)|0;_=Y;break L6730}y=1201388+(U<<6)|0;if((a[y]|0)==0){bR(l|0,256,58176,(X=i,i=i+8|0,c[X>>2]=U,X)|0)|0;i=X;_=Y;break L6730}else{i5(l,y,256)|0;_=Y;break L6730}break};default:{a[l]=0;_=0;break L6730}}}}while(0);if((T|0)==0){i5(l,72976,256)|0;_=6;break}else if((T|0)==3){a[l]=0;_=0;break}else{i5(l,78904,256)|0;c[o>>2]=1;_=5;break}}}while(0);T=(u|0)==(c[x>>2]|0);i5(f,c[n>>2]|0,256)|0;i5(v,l,64)|0;if((c[o>>2]|0)>>>0<2){V=-3-_|0;kG(f,V+((((c[28080]|0)-30|0)>>>0)/6|0)|0,((c[350074]|0)>>>0)/15|0,c[n>>2]|0,T);ad=V}else{kG(v,_,((c[350074]|0)>>>0)/15|0,l,T);ad=-3-_|0}V=ad+((((c[28080]|0)-30|0)>>>0)/6|0)|0;bR(w|0,256,51352,(X=i,i=i+48|0,c[X>>2]=T?62:32,c[X+8>>2]=V,c[X+16>>2]=V,c[X+24>>2]=f,c[X+32>>2]=_,c[X+40>>2]=v,X)|0)|0;i=X;kQ(d,15,C,w,T);T=u+1|0;if(T>>>0<B>>>0){u=T;C=C+11|0}else{break}}i=e;return}function kQ(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=a[h]|0;if(j<<24>>24==0){return}k=e+4152|0;l=i?32639:-1;i=e+32|0;m=e+28|0;e=h;h=f;f=j;while(1){j=0;n=f;while(1){o=j*5|0;p=j+g|0;q=c[k>>2]|0;if((1<<(o&7)&(d[q+(((n&255)*7|0)+(o>>3))|0]|0)|0)==0){r=n;s=q}else{q=h+(ab((c[i>>2]|0)>>>1,p)|0)|0;b[(c[m>>2]|0)+(q<<1)>>1]=l;r=a[e]|0;s=c[k>>2]|0}q=o+1|0;if((1<<(q&7)&(d[s+(((r&255)*7|0)+(q>>3))|0]|0)|0)==0){t=r;u=s}else{q=h+1+(ab((c[i>>2]|0)>>>1,p)|0)|0;b[(c[m>>2]|0)+(q<<1)>>1]=l;t=a[e]|0;u=c[k>>2]|0}q=o+2|0;if((1<<(q&7)&(d[u+(((t&255)*7|0)+(q>>3))|0]|0)|0)==0){v=t;w=u}else{q=h+2+(ab((c[i>>2]|0)>>>1,p)|0)|0;b[(c[m>>2]|0)+(q<<1)>>1]=l;v=a[e]|0;w=c[k>>2]|0}q=o+3|0;if((1<<(q&7)&(d[w+(((v&255)*7|0)+(q>>3))|0]|0)|0)==0){x=v;y=w}else{q=h+3+(ab((c[i>>2]|0)>>>1,p)|0)|0;b[(c[m>>2]|0)+(q<<1)>>1]=l;x=a[e]|0;y=c[k>>2]|0}q=o+4|0;if((1<<(q&7)&(d[y+(((x&255)*7|0)+(q>>3))|0]|0)|0)!=0){q=h+4+(ab((c[i>>2]|0)>>>1,p)|0)|0;b[(c[m>>2]|0)+(q<<1)>>1]=l}q=j+1|0;if((q|0)>=10){break}j=q;n=a[e]|0}n=e+1|0;j=a[n]|0;if(j<<24>>24==0){break}else{e=n;h=h+6|0;f=j}}return}function kR(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;g=a|0;c[d>>2]=c[(c[g>>2]|0)+(b*12|0)>>2];c[e>>2]=c[(c[g>>2]|0)+(b*12|0)+4>>2];c[f>>2]=c[(c[g>>2]|0)+(b*12|0)+8>>2];return}function kS(a){a=a|0;return c[a+4>>2]|0}function kT(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;e=i;i=i+8|0;d=e|0;b=c[155632]|0;f=b+8|0;do{if((c[f>>2]&256|0)==0&(c[f+4>>2]&0|0)==0){g=0}else{if((a[1400540]&1)==0){g=0;break}if((a[1401613]&1)!=0){g=0;break}h=1400528;j=c[h+4>>2]|0;k=1400528;c[k>>2]=c[h>>2]|65;c[k+4>>2]=j;g=-1}}while(0);f=1400528;j=c[f>>2]|0;k=c[f+4>>2]|0;if(!((j&64|0)==0&(k&0|0)==0)){f=1400528;c[f>>2]=j&-65;c[f+4>>2]=k|0}if((g|0)>=0){i=e;return g|0}c[d>>2]=0;kv(c[b+40>>2]|0,0,d);if((c[d>>2]|0)==4){i=e;return g|0}do{b=c[155632]|0;ky(c[b+40>>2]|0,b+48|0);kv(c[(c[155632]|0)+40>>2]|0,0,d);}while((c[d>>2]|0)!=4);i=e;return g|0}function kU(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+16|0;g=f|0;h=a+4|0;j=c[h>>2]|0;L6883:do{if((j|0)==0){k=0}else{l=a|0;L6885:do{if((b|0)==0){m=0;while(1){n=c[l>>2]|0;do{if((c[n+(m*12|0)>>2]|0)==0){if((cS(c[n+(m*12|0)+4>>2]|0,d|0)|0)!=0){break}if((cS(c[n+(m*12|0)+8>>2]|0,e|0)|0)==0){o=m;p=n;break L6885}}}while(0);n=m+1|0;if(n>>>0<j>>>0){m=n}else{k=j;break L6883}}}else{m=0;while(1){n=c[l>>2]|0;q=c[n+(m*12|0)>>2]|0;do{if((q|0)!=0){if((cS(b|0,q|0)|0)!=0){break}if((cS(c[n+(m*12|0)+4>>2]|0,d|0)|0)!=0){break}if((cS(c[n+(m*12|0)+8>>2]|0,e|0)|0)==0){o=m;p=n;break L6885}}}while(0);n=m+1|0;if(n>>>0<j>>>0){m=n}else{k=j;break L6883}}}}while(0);if((o|0)==0){i=f;return}m=g;n=p+(o*12|0)|0;c[m>>2]=c[n>>2];c[m+4>>2]=c[n+4>>2];c[m+8>>2]=c[n+8>>2];yN(p+12|0,p|0,o*12|0|0);n=c[l>>2]|0;c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];i=f;return}}while(0);o=a+8|0;p=c[o>>2]|0;if((k|0)==(p|0)){g=k-1|0;k=a|0;j=c[k>>2]|0;m=j+(g*12|0)|0;yz(c[m>>2]|0);yz(c[j+(g*12|0)+4>>2]|0);yz(c[j+(g*12|0)+8>>2]|0);yG(m|0,0,12);c[h>>2]=(c[h>>2]|0)-1;r=c[o>>2]|0;s=k}else{r=p;s=a|0}a=c[s>>2]|0;yN(a+12|0,a|0,(r*12|0)-12|0);if((b|0)==0){t=0}else{t=dy(b|0)|0}c[c[s>>2]>>2]=t;t=dy(d|0)|0;c[(c[s>>2]|0)+4>>2]=t;t=dy(e|0)|0;c[(c[s>>2]|0)+8>>2]=t;c[h>>2]=(c[h>>2]|0)+1;i=f;return}function kV(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;if((a|0)==0){i=b;return}d=a+12|0;e=c[d>>2]|0;do{if((e|0)!=0){f=dc(e|0,103616)|0;if((f|0)==0){break}g=a+4|0;if((c[g>>2]|0)!=0){h=a|0;j=0;do{k=c[h>>2]|0;l=c[k+(j*12|0)>>2]|0;m=c[k+(j*12|0)+4>>2]|0;n=c[k+(j*12|0)+8>>2]|0;en(f|0,83808,(k=i,i=i+24|0,c[k>>2]=(l|0)==0?2659264:l,c[k+8>>2]=m,c[k+16>>2]=n,k)|0)|0;i=k;j=j+1|0;}while(j>>>0<(c[g>>2]|0)>>>0)}aS(f|0)|0}}while(0);yz(c[d>>2]|0);d=a+8|0;e=a|0;g=c[e>>2]|0;if((c[d>>2]|0)==0){o=g}else{j=0;h=g;while(1){g=h+(j*12|0)|0;yz(c[g>>2]|0);yz(c[h+(j*12|0)+4>>2]|0);yz(c[h+(j*12|0)+8>>2]|0);yG(g|0,0,12);g=j+1|0;k=c[e>>2]|0;if(g>>>0<(c[d>>2]|0)>>>0){j=g;h=k}else{o=k;break}}}yz(o);yz(a);i=b;return}function kW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+12288|0;f=e|0;g=yy(1,16)|0;h=g;if((g|0)==0){j=0;i=e;return j|0}k=yy(d,12)|0;l=g;c[l>>2]=k;if((k|0)==0){kV(h);j=0;i=e;return j|0}k=g+8|0;c[k>>2]=d;d=f|0;m=dc(b|0,93416)|0;if((m|0)!=0){n=g+4|0;c[n>>2]=0;L6941:do{if((c[k>>2]|0)!=0){o=f+4096|0;p=f+8192|0;do{a[d]=0;if((b1(d|0,4096,m|0)|0)==0){break L6941}q=cn(d|0,10)|0;if((q|0)!=0){a[q]=0}a[o]=0;if((b1(o|0,4096,m|0)|0)==0){break L6941}q=cn(o|0,10)|0;if((q|0)!=0){a[q]=0}a[p]=0;if((b1(p|0,4096,m|0)|0)==0){break L6941}q=cn(p|0,10)|0;if((q|0)!=0){a[q]=0}q=c[n>>2]|0;r=c[l>>2]|0;if((a[o]|0)==0){break L6941}if((a[p]|0)==0){break L6941}if((a[d]|0)!=0){c[r+(q*12|0)>>2]=dy(d|0)|0}c[r+(q*12|0)+4>>2]=dy(o|0)|0;c[r+(q*12|0)+8>>2]=dy(p|0)|0;q=(c[n>>2]|0)+1|0;c[n>>2]=q;}while(q>>>0<(c[k>>2]|0)>>>0)}}while(0);aS(m|0)|0}c[g+12>>2]=dy(b|0)|0;j=h;i=e;return j|0}function kX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+4|0;a=c[e>>2]|0;if((a|0)==0){return}fv[c[a+32>>2]&127](b)|0;b=c[e>>2]|0;if((b|0)==0){return}fv[c[b+36>>2]&127](d)|0;return}function kY(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+72|0;h=f|0;j=f+8|0;k=f+40|0;l=b+4|0;m=c[l>>2]|0;if((m|0)==0){i=f;return}if((fN[c[m+16>>2]&63]()|0)==0){i=f;return}m=j|0;a[m]=0;n=c[l>>2]|0;do{if((n|0)==0){o=5262}else{ft[c[n+28>>2]&127](1,j);q=c[l>>2]|0;if((q|0)==0){o=5262;break}r=fN[c[q+16>>2]&63]()|0;q=c[l>>2]|0;s=k|0;a[s]=0;if((q|0)==0){t=0;u=s;break}ft[c[q+28>>2]&127](r,k);r=c[l>>2]|0;if((r|0)==0){t=0;u=s;break}do{if((fN[c[r+16>>2]&63]()|0)==1){if((a[m]&1)!=0){break}i=f;return}}while(0);r=c[l>>2]|0;if((r|0)==0){t=0;u=s;break}t=fN[c[r+16>>2]&63]()|0;u=s}}while(0);if((o|0)==5262){n=k|0;a[n]=0;t=0;u=n}n=t-1|0;k=b+1636|0;c[k>>2]=n;if((a[u]&1)==0){v=n}else{c[k>>2]=t;v=t}if((a[m]&1)==0){g[j+12>>2]=1.0;g[j+16>>2]=1.0;c[j+8>>2]=0;c[j+4>>2]=0;a[m]=1}j=b+1124|0;t=j;yJ(j|0,m|0,32)|0;if((v|0)>1){v=1;while(1){m=v+1|0;j=t+(v<<5)|0;n=j|0;a[n]=0;u=c[l>>2]|0;if((u|0)==0){o=5277}else{ft[c[u+28>>2]&127](m,j);if((a[n]&1)==0){o=5277}}if((o|0)==5277){o=0;g[t+(v<<5)+16>>2]=1.0;g[t+(v<<5)+12>>2]=1.0;c[t+(v<<5)+8>>2]=0;c[t+(v<<5)+4>>2]=0;a[n]=1}if((m|0)<(c[k>>2]|0)){v=m}else{break}}}kZ(b,d,e,c[b+1728>>2]|0,c[b+1732>>2]|0);e=c[k>>2]|0;if((e|0)>0){d=b+740|0;v=0;while(1){m=(c[d+(v*24|0)>>2]|0)-1|0;n=m>>>1|m;m=n>>>2|n;n=m>>>4|m;m=n>>>8|n;n=(m>>>16|m)+1|0;c[d+(v*24|0)+16>>2]=n;m=(c[d+(v*24|0)+4>>2]|0)-1|0;j=m>>>1|m;m=j>>>2|j;j=m>>>4|m;m=j>>>8|j;j=(m>>>16|m)+1|0;c[d+(v*24|0)+20>>2]=j;if((a[1243488]&1)!=0){m=c[350134]|0;u=(m|0)!=0?m:c[p>>2]|0;en(u|0,93168,(w=i,i=i+24|0,c[w>>2]=v,c[w+8>>2]=n,c[w+16>>2]=j,w)|0)|0;i=w;j=c[350134]|0;n=(j|0)!=0?j:c[p>>2]|0;a_(n|0)|0}n=v+1|0;j=c[k>>2]|0;if((n|0)<(j|0)){v=n}else{x=j;break}}}else{x=e}e=b+676|0;v=e;d=e;bz(x|0,d|0);x=(a[1140668]&1)!=0?9729:9728;if((c[k>>2]|0)>0){e=b+740|0;j=b+2584|0;n=0;do{aZ(3553,c[v+(n<<2)>>2]|0);a[h]=0;u=c[l>>2]|0;do{if((u|0)==0){y=33071;z=x}else{m=n+2|0;if(fL[c[u+20>>2]&63](m,h)|0){A=(a[h]&1)!=0?9729:9728}else{A=x}r=c[l>>2]|0;if((r|0)==0){y=33071;z=A;break}q=fv[c[r+24>>2]&127](m)|0;if((q|0)==3){y=33648;z=A;break}else if((q|0)==0|(q|0)==1){y=33071;z=A;break}else if((q|0)==2){y=10497;z=A;break}else{y=0;z=A;break}}}while(0);fa(3553,10240,z|0);fa(3553,10241,z|0);fa(3553,10242,y|0);fa(3553,10243,y|0);do{if((a[t+(n<<5)|0]&1)==0){o=5305}else{if((a[t+(n<<5)+28|0]&1)==0){o=5305;break}do{if((a[j]&1)==0){u=a3(7939)|0;if((u|0)==0){B=0;break}B=(bw(u|0,57104)|0)!=0}else{B=0}}while(0);if((a[1243488]&1)!=0){u=c[350134]|0;s=(u|0)!=0?u:c[p>>2]|0;u=B?105328:102048;en(s|0,108560,(w=i,i=i+16|0,c[w>>2]=57104,c[w+8>>2]=u,w)|0)|0;i=w;u=c[350134]|0;s=(u|0)!=0?u:c[p>>2]|0;a_(s|0)|0}if(!B){s=c[350134]|0;u=(s|0)!=0?s:c[p>>2]|0;a5(56672,67,1,u|0)|0;u=c[350134]|0;s=(u|0)!=0?u:c[p>>2]|0;a_(s|0)|0}if((a[1243488]&1)!=0){s=c[350134]|0;u=(s|0)!=0?s:c[p>>2]|0;en(u|0,56192,(w=i,i=i+8|0,c[w>>2]=n,w)|0)|0;i=w;u=c[350134]|0;s=(u|0)!=0?u:c[p>>2]|0;a_(s|0)|0}ed(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5126,0)}}while(0);if((o|0)==5305){o=0;ed(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5121,0)}n=n+1|0;}while((n|0)<(c[k>>2]|0))}aZ(3553,0);aZ(3553,0);n=b+612|0;e=n;w=n;dX(c[k>>2]|0,w|0);n=0;while(1){if((n|0)>=(c[k>>2]|0)){o=5311;break}b5(36160,c[e+(n<<2)>>2]|0);dB(36160,36064,3553,c[v+(n<<2)>>2]|0,0);if((cs(36160)|0)==36053){n=n+1|0}else{o=5310;break}}if((o|0)==5310){cc(c[k>>2]|0,w|0);w=c[350134]|0;n=(w|0)!=0?w:c[p>>2]|0;a5(57616,94,1,n|0)|0;n=c[350134]|0;w=(n|0)!=0?n:c[p>>2]|0;a_(w|0)|0;bh(c[k>>2]|0,d|0);d=c[350134]|0;k=(d|0)!=0?d:c[p>>2]|0;a5(103536,78,1,k|0)|0;k=c[350134]|0;d=(k|0)!=0?k:c[p>>2]|0;a_(d|0)|0;i=f;return}else if((o|0)==5311){a[b+1640|0]=1;i=f;return}}function kZ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0.0,r=0.0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+8|0;j=h|0;k=c[a+1832>>2]|0;l=c[a+1836>>2]|0;c[j>>2]=0;d1(3379,j|0);m=a+1636|0;if((c[m>>2]|0)<=0){i=h;return}n=a+1124|0;o=a+740|0;q=+(f>>>0>>>0);r=+(e>>>0>>>0);e=b;b=d;d=k;k=l;l=0;f=0;while(1){a=c[n+(f<<5)+4>>2]|0;if((a|0)==0){s=+g[n+(f<<5)+12>>2];c[o+(f*24|0)>>2]=~~(+(e>>>0>>>0)*s);c[o+(f*24|0)+8>>2]=~~(+(d>>>0>>>0)*s)}else if((a|0)==1){t=c[n+(f<<5)+20>>2]|0;c[o+(f*24|0)+8>>2]=t;c[o+(f*24|0)>>2]=t}else if((a|0)==2){a=~~(r*+g[n+(f<<5)+12>>2]);c[o+(f*24|0)+8>>2]=a;c[o+(f*24|0)>>2]=a}a=c[n+(f<<5)+8>>2]|0;if((a|0)==2){t=~~(q*+g[n+(f<<5)+16>>2]);c[o+(f*24|0)+12>>2]=t;c[o+(f*24|0)+4>>2]=t}else if((a|0)==0){s=+g[n+(f<<5)+16>>2];c[o+(f*24|0)+4>>2]=~~(+(b>>>0>>>0)*s);c[o+(f*24|0)+12>>2]=~~(+(k>>>0>>>0)*s)}else if((a|0)==1){a=c[n+(f<<5)+24>>2]|0;c[o+(f*24|0)+12>>2]=a;c[o+(f*24|0)+4>>2]=a}a=o+(f*24|0)|0;t=c[a>>2]|0;u=c[j>>2]|0;if(t>>>0>u>>>0){c[a>>2]=u;v=1;w=u}else{v=l;w=t}t=o+(f*24|0)+4|0;x=c[t>>2]|0;if(x>>>0>u>>>0){c[t>>2]=u;y=1;z=u}else{y=v;z=x}x=o+(f*24|0)+8|0;A=c[x>>2]|0;if(A>>>0>u>>>0){c[x>>2]=u;B=1;C=u}else{B=y;C=A}A=o+(f*24|0)+12|0;D=c[A>>2]|0;if(D>>>0>u>>>0){c[A>>2]=u;E=5337}else{if(B){E=5337}else{F=0;G=w;H=z;I=C;J=D}}if((E|0)==5337){E=0;D=c[350134]|0;K=(D|0)!=0?D:c[p>>2]|0;en(K|0,55792,(K=i,i=i+16|0,c[K>>2]=u,c[K+8>>2]=u,K)|0)|0;i=K;K=c[350134]|0;u=(K|0)!=0?K:c[p>>2]|0;a_(u|0)|0;F=1;G=c[a>>2]|0;H=c[t>>2]|0;I=c[x>>2]|0;J=c[A>>2]|0}A=f+1|0;if((A|0)<(c[m>>2]|0)){e=G;b=H;d=I;k=J;l=F;f=A}else{break}}i=h;return}function k_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0;e=i;i=i+64|0;f=e|0;h=a+1936|0;j=h;lv(j,+g[b>>2],+g[b+4>>2],+g[b+8>>2],+g[b+12>>2],+g[b+16>>2],+g[b+20>>2]);if(d){lu(f,+((c[a+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0);lw(a+1872|0,f,j);i=e;return}else{j=a+1872|0;yJ(j|0,h|0,64)|0;i=e;return}}function k$(b,d,e,f,h){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0.0,x=0.0;j=i;i=i+64|0;k=j|0;l=c[(c[b>>2]|0)+24>>2]|0;if((l|0)==0){m=+(d>>>0>>>0)/+(e>>>0>>>0)}else{m=+fE[l&3](d,e)}do{if((a[1140677]&1)==0|f){if((a[b+1714|0]&1)==0|f){c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=d;c[b+1748>>2]=e;n=d;o=e;p=0;q=0;break}r=+g[334458];do{if((c[285170]|0)==7){l=c[350122]|0;s=c[350121]|0;t=l;u=(c[b+1732>>2]|0)-(c[350120]|0)-l|0;v=c[350119]|0}else{if(+Q(+(m-r))<9999999747378752.0e-20){s=d;t=e;u=0;v=0;break}if(m>r){w=(r/m+-1.0)*.5+.5;x=+(d>>>0>>>0);l=~~+bL(+(x*(.5-w)));s=~~+bL(+(x*2.0*w));t=e;u=0;v=l;break}else{w=(m/r+-1.0)*.5+.5;x=+(e>>>0>>>0);l=~~+bL(+(x*(.5-w)));s=d;t=~~+bL(+(x*2.0*w));u=l;v=0;break}}}while(0);c[b+1736>>2]=v;c[b+1740>>2]=u;c[b+1744>>2]=s;c[b+1748>>2]=t;n=s;o=t;p=v;q=u}else{l=b+1736|0;iJ(l,d,e,+g[334458],(a[b+1714|0]&1)!=0);n=c[b+1744>>2]|0;o=c[b+1748>>2]|0;p=c[l>>2]|0;q=c[b+1740>>2]|0}}while(0);eS(p|0,q|0,n|0,o|0);q=b+1936|0;p=q;lv(p,0.0,1.0,0.0,1.0,-1.0,1.0);if(h){lu(k,+((c[b+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0);lw(b+1872|0,k,p)}else{p=b+1872|0;yJ(p|0,q|0,64)|0}if(f){i=j;return}c[b+1760>>2]=n;c[b+1764>>2]=o;i=j;return}function k0(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+8|0;h=f|0;j=yy(1,2592)|0;k=j;if((j|0)==0){l=0;i=f;return l|0}m=c[335630]|0;n=c[335631]|0;do{if((a[1140600]|0)==0){o=lN(1,m,n)|0;q=5379}else{r=lM(1140600)|0;if((r|0)==0){s=c[350134]|0;t=(s|0)!=0?s:c[p>>2]|0;en(t|0,58120,(u=i,i=i+8|0,c[u>>2]=1140600,u)|0)|0;i=u;t=c[350134]|0;s=(t|0)!=0?t:c[p>>2]|0;a_(s|0)|0;break}if(!(fA[c[r+8>>2]&63](1,m,n)|0)){s=c[350134]|0;t=(s|0)!=0?s:c[p>>2]|0;en(t|0,59216,(u=i,i=i+16|0,c[u>>2]=59792,c[u+8>>2]=1140600,u)|0)|0;i=u;t=c[350134]|0;s=(t|0)!=0?t:c[p>>2]|0;a_(s|0)|0;break}if(fN[c[r>>2]&63]()|0){o=r;q=5379;break}s=c[350134]|0;t=(s|0)!=0?s:c[p>>2]|0;s=c[r+68>>2]|0;en(t|0,58688,(u=i,i=i+8|0,c[u>>2]=s,u)|0)|0;i=u;s=c[350134]|0;t=(s|0)!=0?s:c[p>>2]|0;a_(t|0)|0}}while(0);do{if((q|0)==5379){n=j;c[n>>2]=o;if((o|0)==0){break}m=j+2476|0;t=b;c[m>>2]=c[t>>2];c[m+4>>2]=c[t+4>>2];c[m+8>>2]=c[t+8>>2];c[m+12>>2]=c[t+12>>2];c[m+16>>2]=c[t+16>>2];if((a[1243488]&1)==0){v=o}else{t=c[350134]|0;m=(t|0)!=0?t:c[p>>2]|0;t=c[o+68>>2]|0;en(m|0,82592,(u=i,i=i+8|0,c[u>>2]=t,u)|0)|0;i=u;t=c[350134]|0;m=(t|0)!=0?t:c[p>>2]|0;a_(m|0)|0;v=c[n>>2]|0}m=j+1720|0;t=j+1724|0;ft[c[v+20>>2]&127](m,t);if((a[1243488]&1)!=0){s=c[350134]|0;r=(s|0)!=0?s:c[p>>2]|0;s=c[m>>2]|0;w=c[t>>2]|0;en(r|0,80608,(u=i,i=i+16|0,c[u>>2]=s,c[u+8>>2]=w,u)|0)|0;i=u;w=c[350134]|0;s=(w|0)!=0?w:c[p>>2]|0;a_(s|0)|0}s=b+9|0;fs[c[(c[n>>2]|0)+12>>2]&255]((a[s]&1)!=0?c[285165]|0:0);w=c[b>>2]|0;r=c[b+4>>2]|0;x=b+8|0;y=(a[x]&1)!=0;if(y&(w|0)==0&(r|0)==0){z=c[m>>2]|0;A=c[t>>2]|0}else{z=w;A=r}if(!(fA[c[(c[n>>2]|0)+16>>2]&63](z,A,y)|0)){yz(j);l=0;i=f;return l|0}dN()|0;y=a3(7936)|0;r=a3(7937)|0;if((a[1243488]&1)!=0){w=c[350134]|0;B=(w|0)!=0?w:c[p>>2]|0;en(B|0,78832,(u=i,i=i+16|0,c[u>>2]=y,c[u+8>>2]=r,u)|0)|0;i=u;r=c[350134]|0;y=(r|0)!=0?r:c[p>>2]|0;a_(y|0)|0}y=a3(7938)|0;if((a[1243488]&1)!=0){r=c[350134]|0;B=(r|0)!=0?r:c[p>>2]|0;en(B|0,77568,(u=i,i=i+8|0,c[u>>2]=y,u)|0)|0;i=u;y=c[350134]|0;B=(y|0)!=0?y:c[p>>2]|0;a_(B|0)|0}l9(c[(c[n>>2]|0)+52>>2]|0);eM(770,771);a[1402804]=0;B=j+2584|0;do{if((a[B]&1)==0){y=a3(7939)|0;if((y|0)==0){C=0;break}C=(bw(y|0,62720)|0)!=0}else{C=0}}while(0);if((a[1243488]&1)!=0){y=c[350134]|0;r=(y|0)!=0?y:c[p>>2]|0;y=C?105328:102048;en(r|0,108560,(u=i,i=i+16|0,c[u>>2]=62720,c[u+8>>2]=y,u)|0)|0;i=u;y=c[350134]|0;r=(y|0)!=0?y:c[p>>2]|0;a_(r|0)|0}do{if(C){if((a[1243488]&1)==0){break}r=c[350134]|0;y=(r|0)!=0?r:c[p>>2]|0;a5(62056,52,1,y|0)|0;y=c[350134]|0;r=(y|0)!=0?y:c[p>>2]|0;a_(r|0)|0}else{a[1402804]=1;r=c[350134]|0;y=(r|0)!=0?r:c[p>>2]|0;a5(61064,117,1,y|0)|0;y=c[350134]|0;r=(y|0)!=0?y:c[p>>2]|0;a_(r|0)|0}}while(0);a[j+8|0]=a[s]&1;a[j+1713|0]=a[x]&1;r=j+1728|0;y=j+1732|0;ft[c[(c[n>>2]|0)+20>>2]&127](r,y);if((a[1243488]&1)!=0){w=c[350134]|0;D=(w|0)!=0?w:c[p>>2]|0;w=c[r>>2]|0;E=c[y>>2]|0;en(D|0,76168,(u=i,i=i+16|0,c[u>>2]=w,c[u+8>>2]=E,u)|0)|0;i=u;E=c[350134]|0;w=(E|0)!=0?E:c[p>>2]|0;a_(w|0)|0}if((c[m>>2]|0)==0){if((c[t>>2]|0)!=0){q=5406}}else{q=5406}if((q|0)==5406){c[m>>2]=c[r>>2];c[t>>2]=c[y>>2]}w=j+2016|0;c[w>>2]=(a[1342518]&1)!=0?328:296;E=j+48|0;c[E>>2]=4;D=(c[335625]|0)==2;F=j+1710|0;a[F]=D&1;if(D){c[E>>2]=1}D=j+2020|0;c[D>>2]=104;lF(c[(c[n>>2]|0)+52>>2]|0);lK((a[B]&1)!=0,c[335630]|0,c[335631]|0);if((a[1144780]&1)==0){G=0}else{G=(a[1140684]|0)!=0?1140684:0}H=j6(G,2)|0;do{if((H|0)==3){if((a[1243488]&1)==0){break}I=c[350134]|0;J=(I|0)!=0?I:c[p>>2]|0;a5(66976,41,1,J|0)|0;J=c[350134]|0;I=(J|0)!=0?J:c[p>>2]|0;a_(I|0)|0}else if((H|0)==2){if((a[1243488]&1)!=0){I=c[350134]|0;J=(I|0)!=0?I:c[p>>2]|0;a5(65976,44,1,J|0)|0;J=c[350134]|0;I=(J|0)!=0?J:c[p>>2]|0;a_(I|0)|0}I=j+4|0;c[I>>2]=19072;if(fv[c[4768]&127](G)|0){break}J=c[350134]|0;a5(63480,73,1,((J|0)!=0?J:c[p>>2]|0)|0)|0;J=c[350134]|0;a_(((J|0)!=0?J:c[p>>2]|0)|0)|0;if(fv[c[c[I>>2]>>2]&127](0)|0){break}I=c[350134]|0;a5(74904,47,1,((I|0)!=0?I:c[p>>2]|0)|0)|0;I=c[350134]|0;a_(((I|0)!=0?I:c[p>>2]|0)|0)|0;fQ[c[(c[n>>2]|0)+4>>2]&1023]();yz(j);l=0;i=f;return l|0}else{I=c[350134]|0;a5(65040,89,1,((I|0)!=0?I:c[p>>2]|0)|0)|0;I=c[350134]|0;a_(((I|0)!=0?I:c[p>>2]|0)|0)|0}}while(0);H=j+4|0;B=c[H>>2]|0;if((B|0)!=0){t=(fN[c[B+40>>2]&63]()|0)+1|0;B=c[E>>2]|0;c[E>>2]=t>>>0>B>>>0?t:B}B=a[1243488]|0;if((B&1)==0){K=B}else{B=c[350134]|0;t=(B|0)!=0?B:c[p>>2]|0;B=c[E>>2]|0;en(t|0,54624,(u=i,i=i+8|0,c[u>>2]=B,u)|0)|0;i=u;B=c[350134]|0;t=(B|0)!=0?B:c[p>>2]|0;a_(t|0)|0;K=a[1243488]|0}if((K&1)!=0){t=c[350134]|0;B=(t|0)!=0?t:c[p>>2]|0;t=c[H>>2]|0;if((t|0)==0){L=0}else{L=fN[c[t+16>>2]&63]()|0}en(B|0,73984,(u=i,i=i+8|0,c[u>>2]=L,u)|0)|0;i=u;B=c[350134]|0;t=(B|0)!=0?B:c[p>>2]|0;a_(t|0)|0}t=c[b+12>>2]<<8;B=j+1832|0;c[B>>2]=t;m=j+1836|0;c[m>>2]=t;a[j+1714|0]=a[b+10|0]&1;t=c[H>>2]|0;if((t|0)!=0){fs[c[t+12>>2]&255](0)}k$(j,c[r>>2]|0,c[y>>2]|0,0,1);t=c[H>>2]|0;if((t|0)!=0){fs[c[t+12>>2]&255](1)}k$(j,c[r>>2]|0,c[y>>2]|0,0,1);a[h]=0;t=c[H>>2]|0;do{if((t|0)==0){q=5435}else{if(!(fL[c[t+20>>2]&63](1,h)|0)){q=5435;break}c[j+468>>2]=(a[h]&1)!=0?9729:9728}}while(0);if((q|0)==5435){c[j+468>>2]=(a[b+11|0]&1)!=0?9729:9728}t=c[H>>2]|0;do{if((t|0)==0){M=33071}else{y=fv[c[t+24>>2]&127](1)|0;if((y|0)==3){M=33648;break}else if((y|0)==2){M=10497;break}else if((y|0)==0|(y|0)==1){M=33071;break}else{M=0;break}}}while(0);c[j+2040>>2]=M;t=(a[b+16|0]&1)!=0;H=t?32993:6407;y=j+2028|0;c[y>>2]=H;r=j+2032|0;c[r>>2]=H;c[j+2036>>2]=t?5121:33635;c[j+2044>>2]=t?4:2;if(!((a[1402804]&1)==0|t^1)){c[y>>2]=6408;c[r>>2]=6408}dk(2929);dk(2884);dk(3024);r=j+1840|0;yJ(r|0,1808,32)|0;c[j+2e3>>2]=c[w>>2];c[j+2008>>2]=r;c[j+2004>>2]=c[D>>2];c[j+2012>>2]=1808;r=ab(c[m>>2]|0,c[B>>2]|0)|0;c[j+472>>2]=yy(4,r)|0;y=yy(4,r)|0;c[j+476>>2]=y;if((y|0)==0){fQ[c[(c[n>>2]|0)+4>>2]&1023]();yz(j);l=0;i=f;return l|0}ls(j,b);do{if((c[E>>2]|0)!=0){y=j+1768|0;r=j+1800|0;t=0;do{c[y+(t<<2)>>2]=c[B>>2];c[r+(t<<2)>>2]=c[m>>2];t=t+1|0;N=c[E>>2]|0;}while(t>>>0<N>>>0);if((N|0)==0){break}t=j+12|0;r=j+52|0;y=0;do{c[r+(y*52|0)>>2]=c[t>>2];g[r+(y*52|0)+4>>2]=+((c[B>>2]|0)>>>0>>>0);g[r+(y*52|0)+12>>2]=+((c[B>>2]|0)>>>0>>>0);g[r+(y*52|0)+8>>2]=+((c[m>>2]|0)>>>0>>>0);g[r+(y*52|0)+16>>2]=+((c[m>>2]|0)>>>0>>>0);H=r+(y*52|0)+20|0;yJ(H|0,1808,32)|0;y=y+1|0;}while(y>>>0<(c[E>>2]|0)>>>0)}}while(0);kY(j,c[B>>2]|0,c[m>>2]|0);do{if((a[F]&1)!=0){if(lt(k,c[B>>2]|0,c[m>>2]|0)|0){break}fQ[c[(c[n>>2]|0)+4>>2]&1023]();yz(j);l=0;i=f;return l|0}}while(0);if(!((d|0)==0|(e|0)==0)){ft[c[(c[n>>2]|0)+48>>2]&127](d,e)}if((a[1157084]&1)!=0){c[j+2052>>2]=lx(j,1152981,+g[289270])|0}switch(dN()|0){case 0:{l=j;i=f;return l|0};case 1282:{m=c[350134]|0;a5(70824,44,1,((m|0)!=0?m:c[p>>2]|0)|0)|0;m=c[350134]|0;a_(((m|0)!=0?m:c[p>>2]|0)|0)|0;break};case 1285:{m=c[350134]|0;a5(69248,40,1,((m|0)!=0?m:c[p>>2]|0)|0)|0;m=c[350134]|0;a_(((m|0)!=0?m:c[p>>2]|0)|0)|0;break};case 1280:{m=c[350134]|0;a5(72920,39,1,((m|0)!=0?m:c[p>>2]|0)|0)|0;m=c[350134]|0;a_(((m|0)!=0?m:c[p>>2]|0)|0)|0;break};case 1281:{m=c[350134]|0;a5(72048,40,1,((m|0)!=0?m:c[p>>2]|0)|0)|0;m=c[350134]|0;a_(((m|0)!=0?m:c[p>>2]|0)|0)|0;break};default:{m=c[350134]|0;a5(67976,45,1,((m|0)!=0?m:c[p>>2]|0)|0)|0;m=c[350134]|0;a_(((m|0)!=0?m:c[p>>2]|0)|0)|0}}fQ[c[(c[n>>2]|0)+4>>2]&1023]();yz(j);l=0;i=f;return l|0}}while(0);yz(j);l=0;i=f;return l|0}function k1(b,d,e,f,h,j){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0,Y=0.0,Z=0,_=0.0,$=0.0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;k=i;i=i+992|0;l=k|0;m=k+64|0;n=k+96|0;o=k+928|0;q=k+936|0;r=b+4|0;s=c[r>>2]|0;if((s|0)!=0){fs[c[s+12>>2]&255](1)}s=b+1640|0;if((a[s]&1)!=0){kZ(b,e,f,c[b+1760>>2]|0,c[b+1764>>2]|0);aZ(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);b5(36160,c[b+612>>2]|0);t=c[b+740>>2]|0;u=c[b+744>>2]|0;v=c[(c[b>>2]|0)+24>>2]|0;if((v|0)!=0){+fE[v&3](t,u)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=t;c[b+1748>>2]=u;eS(0,0,t|0,u|0);u=b+1936|0;lv(u,0.0,1.0,0.0,1.0,-1.0,1.0);t=b+1872|0;yJ(t|0,u|0,64)|0;c[b+2e3>>2]=328}u=b+1711|0;do{if((a[u]&1)!=0){a[u]=0;t=b;v=b+1728|0;w=b+1732|0;ft[c[(c[t>>2]|0)+36>>2]&127](c[v>>2]|0,c[w>>2]|0);if((a[s]&1)==0){k$(b,c[v>>2]|0,c[w>>2]|0,0,1);break}w=b+1636|0;if((c[w>>2]|0)>0){v=b+740|0;x=v;y=b+612|0;z=y;A=b+676|0;B=0;while(1){C=c[x+(B*24|0)+8>>2]|0;D=x+(B*24|0)+16|0;E=c[x+(B*24|0)+12>>2]|0;F=x+(B*24|0)+20|0;if(C>>>0>(c[D>>2]|0)>>>0){G=5488}else{if(E>>>0>(c[F>>2]|0)>>>0){G=5488}}do{if((G|0)==5488){G=0;H=(C>>>0>E>>>0?C:E)-1|0;I=H>>>1|H;H=I>>>2|I;I=H>>>4|H;H=I>>>8|I;I=(H>>>16|H)+1|0;c[F>>2]=I;c[D>>2]=I;b5(36160,c[z+(B<<2)>>2]|0);I=A+(B<<2)|0;aZ(3553,c[I>>2]|0);ed(3553,0,32993,c[D>>2]|0,c[F>>2]|0,0,32993,5121,0);dB(36160,36064,3553,c[I>>2]|0,0);if((cs(36160)|0)!=36053){I=c[350134]|0;H=(I|0)!=0?I:c[p>>2]|0;a5(86952,50,1,H|0)|0;H=c[350134]|0;I=(H|0)!=0?H:c[p>>2]|0;a_(I|0)|0}if((a[1243488]&1)==0){break}I=c[350134]|0;H=(I|0)!=0?I:c[p>>2]|0;I=c[D>>2]|0;J=c[F>>2]|0;en(H|0,85040,(H=i,i=i+24|0,c[H>>2]=B,c[H+8>>2]=I,c[H+16>>2]=J,H)|0)|0;i=H;H=c[350134]|0;J=(H|0)!=0?H:c[p>>2]|0;a_(J|0)|0}}while(0);F=B+1|0;if((F|0)<(c[w>>2]|0)){B=F}else{K=y;L=v;break}}}else{K=b+612|0;L=b+740|0}aZ(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);b5(36160,c[K>>2]|0);v=c[L>>2]|0;y=c[b+744>>2]|0;B=c[(c[t>>2]|0)+24>>2]|0;if((B|0)!=0){+fE[B&3](v,y)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=v;c[b+1748>>2]=y;eS(0,0,v|0,y|0);y=b+1936|0;lv(y,0.0,1.0,0.0,1.0,-1.0,1.0);v=b+1872|0;yJ(v|0,y|0,64)|0;c[b+2e3>>2]=328}}while(0);L=b+44|0;K=c[L>>2]|0;L7302:do{if((d|0)==0){aZ(3553,c[b+12+(K<<2)>>2]|0);M=b+1708|0}else{u=b+48|0;y=((K+1|0)>>>0)%((c[u>>2]|0)>>>0)|0;c[L>>2]=y;aZ(3553,c[b+12+(y<<2)>>2]|0);y=b+1708|0;if((a[y]&1)!=0){M=y;break}v=c[L>>2]|0;B=b+1768|0;w=B+(v<<2)|0;if((c[w>>2]|0)==(e|0)){if((c[b+1800+(v<<2)>>2]|0)==(f|0)){G=5502}else{G=5500}}else{G=5500}do{if((G|0)==5500){A=b+472|0;if((c[A>>2]|0)==0){G=5502;break}c[w>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;fl(3317,(e<<2&4^4)+4|0);z=b+1832|0;x=b+1836|0;ef(3553,0,0,0,c[z>>2]|0,c[x>>2]|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[A>>2]|0);N=+(e>>>0>>>0)/+((c[z>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[x>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==5502){w=c[u>>2]|0;t=((v-1+w|0)>>>0)%(w>>>0)|0;if((c[B+(t<<2)>>2]|0)==(e|0)){if((c[b+1800+(t<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[b+2472|0]&1)!=0){c[o>>2]=0;B=fp[c[(c[b>>2]|0)+60>>2]&3](d,e,f,h,(c[b+2044>>2]|0)==4,c[L>>2]|0,o)|0;v=c[o>>2]|0;if((v|0)==0){u=c[350134]|0;t=(u|0)!=0?u:c[p>>2]|0;a5(88704,55,1,t|0)|0;t=c[350134]|0;u=(t|0)!=0?t:c[p>>2]|0;a_(u|0)|0;M=y;break}if(!B){M=y;break}ft[c[664998]&127](3553,v);M=y;break}v=b+2044|0;B=ab(c[v>>2]|0,e)|0;do{if((B&1|0)==0){if((B&2|0)!=0){P=2;break}P=(B&4^4)+4|0}else{P=1}}while(0);fl(3317,P|0);B=c[v>>2]|0;do{if((B|0)==4){if((a[1402804]&1)==0){break}u=b+476|0;t=c[u>>2]|0;w=b+480|0;x=w;z=w;w=b+484|0;if((c[z>>2]|0)==(e|0)){if((c[w>>2]|0)!=(f|0)){G=5517}}else{G=5517}if((G|0)==5517){c[z>>2]=e;c[w>>2]=f;c[b+492>>2]=e;c[b+496>>2]=f;c[b+504>>2]=0;c[b+508>>2]=1;c[b+512>>2]=1;jL(x)|0}c[b+488>>2]=h;c[b+500>>2]=e<<2;jN(x,t,d);ef(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y;break L7302}}while(0);if(((h>>>0)/(B>>>0)|0|0)==(e|0)){ef(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,d|0);M=y;break}v=ab(B,e)|0;u=b+476|0;if((f|0)!=0){t=c[u>>2]|0;x=d;w=0;while(1){yJ(t|0,x|0,v)|0;z=w+1|0;if(z>>>0<f>>>0){t=t+v|0;x=x+h|0;w=z}else{break}}}ef(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y}}while(0);if((a[M]&1)!=0){h=c[L>>2]|0;d=b+1768|0;P=d+(h<<2)|0;if((c[P>>2]|0)==(e|0)){if((c[b+1800+(h<<2)>>2]|0)==(f|0)){G=5531}else{G=5529}}else{G=5529}do{if((G|0)==5529){if((c[b+472>>2]|0)==0){G=5531;break}c[P>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;N=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==5531){P=c[b+48>>2]|0;o=((h-1+P|0)>>>0)%(P>>>0)|0;if((c[d+(o<<2)>>2]|0)==(e|0)){if((c[b+1800+(o<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[s]&1)==0){b5(36160,0);k$(b,c[b+1728>>2]|0,c[b+1732>>2]|0,0,1)}dk(2929);dk(2960);dk(2884);dk(3024);dk(3042);eM(770,771);aO(0.0,0.0,0.0,1.0)}d=q;yG(d|0,0,52);c[q>>2]=c[b+12+(c[L>>2]<<2)>>2];g[q+4>>2]=+(e>>>0>>>0);g[q+8>>2]=+(f>>>0>>>0);L=b+1832|0;g[q+12>>2]=+((c[L>>2]|0)>>>0>>>0);h=b+1836|0;g[q+16>>2]=+((c[h>>2]|0)>>>0>>>0);G=q+20|0;o=b+1840|0;yJ(G|0,o|0,32)|0;dp(16384);if((a[1140658]&1)!=0){fQ[c[(c[b>>2]|0)+44>>2]&1023]();dp(16384)}G=c[r>>2]|0;do{if((G|0)==0){P=b+2e3|0;K=b+1872|0;Q=P;R=P;S=K;T=K}else{fw[c[G+8>>2]&3](e,f,c[L>>2]|0,c[h>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[350074]|0,q,b+52|0,0,0);K=c[r>>2]|0;P=b+2e3|0;w=P;x=b+1872|0;v=x;if((K|0)==0){Q=P;R=w;S=x;T=v;break}t=c[K+32>>2]|0;fv[t&127](w)|0;t=c[r>>2]|0;if((t|0)==0){Q=P;R=w;S=x;T=v;break}K=c[t+36>>2]|0;fv[K&127](v)|0;Q=P;R=w;S=x;T=v}}while(0);de(5,0,4);if((a[s]&1)!=0){s=m;yG(s|0,0,32);h=b+2008|0;c[h>>2]=m;L=b+1636|0;f=c[L>>2]|0;e=b+740|0;G=m+8|0;v=m+24|0;x=m+20|0;w=m+28|0;if((f|0)>1){m=b+676|0;P=b+612|0;K=b;t=b+1740|0;B=b+1736|0;z=b+1744|0;A=b+1748|0;F=b+1936|0;D=F;E=b+52|0;C=n|0;J=1;H=0;while(1){I=J-1|0;U=e+(I*24|0)|0;N=+((c[U>>2]|0)>>>0>>>0);V=e+(I*24|0)+16|0;O=+((c[V>>2]|0)>>>0>>>0);W=N/O;X=e+(I*24|0)+4|0;Y=+((c[X>>2]|0)>>>0>>>0);Z=e+(I*24|0)+20|0;_=+((c[Z>>2]|0)>>>0>>>0);$=Y/_;g[G>>2]=W;g[v>>2]=W;g[x>>2]=$;g[w>>2]=$;aa=m+(I<<2)|0;c[n+(I*52|0)>>2]=c[aa>>2];g[n+(I*52|0)+4>>2]=N;g[n+(I*52|0)+8>>2]=Y;g[n+(I*52|0)+12>>2]=O;g[n+(I*52|0)+16>>2]=_;ac=n+(I*52|0)+20|0;yJ(ac|0,s|0,32)|0;b5(36160,c[P+(J<<2)>>2]|0);ac=c[r>>2]|0;if((ac|0)!=0){fs[c[ac+12>>2]&255](J+1|0)}aZ(3553,c[aa>>2]|0);dp(16384);aa=c[e+(J*24|0)>>2]|0;ac=c[e+(J*24|0)+4>>2]|0;I=c[(c[K>>2]|0)+24>>2]|0;if((I|0)!=0){+fE[I&3](aa,ac)}c[t>>2]=0;c[B>>2]=0;c[z>>2]=aa;c[A>>2]=ac;eS(0,0,aa|0,ac|0);lv(D,0.0,1.0,0.0,1.0,-1.0,1.0);yJ(S|0,F|0,64)|0;ac=c[r>>2]|0;do{if((ac|0)!=0){fw[c[ac+8>>2]&3](c[U>>2]|0,c[X>>2]|0,c[V>>2]|0,c[Z>>2]|0,c[z>>2]|0,c[A>>2]|0,c[350074]|0,q,E,C,H);aa=c[r>>2]|0;if((aa|0)==0){break}I=c[aa+32>>2]|0;fv[I&127](R)|0;I=c[r>>2]|0;if((I|0)==0){break}aa=c[I+36>>2]|0;fv[aa&127](T)|0}}while(0);de(5,0,4);Z=H+1|0;V=J+1|0;X=c[L>>2]|0;if((V|0)<(X|0)){J=V;H=Z}else{ad=Z;ae=X;break}}}else{ad=0;ae=f}f=ae-1|0;ae=e+(f*24|0)|0;H=e+(f*24|0)+16|0;_=+((c[ae>>2]|0)>>>0>>>0)/+((c[H>>2]|0)>>>0>>>0);J=e+(f*24|0)+4|0;C=e+(f*24|0)+20|0;O=+((c[J>>2]|0)>>>0>>>0)/+((c[C>>2]|0)>>>0>>>0);g[G>>2]=_;g[v>>2]=_;g[x>>2]=O;g[w>>2]=O;b5(36160,0);w=c[r>>2]|0;if((w|0)!=0){fs[c[w+12>>2]&255]((c[L>>2]|0)+1|0)}aZ(3553,c[b+676+((c[L>>2]|0)-1<<2)>>2]|0);dp(16384);k$(b,c[b+1728>>2]|0,c[b+1732>>2]|0,0,1);L=c[r>>2]|0;do{if((L|0)==0){c[Q>>2]=c[b+2016>>2]}else{fw[c[L+8>>2]&3](c[ae>>2]|0,c[J>>2]|0,c[H>>2]|0,c[C>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[350074]|0,q,b+52|0,n|0,ad);w=c[r>>2]|0;c[Q>>2]=c[b+2016>>2];if((w|0)==0){break}x=c[w+32>>2]|0;fv[x&127](R)|0;x=c[r>>2]|0;if((x|0)==0){break}w=c[x+36>>2]|0;fv[w&127](T)|0}}while(0);de(5,0,4);c[h>>2]=o}h=b+52|0;yN(b+104|0,h|0,((c[b+48>>2]|0)*52|0)-52|0);yJ(h|0,d|0,52)|0;do{if((a[b+2576|0]&1)!=0){d=c[b+2572>>2]|0;if((d|0)==0){break}h=l|0;g[h>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2580>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;T=Q;c[T>>2]=296;ad=b+2008|0;c[ad>>2]=1808;n=b+2004|0;c[n>>2]=h;aZ(3553,d|0);d=c[r>>2]|0;do{if((d|0)!=0){fs[c[d+12>>2]&255](15);h=c[r>>2]|0;q=b+1936|0;if((h|0)==0){break}C=c[h+32>>2]|0;fv[C&127](R)|0;C=c[r>>2]|0;if((C|0)==0){break}h=c[C+36>>2]|0;fv[h&127](q)|0}}while(0);ex(3042);if((a[b+2577|0]&1)==0){de(5,0,4)}else{eS(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);de(5,0,4);eS(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}dk(3042);c[T>>2]=c[b+2016>>2];c[ad>>2]=o;c[n>>2]=c[b+2020>>2]}}while(0);do{if((j|0)!=0){d=c[b+2052>>2]|0;if((d|0)==0){break}fP[c[d+8>>2]&127](b,j,0)}}while(0);if((a[b+2496|0]&1)!=0){aZ(3553,c[b+2500>>2]|0);j=l|0;g[j>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2568>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;l=c[r>>2]|0;if((l|0)!=0){fs[c[l+12>>2]&255](15)}ex(3042);l=Q;c[l>>2]=b+2536;Q=b+2008|0;c[Q>>2]=b+2504;d=b+2004|0;c[d>>2]=j;j=b+1936|0;q=c[r>>2]|0;do{if((q|0)!=0){h=c[q+32>>2]|0;fv[h&127](R)|0;h=c[r>>2]|0;if((h|0)==0){break}C=c[h+36>>2]|0;fv[C&127](j)|0}}while(0);if((a[b+2497|0]&1)==0){de(5,0,4)}else{eS(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);de(5,0,4);eS(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}dk(3042);c[l>>2]=c[b+2016>>2];c[Q>>2]=o;c[d>>2]=c[b+2020>>2]}d=b;fQ[c[(c[d>>2]|0)+28>>2]&1023]();if((a[M]&1)==0){af=c[d>>2]|0;ag=af+44|0;ah=c[ag>>2]|0;fQ[ah&1023]();ai=c[350074]|0;aj=ai+1|0;c[350074]=aj;i=k;return 1}M=c[r>>2]|0;if((M|0)!=0){fs[c[M+12>>2]&255](0)}aZ(3553,0);af=c[d>>2]|0;ag=af+44|0;ah=c[ag>>2]|0;fQ[ah&1023]();ai=c[350074]|0;aj=ai+1|0;c[350074]=aj;i=k;return 1}function k2(a,b){a=a|0;b=b|0;c[b>>2]=19048;return}function k3(a,b){a=a|0;b=b|0;c[b>>2]=19008;return}function k4(a){a=a|0;return c[a+1644+(((((c[a+44>>2]|0)+1|0)>>>0)%((c[a+48>>2]|0)>>>0)|0)<<2)>>2]|0}function k5(b){b=b|0;a[b+1711|0]=1;return}function k6(b,c,d){b=b|0;c=c|0;d=d|0;a[b+2576|0]=c&1;a[b+2577|0]=d&1;return}function k7(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;if((a[1243488]&1)!=0){f=c[350134]|0;g=(f|0)!=0?f:c[p>>2]|0;f=d?92256:90584;en(g|0,93888,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;g=c[350134]|0;f=(g|0)!=0?g:c[p>>2]|0;a_(f|0)|0}fs[c[(c[b>>2]|0)+12>>2]&255](d?0:c[285165]|0);i=e;return}function k8(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;f=d+8|0;fr[c[(c[b>>2]|0)+32>>2]&15](e,f,b+1728|0,b+1732|0,c[350074]|0);do{if((a[e]&1)==0){if((a[f]&1)==0){break}a[b+1711|0]=1}else{a[b+1712|0]=1}}while(0);i=d;return(a[b+1712|0]&1)==0|0}function k9(a){a=a|0;return fN[c[(c[a>>2]|0)+40>>2]&63]()|0}function la(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+8|0;h=f|0;j=b;if((d|0)==3){k=0;i=f;return k|0}l=b+4|0;m=c[l>>2]|0;if((m|0)!=0){fQ[c[m+4>>2]&1023]()}m=(d|0)==2;c[l>>2]=m?19072:0;if(!m){m=c[350134]|0;d=(m|0)!=0?m:c[p>>2]|0;en(d|0,70048,(n=i,i=i+8|0,c[n>>2]=e,n)|0)|0;i=n;d=c[350134]|0;m=(d|0)!=0?d:c[p>>2]|0;a_(m|0)|0;k=0;i=f;return k|0}m=b+1640|0;if((a[m]&1)!=0){d=b+1636|0;bh(c[d>>2]|0,b+676|0);o=b+612|0;cc(c[d>>2]|0,o|0);a[m]=0;c[d>>2]=0;yG(o|0,0,128)}o=b+44|0;d=b+12|0;aZ(3553,c[d+(c[o>>2]<<2)>>2]|0);if(!(fv[c[c[l>>2]>>2]&127](e)|0)){e=c[350134]|0;m=(e|0)!=0?e:c[p>>2]|0;a5(60448,81,1,m|0)|0;m=c[350134]|0;e=(m|0)!=0?m:c[p>>2]|0;a_(e|0)|0;if(fv[c[c[l>>2]>>2]&127](0)|0){k=0;i=f;return k|0}c[l>>2]=0;k=0;i=f;return k|0}a[h]=0;e=c[l>>2]|0;if((e|0)==0){q=5620}else{if(!(fL[c[e+20>>2]&63](1,h)|0)){q=5620}}if((q|0)==5620){a[h]=a[1140668]&1}e=c[l>>2]|0;do{if((e|0)==0){r=33071}else{m=fv[c[e+24>>2]&127](1)|0;if((m|0)==2){r=10497;break}else if((m|0)==3){r=33648;break}else if((m|0)==0|(m|0)==1){r=33071;break}else{r=0;break}}}while(0);e=a[h]&1;a[b+2487|0]=e;h=e<<24>>24!=0?9729:9728;e=b+468|0;m=b+2040|0;if((h|0)==(c[e>>2]|0)){if((r|0)!=(c[m>>2]|0)){q=5628}}else{q=5628}if((q|0)==5628){c[e>>2]=h;c[m>>2]=r;r=b+48|0;h=c[r>>2]|0;if((h|0)!=0){q=0;s=h;while(1){h=c[j+12+(q<<2)>>2]|0;if((h|0)==0){t=s}else{aZ(3553,h|0);fa(3553,10242,c[m>>2]|0);fa(3553,10243,c[m>>2]|0);fa(3553,10240,c[e>>2]|0);fa(3553,10241,c[e>>2]|0);t=c[r>>2]|0}h=q+1|0;if(h>>>0<t>>>0){q=h;s=t}else{break}}}aZ(3553,c[j+12+(c[o>>2]<<2)>>2]|0)}t=c[l>>2]|0;do{if((t|0)!=0){s=(fN[c[t+40>>2]&63]()|0)+1|0;q=b+48|0;r=c[q>>2]|0;if(s>>>0<=r>>>0){break}e=b+1708|0;if((a[e]&1)!=0){cc(r|0,b+1644|0)}if((a[b+1709|0]&1)!=0){bP(c[q>>2]|0,b+1676|0)}a[e]=0;e=d;bh(c[q>>2]|0,e|0);c[q>>2]=s;if((a[1243488]&1)!=0){r=c[350134]|0;m=(r|0)!=0?r:c[p>>2]|0;en(m|0,54624,(n=i,i=i+8|0,c[n>>2]=s,n)|0)|0;i=n;s=c[350134]|0;m=(s|0)!=0?s:c[p>>2]|0;a_(m|0)|0}c[o>>2]=0;ls(b,b+2476|0);do{if((c[q>>2]|0)!=0){m=b+1832|0;s=b+1768|0;r=b+1836|0;h=b+1800|0;u=0;do{c[s+(u<<2)>>2]=c[m>>2];c[h+(u<<2)>>2]=c[r>>2];u=u+1|0;v=c[q>>2]|0;}while(u>>>0<v>>>0);if((v|0)==0){break}u=b+52|0;h=0;do{c[u+(h*52|0)>>2]=c[e>>2];g[u+(h*52|0)+4>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+12>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+8>>2]=+((c[r>>2]|0)>>>0>>>0);g[u+(h*52|0)+16>>2]=+((c[r>>2]|0)>>>0>>>0);s=u+(h*52|0)+20|0;yJ(s|0,1808,32)|0;h=h+1|0;}while(h>>>0<(c[q>>2]|0)>>>0)}}while(0);if((a[b+1710|0]&1)==0){break}q=c[b+1832>>2]|0;e=c[b+1836>>2]|0;lt(j,q,e)|0}}while(0);kY(b,c[b+1832>>2]|0,c[b+1836>>2]|0);j=c[l>>2]|0;if((j|0)!=0){fs[c[j+12>>2]&255](0)}j=b+1728|0;v=b+1732|0;k$(b,c[j>>2]|0,c[v>>2]|0,0,1);o=c[l>>2]|0;if((o|0)!=0){fs[c[o+12>>2]&255](1)}k$(b,c[j>>2]|0,c[v>>2]|0,0,1);k=1;i=f;return k|0}function lb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[b+2052>>2]|0;if((d|0)!=0){fs[c[d+4>>2]&255](b)}d=b+4|0;e=c[d>>2]|0;if((e|0)!=0){fQ[c[e+4>>2]&1023]()}c[d>>2]=0;d=b+48|0;bh(c[d>>2]|0,b+12|0);e=b+2572|0;if((c[e>>2]|0)!=0){bh(1,e|0)}e=b+2500|0;if((c[e>>2]|0)!=0){bh(1,e|0)}jM(b+480|0);e=b+1640|0;if((a[e]&1)!=0){f=b+1636|0;bh(c[f>>2]|0,b+676|0);g=b+612|0;cc(c[f>>2]|0,g|0);a[e]=0;c[f>>2]=0;yG(g|0,0,128)}g=b+1708|0;if((a[g]&1)!=0){cc(c[d>>2]|0,b+1644|0)}if((a[b+1709|0]&1)==0){a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;fQ[k&1023]();l=b+472|0;m=l;n=c[m>>2]|0;yz(n);o=b+476|0;p=o;q=c[p>>2]|0;yz(q);yz(b);return}bP(c[d>>2]|0,b+1676|0);a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;fQ[k&1023]();l=b+472|0;m=l;n=c[m>>2]|0;yz(n);o=b+476|0;p=o;q=c[p>>2]|0;yz(q);yz(b);return}function lc(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=d;c[e>>2]=c[4742];c[e+4>>2]=c[4743];c[e+8>>2]=c[4744];c[e+12>>2]=c[4745];c[e+16>>2]=c[4746];a[d+9|0]=a[1140656]&1;a[d+10|0]=0;a[d+11|0]=a[1140668]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[285170]|0)==7){c[d>>2]=c[350121];c[d+4>>2]=c[350122]}e=k0(d,0,0)|0;c[350660]=e;c[350708]=19008;c[e+2052>>2]=lx(e,1152981,+g[289270])|0;i=b;return}function ld(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=c[350660]|0;if((e|0)==0){i=b;return}c[350660]=0;lb(e);e=d;c[e>>2]=c[4742];c[e+4>>2]=c[4743];c[e+8>>2]=c[4744];c[e+12>>2]=c[4745];c[e+16>>2]=c[4746];a[d+9|0]=a[1140656]&1;a[d+10|0]=0;a[d+11|0]=a[1140668]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[285170]|0)==7){c[d>>2]=c[350121];c[d+4>>2]=c[350122]}e=k0(d,0,0)|0;c[350660]=e;c[350708]=19008;c[e+2052>>2]=lx(e,1152981,+g[289270])|0;i=b;return}function le(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+64|0;e=d|0;f=a+1716|0;c[f>>2]=b*90|0;b=a+1936|0;lv(b,0.0,1.0,0.0,1.0,-1.0,1.0);lu(e,+((c[f>>2]|0)>>>0>>>0)*3.141592653589793/180.0);lw(a+1872|0,e,b);i=d;return}function lf(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+1736|0;e=b;c[e>>2]=c[d>>2];c[e+4>>2]=c[d+4>>2];c[e+8>>2]=c[d+8>>2];c[e+12>>2]=c[d+12>>2];c[e+16>>2]=c[d+16>>2];c[e+20>>2]=c[d+20>>2];c[b+16>>2]=c[a+1728>>2];d=a+1732|0;c[b+20>>2]=c[d>>2];a=b+4|0;c[a>>2]=(c[d>>2]|0)-((c[b+12>>2]|0)+(c[a>>2]|0));return}function lg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((a[b+1708|0]&1)==0){if((a[b+1640|0]&1)!=0){e=5691}}else{e=5691}if((e|0)==5691){b5(36160,0)}e=b+1736|0;f=b+1744|0;g=(c[f>>2]|0)*3|0;do{if((g&1|0)==0){if((g&2|0)!=0){h=2;break}h=(g&4^4)+4|0}else{h=1}}while(0);fl(3333,h|0);h=b+1748|0;dW(c[e>>2]|0,c[b+1740>>2]|0,c[f>>2]|0,c[h>>2]|0,6407,5121,d|0);b=ab(c[h>>2]|0,c[f>>2]|0)|0;f=0;h=d;while(1){d=h+2|0;e=a[d]|0;a[d]=a[h]|0;a[h]=e;e=f+1|0;if(e>>>0>b>>>0){break}else{f=e;h=h+3|0}}return 1}function lh(a,b){a=a|0;b=b|0;return fv[c[(c[a>>2]|0)+52>>2]&127](b)|0}function li(b,d){b=b|0;d=d|0;if((d|0)==6){iB()}else if((d|0)==4){iC()}else if((d|0)==5){iK(c[334448]|0,c[334449]|0)}g[334458]=+g[27176+(d*68|0)>>2];a[b+1714|0]=1;a[b+1711|0]=1;return}function lj(b,d,e,f,h,i){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=+i;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=b+2572|0;k=c[j>>2]|0;if((k|0)==0){bz(1,j|0);aZ(3553,c[j>>2]|0);fa(3553,10242,33071);fa(3553,10243,33071);fa(3553,10240,9729);fa(3553,10241,9729)}else{aZ(3553,k|0)}g[b+2580>>2]=i;k=ab(e?4:2,f)|0;if((k&2|0)==0){l=(k&4^4)+4|0}else{l=2}fl(3317,l|0);if(e){e=(a[1402804]&1)!=0?6408:32993;ed(3553,0,e|0,f|0,h|0,0,e|0,5121,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;aZ(3553,s|0);return}else{ed(3553,0,6408,f|0,h|0,0,6408,32819,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;aZ(3553,s|0);return}}function lk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+2052>>2]|0;if((e|0)==0){return}fP[c[e+8>>2]&127](a,b,d);return}function ll(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;g[a+2504>>2]=b;g[a+2508>>2]=c;f=b+d;g[a+2512>>2]=f;g[a+2516>>2]=c;g[a+2520>>2]=b;b=c+e;g[a+2524>>2]=b;g[a+2528>>2]=f;g[a+2532>>2]=b;return}function lm(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;f=1.0-c;g[a+2536>>2]=b;g[a+2540>>2]=f;c=b+d;g[a+2544>>2]=c;g[a+2548>>2]=f;g[a+2552>>2]=b;b=f-e;g[a+2556>>2]=b;g[a+2560>>2]=c;g[a+2564>>2]=b;return}function ln(b,c){b=b|0;c=c|0;a[b+2497|0]=c&1;return}function lo(a,b){a=a|0;b=+b;g[a+2568>>2]=b;return}function lp(a,b){a=a|0;b=b|0;var d=0;d=c[(c[a>>2]|0)+64>>2]|0;if((d|0)==0){return}fs[d&255](b);return}function lq(b,d){b=b|0;d=d|0;var e=0;a[b+2496|0]=d&1;e=c[(c[b>>2]|0)+64>>2]|0;if((e|0)==0){return}if((a[b+1713|0]&1)==0){return}fs[e&255](d);return}function lr(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0;h=b+2500|0;i=c[h>>2]|0;if((i|0)==0){bz(1,h|0);j=c[h>>2]|0}else{j=i}aZ(3553,j|0);fa(3553,10242,33071);fa(3553,10243,33071);fa(3553,10240,9729);fa(3553,10241,9729);fl(3317,(e<<2&4^4)+4|0);j=(a[1402804]&1)!=0?6408:32993;ed(3553,0,j|0,e|0,f|0,0,j|0,5121,d|0);g[b+2504>>2]=0.0;g[b+2508>>2]=0.0;g[b+2512>>2]=1.0;g[b+2516>>2]=0.0;g[b+2520>>2]=0.0;g[b+2524>>2]=1.0;g[b+2528>>2]=1.0;g[b+2532>>2]=1.0;g[b+2536>>2]=0.0;g[b+2540>>2]=1.0;g[b+2544>>2]=1.0;g[b+2548>>2]=1.0;g[b+2552>>2]=0.0;g[b+2556>>2]=0.0;g[b+2560>>2]=1.0;g[b+2564>>2]=0.0;return 1}function ls(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;f=b+1710|0;g=a[f]|0;if((g&1)==0&(c[664998]|0)!=0){h=(fv[c[(c[b>>2]|0)+56>>2]&127](d)|0)&1;j=h;k=a[f]|0}else{j=0;k=g}g=b+2472|0;a[g]=j;j=c[b+2028>>2]|0;f=c[b+2032>>2]|0;h=c[b+2036>>2]|0;do{if((k&1)==0){l=j;m=h;n=f}else{if((c[b+2044>>2]|0)!=4){l=j;m=h;n=f;break}d=b+2584|0;do{if((a[d]&1)==0){o=a3(7939)|0;if((o|0)==0){q=0;break}q=(bw(o|0,99784)|0)!=0}else{q=0}}while(0);if((a[1243488]&1)!=0){o=c[350134]|0;r=(o|0)!=0?o:c[p>>2]|0;o=q?105328:102048;en(r|0,108560,(s=i,i=i+16|0,c[s>>2]=99784,c[s+8>>2]=o,s)|0)|0;i=s;o=c[350134]|0;r=(o|0)!=0?o:c[p>>2]|0;a_(r|0)|0}if(q){l=6408;m=5121;n=6408;break}do{if((a[d]&1)==0){r=a3(7939)|0;if((r|0)==0){t=0;break}t=(bw(r|0,98208)|0)!=0}else{t=0}}while(0);if((a[1243488]&1)!=0){d=c[350134]|0;r=(d|0)!=0?d:c[p>>2]|0;d=t?105328:102048;en(r|0,108560,(s=i,i=i+16|0,c[s>>2]=98208,c[s+8>>2]=d,s)|0)|0;i=s;d=c[350134]|0;r=(d|0)!=0?d:c[p>>2]|0;a_(r|0)|0}if(t){l=6408;m=5121;n=6408;break}r=c[350134]|0;d=(r|0)!=0?r:c[p>>2]|0;a5(95968,76,1,d|0)|0;d=c[350134]|0;r=(d|0)!=0?d:c[p>>2]|0;a_(r|0)|0;l=6407;m=33635;n=6407}}while(0);t=b+48|0;s=b+12|0;q=s;bz(c[t>>2]|0,s|0);if((c[t>>2]|0)==0){u=b+44|0;v=u;w=c[v>>2]|0;x=q+(w<<2)|0;y=c[x>>2]|0;aZ(3553,y|0);i=e;return}s=b+2040|0;f=b+468|0;h=b+1832|0;j=b+1836|0;k=b+472|0;r=0;do{aZ(3553,c[q+(r<<2)>>2]|0);fa(3553,10242,c[s>>2]|0);fa(3553,10243,c[s>>2]|0);fa(3553,10240,c[f>>2]|0);fa(3553,10241,c[f>>2]|0);if((a[g]&1)==0){ed(3553,0,l|0,c[h>>2]|0,c[j>>2]|0,0,n|0,m|0,c[k>>2]|0)}r=r+1|0;}while(r>>>0<(c[t>>2]|0)>>>0);u=b+44|0;v=u;w=c[v>>2]|0;x=q+(w<<2)|0;y=c[x>>2]|0;aZ(3553,y|0);i=e;return}function lt(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=i;i=i+16|0;g=f|0;h=f+8|0;if((a[1243488]&1)!=0){j=c[350134]|0;k=(j|0)!=0?j:c[p>>2]|0;en(k|0,50312,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;k=c[350134]|0;j=(k|0)!=0?k:c[p>>2]|0;a_(j|0)|0}c[g>>2]=0;c[h>>2]=0;d1(3379,g|0);d1(34024,h|0);if((a[1243488]&1)!=0){j=c[350134]|0;k=(j|0)!=0?j:c[p>>2]|0;j=c[g>>2]|0;g=c[h>>2]|0;en(k|0,46432,(l=i,i=i+16|0,c[l>>2]=j,c[l+8>>2]=g,l)|0)|0;i=l;g=c[350134]|0;j=(g|0)!=0?g:c[p>>2]|0;a_(j|0)|0}aZ(3553,0);j=b+48|0;dX(c[j>>2]|0,b+1644|0);g=(a[1342516]&1)==0;k=(a[1342517]&1)!=0;do{if(k){do{if((a[b+2584|0]&1)==0){h=a3(7939)|0;if((h|0)==0){m=0;break}m=(bw(h|0,42240)|0)!=0}else{m=0}}while(0);if((a[1243488]&1)!=0){h=c[350134]|0;n=(h|0)!=0?h:c[p>>2]|0;h=m?105328:102048;en(n|0,108560,(l=i,i=i+16|0,c[l>>2]=42240,c[l+8>>2]=h,l)|0)|0;i=l;h=c[350134]|0;n=(h|0)!=0?h:c[p>>2]|0;a_(n|0)|0}if(m){break}else{o=0}i=f;return o|0}}while(0);L7676:do{if(g){if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=5787;break L7676}b5(36160,c[b+1644+(m<<2)>>2]|0);dB(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=cs(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=5786;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=5787;break L7676}b5(36160,c[b+1644+(m<<2)>>2]|0);dB(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=cs(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=5786;break}}}}else{c0(c[j>>2]|0,b+1676|0);a[b+1709|0]=1;if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=5787;break L7676}b5(36160,c[b+1644+(m<<2)>>2]|0);dB(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;da(36161,c[n>>2]|0);cm(36161,35056,d|0,e|0);da(36161,0);dY(36160,36096,36161,c[n>>2]|0);dY(36160,36128,36161,c[n>>2]|0);n=cs(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=5786;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=5787;break L7676}b5(36160,c[b+1644+(m<<2)>>2]|0);dB(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;da(36161,c[n>>2]|0);cm(36161,33189,d|0,e|0);da(36161,0);dY(36160,36096,36161,c[n>>2]|0);n=cs(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=5786;break}}}}}while(0);if((q|0)==5786){e=c[350134]|0;d=(e|0)!=0?e:c[p>>2]|0;en(d|0,38488,(l=i,i=i+16|0,c[l>>2]=r,c[l+8>>2]=s,l)|0)|0;i=l;l=c[350134]|0;s=(l|0)!=0?l:c[p>>2]|0;a_(s|0)|0;o=0;i=f;return o|0}else if((q|0)==5787){b5(36160,0);a[b+1708|0]=1;o=1;i=f;return o|0}return 0}function lu(a,b){a=a|0;b=+b;var c=0.0,d=0.0;c=+T(+b);d=+U(+b);yG(a|0,0,60);g[a+40>>2]=1.0;g[a+60>>2]=1.0;g[a>>2]=c;g[a+20>>2]=c;g[a+16>>2]=-0.0-d;g[a+4>>2]=d;return}function lv(a,b,c,d,e,f,h){a=a|0;b=+b;c=+c;d=+d;e=+e;f=+f;h=+h;var i=0.0,j=0.0,k=0.0;yG(a|0,0,56);g[a+60>>2]=1.0;i=c-b;j=e-d;k=h-f;g[a>>2]=2.0/i;g[a+20>>2]=2.0/j;g[a+40>>2]=-2.0/k;g[a+48>>2]=(-0.0-(b+c))/i;g[a+52>>2]=(-0.0-(d+e))/j;g[a+56>>2]=(-0.0-(f+h))/k;return}function lw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,h=0.0,j=0,k=0;d=i;i=i+64|0;e=d|0;f=0;do{h=+g[b+(f<<2)>>2];j=0;do{k=j<<2;g[e+(k+f<<2)>>2]=h*+g[c+(k<<2)>>2]+0.0+ +g[b+(f+4<<2)>>2]*+g[c+((k|1)<<2)>>2]+ +g[b+(f+8<<2)>>2]*+g[c+((k|2)<<2)>>2]+ +g[b+(f+12<<2)>>2]*+g[c+((k|3)<<2)>>2];j=j+1|0;}while(j>>>0<4);f=f+1|0;}while(f>>>0<4);f=a;a=e;yJ(f|0,a|0,64)|0;i=d;return}function lx(a,b,d){a=a|0;b=b|0;d=+d;return(fF[c[4748]&3](a,b,d)|0?18992:0)|0}function ly(a){a=a|0;var b=0;b=c[a+2048>>2]|0;if((b|0)==0){return}fs[c[(c[a+2056>>2]|0)+12>>2]&255](b);bh(1,a+2060|0);b=c[a+2076>>2]|0;if((b|0)==0){return}yz(b);return}function lz(b,d,e){b=b|0;d=d|0;e=+e;var f=0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,q=0.0,r=0.0,s=0.0;if((a[1157084]&1)==0){f=0;return f|0}if(j9(b+2056|0,b+2048|0)|0){d=b+2060|0;bz(1,d|0);aZ(3553,c[d>>2]|0);fa(3553,10242,33071);fa(3553,10243,33071);fa(3553,10240,9729);fa(3553,10241,9729);aZ(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);d1(3379,b+2064|0);e=+g[289274];g[b+2344>>2]=e;h=+g[289275];g[b+2348>>2]=h;i=+g[289276];g[b+2352>>2]=i;g[b+2356>>2]=1.0;j=+g[289274];g[b+2360>>2]=j;k=+g[289275];g[b+2364>>2]=k;l=+g[289276];g[b+2368>>2]=l;g[b+2372>>2]=1.0;m=+g[289274];g[b+2376>>2]=m;n=+g[289275];g[b+2380>>2]=n;o=+g[289276];g[b+2384>>2]=o;g[b+2388>>2]=1.0;q=+g[289274];g[b+2392>>2]=q;r=+g[289275];g[b+2396>>2]=r;s=+g[289276];g[b+2400>>2]=s;g[b+2404>>2]=1.0;g[b+2408>>2]=e*.3;g[b+2412>>2]=h*.3;g[b+2416>>2]=i*.3;g[b+2420>>2]=1.0;g[b+2424>>2]=j*.3;g[b+2428>>2]=k*.3;g[b+2432>>2]=l*.3;g[b+2436>>2]=1.0;g[b+2440>>2]=m*.3;g[b+2444>>2]=n*.3;g[b+2448>>2]=o*.3;g[b+2452>>2]=1.0;g[b+2456>>2]=q*.3;g[b+2460>>2]=r*.3;g[b+2464>>2]=s*.3;g[b+2468>>2]=1.0;f=1;return f|0}else{b=c[350134]|0;d=(b|0)!=0?b:c[p>>2]|0;a5(103200,49,1,d|0)|0;d=c[350134]|0;b=(d|0)!=0?d:c[p>>2]|0;a_(b|0)|0;f=0;return f|0}return 0}function lA(a){a=a|0;return}function lB(a,b){a=a|0;b=b|0;return}function lC(){return}function lD(a){a=a|0;return 0}function lE(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return 0}function lF(a){a=a|0;c[283008]=a;return}function lG(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;if(a[19360]|0){e=0}else{a[19360]=1;e=1}return e|0}function lH(a,b){a=a|0;b=b|0;c[a>>2]=c[310868];c[b>>2]=c[310870];return}function lI(){return a[19360]|0}function lJ(a,b){a=a|0;b=b|0;return+(+(a>>>0>>>0)/+(b>>>0>>>0))}function lK(b,d,e){b=b|0;d=d|0;e=e|0;a[1132040]=b&1;c[283006]=d;c[283004]=e;return}function lL(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0.0,aa=0.0,ac=0.0,ad=0.0;f=i;i=i+128|0;h=f|0;j=f+32|0;k=f+64|0;l=f+96|0;m=f+104|0;do{if((e|0)==0){n=+g[289272];o=+g[289273];if((a[1157085]&1)==0){p=n;q=o;r=1.0;break}p=n;q=o;r=+((c[b+1744>>2]|0)>>>0>>>0)/+((c[b+1720>>2]|0)>>>0>>>0)}else{p=+g[e>>2];q=+g[e+4>>2];r=+g[e+8>>2]}}while(0);e=m;s=b+2048|0;if((c[s>>2]|0)==0){i=f;return}t=c[b+4>>2]|0;if((t|0)!=0){fs[c[t+12>>2]&255](15)}k$(b,c[b+1728>>2]|0,c[b+1732>>2]|0,0,0);ex(3042);aZ(3553,c[b+2060>>2]|0);t=k|0;u=b+2e3|0;v=u;w=b+2008|0;c[w>>2]=t;x=b+2080|0;if((cS(x|0,d|0)|0)==0){y=c[b+2336>>2]|0;z=c[b+2340>>2]|0;A=b+2068|0;B=b+2072|0}else{C=b+2056|0;fP[c[(c[C>>2]|0)+4>>2]&127](c[s>>2]|0,d,l);D=c[l>>2]|0;E=c[D+24>>2]|0;F=(c[D+4>>2]|0)+E|0;G=c[D+28>>2]|0;H=(c[D+8>>2]|0)+G|0;I=c[D+48>>2]|0;if((I|0)==0){J=H;K=G;L=F;M=E}else{N=H;H=G;G=F;F=E;E=I;while(1){I=c[E+24>>2]|0;O=(c[E+4>>2]|0)+I|0;P=c[E+28>>2]|0;Q=(c[E+8>>2]|0)+P|0;R=(I|0)<(F|0)?I:F;I=(O|0)>(G|0)?O:G;O=(P|0)<(H|0)?P:H;P=(Q|0)>(N|0)?Q:N;Q=c[E+48>>2]|0;if((Q|0)==0){J=P;K=O;L=I;M=R;break}else{N=P;H=O;G=I;F=R;E=Q}}}E=L-M|0;L=J-K|0;J=E-1|0;F=J>>>1|J;J=F>>>2|F;F=J>>>4|J;J=F>>>8|F;F=(J>>>16|J)+1|0;J=L-1|0;G=J>>>1|J;J=G>>>2|G;G=J>>>4|J;J=G>>>8|G;G=(J>>>16|J)+1|0;J=c[b+2064>>2]|0;H=(F|0)>(J|0)?J:F;F=(G|0)>(J|0)?J:G;G=b+2068|0;J=c[G>>2]|0;N=b+2072|0;do{if((H|0)>(J|0)){S=5842}else{Q=c[N>>2]|0;if((F|0)>(Q|0)){S=5842;break}T=J;U=Q;V=b+2076|0}}while(0);if((S|0)==5842){S=b+2076|0;J=c[S>>2]|0;c[S>>2]=yA(J,ab(H<<2,F)|0)|0;ed(3553,0,6408,H|0,F|0,0,6408,5121,0);c[G>>2]=H;c[N>>2]=F;T=H;U=F;V=S}S=c[V>>2]|0;yG(S|0,0,ab(U<<2,T)|0);if((D|0)!=0){T=D;do{D=c[V>>2]|0;U=c[G>>2]|0;S=c[N>>2]|0;F=(c[T+24>>2]|0)-M|0;H=c[T+8>>2]|0;J=S-H+(K-(c[T+28>>2]|0))|0;Q=J-1|0;R=c[T>>2]|0;I=(F|0)<0;O=(c[T+4>>2]|0)+(I?F:0)|0;P=(Q|0)<0;W=(P?Q:0)+H|0;if(I){X=R+(-F|0)|0;Y=0}else{X=R;Y=F}if(P){Z=X+(ab(c[T+12>>2]|0,1-J|0)|0)|0;_=0}else{Z=X;_=Q}Q=(Y+O|0)>(U|0)?U-Y|0:O;O=(_+W|0)>(S|0)?S-_|0:W;do{if((O|0)>0){W=T+12|0;if((Q|0)<=0){break}S=Z;J=D+((ab(_,U)|0)+Y<<2)|0;P=0;while(1){F=J;R=0;while(1){a[F]=-1;a[F+1|0]=-1;a[F+2|0]=-1;a[F+3|0]=a[S+R|0]|0;I=R+1|0;if((I|0)<(Q|0)){F=F+4|0;R=I}else{break}}R=P+1|0;if((R|0)<(O|0)){S=S+(c[W>>2]|0)|0;J=J+(U<<2)|0;P=R}else{break}}}}while(0);T=c[T+48>>2]|0;}while((T|0)!=0)}fl(3317,8);ef(3553,0,0,0,c[G>>2]|0,c[N>>2]|0,6408,5121,c[V>>2]|0);ft[c[(c[C>>2]|0)+8>>2]&127](c[s>>2]|0,l);i5(x,d,256)|0;c[b+2336>>2]=E;c[b+2340>>2]=L;y=E;z=L;A=G;B=N}N=h|0;G=j|0;o=+(y|0);n=+((c[b+1744>>2]|0)>>>0>>>0);$=p+r*o/n;aa=+(z|0);ac=+((c[b+1748>>2]|0)>>>0>>>0);ad=q+r*aa/ac;g[N>>2]=p;g[h+8>>2]=$;g[h+16>>2]=p;g[h+24>>2]=$;g[h+4>>2]=ad;g[h+12>>2]=ad;g[h+20>>2]=q;g[h+28>>2]=q;r=2.0/n;n=2.0/ac;ac=p-r;g[G>>2]=ac;p=ad-n;g[j+4>>2]=p;ad=$-r;g[j+8>>2]=ad;g[j+12>>2]=p;g[j+16>>2]=ac;ac=q-n;g[j+20>>2]=ac;g[j+24>>2]=ad;g[j+28>>2]=ac;ac=o/+(c[A>>2]|0);o=1.0-aa/+(c[B>>2]|0);g[t>>2]=0.0;g[k+8>>2]=ac;g[k+16>>2]=0.0;g[k+24>>2]=ac;g[k+4>>2]=o;g[k+12>>2]=o;g[k+20>>2]=1.0;g[k+28>>2]=1.0;k=u;c[k>>2]=G;G=b+2004|0;c[G>>2]=b+2408;u=b+1872|0;kX(b,v,u);de(5,0,4);c[k>>2]=N;c[G>>2]=b+2344;kX(b,v,u);de(5,0,4);c[k>>2]=c[b+2016>>2];c[w>>2]=b+1840;c[G>>2]=c[b+2020>>2];aZ(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);dk(3042);c[e>>2]=c[928];c[e+4>>2]=c[929];c[e+8>>2]=c[930];c[e+12>>2]=c[931];c[e+16>>2]=c[932];c[e+20>>2]=c[933];k_(b,m,1);i=f;return}function lM(a){a=a|0;return((cS(c[4815]|0,a|0)|0)==0?19192:0)|0}function lN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;do{if(fA[c[4800]&63](a,b,d)|0){if(fN[c[4798]&63]()|0){e=19192}else{break}return e|0}}while(0);e=0;return e|0}function lO(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;if((a[1243488]&1)!=0){g=c[350134]|0;h=(g|0)!=0?g:c[p>>2]|0;a5(83536,45,1,h|0)|0;h=c[350134]|0;g=(h|0)!=0?h:c[p>>2]|0;a_(g|0)|0}if(a[19360]|0){if((a[1243488]&1)==0){j=1;i=b;return j|0}g=c[350134]|0;h=(g|0)!=0?g:c[p>>2]|0;a5(69856,64,1,h|0)|0;h=c[350134]|0;g=(h|0)!=0?h:c[p>>2]|0;a_(g|0)|0;j=1;i=b;return j|0}g=ff(0)|0;c[350406]=g;do{if((g|0)!=0){do{if((cH(g|0,0,0)|0)!=0){if((eq(c[350406]|0,19144,1401640,1,f|0)|0)==0){break}h=bc(c[350406]|0,c[350410]|0,0,19128)|0;c[350408]=h;if((h|0)==0){break}h=em(c[350406]|0,c[350410]|0,0,0)|0;c[350404]=h;if((h|0)==0){break}if((dE(c[350406]|0,h|0,h|0,c[350408]|0)|0)==0){break}h=c[350406]|0;k=c[350404]|0;fk(h|0,k|0,12375,d|0)|0;k=c[350406]|0;h=c[350404]|0;fk(k|0,h|0,12374,e|0)|0;h=c[d>>2]|0;c[310868]=h;k=c[e>>2]|0;c[310870]=k;if((a[1243488]&1)==0){j=1;i=b;return j|0}l=c[350134]|0;m=(l|0)!=0?l:c[p>>2]|0;en(m|0,60280,(m=i,i=i+16|0,c[m>>2]=h,c[m+8>>2]=k,m)|0)|0;i=m;m=c[350134]|0;k=(m|0)!=0?m:c[p>>2]|0;a_(k|0)|0;j=1;i=b;return j|0}}while(0);k=c[350406]|0;if((k|0)==0){break}dE(k|0,0,0,0)|0;k=c[350408]|0;if((k|0)!=0){m=c[350406]|0;ds(m|0,k|0)|0}k=c[350404]|0;if((k|0)!=0){m=c[350406]|0;aW(m|0,k|0)|0}k=c[350406]|0;cd(k|0)|0}}while(0);c[350408]=0;c[350404]=0;c[350406]=0;c[350410]=0;a[19360]=0;j=0;i=b;return j|0}function lP(){var b=0,d=0;b=c[350406]|0;if((b|0)!=0){dE(b|0,0,0,0)|0;b=c[350408]|0;if((b|0)!=0){d=c[350406]|0;ds(d|0,b|0)|0}b=c[350404]|0;if((b|0)!=0){d=c[350406]|0;aW(d|0,b|0)|0}b=c[350406]|0;cd(b|0)|0}c[350408]=0;c[350404]=0;c[350406]=0;c[350410]=0;a[19360]=0;return}function lQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)==1){d=(bi(12448)|0)!=0}else{d=0}return d|0}function lR(){var b=0,d=0,e=0;b=i;i=i+128|0;d=b|0;if(!(iI(d,128,0)|0)){i=b;return}if((a[1243488]&1)==0){i=b;return}e=c[350134]|0;en(((e|0)!=0?e:c[p>>2]|0)|0,103168,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;e=c[350134]|0;a_(((e|0)!=0?e:c[p>>2]|0)|0)|0;i=b;return}function lS(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;g=i;i=i+24|0;h=g|0;j=g+8|0;cB(h|0,j|0,g+16|0);k=c[h>>2]|0;c[e>>2]=k;h=c[j>>2]|0;c[f>>2]=h;a[d]=(c[e>>2]|0)==(c[310868]|0)&(h|0)==(c[310870]|0)&1^1;c[310868]=k;c[310870]=h;a[b]=0;i=g;return}function lT(a,b){a=a|0;b=b|0;var d=0;c[a>>2]=0;d=fN[c[4192]&63]()|0;if((d|0)==0){return}c[a>>2]=16768;c[b>>2]=d;return}function lU(a){a=a|0;return ch(a|0)|0}function lV(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+32|0;e=d|0;f=d+16|0;g=yy(1,109528)|0;c[283002]=g;if((g|0)==0){h=0;i=d;return h|0}L7858:do{if((b|0)==0){g=c[350134]|0;j=(g|0)!=0?g:c[p>>2]|0;a5(69792,59,1,j|0)|0;j=c[350134]|0;g=(j|0)!=0?j:c[p>>2]|0;a_(g|0)|0;c[(c[283002]|0)+72>>2]=1;g=dy(((a[1132040]&1)!=0?53312:53880)|0)|0;c[(c[283002]|0)+4172>>2]=g;g=dy(((a[1132040]&1)!=0?54976:55608)|0)|0;c[(c[283002]|0)+4176>>2]=g;a[(c[283002]|0)+4|0]=1}else{if((cS(gU(b)|0,91800)|0)==0){g=(c[283002]|0)+76|0;i5(g,b,4096)|0;c[(c[283002]|0)+72>>2]=1;a[(c[283002]|0)+4|0]=1;break}do{if((cS(gU(b)|0,103160)|0)==0){g=hs(b)|0;if((g|0)==0){break}j=j1(g,c[283002]|0)|0;a[(c[283002]|0)+4|0]=1;ht(g);if(j){break L7858}}else{if(j2(b,c[283002]|0)|0){break L7858}}}while(0);j=c[350134]|0;g=(j|0)!=0?j:c[p>>2]|0;a5(83472,56,1,g|0)|0;g=c[350134]|0;j=(g|0)!=0?g:c[p>>2]|0;a_(j|0)|0;h=0;i=d;return h|0}}while(0);j7(c[283002]|0,b);b=(a[1132040]&1)==0;L7871:do{if((a[(c[283002]|0)+4|0]&1)==0){j=c[350134]|0;g=(j|0)!=0?j:c[p>>2]|0;a5(60184,90,1,g|0)|0;g=c[350134]|0;j=(g|0)!=0?g:c[p>>2]|0;a_(j|0)|0}else{j=l5(b?53880:53312,b?55608:54976,0)|0;c[284862]=j;if((j|0)==0){j=c[350134]|0;g=(j|0)!=0?j:c[p>>2]|0;a5(54480,60,1,g|0)|0;g=c[350134]|0;j=(g|0)!=0?g:c[p>>2]|0;a_(j|0)|0;break}else{k=0}while(1){l=c[283002]|0;if(k>>>0>=(c[l+72>>2]|0)>>>0){m=5940;break}n=l+76+(k*4148|0)|0;j=l+76+(k*4148|0)+4096|0;if((a[n]|0)==0){o=c[j>>2]|0;q=c[l+76+(k*4148|0)+4100>>2]|0}else{if((gJ(n,j)|0)<1){m=5937;break}g=dy(c[j>>2]|0)|0;c[l+76+(k*4148|0)+4100>>2]=g;if((g|0)==0){m=5937;break}r=c[j>>2]|0;if((r|0)==0){m=5937;break}else{o=r;q=g}}a[n]=0;g=l5(o,q,k)|0;r=k+1|0;c[1139448+(r<<2)>>2]=g;if((g|0)==0){m=5939;break}else{k=r}}if((m|0)==5939){r=c[350134]|0;g=(r|0)!=0?r:c[p>>2]|0;en(g|0,66912,(s=i,i=i+8|0,c[s>>2]=k,s)|0)|0;i=s;g=c[350134]|0;r=(g|0)!=0?g:c[p>>2]|0;a_(r|0)|0;break}else if((m|0)==5940){r=e;L7888:do{if((c[l+66444>>2]|0)==0){t=0}else{bz(1,1139408);g=c[283002]|0;if((c[g+66444>>2]|0)==0){t=0;break}j=e|0;u=e+4|0;v=e+8|0;w=0;x=g;while(1){if((a[1243488]&1)==0){y=x}else{g=c[350134]|0;z=(g|0)!=0?g:c[p>>2]|0;g=x+66448+(w*4168|0)+64|0;en(z|0,70728,(s=i,i=i+8|0,c[s>>2]=g,s)|0)|0;i=s;g=c[350134]|0;z=(g|0)!=0?g:c[p>>2]|0;a_(z|0)|0;y=c[283002]|0}yG(r|0,0,12);if(!(ko(y+66448+(w*4168|0)+64|0,e)|0)){break}aZ(3553,c[1139408+(w<<2)>>2]|0);fa(3553,10242,33071);fa(3553,10243,33071);z=(c[(c[283002]|0)+66448+(w*4168|0)+4160>>2]|0)==2?9728:9729;fa(3553,10240,z|0);fa(3553,10241,z|0);fl(3317,4);z=(a[1402804]&1)!=0?6408:32993;ed(3553,0,z|0,c[j>>2]|0,c[u>>2]|0,0,z|0,5121,c[v>>2]|0);aZ(3553,0);yz(c[v>>2]|0);z=w+1|0;g=c[283002]|0;if(z>>>0<(c[g+66444>>2]|0)>>>0){w=z;x=g}else{t=0;break L7888}}x=c[350134]|0;en(((x|0)!=0?x:c[p>>2]|0)|0,69168,(s=i,i=i+8|0,c[s>>2]=(c[283002]|0)+66448+(w*4168|0)+64,s)|0)|0;i=s;x=c[350134]|0;a_(((x|0)!=0?x:c[p>>2]|0)|0)|0;x=c[350134]|0;a5(50216,48,1,((x|0)!=0?x:c[p>>2]|0)|0)|0;x=c[350134]|0;a_(((x|0)!=0?x:c[p>>2]|0)|0)|0;break L7871}}while(0);do{l6(t,c[1139448+(t<<2)>>2]|0,1132048+(t*460|0)|0);t=t+1|0;A=c[283002]|0;}while(t>>>0<=(c[A+72>>2]|0)>>>0);do{if((c[A+99792>>2]|0)!=0){yG(f|0,0,12);c[f>>2]=fv[c[157586]&127](2)|0;r=c[283002]|0;c[f+4>>2]=r+99796;c[f+8>>2]=c[r+99792>>2];r=j_(f)|0;c[284860]=r;if((r|0)!=0){break}r=c[350134]|0;x=(r|0)!=0?r:c[p>>2]|0;a5(46344,50,1,x|0)|0;x=c[350134]|0;r=(x|0)!=0?x:c[p>>2]|0;a_(r|0)|0}}while(0);a[18960]=1;r=c[283002]|0;x=r+72|0;c[1139448+((c[x>>2]|0)+1<<2)>>2]=c[284862];v=1132048+(((c[x>>2]|0)+1|0)*460|0)|0;yJ(v|0,1132048,460)|0;if((a[r+4|0]&1)==0){c[284877]=c[284862];yJ(1138948,1132048,460)|0}else{r=(a[1132040]&1)!=0;v=l5(r?105072:108280,r?38320:42032,15)|0;c[284877]=v;l6(0,v,1138948)}if((c[285036]|0)!=0){v=0;do{c7(c[1140032+(v<<2)>>2]|0);v=v+1|0;}while(v>>>0<(c[285036]|0)>>>0)}c[285036]=0;v=0;while(1){eG(1,1115368+(v*1040|0)|0);eG(1,1115888+(v*1040|0)|0);r=v+1|0;if(r>>>0<16){v=r}else{h=1;break}}i=d;return h|0}else if((m|0)==5937){v=c[350134]|0;en(((v|0)!=0?v:c[p>>2]|0)|0,67904,(s=i,i=i+8|0,c[s>>2]=n,s)|0)|0;i=s;v=c[350134]|0;a_(((v|0)!=0?v:c[p>>2]|0)|0)|0;break}}}while(0);lW();h=0;i=d;return h|0}function lW(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;ec(0);f=e;g=e;h=0;do{j=c[1139448+(h<<2)>>2]|0;do{if((j|0)!=0){if((h|0)!=0&(j|0)==(c[284862]|0)){break}c[e>>2]=0;c[e+4>>2]=0;b4(j|0,2,d|0,g|0);if((c[d>>2]|0)>0){k=0;do{l=f+(k<<2)|0;cX(j|0,c[l>>2]|0);bn(c[l>>2]|0);k=k+1|0;}while((k|0)<(c[d>>2]|0))}cj(j|0)}}while(0);h=h+1|0;}while(h>>>0<16);h=c[283002]|0;do{if((h|0)==0){m=0}else{d=c[h+66444>>2]|0;if((d|0)==0){m=h;break}bh(d|0,1139408);m=c[283002]|0}}while(0);yG(1139448,0,64);yG(1132048,0,7360);a[18960]=0;c[664794]=0;if((m|0)!=0){if((c[m+72>>2]|0)==0){n=m}else{h=0;d=m;while(1){yz(c[d+76+(h*4148|0)+4096>>2]|0);yz(c[(c[283002]|0)+76+(h*4148|0)+4100>>2]|0);m=h+1|0;f=c[283002]|0;if(m>>>0<(c[f+72>>2]|0)>>>0){h=m;d=f}else{n=f;break}}}yz(c[n+109012>>2]|0);yz(c[283002]|0);c[283002]=0}n=c[284860]|0;if((n|0)!=0){j$(n)}c[284860]=0;if((c[285036]|0)!=0){n=0;do{c7(c[1140032+(n<<2)>>2]|0);n=n+1|0;}while(n>>>0<(c[285036]|0)>>>0)}c[285036]=0;n=0;do{d=1115368+(n*1040|0)|0;if((c[d>>2]|0)!=0){fe(1,d|0)}d=1115888+(n*1040|0)|0;if((c[d>>2]|0)!=0){fe(1,d|0)}n=n+1|0;}while(n>>>0<16);yG(1115368,0,16640);i=b;return}function lX(){return c[(c[283002]|0)+72>>2]|0}function lY(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==0|a[18960]^1){e=0;return e|0}f=c[(c[283002]|0)+76+((b-1|0)*4148|0)+4136>>2]|0;if((f|0)==0){e=0;return e|0}a[d]=(f|0)==1|0;e=1;return e|0}function lZ(b){b=b|0;var d=0;if((b|0)==0|a[18960]^1){d=0;return d|0}d=c[(c[283002]|0)+76+((b-1|0)*4148|0)+4140>>2]|0;return d|0}function l_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(!(a[18960]|0)){b=0;return b|0}d=c[(c[283002]|0)+72>>2]|0;if((d|0)==0){b=0;return b|0}else{e=0;f=1}while(1){if((c[1132396+(f*460|0)>>2]|0)>-1){g=(e|0)==0?1:e}else{g=e}if((c[1132412+(f*460|0)>>2]|0)>-1){h=g>>>0<2?2:g}else{h=g}if((c[1132428+(f*460|0)>>2]|0)>-1){i=h>>>0<3?3:h}else{i=h}if((c[1132444+(f*460|0)>>2]|0)>-1){j=i>>>0<4?4:i}else{j=i}if((c[1132460+(f*460|0)>>2]|0)>-1){k=j>>>0<5?5:j}else{k=j}if((c[1132476+(f*460|0)>>2]|0)>-1){l=k>>>0<6?6:k}else{l=k}if((c[1132492+(f*460|0)>>2]|0)>-1){m=l>>>0<7?7:l}else{m=l}n=f+1|0;if(n>>>0>d>>>0){b=m;break}else{e=m;f=n}}return b|0}function l$(b,d,e,f,h,j,k,l,m,n,o){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;p=i;i=i+920|0;q=p|0;r=p+512|0;s=p+896|0;t=p+904|0;u=p+912|0;if(!(a[18960]|0)){i=p;return}v=c[664794]|0;if((c[1139448+(v<<2)>>2]|0)==0){i=p;return}w=r|0;x=s|0;g[x>>2]=+(b>>>0>>>0);g[s+4>>2]=+(d>>>0>>>0);d=t|0;g[d>>2]=+(h>>>0>>>0);g[t+4>>2]=+(j>>>0>>>0);j=u|0;g[j>>2]=+(e>>>0>>>0);g[u+4>>2]=+(f>>>0>>>0);f=c[1132068+(v*460|0)>>2]|0;if((f|0)>-1){ba(f|0,1,x|0)}x=c[1132072+(v*460|0)>>2]|0;if((x|0)>-1){ba(x|0,1,d|0)}d=c[1132076+(v*460|0)>>2]|0;if((d|0)>-1){ba(d|0,1,j|0)}j=c[1132080+(v*460|0)>>2]|0;d=c[664794]|0;if((j|0)>-1&(d|0)!=0){x=c[(c[283002]|0)+76+((d-1|0)*4148|0)+4144>>2]|0;if((x|0)==0){y=k}else{y=(k>>>0)%(x>>>0)|0}bM(j|0,y|0);z=y}else{z=k}k=c[1132088+(v*460|0)>>2]|0;if((k|0)>-1){bM(k|0,((a[1392032]&1)!=0?-1:1)|0)}k=c[283002]|0;if((c[k+66444>>2]|0)==0){A=0}else{y=0;j=k;while(1){k=1132092+(v*460|0)+(y<<2)|0;if((c[k>>2]|0)>-1){cP(y+33985|0);aZ(3553,c[1139408+(y<<2)>>2]|0);x=y+1|0;bM(c[k>>2]|0,x|0);B=c[283002]|0;C=x}else{B=j;C=y+1|0}x=c[B+66444>>2]|0;if(C>>>0<x>>>0){y=C;j=B}else{A=x;break}}}B=A+1|0;do{if((c[664794]|0)>>>0>1){j=1132124+(v*460|0)|0;if((c[j>>2]|0)>-1){cP(A+33985|0);bM(c[j>>2]|0,B|0);aZ(3553,c[l>>2]|0)}j=A+2|0;C=c[1132132+(v*460|0)>>2]|0;if((C|0)>-1){ba(C|0,1,l+12|0)}C=c[1132128+(v*460|0)>>2]|0;if((C|0)>-1){ba(C|0,1,l+4|0)}C=c[1132136+(v*460|0)>>2]|0;if((C|0)>-1){c[r>>2]=C;c[r+4>>2]=2;c[r+8>>2]=0;C=r+12|0;y=q;x=l+20|0;yJ(y|0,x|0,32)|0;D=8;E=1;F=C}else{D=0;E=0;F=w}if((o|0)==0){G=F;H=E;I=j;J=D;K=0;break}cP(o+33985+A|0);aZ(3553,c[n+((o-1|0)*52|0)>>2]|0);C=A+o|0;x=F;y=E;k=j;j=0;d=D;while(1){f=c[1132140+(v*460|0)+(j<<4)>>2]|0;if((f|0)!=0){bM(f|0,k|0)}f=c[1132140+(v*460|0)+(j<<4)+8>>2]|0;if((f|0)>-1){ba(f|0,1,n+(j*52|0)+12|0)}f=c[1132140+(v*460|0)+(j<<4)+4>>2]|0;if((f|0)>-1){ba(f|0,1,n+(j*52|0)+4|0)}f=c[1132140+(v*460|0)+(j<<4)+12>>2]|0;if((f|0)>-1){c[x>>2]=f;c[x+4>>2]=2;c[x+8>>2]=d<<2;f=y+1|0;u=x+12|0;e=q+(d<<2)|0;t=n+(j*52|0)+20|0;yJ(e|0,t|0,32)|0;L=d+8|0;M=f;N=u}else{L=d;M=y;N=x}u=j+1|0;if(u>>>0<o>>>0){x=N;y=M;k=k+1|0;j=u;d=L}else{break}}G=N;H=M;I=C+2|0;J=L;K=0}else{cP(A+33985|0);aZ(3553,0);if((c[(c[283002]|0)+72>>2]|0)==0){G=w;H=0;I=B;J=0;K=0;break}d=A+33986|0;j=0;while(1){cP(d+j|0);aZ(3553,0);k=j+1|0;if(k>>>0<(c[(c[283002]|0)+72>>2]|0)>>>0){j=k}else{G=w;H=0;I=B;J=0;K=0;break}}}}while(0);while(1){B=1132396+(v*460|0)+(K<<4)|0;if((c[B>>2]|0)>-1){cP(I+33984|0);aZ(3553,c[m+(K*52|0)>>2]|0);bM(c[B>>2]|0,I|0);O=I+1|0}else{O=I}B=c[1132396+(v*460|0)+(K<<4)+8>>2]|0;if((B|0)>-1){ba(B|0,1,m+(K*52|0)+12|0)}B=c[1132396+(v*460|0)+(K<<4)+4>>2]|0;if((B|0)>-1){ba(B|0,1,m+(K*52|0)+4|0)}B=c[1132396+(v*460|0)+(K<<4)+12>>2]|0;if((B|0)>-1){c[G>>2]=B;c[G+4>>2]=2;c[G+8>>2]=J<<2;B=H+1|0;A=G+12|0;L=q+(J<<2)|0;M=m+(K*52|0)+20|0;yJ(L|0,M|0,32)|0;P=J+8|0;Q=B;R=A}else{P=J;Q=H;R=G}A=K+1|0;if(A>>>0<7){G=R;H=Q;I=O+1|0;J=P;K=A}else{break}}if((P|0)!=0){K=c[664794]|0;l4(c[1115888+(K*1040|0)>>2]|0,1115892+(K*1040|0)|0,1116404+(K*1040|0)|0,q|0,P,w,Q)}cP(33984);Q=c[284860]|0;if((Q|0)==0){i=p;return}if((c[664794]|0)==1){w=j0(Q,1139512,64,z)|0;c[285006]=w;S=w}else{S=c[285006]|0}if((S|0)==0){i=p;return}else{T=0}do{S=dJ(c[1139448+(c[664794]<<2)>>2]|0,c[1139512+(T<<3)>>2]|0)|0;bE(S|0,+(+g[1139516+(T<<3)>>2]));T=T+1|0;}while(T>>>0<(c[285006]|0)>>>0);i=p;return}function l0(b){b=b|0;var d=0;if(!(a[18960]|0)){return}if((c[285036]|0)!=0){d=0;do{c7(c[1140032+(d<<2)>>2]|0);d=d+1|0;}while(d>>>0<(c[285036]|0)>>>0)}c[285036]=0;c[664794]=b;ec(c[1139448+(b<<2)>>2]|0);return}function l1(b,d){b=b|0;d=d|0;var e=0;if((b|0)==0|a[18960]^1){a[d|0]=0;return}else{e=d|0;d=(c[283002]|0)+76+((b-1|0)*4148|0)+4104|0;yJ(e|0,d|0,32)|0;return}}function l2(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+560|0;e=d|0;f=d+512|0;if(!(a[18960]|0)){g=0;i=d;return g|0}if((a[(c[283002]|0)+4|0]&1)==0){g=0;i=d;return g|0}h=f|0;j=c[664794]|0;k=c[1132052+(j*460|0)>>2]|0;if((k|0)>-1){c[f>>2]=k;c[f+4>>2]=2;c[f+8>>2]=0;k=f+12|0;f=e;l=c[b+8>>2]|0;yJ(f|0,l|0,32)|0;m=k;n=1;o=8}else{m=h;n=0;o=0}k=c[1132056+(j*460|0)>>2]|0;if((k|0)>-1){c[m>>2]=k;c[m+4>>2]=2;c[m+8>>2]=o<<2;k=n+1|0;l=m+12|0;f=e+(o<<2)|0;p=c[b>>2]|0;yJ(f|0,p|0,32)|0;q=l;r=k;s=o+8|0}else{q=m;r=n;s=o}o=c[1132060+(j*460|0)>>2]|0;if((o|0)>-1){c[q>>2]=o;c[q+4>>2]=4;c[q+8>>2]=s<<2;o=r+1|0;n=q+12|0;m=e+(s<<2)|0;k=c[b+4>>2]|0;yJ(m|0,k|0,64)|0;t=n;u=o;v=s+16|0}else{t=q;u=r;v=s}s=c[1132064+(j*460|0)>>2]|0;if((s|0)>-1){c[t>>2]=s;c[t+4>>2]=2;c[t+8>>2]=v<<2;t=u+1|0;s=e+(v<<2)|0;j=c[b+12>>2]|0;yJ(s|0,j|0,32)|0;w=t;x=v+8|0}else{w=u;x=v}if((x|0)==0){g=1;i=d;return g|0}v=c[664794]|0;l4(c[1115368+(v*1040|0)>>2]|0,1115372+(v*1040|0)|0,1115884+(v*1040|0)|0,e|0,x,h,w);g=1;i=d;return g|0}function l3(b){b=b|0;var d=0,e=0;if(!(a[18960]|0)){d=0;return d|0}if((a[(c[283002]|0)+4|0]&1)==0){d=0;return d|0}e=c[1132048+((c[664794]|0)*460|0)>>2]|0;if((e|0)<=-1){d=1;return d|0}e1(e|0,1,0,b|0);d=1;return d|0}function l4(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;b$(34962,a|0);if((c[d>>2]|0)==(f|0)){a=e;i=b;j=f<<2;if((yO(a|0,i|0,j|0)|0)!=0){k=i;l=a;m=j;n=6132}}else{k=b;l=e;m=f<<2;n=6132}if((n|0)==6132){yJ(k|0,l|0,m)|0;dH(34962,m|0,l|0,35044);c[d>>2]=f}if((h|0)==0){b$(34962,0);return}else{o=0}do{f=c[g+(o*12|0)>>2]|0;du(f|0);d=c[285036]|0;c[285036]=d+1;c[1140032+(d<<2)>>2]=f;bY(f|0,c[g+(o*12|0)+4>>2]|0,5126,0,0,c[g+(o*12|0)+8>>2]|0);o=o+1|0;}while(o>>>0<h>>>0);b$(34962,0);return}function l5(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=i;i=i+88|0;g=f|0;h=f+64|0;j=f+72|0;k=f+80|0;l=eN()|0;if((l|0)==0){m=0;i=f;return m|0}n=(b|0)!=0;do{if(n){if((a[1243488]&1)!=0){o=c[350134]|0;q=(o|0)!=0?o:c[p>>2]|0;a5(65928,37,1,q|0)|0;q=c[350134]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0}o=bK(35633)|0;if(l8(o,65008,b)|0){co(l|0,o|0);break}o=c[350134]|0;q=(o|0)!=0?o:c[p>>2]|0;en(q|0,64216,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;q=c[350134]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;m=0;i=f;return m|0}}while(0);b=(d|0)!=0;do{if(b){if((a[1243488]&1)!=0){o=c[350134]|0;q=(o|0)!=0?o:c[p>>2]|0;a5(63432,39,1,q|0)|0;q=c[350134]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0}o=bK(35632)|0;if(l8(o,62688,d)|0){co(l|0,o|0);break}o=c[350134]|0;q=(o|0)!=0?o:c[p>>2]|0;en(q|0,61976,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;q=c[350134]|0;o=(q|0)!=0?q:c[p>>2]|0;a_(o|0)|0;m=0;i=f;return m|0}}while(0);if(!(n|b)){m=l;i=f;return m|0}if((a[1243488]&1)!=0){b=c[350134]|0;n=(b|0)!=0?b:c[p>>2]|0;a5(60968,33,1,n|0)|0;n=c[350134]|0;b=(n|0)!=0?n:c[p>>2]|0;a_(b|0)|0}bQ(l|0);dR(l|0,35714,k|0);c[h>>2]=0;dR(l|0,35716,j|0);b=c[j>>2]|0;do{if((b|0)!=0){j=yx(b)|0;if((j|0)==0){break}ee(l|0,b|0,h|0,j|0);do{if((c[h>>2]|0)>0){if((a[1243488]&1)==0){break}n=c[350134]|0;d=(n|0)!=0?n:c[p>>2]|0;en(d|0,59168,(r=i,i=i+8|0,c[r>>2]=j,r)|0)|0;i=r;d=c[350134]|0;n=(d|0)!=0?d:c[p>>2]|0;a_(n|0)|0}}while(0);yz(j)}}while(0);if((c[k>>2]|0)!=1){k=c[350134]|0;h=(k|0)!=0?k:c[p>>2]|0;en(h|0,59720,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;e=c[350134]|0;h=(e|0)!=0?e:c[p>>2]|0;a_(h|0)|0;m=0;i=f;return m|0}ec(l|0);ec(l|0);h=g|0;bR(h|0,64,74880,(r=i,i=i+16|0,c[r>>2]=(c[283002]|0)+5,c[r+8>>2]=73960,r)|0)|0;i=r;g=dJ(l|0,h|0)|0;L8202:do{if((g|0)>-1){s=g}else{e=0;while(1){if(e>>>0>=2){s=-1;break L8202}bR(h|0,64,74880,(r=i,i=i+16|0,c[r>>2]=c[18952+(e<<2)>>2],c[r+8>>2]=73960,r)|0)|0;i=r;k=dJ(l|0,h|0)|0;if((k|0)>-1){s=k;break}else{e=e+1|0}}}}while(0);bM(s|0,0);ec(0);m=l;i=f;return m|0}function l6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+128|0;f=e+64|0;ec(b|0);g=e|0;bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=(c[283002]|0)+5,c[h+8>>2]=102016,h)|0)|0;i=h;j=dJ(b|0,g|0)|0;L8209:do{if((j|0)>-1){k=j}else{l=0;while(1){if(l>>>0>=2){k=-1;break L8209}bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(l<<2)>>2],c[h+8>>2]=102016,h)|0)|0;i=h;m=dJ(b|0,g|0)|0;if((m|0)>-1){k=m;break}else{l=l+1|0}}}}while(0);c[d>>2]=k;bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=(c[283002]|0)+5,c[h+8>>2]=99752,h)|0)|0;i=h;k=dJ(b|0,g|0)|0;L8214:do{if((k|0)>-1){n=k}else{j=0;while(1){if(j>>>0>=2){n=-1;break L8214}bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(j<<2)>>2],c[h+8>>2]=99752,h)|0)|0;i=h;l=eI(b|0,g|0)|0;if((l|0)>-1){n=l;break}else{j=j+1|0}}}}while(0);c[d+4>>2]=n;bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=(c[283002]|0)+5,c[h+8>>2]=98168,h)|0)|0;i=h;n=dJ(b|0,g|0)|0;L8219:do{if((n|0)>-1){o=n}else{k=0;while(1){if(k>>>0>=2){o=-1;break L8219}bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(k<<2)>>2],c[h+8>>2]=98168,h)|0)|0;i=h;j=eI(b|0,g|0)|0;if((j|0)>-1){o=j;break}else{k=k+1|0}}}}while(0);c[d+8>>2]=o;bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=(c[283002]|0)+5,c[h+8>>2]=95944,h)|0)|0;i=h;o=dJ(b|0,g|0)|0;L8224:do{if((o|0)>-1){p=o}else{n=0;while(1){if(n>>>0>=2){p=-1;break L8224}bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(n<<2)>>2],c[h+8>>2]=95944,h)|0)|0;i=h;k=eI(b|0,g|0)|0;if((k|0)>-1){p=k;break}else{n=n+1|0}}}}while(0);c[d+12>>2]=p;bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=(c[283002]|0)+5,c[h+8>>2]=93856,h)|0)|0;i=h;p=dJ(b|0,g|0)|0;L8229:do{if((p|0)>-1){q=p}else{o=0;while(1){if(o>>>0>=2){q=-1;break L8229}bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(o<<2)>>2],c[h+8>>2]=93856,h)|0)|0;i=h;n=eI(b|0,g|0)|0;if((n|0)>-1){q=n;break}else{o=o+1|0}}}}while(0);c[d+16>>2]=q;bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=(c[283002]|0)+5,c[h+8>>2]=92224,h)|0)|0;i=h;q=dJ(b|0,g|0)|0;L8234:do{if((q|0)>-1){r=q}else{p=0;while(1){if(p>>>0>=2){r=-1;break L8234}bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(p<<2)>>2],c[h+8>>2]=92224,h)|0)|0;i=h;o=dJ(b|0,g|0)|0;if((o|0)>-1){r=o;break}else{p=p+1|0}}}}while(0);c[d+20>>2]=r;bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=(c[283002]|0)+5,c[h+8>>2]=90488,h)|0)|0;i=h;r=dJ(b|0,g|0)|0;L8239:do{if((r|0)>-1){s=r}else{q=0;while(1){if(q>>>0>=2){s=-1;break L8239}bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(q<<2)>>2],c[h+8>>2]=90488,h)|0)|0;i=h;p=dJ(b|0,g|0)|0;if((p|0)>-1){s=p;break}else{q=q+1|0}}}}while(0);c[d+24>>2]=s;bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=(c[283002]|0)+5,c[h+8>>2]=88672,h)|0)|0;i=h;s=dJ(b|0,g|0)|0;L8244:do{if((s|0)>-1){t=s}else{r=0;while(1){if(r>>>0>=2){t=-1;break L8244}bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(r<<2)>>2],c[h+8>>2]=88672,h)|0)|0;i=h;q=dJ(b|0,g|0)|0;if((q|0)>-1){t=q;break}else{r=r+1|0}}}}while(0);c[d+28>>2]=t;bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=(c[283002]|0)+5,c[h+8>>2]=86920,h)|0)|0;i=h;t=dJ(b|0,g|0)|0;L8249:do{if((t|0)>-1){u=t}else{s=0;while(1){if(s>>>0>=2){u=-1;break L8249}bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(s<<2)>>2],c[h+8>>2]=86920,h)|0)|0;i=h;r=dJ(b|0,g|0)|0;if((r|0)>-1){u=r;break}else{s=s+1|0}}}}while(0);c[d+32>>2]=u;bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=(c[283002]|0)+5,c[h+8>>2]=84976,h)|0)|0;i=h;u=dJ(b|0,g|0)|0;L8254:do{if((u|0)>-1){v=u}else{t=0;while(1){if(t>>>0>=2){v=-1;break L8254}bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(t<<2)>>2],c[h+8>>2]=84976,h)|0)|0;i=h;s=dJ(b|0,g|0)|0;if((s|0)>-1){v=s;break}else{t=t+1|0}}}}while(0);c[d+40>>2]=v;v=c[283002]|0;if((c[v+66444>>2]|0)!=0){g=0;u=v;do{c[d+44+(g<<2)>>2]=dJ(b|0,u+66448+(g*4168|0)|0)|0;g=g+1|0;u=c[283002]|0;}while(g>>>0<(c[u+66444>>2]|0)>>>0)}u=d+76|0;yG(u|0,-1|0,16);l7(b,u,82568);g=f|0;if(a>>>0>1){bR(g|0,64,80576,(h=i,i=i+8|0,c[h>>2]=a,h)|0)|0;i=h;l7(b,u,g);w=0}else{w=0}while(1){u=w+1|0;bR(g|0,64,78808,(h=i,i=i+8|0,c[h>>2]=u,h)|0)|0;i=h;f=d+92+(w<<4)|0;yG(f|0,-1|0,16);l7(b,f,g);if((w|0)!=0&u>>>0<a>>>0){v=a-w|0;bR(g|0,64,80576,(h=i,i=i+8|0,c[h>>2]=v,h)|0)|0;i=h;l7(b,f,g)}if(u>>>0<16){w=u}else{break}}w=d+348|0;yG(w|0,-1|0,16);l7(b,w,77544);bR(g|0,64,76144,(h=i,i=i+8|0,c[h>>2]=1,h)|0)|0;i=h;w=d+364|0;yG(w|0,-1|0,16);l7(b,w,g);bR(g|0,64,76144,(h=i,i=i+8|0,c[h>>2]=2,h)|0)|0;i=h;w=d+380|0;yG(w|0,-1|0,16);l7(b,w,g);bR(g|0,64,76144,(h=i,i=i+8|0,c[h>>2]=3,h)|0)|0;i=h;w=d+396|0;yG(w|0,-1|0,16);l7(b,w,g);bR(g|0,64,76144,(h=i,i=i+8|0,c[h>>2]=4,h)|0)|0;i=h;w=d+412|0;yG(w|0,-1|0,16);l7(b,w,g);bR(g|0,64,76144,(h=i,i=i+8|0,c[h>>2]=5,h)|0)|0;i=h;w=d+428|0;yG(w|0,-1|0,16);l7(b,w,g);bR(g|0,64,76144,(h=i,i=i+8|0,c[h>>2]=6,h)|0)|0;i=h;h=d+444|0;yG(h|0,-1|0,16);l7(b,h,g);ec(0);i=e;return}function l7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+320|0;f=e|0;g=e+64|0;bR(g|0,64,74880,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=73960,h)|0)|0;i=h;j=e+128|0;bR(j|0,64,74880,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=88672,h)|0)|0;i=h;k=e+192|0;bR(k|0,64,74880,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=92224,h)|0)|0;i=h;l=e+256|0;bR(l|0,64,74880,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=99752,h)|0)|0;i=h;d=b|0;if((c[d>>2]|0)<0){m=f|0;n=(c[283002]|0)+5|0;bR(m|0,64,74880,(h=i,i=i+16|0,c[h>>2]=n,c[h+8>>2]=g,h)|0)|0;i=h;n=dJ(a|0,m|0)|0;L8274:do{if((n|0)>-1){o=n}else{p=0;while(1){if(p>>>0>=2){o=-1;break L8274}bR(m|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(p<<2)>>2],c[h+8>>2]=g,h)|0)|0;i=h;q=dJ(a|0,m|0)|0;if((q|0)>-1){o=q;break}else{p=p+1|0}}}}while(0);c[d>>2]=o}o=b+8|0;if((c[o>>2]|0)<0){d=f|0;m=(c[283002]|0)+5|0;bR(d|0,64,74880,(h=i,i=i+16|0,c[h>>2]=m,c[h+8>>2]=j,h)|0)|0;i=h;m=dJ(a|0,d|0)|0;L8282:do{if((m|0)>-1){r=m}else{g=0;while(1){if(g>>>0>=2){r=-1;break L8282}bR(d|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(g<<2)>>2],c[h+8>>2]=j,h)|0)|0;i=h;n=dJ(a|0,d|0)|0;if((n|0)>-1){r=n;break}else{g=g+1|0}}}}while(0);c[o>>2]=r}r=b+4|0;if((c[r>>2]|0)<0){o=f|0;d=(c[283002]|0)+5|0;bR(o|0,64,74880,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=k,h)|0)|0;i=h;d=dJ(a|0,o|0)|0;L8290:do{if((d|0)>-1){s=d}else{j=0;while(1){if(j>>>0>=2){s=-1;break L8290}bR(o|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(j<<2)>>2],c[h+8>>2]=k,h)|0)|0;i=h;m=dJ(a|0,o|0)|0;if((m|0)>-1){s=m;break}else{j=j+1|0}}}}while(0);c[r>>2]=s}s=b+12|0;if((c[s>>2]|0)>=0){i=e;return}b=f|0;bR(b|0,64,74880,(h=i,i=i+16|0,c[h>>2]=(c[283002]|0)+5,c[h+8>>2]=l,h)|0)|0;i=h;f=dJ(a|0,b|0)|0;L8299:do{if((f|0)>-1){t=f}else{r=0;while(1){if(r>>>0>=2){t=-1;break L8299}bR(b|0,64,74880,(h=i,i=i+16|0,c[h>>2]=c[18952+(r<<2)>>2],c[h+8>>2]=l,h)|0)|0;i=h;o=eI(a|0,b|0)|0;if((o|0)>-1){t=o;break}else{r=r+1|0}}}}while(0);c[s>>2]=t;i=e;return}function l8(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=i;i=i+72|0;g=f|0;h=f+8|0;j=f+48|0;k=f+64|0;l=f+16|0;yG(l|0,0,32);do{if((a[1132040]&1)!=0){if((bw(e|0,58664)|0)!=0){break}m=((c[283004]|0)*10|0)+((c[283006]|0)*100|0)|0;if((m|0)==320){n=150}else if((m|0)==310){n=140}else if((m|0)==300){n=130}else{n=m}bR(l|0,32,58096,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;if((a[1243488]&1)==0){break}m=c[350134]|0;q=(m|0)!=0?m:c[p>>2]|0;en(q|0,57560,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;q=c[350134]|0;m=(q|0)!=0?q:c[p>>2]|0;a_(m|0)|0}}while(0);n=j|0;c[n>>2]=l;c[j+4>>2]=d;c[j+8>>2]=e;bW(b|0,3,n|0,0);be(b|0);cY(b|0,35713,k|0);c[g>>2]=0;cY(b|0,35716,h|0);n=c[h>>2]|0;if((n|0)==0){r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}h=yx(n)|0;if((h|0)==0){r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}ek(b|0,n|0,g|0,h|0);do{if((c[g>>2]|0)>0){if((a[1243488]&1)==0){break}n=c[350134]|0;b=(n|0)!=0?n:c[p>>2]|0;en(b|0,57064,(o=i,i=i+8|0,c[o>>2]=h,o)|0)|0;i=o;b=c[350134]|0;n=(b|0)!=0?b:c[p>>2]|0;a_(n|0)|0}}while(0);yz(h);r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}function l9(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[1418]|0;if((d|0)==0){return}else{e=5672;f=d}do{d=fv[b&127](f)|0;g=c[e+4>>2]|0;x=d;a[g]=x&255;x=x>>8;a[g+1|0]=x&255;x=x>>8;a[g+2|0]=x&255;x=x>>8;a[g+3|0]=x&255;e=e+8|0;f=c[e>>2]|0;}while((f|0)!=0);return}function ma(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0;switch(d[a+9|0]|0|0){case 3:{g=d[a+8|0]|0;h=((ab(c[a>>2]|0,g)|0)+7|0)>>>3;i=(g+7|0)>>>3;break};case 6:{g=(d[a+8|0]|0)<<2;h=((ab(g,c[a>>2]|0)|0)+7|0)>>>3;i=(g+7|0)>>>3;break};case 0:{g=d[a+8|0]|0;h=((ab(c[a>>2]|0,g)|0)+7|0)>>>3;i=(g+7|0)>>>3;break};case 2:{g=(d[a+8|0]|0)*3|0;h=((ab(g,c[a>>2]|0)|0)+7|0)>>>3;i=(g+7|0)>>>3;break};case 4:{g=(d[a+8|0]|0)<<1;h=((ab(g,c[a>>2]|0)|0)+7|0)>>>3;i=(g+7|0)>>>3;break};default:{h=0;i=0}}if((f|0)!=0){c[f>>2]=ab(c[a+4>>2]|0,h+1|0)|0}if((b|0)!=0){c[b>>2]=i}if((e|0)==0){return}c[e>>2]=h;return}function mb(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;h=i;i=i+1904|0;j=h|0;k=h+16|0;l=h+784|0;m=h+792|0;n=h+840|0;o=h+856|0;q=h+1888|0;c[e>>2]=0;c[f>>2]=0;c[g>>2]=0;r=dc(b|0,90352)|0;if((r|0)==0){s=0;i=h;return s|0}eC(r|0,0,2)|0;b=ci(r|0)|0;eK(r|0);yG(m|0,0,48);t=n;c[t>>2]=c[1294];c[t+4>>2]=c[1295];c[t+8>>2]=c[1296];c[t+12>>2]=c[1297];yG(o|0,0,1024);u=h+1880|0;L8355:do{if((eh(u|0,1,8,r|0)|0)==8){L8357:do{if((yO(u|0,14792,8)|0)==0){v=ci(r|0)|0;do{if((v|0)<(b|0)&(v|0)>-1){w=q;x=l;y=x+1|0;z=x+2|0;A=x+3|0;B=q|0;C=q+4|0;D=q+8|0;E=n|0;F=n+4|0;G=n+8|0;H=n+9|0;I=n+10|0;J=n+11|0;K=n+12|0;L=k|0;M=0;N=0;O=0;P=0;Q=0;R=0;L8362:while(1){yG(w|0,0,12);c[l>>2]=0;if((eh(x|0,1,4,r|0)|0)!=4){S=6281;break}c[B>>2]=d[y]<<16|d[x]<<24|d[z]<<8|d[A];if((eh(C|0,1,4,r|0)|0)==4){T=0}else{S=6281;break}while(1){if(T>>>0>=4){S=6285;break}if((yO(C|0,c[22720+(T<<3)>>2]|0,4)|0)==0){S=6284;break}else{T=T+1|0}}L8368:do{if((S|0)==6284){S=0;switch(c[22724+(T<<3)>>2]|0){case 5:{if(!(O&P)){S=6333;break L8362}if((eC(r|0,4,1)|0)<0){S=6335;break L8362}else{U=R;V=1;W=1;X=1;Y=N;Z=M;break L8368}break};case 2:{if(O|P|Q){S=6289;break L8362}yz(c[D>>2]|0);_=c[B>>2]|0;$=_+4|0;aa=yy(1,$)|0;c[D>>2]=aa;if((aa|0)==0){break L8362}if((eh(aa|0,1,$|0,r|0)|0)!=($|0)){S=6292;break L8362}if((_|0)!=13){S=6294;break L8362}_=d[aa+1|0]<<16|d[aa]<<24|d[aa+2|0]<<8|d[aa+3|0];c[E>>2]=_;$=d[aa+5|0]<<16|d[aa+4|0]<<24|d[aa+6|0]<<8|d[aa+7|0];c[F>>2]=$;ac=a[aa+8|0]|0;a[G]=ac;ad=a[aa+9|0]|0;a[H]=ad;ae=a[aa+10|0]|0;a[I]=ae;a[J]=a[aa+11|0]|0;a[K]=a[aa+12|0]|0;if((_|0)==0|($|0)==0){S=6296;break L8362}switch(ad<<24>>24){case 2:case 4:case 6:{if(!((ac<<24>>24|0)==8|(ac<<24>>24|0)==16)){S=6301;break L8362}break};case 0:{ad=ac&255;$=0;while(1){if($>>>0>=5){S=6304;break L8362}if((c[14768+($<<2)>>2]|0)==(ad|0)){break}else{$=$+1|0}}break};case 3:{$=ac&255;ad=0;while(1){if(ad>>>0>=4){S=6307;break L8362}if((c[14752+(ad<<2)>>2]|0)==($|0)){break}else{ad=ad+1|0}}break};default:{S=6308;break L8362}}if(ae<<24>>24!=0){S=6310;break L8362}yz(aa);c[D>>2]=0;U=R;V=0;W=0;X=1;Y=N;Z=M;break L8368;break};case 4:{if(R|O^1|Q|P){S=6315;break L8362}ad=c[B>>2]|0;if(((ad>>>0)%3|0|0)!=0){S=6317;break L8362}$=(ad>>>0)/3|0;if(ad>>>0>770){S=6323;break L8362}if((eh(L|0,3,$|0,r|0)|0)!=($|0)){S=6323;break L8362}if(ad>>>0>=3){ad=0;do{ac=ad*3|0;c[o+(ad<<2)>>2]=d[k+ac|0]<<16|d[k+(ac+1)|0]<<8|d[k+(ac+2)|0]|-16777216;ad=ad+1|0;}while(ad>>>0<$>>>0)}if((eC(r|0,4,1)|0)>-1){U=1;V=0;W=0;X=O;Y=N;Z=M;break L8368}else{S=6323;break L8362}break};case 1:{S=6287;break L8362;break};case 3:{if(Q|O^1){S=6326;break L8362}if(!((a[H]|0)!=3|R)){S=6326;break L8362}$=yA(N,(c[B>>2]|0)+M|0)|0;if(($|0)==0){af=N;S=6331;break L8362}ad=c[B>>2]|0;if((eh($+M|0,1,ad|0,r|0)|0)!=(ad|0)){af=$;S=6331;break L8362}if((eC(r|0,4,1)|0)<0){af=$;S=6331;break L8362}U=R;V=0;W=1;X=O;Y=$;Z=ad+M|0;break L8368;break};default:{S=6285;break L8368}}}}while(0);if((S|0)==6285){S=0;if((eC(r|0,(c[B>>2]|0)+4|0,1)|0)<0){S=6286;break}else{U=R;V=Q;W=P;X=O;Y=N;Z=M}}ad=ci(r|0)|0;if((ad|0)<(b|0)&(ad|0)>-1){M=Z;N=Y;O=X;P=W;Q=V;R=U}else{S=6337;break}}if((S|0)==6281){R=c[p>>2]|0;en(R|0,102936,(ag=i,i=i+8|0,c[ag>>2]=613,ag)|0)|0;i=ag;ah=0;ai=N;break L8357}else if((S|0)==6301){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=170,ag)|0)|0;i=ag;S=6311}else if((S|0)==6337){if(!(X&W&V)){aj=Y;break}if((mg(m)|0)!=0){R=c[p>>2]|0;en(R|0,102936,(ag=i,i=i+8|0,c[ag>>2]=675,ag)|0)|0;i=ag;ah=0;ai=Y;break L8357}R=n|0;Q=n+4|0;switch(d[n+9|0]|0){case 2:{ak=((ab((d[n+8|0]|0)*3|0,c[R>>2]|0)|0)+7|0)>>>3;break};case 6:{ak=((ab(d[n+8|0]<<2,c[R>>2]|0)|0)+7|0)>>>3;break};case 0:{ak=((ab(c[R>>2]|0,d[n+8|0]|0)|0)+7|0)>>>3;break};case 3:{ak=((ab(c[R>>2]|0,d[n+8|0]|0)|0)+7|0)>>>3;break};case 4:{ak=((ab(d[n+8|0]<<1,c[R>>2]|0)|0)+7|0)>>>3;break};default:{ak=0}}P=c[Q>>2]|0;O=ab(P,ak+1|0)|0;M=(a[n+12|0]|0)==1;B=O<<(M&1);O=yx(B)|0;if((O|0)==0){H=c[p>>2]|0;en(H|0,102936,(ag=i,i=i+8|0,c[ag>>2]=683,ag)|0)|0;i=ag;ah=0;ai=Y;break L8357}c[m>>2]=Y;c[m+4>>2]=Z;c[m+16>>2]=B;c[m+12>>2]=O;B=(mh(m,4)|0)==1;mj(m)|0;if(!B){B=c[p>>2]|0;en(B|0,102936,(ag=i,i=i+8|0,c[ag>>2]=693,ag)|0)|0;i=ag;ah=O;ai=Y;break L8357}B=c[R>>2]|0;c[f>>2]=B;c[g>>2]=P;H=yx(ab(B<<2,P)|0)|0;P=H;c[e>>2]=P;if((H|0)==0){H=c[p>>2]|0;en(H|0,102936,(ag=i,i=i+8|0,c[ag>>2]=701,ag)|0)|0;i=ag;ah=O;ai=Y;break L8357}H=c[m+20>>2]|0;L=o|0;L8433:do{if(M){K=j;J=j|0;I=j+4|0;G=j+9|0;F=j+8|0;E=0;C=H;A=O;z=B;L8437:while(1){x=c[14640+(E<<4)>>2]|0;do{if(z>>>0>x>>>0){y=c[Q>>2]|0;w=c[14644+(E<<4)>>2]|0;if(y>>>0<=w>>>0){al=A;am=C;break}ad=c[14648+(E<<4)>>2]|0;$=((z-1-x+ad|0)>>>0)/(ad>>>0)|0;ae=c[14652+(E<<4)>>2]|0;ac=((y-1-w+ae|0)>>>0)/(ae>>>0)|0;y=$<<2;an=yx(ab(y,ac)|0)|0;_=an;if((an|0)==0){break L8437}c[K>>2]=c[t>>2];c[K+4>>2]=c[t+4>>2];c[K+8>>2]=c[t+8>>2];c[K+12>>2]=c[t+12>>2];c[J>>2]=$;c[I>>2]=ac;switch(d[G]|0){case 6:{ao=((ab(y,d[F]|0)|0)+7|0)>>>3;break};case 3:{ao=((ab(d[F]|0,$)|0)+7|0)>>>3;break};case 4:{ao=((ab($<<1,d[F]|0)|0)+7|0)>>>3;break};case 0:{ao=((ab(d[F]|0,$)|0)+7|0)>>>3;break};case 2:{ao=((ab($*3|0,d[F]|0)|0)+7|0)>>>3;break};default:{ao=0}}y=ab(ao+1|0,ac)|0;if(y>>>0>C>>>0){S=6365;break L8437}if(!(mc(_,j,A,y,L)|0)){S=6367;break L8437}ap=A+y|0;aq=C-y|0;if(!((ac|0)==0|($|0)==0)){y=_;_=P+((ab(c[R>>2]|0,w)|0)+x<<2)|0;w=0;while(1){ar=_;as=0;while(1){c[ar>>2]=c[y+(as<<2)>>2];at=as+1|0;if(at>>>0<$>>>0){ar=ar+(ad<<2)|0;as=at}else{break}}as=w+1|0;ar=_+((ab(c[R>>2]|0,ae)|0)<<2)|0;if(as>>>0<ac>>>0){y=y+($<<2)|0;_=ar;w=as}else{break}}}yz(an);al=ap;am=aq}else{al=A;am=C}}while(0);x=E+1|0;if(x>>>0>=7){break L8433}E=x;C=am;A=al;z=c[R>>2]|0}if((S|0)==6367){yz(an)}else if((S|0)==6365){yz(an)}en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=706,ag)|0)|0;i=ag;ah=O;ai=Y;break L8357}else{if(mc(P,n,O,H,L)|0){break}en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=709,ag)|0)|0;i=ag;ah=O;ai=Y;break L8357}}while(0);aS(r|0)|0;au=O;av=1;aw=Y;break L8355}else if((S|0)==6307){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=202,ag)|0)|0;i=ag;S=6311}else if((S|0)==6308){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=205,ag)|0)|0;i=ag;S=6311}else if((S|0)==6310){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=217,ag)|0)|0;i=ag;S=6311}else if((S|0)==6326){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=651,ag)|0)|0;i=ag;ah=0;ai=N;break L8357}else if((S|0)==6296){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=165,ag)|0)|0;i=ag;S=6311}else if((S|0)==6294){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=154,ag)|0)|0;i=ag;S=6311}else if((S|0)==6331){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=654,ag)|0)|0;i=ag;ah=0;ai=af;break L8357}else if((S|0)==6333){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=661,ag)|0)|0;i=ag;ah=0;ai=N;break L8357}else if((S|0)==6335){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=664,ag)|0)|0;i=ag;ah=0;ai=N;break L8357}else if((S|0)==6286){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=620,ag)|0)|0;i=ag;ah=0;ai=N;break L8357}else if((S|0)==6292){yz(aa)}else if((S|0)==6304){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=186,ag)|0)|0;i=ag;S=6311}else if((S|0)==6317){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=641,ag)|0)|0;i=ag;ah=0;ai=N;break L8357}else if((S|0)==6315){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=638,ag)|0)|0;i=ag;ah=0;ai=N;break L8357}else if((S|0)==6323){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=644,ag)|0)|0;i=ag;ah=0;ai=N;break L8357}else if((S|0)==6287){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=624,ag)|0)|0;i=ag;ah=0;ai=N;break L8357}else if((S|0)==6289){en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=628,ag)|0)|0;i=ag;ah=0;ai=N;break L8357}if((S|0)==6311){yz(aa);c[D>>2]=0}en(c[p>>2]|0,102936,(ag=i,i=i+8|0,c[ag>>2]=631,ag)|0)|0;i=ag;ah=0;ai=N;break L8357}else{aj=0}}while(0);v=c[p>>2]|0;en(v|0,102936,(ag=i,i=i+8|0,c[ag>>2]=672,ag)|0)|0;i=ag;ah=0;ai=aj}else{v=c[p>>2]|0;en(v|0,102936,(ag=i,i=i+8|0,c[ag>>2]=606,ag)|0)|0;i=ag;ah=0;ai=0}}while(0);aS(r|0)|0;ax=ah;ay=ai;S=6381}else{v=c[p>>2]|0;en(v|0,102936,(ag=i,i=i+8|0,c[ag>>2]=603,ag)|0)|0;i=ag;aS(r|0)|0;ax=0;ay=0;S=6381}}while(0);if((S|0)==6381){yz(c[e>>2]|0);au=ax;av=0;aw=ay}yz(aw);yz(au);s=av;i=h;return s|0}function mc(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;j=i;i=i+24|0;k=j|0;l=j+8|0;m=j+16|0;n=e|0;o=e+4|0;ma(e,k,l,m);if((c[m>>2]|0)>>>0>g>>>0){q=0;i=j;return q|0}g=c[l>>2]|0;m=yy(1,g)|0;r=yy(1,g)|0;L8498:do{if((r|0)==0){s=c[p>>2]|0;en(s|0,102936,(t=i,i=i+8|0,c[t>>2]=394,t)|0)|0;i=t;u=0}else{if((c[o>>2]|0)==0){u=1;break}s=e+9|0;v=e+8|0;w=0;x=f;y=b;z=g;L8501:while(1){L8503:do{switch(d[x]|0){case 4:{A=c[k>>2]|0;if((A|0)==0){B=0}else{C=0;while(1){D=C+1|0;a[r+C|0]=(a[x+D|0]|0)+(a[m+C|0]|0)&255;if(D>>>0<A>>>0){C=D}else{B=A;break}}}if(B>>>0<z>>>0){E=B}else{break L8503}while(1){A=E-B|0;C=a[r+A|0]|0;D=C&255;F=a[m+E|0]|0;G=F&255;H=a[m+A|0]|0;A=H&255;I=G+D-A|0;J=I-D|0;D=(J|0)>-1?J:-J|0;J=I-G|0;G=(J|0)>-1?J:-J|0;J=I-A|0;A=(J|0)>-1?J:-J|0;if((D|0)>(G|0)|(D|0)>(A|0)){K=(G|0)>(A|0)?H:F}else{K=C}C=E+1|0;a[r+E|0]=(a[x+C|0]|0)+K&255;if(C>>>0<z>>>0){E=C}else{break}}break};case 2:{if((z|0)==0){break L8503}else{L=0}while(1){C=L+1|0;a[r+L|0]=(a[x+C|0]|0)+(a[m+L|0]|0)&255;if(C>>>0<z>>>0){L=C}else{break}}break};case 0:{C=x+1|0;yJ(r|0,C|0,z)|0;break};case 1:{C=c[k>>2]|0;if((C|0)==0){M=0}else{F=0;while(1){H=F+1|0;a[r+F|0]=a[x+H|0]|0;if(H>>>0<C>>>0){F=H}else{M=C;break}}}if(M>>>0<z>>>0){N=M}else{break L8503}while(1){C=N+1|0;a[r+N|0]=(a[x+C|0]|0)+(a[r+(N-M)|0]|0)&255;if(C>>>0<z>>>0){N=C}else{break}}break};case 3:{C=c[k>>2]|0;if((C|0)==0){O=0}else{F=0;while(1){H=F+1|0;a[r+F|0]=((d[m+F|0]|0)>>>1)+(a[x+H|0]|0)&255;if(H>>>0<C>>>0){F=H}else{O=C;break}}}if(O>>>0<z>>>0){P=O}else{break L8503}while(1){C=P+1|0;a[r+P|0]=(((d[m+P|0]|0)+(d[r+(P-O)|0]|0)|0)>>>1)+(d[x+C|0]|0)&255;if(C>>>0<z>>>0){P=C}else{break}}break};default:{break L8501}}}while(0);L8533:do{switch(a[s]|0){case 0:{C=c[n>>2]|0;F=a[v]|0;H=F&255;if(F<<24>>24==16){if((C|0)==0){break L8533}else{Q=0}while(1){c[y+(Q<<2)>>2]=(d[r+(Q<<1)|0]|0)*65793|0|-16777216;Q=Q+1|0;if(Q>>>0>=C>>>0){break L8533}}}F=(1<<H)-1|0;if((C|0)==0){break L8533}A=8-H|0;G=(c[21320+(H<<2)>>2]|0)*65793|0;D=0;J=0;while(1){c[y+(J<<2)>>2]=ab(G,(d[r+(D>>>3)|0]|0)>>>((A-(D&7)|0)>>>0)&F)|0|-16777216;I=J+1|0;if(I>>>0<C>>>0){D=D+H|0;J=I}else{break}}break};case 2:{J=c[n>>2]|0;H=(d[v]|0)>>>3;if((J|0)==0){break L8533}D=H<<1;C=D+H|0;F=0;A=r;while(1){c[y+(F<<2)>>2]=d[A]<<16|d[A+H|0]<<8|d[A+D|0]|-16777216;G=F+1|0;if(G>>>0<J>>>0){F=G;A=A+C|0}else{break}}break};case 3:{C=c[n>>2]|0;A=d[v]|0;F=(1<<A)-1|0;if((C|0)==0){break L8533}J=8-A|0;D=0;H=0;while(1){c[y+(H<<2)>>2]=c[h+(((d[r+(D>>>3)|0]|0)>>>((J-(D&7)|0)>>>0)&F)<<2)>>2];G=H+1|0;if(G>>>0<C>>>0){D=D+A|0;H=G}else{break}}break};case 4:{H=c[n>>2]|0;A=(d[v]|0)>>>3;if((H|0)==0){break L8533}D=A<<1;C=0;F=r;while(1){c[y+(C<<2)>>2]=d[F+A|0]<<24|((d[F]|0)*65793|0);J=C+1|0;if(J>>>0<H>>>0){C=J;F=F+D|0}else{break}}break};case 6:{D=c[n>>2]|0;F=(d[v]|0)>>>3;if((D|0)==0){break L8533}C=F<<1;H=C+F|0;A=H+F|0;J=0;G=r;while(1){c[y+(J<<2)>>2]=d[G+F|0]<<8|d[G]<<16|d[G+C|0]|d[G+H|0]<<24;I=J+1|0;if(I>>>0<D>>>0){J=I;G=G+A|0}else{break}}break};default:{}}}while(0);A=c[l>>2]|0;yJ(m|0,r|0,A)|0;G=w+1|0;if(G>>>0<(c[o>>2]|0)>>>0){w=G;x=x+(A+1)|0;y=y+(c[n>>2]<<2)|0;z=A}else{u=1;break L8498}}en(c[p>>2]|0,102936,(t=i,i=i+8|0,c[t>>2]=439,t)|0)|0;i=t;u=0}}while(0);yz(r);yz(m);q=u;i=j;return q|0}function md(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;i=i+8248|0;h=g|0;j=g+48|0;k=g+56|0;l=g+4152|0;if((f|0)==0){m=c[350134]|0;n=(m|0)!=0?m:c[p>>2]|0;a5(90064,116,1,n|0)|0;n=c[350134]|0;m=(n|0)!=0?n:c[p>>2]|0;a_(m|0)|0;o=0;i=g;return o|0}m=gY(f,102928)|0;if((m|0)==0){o=0;i=g;return o|0}c[j>>2]=0;f=gJ(b,j)|0;L8572:do{if((f|0)<22){n=c[350134]|0;q=(n|0)!=0?n:c[p>>2]|0;en(q|0,83312,(r=i,i=i+8|0,c[r>>2]=107,r)|0)|0;i=r;q=c[350134]|0;n=(q|0)!=0?q:c[p>>2]|0;a_(n|0)|0;s=0}else{n=f-22|0;L8575:do{if((n|0)>22){q=c[j>>2]|0;t=q+f|0;u=q+22|0;v=q+n|0;while(1){if(((d[v+3|0]|0)<<24|((d[v+2|0]|0)<<16|((d[v+1|0]|0)<<8|(d[v]|0)))|0)==101010256){if((v+(((d[v+21|0]|0)<<8|(d[v+20|0]|0))+22)|0)==(t|0)){break}}w=v-1|0;if(w>>>0>u>>>0){v=w}else{break L8575}}u=k|0;t=q+((d[v+19|0]|0)<<24|((d[v+18|0]|0)<<16|((d[v+17|0]|0)<<8|(d[v+16|0]|0))))|0;while(1){if(((d[t+3|0]|0)<<24|((d[t+2|0]|0)<<16|((d[t+1|0]|0)<<8|(d[t]|0)))|0)!=33639248){x=6470;break}y=(d[t+19|0]|0)<<24|((d[t+18|0]|0)<<16|((d[t+17|0]|0)<<8|(d[t+16|0]|0)));z=(d[t+23|0]|0)<<24|((d[t+22|0]|0)<<16|((d[t+21|0]|0)<<8|(d[t+20|0]|0)));A=(d[t+27|0]|0)<<24|((d[t+26|0]|0)<<16|((d[t+25|0]|0)<<8|(d[t+24|0]|0)));w=(d[t+29|0]|0)<<8|(d[t+28|0]|0);B=(d[t+33|0]|0)<<8|(d[t+32|0]|0);C=(d[t+31|0]|0)<<8|(d[t+30|0]|0);D=(d[t+11|0]|0)<<8|(d[t+10|0]|0);yG(u|0,0,4096);if(w>>>0>4095){x=6448;break}E=t+46|0;yJ(u|0,E|0,w)|0;E=(d[t+45|0]|0)<<24|((d[t+44|0]|0)<<16|((d[t+43|0]|0)<<8|(d[t+42|0]|0)));F=c[j>>2]|0;G=E+30+((d[F+(E+27)|0]|0)<<8|(d[F+(E+26)|0]|0))+((d[F+(E+29)|0]|0)<<8|(d[F+(E+28)|0]|0))|0;H=F+G|0;if((a[1243488]&1)!=0){F=c[350134]|0;E=(F|0)!=0?F:c[p>>2]|0;en(E|0,69664,(r=i,i=i+24|0,c[r>>2]=G,c[r+8>>2]=z,c[r+16>>2]=A,r)|0)|0;i=r;G=c[350134]|0;E=(G|0)!=0?G:c[p>>2]|0;a_(E|0)|0}E=gU(u)|0;if((E|0)!=0){if(gT(m,E)|0){x=6453;break}}t=t+(w+46+C+B)|0}if((x|0)==6470){t=c[350134]|0;v=(t|0)!=0?t:c[p>>2]|0;a5(60032,101,1,v|0)|0;v=c[350134]|0;t=(v|0)!=0?v:c[p>>2]|0;a_(t|0)|0;t=c[350134]|0;v=(t|0)!=0?t:c[p>>2]|0;en(v|0,83312,(r=i,i=i+8|0,c[r>>2]=186,r)|0)|0;i=r;v=c[350134]|0;t=(v|0)!=0?v:c[p>>2]|0;a_(t|0)|0;s=0;break L8572}else if((x|0)==6453){t=l|0;hd(t,b,g0(u)|0,4096);if((D|0)==8){v=yx(A)|0;if((v|0)!=0){yG(h|0,0,48);do{if((mf(h,-15)|0)==0){c[h>>2]=H;c[h+4>>2]=z;c[h+12>>2]=v;c[h+16>>2]=A;q=(mh(h,4)|0)==1;mj(h)|0;if(!q){q=c[350134]|0;B=(q|0)!=0?q:c[p>>2]|0;en(B|0,83312,(r=i,i=i+8|0,c[r>>2]=71,r)|0)|0;i=r;B=c[350134]|0;q=(B|0)!=0?B:c[p>>2]|0;a_(q|0)|0;break}q=me(0,v,A)|0;if((q|0)!=(y|0)){B=c[350134]|0;C=(B|0)!=0?B:c[p>>2]|0;en(C|0,54344,(r=i,i=i+16|0,c[r>>2]=q,c[r+8>>2]=y,r)|0)|0;i=r;q=c[350134]|0;C=(q|0)!=0?q:c[p>>2]|0;a_(C|0)|0}if(gI(t,v,A)|0){yz(v);i5(b,t,e)|0;s=1;break L8572}else{C=c[350134]|0;q=(C|0)!=0?C:c[p>>2]|0;en(q|0,83312,(r=i,i=i+8|0,c[r>>2]=81,r)|0)|0;i=r;q=c[350134]|0;C=(q|0)!=0?q:c[p>>2]|0;a_(C|0)|0;break}}else{C=c[350134]|0;q=(C|0)!=0?C:c[p>>2]|0;en(q|0,83312,(r=i,i=i+8|0,c[r>>2]=61,r)|0)|0;i=r;q=c[350134]|0;C=(q|0)!=0?q:c[p>>2]|0;a_(C|0)|0}}while(0);yz(v)}u=c[350134]|0;C=(u|0)!=0?u:c[p>>2]|0;en(C|0,83312,(r=i,i=i+8|0,c[r>>2]=175,r)|0)|0;i=r;C=c[350134]|0;u=(C|0)!=0?C:c[p>>2]|0;a_(u|0)|0;s=0;break L8572}else if((D|0)==0){if(gI(t,H,A)|0){s=1;break L8572}u=c[350134]|0;en(((u|0)!=0?u:c[p>>2]|0)|0,83312,(r=i,i=i+8|0,c[r>>2]=165,r)|0)|0;i=r;u=c[350134]|0;a_(((u|0)!=0?u:c[p>>2]|0)|0)|0;s=0;break L8572}else{u=c[350134]|0;en(((u|0)!=0?u:c[p>>2]|0)|0,83312,(r=i,i=i+8|0,c[r>>2]=178,r)|0)|0;i=r;u=c[350134]|0;a_(((u|0)!=0?u:c[p>>2]|0)|0)|0;s=0;break L8572}}else if((x|0)==6448){u=c[350134]|0;en(((u|0)!=0?u:c[p>>2]|0)|0,83312,(r=i,i=i+8|0,c[r>>2]=141,r)|0)|0;i=r;u=c[350134]|0;a_(((u|0)!=0?u:c[p>>2]|0)|0)|0;s=0;break L8572}}}while(0);n=c[350134]|0;u=(n|0)!=0?n:c[p>>2]|0;en(u|0,83312,(r=i,i=i+8|0,c[r>>2]=113,r)|0)|0;i=r;u=c[350134]|0;n=(u|0)!=0?u:c[p>>2]|0;a_(n|0)|0;s=0}}while(0);yz(c[j>>2]|0);gS(m);o=s;i=g;return o|0}function me(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==0){f=0;return f|0}g=~a;if((e|0)==0){h=g}else{a=e;e=b;b=g;while(1){g=a-1|0;i=d[e]|0;j=c[21256+(((i^b)&15)<<2)>>2]^b>>>4;k=j>>>4^c[21256+((j&15^i>>>4)<<2)>>2];if((g|0)==0){h=k;break}else{a=g;e=e+1|0;b=k}}}f=~h;return f|0}function mf(a,b){a=a|0;b=b|0;var d=0,e=0;if((a|0)==0){d=-2;return d|0}if(!((b|0)==15|(b|0)==(-15|0))){d=-1e4;return d|0}c[a+36>>2]=0;c[a+40>>2]=0;c[a+24>>2]=0;c[a+8>>2]=0;c[a+20>>2]=0;c[a+44>>2]=0;e=yx(43784)|0;if((e|0)==0){d=-4;return d|0}c[a+28>>2]=e;c[e>>2]=0;c[e+10992>>2]=0;c[e+10996>>2]=0;c[e+43780>>2]=1;c[e+11e3>>2]=1;c[e+11004>>2]=0;c[e+11008>>2]=b;d=0;return d|0}function mg(a){a=a|0;var b=0,d=0;if((a|0)==0){b=-2;return b|0}c[a+36>>2]=0;c[a+40>>2]=0;c[a+24>>2]=0;c[a+8>>2]=0;c[a+20>>2]=0;c[a+44>>2]=0;d=yx(43784)|0;if((d|0)==0){b=-4;return b|0}c[a+28>>2]=d;c[d>>2]=0;c[d+10992>>2]=0;c[d+10996>>2]=0;c[d+43780>>2]=1;c[d+11e3>>2]=1;c[d+11004>>2]=0;c[d+11008>>2]=15;b=0;return b|0}function mh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=i;i=i+16|0;e=d|0;f=d+8|0;if((a|0)==0){g=-2;i=d;return g|0}h=c[a+28>>2]|0;if((h|0)==0){g=-2;i=d;return g|0}j=(b|0)==1?2:b;b=(j|0)!=4;if(!((j|0)==4|(j|0)==2|(j|0)==0)){g=-2;i=d;return g|0}k=h;l=(c[k+11008>>2]|0)>0?9:8;m=a+4|0;n=c[m>>2]|0;o=k+11e3|0;p=c[o>>2]|0;c[o>>2]=0;o=k+43780|0;if((c[o>>2]|0)<0){g=-3;i=d;return g|0}q=k+11004|0;r=c[q>>2]|0;if(!((r|0)==0|b^1)){g=-2;i=d;return g|0}s=(j|0)==4;c[q>>2]=r|s&1;if(!((p|0)==0|s^1)){c[e>>2]=c[m>>2];p=a+16|0;c[f>>2]=c[p>>2];r=h;q=a|0;j=a+12|0;t=c[j>>2]|0;u=mi(r,c[q>>2]|0,e,t,t,f,l|4)|0;c[o>>2]=u;t=c[e>>2]|0;c[q>>2]=(c[q>>2]|0)+t;c[m>>2]=(c[m>>2]|0)-t;q=a+8|0;c[q>>2]=(c[q>>2]|0)+t;c[a+40>>2]=c[r+28>>2];r=c[f>>2]|0;c[j>>2]=(c[j>>2]|0)+r;c[p>>2]=(c[p>>2]|0)-r;p=a+20|0;c[p>>2]=(c[p>>2]|0)+r;if((u|0)<0){g=-3;i=d;return g|0}if((u|0)==0){g=1;i=d;return g|0}c[o>>2]=-1;g=-5;i=d;return g|0}u=b?l|2:l;l=k+10996|0;b=c[l>>2]|0;if((b|0)!=0){r=a+16|0;p=c[r>>2]|0;j=b>>>0<p>>>0?b:p;p=a+12|0;b=c[p>>2]|0;t=k+10992|0;q=(c[t>>2]|0)+(k+11012)|0;yJ(b|0,q|0,j)|0;c[p>>2]=(c[p>>2]|0)+j;c[r>>2]=(c[r>>2]|0)-j;r=a+20|0;c[r>>2]=(c[r>>2]|0)+j;r=c[l>>2]|0;c[l>>2]=r-j;c[t>>2]=(c[t>>2]|0)+j&32767;if((c[o>>2]|0)!=0){g=0;i=d;return g|0}g=(r|0)==(j|0)|0;i=d;return g|0}j=k+10992|0;r=h;h=a|0;t=k+11012|0;p=a+8|0;q=r+28|0;b=a+40|0;v=a+16|0;w=a+12|0;x=a+20|0;a=c[j>>2]|0;L8682:do{if((n|0)==0){y=a;while(1){c[e>>2]=c[m>>2];c[f>>2]=32768-y;z=mi(r,c[h>>2]|0,e,t,k+11012+y|0,f,u)|0;c[o>>2]=z;A=c[e>>2]|0;c[h>>2]=(c[h>>2]|0)+A;c[m>>2]=(c[m>>2]|0)-A;c[p>>2]=(c[p>>2]|0)+A;c[b>>2]=c[q>>2];A=c[f>>2]|0;c[l>>2]=A;B=c[v>>2]|0;C=A>>>0<B>>>0?A:B;B=c[w>>2]|0;A=(c[j>>2]|0)+(k+11012)|0;yJ(B|0,A|0,C)|0;c[w>>2]=(c[w>>2]|0)+C;c[v>>2]=(c[v>>2]|0)-C;c[x>>2]=(c[x>>2]|0)+C;A=c[l>>2]|0;B=A-C|0;c[l>>2]=B;D=(c[j>>2]|0)+C&32767;c[j>>2]=D;if((z|0)<0){g=-3;E=6542;break}if((z|0)==1){g=-5;E=6533;break}F=(z|0)==0;if(s){if(F){G=B;E=6525;break L8682}if((c[v>>2]|0)==0){g=-5;E=6543;break}else{y=D;continue}}if(F){H=B;E=6529;break L8682}if((c[m>>2]|0)==0){g=0;E=6540;break}if((c[v>>2]|0)!=0&(A|0)==(C|0)){y=D}else{g=0;E=6550;break}}if((E|0)==6550){i=d;return g|0}else if((E|0)==6540){i=d;return g|0}else if((E|0)==6543){i=d;return g|0}else if((E|0)==6542){i=d;return g|0}else if((E|0)==6533){i=d;return g|0}}else{if(s){y=a;while(1){c[e>>2]=c[m>>2];c[f>>2]=32768-y;D=mi(r,c[h>>2]|0,e,t,k+11012+y|0,f,u)|0;c[o>>2]=D;C=c[e>>2]|0;c[h>>2]=(c[h>>2]|0)+C;c[m>>2]=(c[m>>2]|0)-C;c[p>>2]=(c[p>>2]|0)+C;c[b>>2]=c[q>>2];C=c[f>>2]|0;c[l>>2]=C;A=c[v>>2]|0;B=C>>>0<A>>>0?C:A;A=c[w>>2]|0;C=(c[j>>2]|0)+(k+11012)|0;yJ(A|0,C|0,B)|0;c[w>>2]=(c[w>>2]|0)+B;c[v>>2]=(c[v>>2]|0)-B;c[x>>2]=(c[x>>2]|0)+B;C=(c[l>>2]|0)-B|0;c[l>>2]=C;A=(c[j>>2]|0)+B&32767;c[j>>2]=A;if((D|0)<0){g=-3;E=6545;break}if((D|0)==0){G=C;E=6525;break L8682}if((c[v>>2]|0)==0){g=-5;E=6541;break}else{y=A}}if((E|0)==6545){i=d;return g|0}else if((E|0)==6541){i=d;return g|0}}else{I=a}while(1){c[e>>2]=c[m>>2];c[f>>2]=32768-I;y=mi(r,c[h>>2]|0,e,t,k+11012+I|0,f,u)|0;c[o>>2]=y;A=c[e>>2]|0;c[h>>2]=(c[h>>2]|0)+A;c[m>>2]=(c[m>>2]|0)-A;c[p>>2]=(c[p>>2]|0)+A;c[b>>2]=c[q>>2];A=c[f>>2]|0;c[l>>2]=A;C=c[v>>2]|0;D=A>>>0<C>>>0?A:C;C=c[w>>2]|0;A=(c[j>>2]|0)+(k+11012)|0;yJ(C|0,A|0,D)|0;c[w>>2]=(c[w>>2]|0)+D;c[v>>2]=(c[v>>2]|0)-D;c[x>>2]=(c[x>>2]|0)+D;A=c[l>>2]|0;C=A-D|0;c[l>>2]=C;B=(c[j>>2]|0)+D&32767;c[j>>2]=B;if((y|0)<0){g=-3;E=6537;break}if((y|0)==0){H=C;E=6529;break L8682}if((c[m>>2]|0)==0){g=0;E=6534;break}if((c[v>>2]|0)!=0&(A|0)==(D|0)){I=B}else{g=0;E=6548;break}}if((E|0)==6537){i=d;return g|0}else if((E|0)==6548){i=d;return g|0}else if((E|0)==6534){i=d;return g|0}}}while(0);if((E|0)==6525){g=(G|0)!=0?-5:1;i=d;return g|0}else if((E|0)==6529){g=(H|0)==0|0;i=d;return g|0}return 0}function mi(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gg=0,gh=0,gi=0,gj=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0,hB=0,hC=0,hD=0,hE=0,hF=0,hG=0,hH=0,hI=0,hJ=0,hK=0,hL=0,hM=0,hN=0,hO=0,hP=0,hQ=0,hR=0,hS=0,hT=0,hU=0,hV=0,hW=0,hX=0,hY=0,hZ=0,h_=0,h$=0,h0=0,h1=0,h2=0,h3=0,h4=0,h5=0,h6=0,h7=0,h8=0,h9=0,ia=0,ib=0,ic=0,id=0,ie=0,ig=0,ih=0,ii=0,ij=0,ik=0,il=0,im=0,io=0,ip=0,iq=0,ir=0,is=0,it=0,iu=0,iv=0,iw=0,ix=0,iy=0,iz=0,iA=0,iB=0,iC=0,iD=0,iE=0,iF=0,iG=0,iH=0,iI=0,iJ=0,iK=0,iL=0,iM=0,iN=0,iO=0,iP=0,iQ=0,iR=0,iS=0,iT=0,iU=0,iV=0,iW=0,iX=0,iY=0,iZ=0,i_=0,i$=0,i0=0,i1=0,i2=0,i3=0,i4=0,i5=0,i6=0,i7=0,i8=0,i9=0,ja=0,jb=0,jc=0,jd=0,je=0,jf=0,jg=0,jh=0,ji=0,jj=0,jk=0,jl=0,jm=0,jn=0,jo=0,jp=0,jq=0,jr=0,js=0,jt=0,ju=0,jv=0,jw=0,jx=0,jy=0,jz=0,jA=0,jB=0,jC=0,jD=0,jE=0,jF=0,jG=0,jH=0,jI=0,jJ=0,jK=0,jL=0,jM=0,jN=0,jO=0,jP=0,jQ=0,jR=0,jS=0,jT=0,jU=0,jV=0,jW=0,jX=0,jY=0,jZ=0,j_=0,j$=0,j0=0,j1=0,j2=0,j3=0,j4=0,j5=0,j6=0,j7=0,j8=0,j9=0,ka=0,kb=0,kc=0,kd=0,ke=0,kf=0,kg=0,kh=0,ki=0,kj=0,kk=0,kl=0,km=0,kn=0,ko=0,kp=0,kq=0,kr=0,ks=0,kt=0,ku=0,kv=0,kw=0,kx=0,ky=0,kz=0,kA=0,kB=0,kC=0,kD=0,kE=0,kF=0,kG=0,kH=0,kI=0,kJ=0,kK=0,kL=0,kM=0,kN=0,kO=0,kP=0,kQ=0,kR=0,kS=0,kT=0,kU=0,kV=0,kW=0,kX=0,kY=0,kZ=0,k_=0,k$=0,k0=0,k1=0,k2=0,k3=0,k4=0,k5=0,k6=0,k7=0,k8=0,k9=0,la=0,lb=0,lc=0,ld=0,le=0,lf=0,lg=0,lh=0,li=0,lj=0,lk=0,ll=0,lm=0,ln=0,lo=0,lp=0,lq=0,lr=0,ls=0,lt=0,lu=0,lv=0,lw=0,lx=0,ly=0,lz=0,lA=0,lB=0,lC=0,lD=0,lE=0,lF=0,lG=0,lH=0,lI=0,lJ=0,lK=0,lL=0,lM=0,lN=0,lO=0,lP=0,lQ=0,lR=0,lS=0,lT=0,lU=0,lV=0,lW=0,lX=0,lY=0,lZ=0,l_=0,l$=0,l0=0,l1=0,l2=0,l3=0,l4=0,l5=0,l6=0,l7=0,l8=0,l9=0,ma=0,mb=0,mc=0,md=0,me=0,mf=0,mg=0,mh=0,mi=0,mj=0,mk=0,ml=0,mm=0,mn=0,mo=0,mp=0,mq=0,mr=0,ms=0,mt=0,mu=0,mv=0,mw=0,mx=0,my=0,mz=0,mA=0,mB=0,mC=0,mD=0,mE=0,mF=0,mG=0,mH=0,mI=0,mJ=0,mK=0,mL=0,mM=0,mN=0,mO=0,mP=0,mQ=0,mR=0,mS=0,mT=0,mU=0,mV=0,mW=0,mX=0,mY=0,mZ=0,m_=0,m$=0,m0=0,m1=0,m2=0,m3=0;m=i;i=i+136|0;n=m|0;o=m+72|0;p=c[g>>2]|0;q=f+p|0;r=c[k>>2]|0;s=j+r|0;t=(l&4|0)!=0;if(t){u=-1}else{u=j+~h+r|0}r=u+1|0;if((r&u|0)!=0|j>>>0<h>>>0){c[k>>2]=0;c[g>>2]=0;v=-3;i=m;return v|0}w=e+4|0;y=c[w>>2]|0;z=e+56|0;A=c[z>>2]|0;B=e+32|0;C=c[B>>2]|0;D=e+36|0;E=c[D>>2]|0;F=e+40|0;G=c[F>>2]|0;H=e+60|0;I=c[H>>2]|0;J=e|0;L8730:do{switch(c[J>>2]|0){case 26:{if((p|0)<=0){K=y;L=C;M=E;N=G;O=A;P=I;Q=f;R=j;S=6788;break L8730}T=d[f]|0;U=y;V=C;W=E;X=G;Y=A;Z=I;_=f+1|0;$=j;S=6793;break};case 9:{aa=y;ab=C;ac=E;ad=G;ae=A;af=I;ag=f;ah=j;S=6634;break};case 10:{ai=y;aj=C;ak=E;al=G;am=A;an=I;ao=f;ap=j;S=6641;break};case 16:{if((p|0)<=0){aq=y;ar=C;as=E;at=G;au=A;av=I;aw=f;ax=j;S=6699;break L8730}ay=d[f]|0;az=y;aA=C;aB=E;aC=G;aD=A;aE=I;aF=f+1|0;aG=j;S=6704;break};case 25:{if((p|0)<=0){aH=y;aI=C;aJ=E;aK=G;aL=A;aM=I;aN=f;aO=j;S=6772;break L8730}aP=d[f]|0;aQ=y;aR=C;aS=E;aT=G;aU=A;aV=I;aW=f+1|0;aX=j;S=6777;break};case 51:{if((p|0)<=0){aY=y;aZ=C;a_=E;a$=G;a0=A;a1=I;a2=f;a3=j;S=6623;break L8730}a4=y;a5=C;a6=E;a7=G;a8=A;a9=d[f]|0;ba=I;bb=f+1|0;bc=j;S=6628;break};case 39:{bd=y;be=C;bf=E;bg=G;bh=A;bi=I;bj=f;bk=j;S=6619;break};case 0:{c[e+12>>2]=0;bl=e+8|0;c[bl>>2]=0;c[e+28>>2]=1;c[e+16>>2]=1;if((l&1|0)==0){bm=0;bn=0;bo=0;bp=0;bq=0;br=I;bs=f;bt=j;S=6581;break L8730}if((p|0)<1){bu=0;bv=0;bw=0;bx=0;by=0;S=6560;break L8730}c[bl>>2]=d[f]|0;bz=0;bA=0;bB=0;bC=0;bD=0;bE=f+1|0;S=6566;break};case 27:{if((p|0)<=0){bF=y;bG=C;bH=E;bI=G;bJ=A;bK=I;bL=f;bM=j;S=6801;break L8730}bN=d[f]|0;bO=y;bP=C;bQ=E;bR=G;bS=A;bT=I;bU=f+1|0;bV=j;S=6806;break};case 37:{bW=y;bX=C;bY=E;bZ=G;b_=A;b$=I;b0=f;b1=j;S=6809;break};case 3:{if((p|0)<=0){b2=y;b3=C;b4=E;b5=G;b6=A;b7=I;b8=f;b9=j;S=6583;break L8730}ca=y;cb=C;cc=E;cd=G;ce=A;cf=d[f]|0;cg=I;ch=f+1|0;ci=j;S=6588;break};case 5:{if((p|0)<=0){cj=y;ck=C;cl=E;cm=G;cn=A;co=I;cp=f;cq=j;S=6592;break L8730}cr=y;cs=C;ct=E;cu=G;cv=A;cw=d[f]|0;cx=I;cy=f+1|0;cz=j;S=6597;break};case 1:{if((p|0)<=0){bu=y;bv=C;bw=E;bx=G;by=A;S=6560;break L8730}c[e+8>>2]=d[f]|0;bz=y;bA=C;bB=E;bC=G;bD=A;bE=f+1|0;S=6566;break};case 52:{cA=y;cB=C;cC=E;cD=G;cE=A;cF=I;cG=f;cH=j;S=6630;break};case 36:{cI=y;cJ=C;cK=E;cL=G;cM=A;cN=f;S=6580;break};case 2:{if((p|0)<=0){cO=y;cP=C;cQ=E;cR=G;cS=A;cT=f;S=6567;break L8730}bl=d[f]|0;c[e+12>>2]=bl;cU=y;cV=C;cW=G;cX=A;cY=f+1|0;cZ=bl;S=6573;break};case 6:{if((p|0)<=0){c_=y;c$=C;c0=E;c1=G;c2=A;c3=I;c4=f;c5=j;S=6603;break L8730}c6=y;c7=C;c8=E;c9=G;da=A;db=d[f]|0;dc=I;dd=f+1|0;de=j;S=6608;break};case 23:{if((p|0)<=0){df=y;dg=C;dh=E;di=G;dj=A;dk=I;dl=f;dm=j;S=6738;break L8730}dn=d[f]|0;dp=y;dq=C;dr=E;ds=G;dt=A;du=I;dv=f+1|0;dw=j;S=6743;break};case 14:{if((p|0)<=0){dx=y;dy=C;dz=E;dA=G;dB=A;dC=I;dD=f;dE=j;S=6656;break L8730}dF=y;dG=C;dH=E;dI=d[f]|0;dJ=G;dK=A;dL=I;dM=f+1|0;dN=j;S=6661;break};case 21:{dO=y;dP=C;dQ=E;dR=G;dS=A;dT=I;dU=f;dV=j;S=6725;break};case 7:{if((p|0)<=0){dW=y;dX=C;dY=E;dZ=G;d_=A;d$=I;d0=f;d1=j;S=6611;break L8730}a[e+10528+E|0]=a[f]|0;d2=y;d3=C;d4=E;d5=G;d6=A;d7=I;d8=f+1|0;d9=j;S=6617;break};case 17:{ea=y;eb=C;ec=E;ed=G;ee=A;ef=I;eg=f;eh=j;S=6712;break};case 42:{if((p|0)<=0){ei=y;ej=C;ek=E;el=G;em=A;en=I;eo=f;ep=j;S=6843;break L8730}eq=d[f]|0;er=y;es=C;et=E;eu=G;ev=A;ew=I;ex=f+1|0;ey=j;S=6848;break};case 34:{ez=y;eA=C;eB=E;eC=G;eD=A;eE=I;eF=f;eG=j;S=6849;break};case 38:{eH=y;eI=C;eJ=E;eK=G;eL=A;eM=I;eN=f;eO=j;S=6636;break};case 40:{eP=y;eQ=C;eR=E;eS=G;eT=A;eU=I;eV=f;eW=j;S=6639;break};case 24:{eX=y;eY=C;eZ=E;e_=G;e$=A;e0=I;e1=f;e2=j;S=6749;break};case 32:{if((p|0)<=0){e3=y;e4=C;e5=E;e6=G;e7=A;e8=I;e9=f;fa=j;S=6824;break L8730}fb=d[f]|0;fc=y;fd=C;fe=E;ff=G;fg=A;fh=I;fi=f+1|0;fj=j;S=6829;break};case 41:{if((p|0)<=0){fk=y;fl=C;fm=E;fn=G;fo=A;fp=I;fq=f;fr=j;S=6835;break L8730}fs=d[f]|0;ft=y;fu=C;fv=E;fw=G;fx=A;fy=I;fz=f+1|0;fA=j;S=6840;break};case 18:{if((p|0)<=0){fB=y;fC=C;fD=E;fE=G;fF=A;fG=I;fH=f;fI=j;S=6715;break L8730}fJ=d[f]|0;fK=y;fL=C;fM=E;fN=G;fO=A;fP=I;fQ=f+1|0;fR=j;S=6720;break};case 11:{if((p|0)<=0){fS=y;fT=C;fU=E;fV=G;fW=A;fX=I;fY=f;fZ=j;S=6645;break L8730}f_=y;f$=C;f0=E;f1=G;f2=d[f]|0;f3=A;f4=I;f5=f+1|0;f6=j;S=6650;break};case 35:{f7=y;f8=C;f9=E;ga=G;gb=A;gc=I;gd=f;ge=j;S=6671;break};case 53:{gf=y;gg=C;gh=E;gi=G;gj=A;gk=I;gl=f;gm=j;S=6812;break};default:{gn=-1;go=y;gp=C;gq=E;gr=G;gs=A;gt=I;gu=f;gv=j;S=6850}}}while(0);do{if((S|0)==6560){if((l&2|0)==0){c[e+8>>2]=0;bz=bu;bA=bv;bB=bw;bC=bx;bD=by;bE=f;S=6566;break}else{c[J>>2]=1;gn=1;go=bu;gp=bv;gq=bw;gr=bx;gs=by;gt=I;gu=f;gv=j;S=6850;break}}}while(0);do{if((S|0)==6566){if(bE>>>0>=q>>>0){cO=bz;cP=bA;cQ=bB;cR=bC;cS=bD;cT=bE;S=6567;break}by=d[bE]|0;c[e+12>>2]=by;cU=bz;cV=bA;cW=bC;cX=bD;cY=bE+1|0;cZ=by;S=6573}}while(0);do{if((S|0)==6567){if((l&2|0)==0){c[e+12>>2]=0;cU=cO;cV=cP;cW=cR;cX=cS;cY=cT;cZ=0;S=6573;break}else{c[J>>2]=2;gn=1;go=cO;gp=cP;gq=cQ;gr=cR;gs=cS;gt=I;gu=cT;gv=j;S=6850;break}}}while(0);if((S|0)==6573){cT=c[e+8>>2]|0;if((((cT<<8|cZ)>>>0)%31|0|cZ&32|0)==0){gw=(cT&15|0)!=8|0}else{gw=1}if(t){gx=gw}else{cZ=1<<(cT>>>4)+8;if(cZ>>>0>32768){gy=1}else{gy=r>>>0<cZ>>>0|0}gx=gy|gw}if((gx|0)==0){bm=cU;bn=cV;bo=0;bp=cW;bq=cX;br=I;bs=cY;bt=j;S=6581}else{cI=cU;cJ=cV;cK=gx;cL=cW;cM=cX;cN=cY;S=6580}}if((S|0)==6580){c[J>>2]=36;gn=-1;go=cI;gp=cJ;gq=cK;gr=cL;gs=cM;gt=I;gu=cN;gv=j;S=6850}L8796:while(1){do{if((S|0)==6788){S=0;if((l&2|0)==0){T=0;U=K;V=L;W=M;X=N;Y=O;Z=P;_=Q;$=R;S=6793;continue L8796}c[J>>2]=26;gn=1;go=K;gp=L;gq=M;gr=N;gs=O;gt=P;gu=Q;gv=R;S=6850;continue L8796}else if((S|0)==6793){S=0;cN=T<<U|Y;I=U+8|0;if(I>>>0<15){gz=I;gA=V;gB=W;gC=X;gD=cN;gE=Z;gF=_;gG=$;S=6781}else{gH=I;gI=W;gJ=cN;gK=Z;gL=_;gM=$;S=6795}}else if((S|0)==6634){S=0;if(ah>>>0<s>>>0){eH=aa;eI=ab;eJ=ac;eK=ad;eL=ae;eM=af;eN=ag;eO=ah;S=6636;continue L8796}c[J>>2]=9;gn=2;go=aa;gp=ab;gq=ac;gr=ad;gs=ae;gt=af;gu=ag;gv=ah;S=6850;continue L8796}else if((S|0)==6699){S=0;if((l&2|0)==0){ay=0;az=aq;aA=ar;aB=as;aC=at;aD=au;aE=av;aF=aw;aG=ax;S=6704;continue L8796}c[J>>2]=16;gn=1;go=aq;gp=ar;gq=as;gr=at;gs=au;gt=av;gu=aw;gv=ax;S=6850;continue L8796}else if((S|0)==6581){S=0;if(bm>>>0<3){gN=bm;gO=bn;gP=bo;gQ=bp;gR=bq;gS=br;gT=bs;gU=bt;S=6582}else{gV=bm;gW=bn;gX=bo;gY=bp;gZ=bq;g_=br;g$=bs;g0=bt;S=6589}}else if((S|0)==6641){S=0;c[J>>2]=10;gn=-1;go=ai;gp=aj;gq=ak;gr=al;gs=am;gt=an;gu=ao;gv=ap;S=6850;continue L8796}else if((S|0)==6704){S=0;cN=ay<<az|aD;I=az+8|0;if(I>>>0<15){g1=I;g2=aA;g3=aB;g4=aC;g5=cN;g6=aE;g7=aF;g8=aG;S=6692}else{g9=I;ha=aB;hb=aC;hc=cN;hd=aE;he=aF;hf=aG;S=6706}}else if((S|0)==6772){S=0;if((l&2|0)==0){aP=0;aQ=aH;aR=aI;aS=aJ;aT=aK;aU=aL;aV=aM;aW=aN;aX=aO;S=6777;continue L8796}c[J>>2]=25;gn=1;go=aH;gp=aI;gq=aJ;gr=aK;gs=aL;gt=aM;gu=aN;gv=aO;S=6850;continue L8796}else if((S|0)==6777){S=0;cN=aP<<aQ|aU;I=aQ+8|0;if(I>>>0<aT>>>0){hg=I;hh=aR;hi=aS;hj=aT;hk=cN;hl=aV;hm=aW;hn=aX;S=6771}else{ho=I;hp=aR;hq=aS;hr=aT;hs=cN;ht=aV;hu=aW;hv=aX;S=6778}}else if((S|0)==6628){S=0;cN=a9<<a4|a8;I=a4+8|0;if(a4>>>0>4294967287){hw=I;hx=a5;hy=a6;hz=a7;hA=cN;hB=ba;hC=bb;hD=bc;S=6622}else{hE=I;hF=a6;hG=a7;hH=cN;hI=ba;hJ=bb;hK=bc;S=6629}}else if((S|0)==6592){S=0;if((l&2|0)==0){cr=cj;cs=ck;ct=cl;cu=cm;cv=cn;cw=0;cx=co;cy=cp;cz=cq;S=6597;continue L8796}c[J>>2]=5;gn=1;go=cj;gp=ck;gq=cl;gr=cm;gs=cn;gt=co;gu=cp;gv=cq;S=6850;continue L8796}else if((S|0)==6619){S=0;c[J>>2]=39;gn=-1;go=bd;gp=be;gq=bf;gr=bg;gs=bh;gt=bi;gu=bj;gv=bk;S=6850;continue L8796}else if((S|0)==6801){S=0;if((l&2|0)==0){bN=0;bO=bF;bP=bG;bQ=bH;bR=bI;bS=bJ;bT=bK;bU=bL;bV=bM;S=6806;continue L8796}c[J>>2]=27;gn=1;go=bF;gp=bG;gq=bH;gr=bI;gs=bJ;gt=bK;gu=bL;gv=bM;S=6850;continue L8796}else if((S|0)==6806){S=0;cN=bN<<bO|bS;I=bO+8|0;if(I>>>0<bR>>>0){hL=I;hM=bP;hN=bQ;hO=bR;hP=cN;hQ=bT;hR=bU;hS=bV;S=6800}else{hT=I;hU=bP;hV=bQ;hW=bR;hX=cN;hY=bU;hZ=bV;S=6807}}else if((S|0)==6809){S=0;c[J>>2]=37;gn=-1;go=bW;gp=bX;gq=bY;gr=bZ;gs=b_;gt=b$;gu=b0;gv=b1;S=6850;continue L8796}else if((S|0)==6738){S=0;if((l&2|0)==0){dn=0;dp=df;dq=dg;dr=dh;ds=di;dt=dj;du=dk;dv=dl;dw=dm;S=6743;continue L8796}c[J>>2]=23;gn=1;go=df;gp=dg;gq=dh;gr=di;gs=dj;gt=dk;gu=dl;gv=dm;S=6850;continue L8796}else if((S|0)==6630){S=0;if(cH>>>0<s>>>0){a[cH]=cB&255;h_=cA;h$=cB;h0=cC-1|0;h1=cD;h2=cE;h3=cF;h4=cG;h5=cH+1|0;S=6620;break}else{c[J>>2]=52;gn=2;go=cA;gp=cB;gq=cC;gr=cD;gs=cE;gt=cF;gu=cG;gv=cH;S=6850;continue L8796}}else if((S|0)==6661){S=0;cN=dI<<dF|dK;I=dF+8|0;if(I>>>0<3){h6=I;h7=dG;h8=dH;h9=dJ;ia=cN;ib=dL;ic=dM;id=dN;S=6655}else{ie=I;ig=dG;ih=dH;ii=dJ;ij=cN;ik=dL;il=dM;im=dN;S=6662}}else if((S|0)==6583){S=0;if((l&2|0)==0){ca=b2;cb=b3;cc=b4;cd=b5;ce=b6;cf=0;cg=b7;ch=b8;ci=b9;S=6588;continue L8796}c[J>>2]=3;gn=1;go=b2;gp=b3;gq=b4;gr=b5;gs=b6;gt=b7;gu=b8;gv=b9;S=6850;continue L8796}else if((S|0)==6588){S=0;cN=cf<<ca|ce;I=ca+8|0;if(I>>>0<3){gN=I;gO=cb;gP=cc;gQ=cd;gR=cN;gS=cg;gT=ch;gU=ci;S=6582}else{gV=I;gW=cb;gX=cc;gY=cd;gZ=cN;g_=cg;g$=ch;g0=ci;S=6589}}else if((S|0)==6608){S=0;cN=db<<c6|da;I=c6+8|0;if(c6>>>0>4294967287){io=I;ip=c7;iq=c8;ir=c9;is=cN;it=dc;iu=dd;iv=de;S=6602}else{iw=I;ix=c7;iy=c8;iz=c9;iA=cN;iB=dc;iC=dd;iD=de;S=6609}}else if((S|0)==6603){S=0;if((l&2|0)==0){c6=c_;c7=c$;c8=c0;c9=c1;da=c2;db=0;dc=c3;dd=c4;de=c5;S=6608;continue L8796}c[J>>2]=6;gn=1;go=c_;gp=c$;gq=c0;gr=c1;gs=c2;gt=c3;gu=c4;gv=c5;S=6850;continue L8796}else if((S|0)==6650){S=0;cN=f2<<f_|f3;I=f_+8|0;cM=a[104968+f0|0]|0;if(I>>>0<cM<<24>>24>>>0){iE=I;iF=f$;iG=f0;iH=f1;iI=cN;iJ=f4;iK=f5;iL=f6;S=6644}else{iM=I;iN=f$;iO=f0;iP=f1;iQ=cN;iR=f4;iS=f5;iT=f6;iU=cM;S=6651}}else if((S|0)==6617){S=0;iV=d2;iW=d3;iX=d4+1|0;iY=d5;iZ=d6;i_=d7;i$=d8;i0=d9;S=6599}else if((S|0)==6743){S=0;cM=dn<<dp|dt;cN=dp+8|0;if(cN>>>0<15){i1=cN;i2=dq;i3=dr;i4=ds;i5=cM;i6=du;i7=dv;i8=dw;S=6731}else{i9=cN;ja=dq;jb=ds;jc=cM;jd=du;je=dv;jf=dw;S=6745}}else if((S|0)==6623){S=0;if((l&2|0)==0){a4=aY;a5=aZ;a6=a_;a7=a$;a8=a0;a9=0;ba=a1;bb=a2;bc=a3;S=6628;continue L8796}c[J>>2]=51;gn=1;go=aY;gp=aZ;gq=a_;gr=a$;gs=a0;gt=a1;gu=a2;gv=a3;S=6850;continue L8796}else if((S|0)==6611){S=0;if((l&2|0)==0){a[e+10528+dY|0]=0;d2=dW;d3=dX;d4=dY;d5=dZ;d6=d_;d7=d$;d8=d0;d9=d1;S=6617;continue L8796}else{c[J>>2]=7;gn=1;go=dW;gp=dX;gq=dY;gr=dZ;gs=d_;gt=d$;gu=d0;gv=d1;S=6850;continue L8796}}else if((S|0)==6656){S=0;if((l&2|0)==0){dF=dx;dG=dy;dH=dz;dI=0;dJ=dA;dK=dB;dL=dC;dM=dD;dN=dE;S=6661;continue L8796}c[J>>2]=14;gn=1;go=dx;gp=dy;gq=dz;gr=dA;gs=dB;gt=dC;gu=dD;gv=dE;S=6850;continue L8796}else if((S|0)==6725){S=0;c[J>>2]=21;gn=-1;go=dO;gp=dP;gq=dQ;gr=dR;gs=dS;gt=dT;gu=dU;gv=dV;S=6850;continue L8796}else if((S|0)==6712){S=0;c[J>>2]=17;gn=-1;go=ea;gp=eb;gq=ec;gr=ed;gs=ee;gt=ef;gu=eg;gv=eh;S=6850;continue L8796}else if((S|0)==6597){S=0;cM=cw<<cr|cv;cN=cr+8|0;if(cN>>>0<(cN&7)>>>0){jg=cN;jh=cs;ji=ct;jj=cu;jk=cM;jl=cx;jm=cy;jn=cz;S=6591}else{jo=cN;jp=cs;jq=cu;jr=cM;js=cx;jt=cy;ju=cz;S=6598}}else if((S|0)==6843){S=0;if((l&2|0)==0){eq=0;er=ei;es=ej;et=ek;eu=el;ev=em;ew=en;ex=eo;ey=ep;S=6848;continue L8796}c[J>>2]=42;gn=1;go=ei;gp=ej;gq=ek;gr=el;gs=em;gt=en;gu=eo;gv=ep;S=6850;continue L8796}else if((S|0)==6848){S=0;cM=e+16|0;c[cM>>2]=c[cM>>2]<<8|eq;jv=er;jw=es;jx=et+1|0;jy=eu;jz=ev;jA=ew;jB=ex;jC=ey;S=6831}else if((S|0)==6849){S=0;c[J>>2]=34;gn=0;go=ez;gp=eA;gq=eB;gr=eC;gs=eD;gt=eE;gu=eF;gv=eG;S=6850;continue L8796}else if((S|0)==6850){S=0;c[w>>2]=go;c[z>>2]=gs;c[B>>2]=gp;c[D>>2]=gq;c[F>>2]=gr;c[H>>2]=gt;c[g>>2]=gu-f;jD=gv-j|0;c[k>>2]=jD;if((l&9|0)!=0&(gn|0)>-1){break L8796}else{v=gn;S=6867;break L8796}}else if((S|0)==6636){S=0;if(eN>>>0<q>>>0){cM=s-eO|0;cN=q-eN|0;I=cM>>>0<cN>>>0?cM:cN;cN=I>>>0<eJ>>>0?I:eJ;yJ(eO|0,eN|0,cN)|0;jE=eH;jF=eI;jG=eJ-cN|0;jH=eK;jI=eL;jJ=eM;jK=eN+cN|0;jL=eO+cN|0;S=6633;break}if((l&2|0)==0){eP=eH;eQ=eI;eR=eJ;eS=eK;eT=eL;eU=eM;eV=eN;eW=eO;S=6639;continue L8796}c[J>>2]=38;gn=1;go=eH;gp=eI;gq=eJ;gr=eK;gs=eL;gt=eM;gu=eN;gv=eO;S=6850;continue L8796}else if((S|0)==6639){S=0;c[J>>2]=40;gn=-1;go=eP;gp=eQ;gq=eR;gr=eS;gs=eT;gt=eU;gu=eV;gv=eW;S=6850;continue L8796}else if((S|0)==6749){S=0;if(e2>>>0<s>>>0){a[e2]=eZ&255;jM=eX;jN=eY;jO=eZ;jP=e_;jQ=e$;jR=e0;jS=e1;jT=e2+1|0;S=6752;break}else{c[J>>2]=24;gn=2;go=eX;gp=eY;gq=eZ;gr=e_;gs=e$;gt=e0;gu=e1;gv=e2;S=6850;continue L8796}}else if((S|0)==6824){S=0;if((l&2|0)==0){fb=0;fc=e3;fd=e4;fe=e5;ff=e6;fg=e7;fh=e8;fi=e9;fj=fa;S=6829;continue L8796}c[J>>2]=32;gn=1;go=e3;gp=e4;gq=e5;gr=e6;gs=e7;gt=e8;gu=e9;gv=fa;S=6850;continue L8796}else if((S|0)==6829){S=0;cN=fb<<fc|fg;I=fc+8|0;if(I>>>0<(I&7)>>>0){jU=I;jV=fd;jW=fe;jX=ff;jY=cN;jZ=fh;j_=fi;j$=fj;S=6823}else{j0=I;j1=fd;j2=ff;j3=cN;j4=fh;j5=fi;j6=fj;S=6830}}else if((S|0)==6835){S=0;if((l&2|0)==0){fs=0;ft=fk;fu=fl;fv=fm;fw=fn;fx=fo;fy=fp;fz=fq;fA=fr;S=6840;continue L8796}c[J>>2]=41;gn=1;go=fk;gp=fl;gq=fm;gr=fn;gs=fo;gt=fp;gu=fq;gv=fr;S=6850;continue L8796}else if((S|0)==6840){S=0;cN=fs<<ft|fx;I=ft+8|0;if(ft>>>0>4294967287){j7=I;j8=fu;j9=fv;ka=fw;kb=cN;kc=fy;kd=fz;ke=fA;S=6834}else{kf=I;kg=fu;kh=fv;ki=fw;kj=cN;kk=fy;kl=fz;km=fA;S=6841}}else if((S|0)==6715){S=0;if((l&2|0)==0){fJ=0;fK=fB;fL=fC;fM=fD;fN=fE;fO=fF;fP=fG;fQ=fH;fR=fI;S=6720;continue L8796}c[J>>2]=18;gn=1;go=fB;gp=fC;gq=fD;gr=fE;gs=fF;gt=fG;gu=fH;gv=fI;S=6850;continue L8796}else if((S|0)==6645){S=0;if((l&2|0)==0){f_=fS;f$=fT;f0=fU;f1=fV;f2=0;f3=fW;f4=fX;f5=fY;f6=fZ;S=6650;continue L8796}c[J>>2]=11;gn=1;go=fS;gp=fT;gq=fU;gr=fV;gs=fW;gt=fX;gu=fY;gv=fZ;S=6850;continue L8796}else if((S|0)==6671){S=0;c[J>>2]=35;gn=-1;go=f7;gp=f8;gq=f9;gr=ga;gs=gb;gt=gc;gu=gd;gv=ge;S=6850;continue L8796}else if((S|0)==6720){S=0;cN=fJ<<fK|fO;I=fK+8|0;if(I>>>0<fN>>>0){kn=I;ko=fL;kp=fM;kq=fN;kr=cN;ks=fP;kt=fQ;ku=fR;S=6714}else{kv=I;kw=fL;kx=fM;ky=fN;kz=cN;kA=fP;kB=fQ;kC=fR;S=6721}}else if((S|0)==6812){S=0;if(gm>>>0<s>>>0){a[gm]=a[h+(gk-gg&u)|0]|0;kD=gf;kE=gg;kF=gh;kG=gi;kH=gj;kI=gk+1|0;kJ=gl;kK=gm+1|0;S=6811;break}else{c[J>>2]=53;gn=2;go=gf;gp=gg;gq=gh;gr=gi;gs=gj;gt=gk;gu=gl;gv=gm;S=6850;continue L8796}}}while(0);if((S|0)==6582){S=0;if(gT>>>0>=q>>>0){b2=gN;b3=gO;b4=gP;b5=gQ;b6=gR;b7=gS;b8=gT;b9=gU;S=6583;continue}ca=gN;cb=gO;cc=gP;cd=gQ;ce=gR;cf=d[gT]|0;cg=gS;ch=gT+1|0;ci=gU;S=6588;continue}do{if((S|0)==6589){S=0;cN=gZ&7;c[e+20>>2]=cN;I=gZ>>>3;cM=gV-3|0;cL=cN>>>1;cN=e+24|0;c[cN>>2]=cL;if((cL|0)==3){ai=cM;aj=gW;ak=gX;al=gY;am=I;an=g_;ao=g$;ap=g0;S=6641;continue L8796}else if((cL|0)==0){if(cM>>>0<(cM&7)>>>0){jg=cM;jh=gW;ji=gX;jj=gY;jk=I;jl=g_;jm=g$;jn=g0;S=6591;break}else{jo=cM;jp=gW;jq=gY;jr=I;js=g_;jt=g$;ju=g0;S=6598;break}}else if((cL|0)==1){c[e+44>>2]=288;c[e+48>>2]=32;yG(e+3552|0,5,32);yG(e+64|0,8,144);yG(e+208|0,9,112);yG(e+320|0,7,24);cL=e+344|0;cK=cL|0;x=134744072;a[cK]=x&255;x=x>>8;a[cK+1|0]=x&255;x=x>>8;a[cK+2|0]=x&255;x=x>>8;a[cK+3|0]=x&255;cK=cL+4|0;x=134744072;a[cK]=x&255;x=x>>8;a[cK+1|0]=x&255;x=x>>8;a[cK+2|0]=x&255;x=x>>8;a[cK+3|0]=x&255;kL=cM;kM=gW;kN=gX;kO=gY;kP=I;kQ=g_;kR=g$;kS=g0;kT=cN;S=6665;break}else{kU=cM;kV=gW;kW=0;kX=gY;kY=I;kZ=g_;k_=g$;k$=g0;S=6642;break}}}while(0);if((S|0)==6598){S=0;I=jo&7;iV=jo-I|0;iW=jp;iX=0;iY=jq;iZ=jr>>>(I>>>0);i_=js;i$=jt;i0=ju;S=6599}else if((S|0)==6591){S=0;if(jm>>>0>=q>>>0){cj=jg;ck=jh;cl=ji;cm=jj;cn=jk;co=jl;cp=jm;cq=jn;S=6592;continue}cr=jg;cs=jh;ct=ji;cu=jj;cv=jk;cw=d[jm]|0;cx=jl;cy=jm+1|0;cz=jn;S=6597;continue}do{if((S|0)==6599){S=0;if(iX>>>0>=4){I=d[e+10529|0]<<8|d[e+10528|0];if((I|0)==((d[e+10531|0]<<8|d[e+10530|0])^65535|0)){h_=iV;h$=iW;h0=I;h1=iY;h2=iZ;h3=i_;h4=i$;h5=i0;S=6620;break}else{bd=iV;be=iW;bf=I;bg=iY;bh=iZ;bi=i_;bj=i$;bk=i0;S=6619;continue L8796}}if((iV|0)!=0){if(iV>>>0<8){io=iV;ip=iW;iq=iX;ir=iY;is=iZ;it=i_;iu=i$;iv=i0;S=6602;break}else{iw=iV;ix=iW;iy=iX;iz=iY;iA=iZ;iB=i_;iC=i$;iD=i0;S=6609;break}}if(i$>>>0>=q>>>0){dW=0;dX=iW;dY=iX;dZ=iY;d_=iZ;d$=i_;d0=i$;d1=i0;S=6611;continue L8796}a[e+10528+iX|0]=a[i$]|0;d2=0;d3=iW;d4=iX;d5=iY;d6=iZ;d7=i_;d8=i$+1|0;d9=i0;S=6617;continue L8796}}while(0);do{if((S|0)==6602){S=0;if(iu>>>0>=q>>>0){c_=io;c$=ip;c0=iq;c1=ir;c2=is;c3=it;c4=iu;c5=iv;S=6603;continue L8796}c6=io;c7=ip;c8=iq;c9=ir;da=is;db=d[iu]|0;dc=it;dd=iu+1|0;de=iv;S=6608;continue L8796}else if((S|0)==6609){S=0;a[e+10528+iy|0]=iA&255;d2=iw-8|0;d3=ix;d4=iy;d5=iz;d6=iA>>>8;d7=iB;d8=iC;d9=iD;S=6617;continue L8796}else if((S|0)==6620){S=0;if((h0|0)==0|(h_|0)==0){jE=h_;jF=h$;jG=h0;jH=h1;jI=h2;jJ=h3;jK=h4;jL=h5;S=6633;break}if(h_>>>0<8){hw=h_;hx=h$;hy=h0;hz=h1;hA=h2;hB=h3;hC=h4;hD=h5;S=6622}else{hE=h_;hF=h0;hG=h1;hH=h2;hI=h3;hJ=h4;hK=h5;S=6629}}}while(0);if((S|0)==6633){S=0;if((jG|0)==0){k0=jE;k1=jF;k2=0;k3=jH;k4=jI;k5=jJ;k6=jK;k7=jL;S=6820}else{aa=jE;ab=jF;ac=jG;ad=jH;ae=jI;af=jJ;ag=jK;ah=jL;S=6634;continue}}else if((S|0)==6629){S=0;cA=hE-8|0;cB=hH&255;cC=hF;cD=hG;cE=hH>>>8;cF=hI;cG=hJ;cH=hK;S=6630;continue}else if((S|0)==6622){S=0;if(hC>>>0>=q>>>0){aY=hw;aZ=hx;a_=hy;a$=hz;a0=hA;a1=hB;a2=hC;a3=hD;S=6623;continue}a4=hw;a5=hx;a6=hy;a7=hz;a8=hA;a9=d[hC]|0;ba=hB;bb=hC+1|0;bc=hD;S=6628;continue}L8909:while(1){L8910:do{if((S|0)==6752){S=0;I=q;cM=I-jS|0;L8912:do{if((cM|0)<4){k8=jT;k9=jS;la=jQ;lb=jO;lc=jM;ld=cM}else{cN=s;cK=jT;cL=jS;cJ=jQ;cI=jO;cY=jM;cX=cM;while(1){if((cN-cK|0)<2){k8=cK;k9=cL;la=cJ;lb=cI;lc=cY;ld=cX;break L8912}if(cY>>>0<15){le=cY+16|0;lf=(d[cL+1|0]<<8|d[cL])<<cY|cJ;lg=cL+2|0}else{le=cY;lf=cJ;lg=cL}cW=b[e+352+((lf&1023)<<1)>>1]|0;gx=cW<<16>>16;if(cW<<16>>16>-1){lh=gx>>9;li=gx}else{cW=10;cV=gx;while(1){gx=cW+1|0;cU=b[e+2400+((lf>>>(cW>>>0)&1)+~cV<<1)>>1]|0;gw=cU<<16>>16;if(cU<<16>>16<0){cW=gx;cV=gw}else{lh=gx;li=gw;break}}}cV=lf>>>(lh>>>0);cW=le-lh|0;if((li&256|0)!=0){lj=cW;lk=jN;ll=li;lm=jP;ln=cV;lo=jR;lp=lg;lq=cK;S=6768;break L8910}if(cW>>>0<15){lr=cW+16|0;ls=(d[lg+1|0]<<8|d[lg])<<cW|cV;lt=lg+2|0}else{lr=cW;ls=cV;lt=lg}cV=b[e+352+((ls&1023)<<1)>>1]|0;cW=cV<<16>>16;if(cV<<16>>16>-1){lu=cW>>9;lv=cW}else{cV=10;gw=cW;while(1){cW=cV+1|0;gx=b[e+2400+((ls>>>(cV>>>0)&1)+~gw<<1)>>1]|0;cU=gx<<16>>16;if(gx<<16>>16<0){cV=cW;gw=cU}else{lu=cW;lv=cU;break}}}lw=ls>>>(lu>>>0);lx=lr-lu|0;a[cK]=li&255;if((lv&256|0)!=0){break}a[cK+1|0]=lv&255;gw=cK+2|0;cV=I-lt|0;if((cV|0)<4){k8=gw;k9=lt;la=lw;lb=li;lc=lx;ld=cV;break L8912}else{cK=gw;cL=lt;cJ=lw;cI=li;cY=lx;cX=cV}}lj=lx;lk=jN;ll=lv;lm=jP;ln=lw;lo=jR;lp=lt;lq=cK+1|0;S=6768;break L8910}}while(0);if(lc>>>0>=15){i9=lc;ja=jN;jb=jP;jc=la;jd=jR;je=k9;jf=k8;S=6745;continue L8909}if((ld|0)<2){i1=lc;i2=jN;i3=lb;i4=jP;i5=la;i6=jR;i7=k9;i8=k8;S=6731;continue L8909}i9=lc+16|0;ja=jN;jb=jP;jc=d[k9]<<lc|la|d[k9+1|0]<<lc+8;jd=jR;je=k9+2|0;jf=k8;S=6745;continue L8909}else if((S|0)==6642){S=0;if(kW>>>0<3){I=a[104968+kW|0]|0;if(kU>>>0<I<<24>>24>>>0){iE=kU;iF=kV;iG=kW;iH=kX;iI=kY;iJ=kZ;iK=k_;iL=k$;S=6644;continue L8909}else{iM=kU;iN=kV;iO=kW;iP=kX;iQ=kY;iR=kZ;iS=k_;iT=k$;iU=I;S=6651;continue L8909}}else{yG(e+7040|0,0,288);ly=kU;lz=kV;lA=0;lB=kX;lC=kY;lD=kZ;lE=k_;lF=k$;S=6653;break}}else if((S|0)==6771){S=0;if(hm>>>0<q>>>0){S=6776;break L8909}else{aH=hg;aI=hh;aJ=hi;aK=hj;aL=hk;aM=hl;aN=hm;aO=hn;S=6772;continue L8796}}else if((S|0)==6778){S=0;lG=ho-hr|0;lH=hp;lI=((1<<hr)-1&hs)+hq|0;lJ=hr;lK=hs>>>(hr>>>0);lL=ht;lM=hu;lN=hv}else if((S|0)==6781){S=0;I=b[e+3840+((gD&1023)<<1)>>1]|0;cM=I<<16>>16;if(I<<16>>16>-1){I=cM>>9;if((I|0)==0|gz>>>0<I>>>0){S=6787;break L8909}else{gH=gz;gI=gB;gJ=gD;gK=gE;gL=gF;gM=gG;S=6795;continue L8909}}if(gz>>>0>10){lO=10;lP=cM}else{S=6787;break L8909}while(1){lQ=b[e+5888+((gD>>>(lO>>>0)&1)+~lP<<1)>>1]|0;if(lQ<<16>>16>=0){gH=gz;gI=gB;gJ=gD;gK=gE;gL=gF;gM=gG;S=6795;continue L8909}if(gz>>>0<(lO+2|0)>>>0){break}else{lO=lO+1|0;lP=lQ<<16>>16}}if(lQ<<16>>16>-1){gH=gz;gI=gB;gJ=gD;gK=gE;gL=gF;gM=gG;S=6795;continue L8909}else{S=6787;break L8909}}else if((S|0)==6795){S=0;cM=b[e+3840+((gJ&1023)<<1)>>1]|0;I=cM<<16>>16;if(cM<<16>>16>-1){lR=I>>9;lS=I&511}else{cM=10;cX=I;while(1){I=cM+1|0;cY=b[e+5888+((gJ>>>(cM>>>0)&1)+~cX<<1)>>1]|0;cI=cY<<16>>16;if(cY<<16>>16<0){cM=I;cX=cI}else{lR=I;lS=cI;break}}}cX=gJ>>>(lR>>>0);cM=gH-lR|0;cI=c[1496+(lS<<2)>>2]|0;I=c[1624+(lS<<2)>>2]|0;if((lS-4|0)>>>0>=26){lT=cM;lU=I;lV=gI;lW=cI;lX=cX;lY=gL;lZ=gM;S=6808;break}if(cM>>>0<cI>>>0){hL=cM;hM=I;hN=gI;hO=cI;hP=cX;hQ=gK;hR=gL;hS=gM;S=6800;continue L8909}else{hT=cM;hU=I;hV=gI;hW=cI;hX=cX;hY=gL;hZ=gM;S=6807;continue L8909}}else if((S|0)==6800){S=0;if(hR>>>0<q>>>0){S=6805;break L8909}else{bF=hL;bG=hM;bH=hN;bI=hO;bJ=hP;bK=hQ;bL=hR;bM=hS;S=6801;continue L8796}}else if((S|0)==6807){S=0;lT=hT-hW|0;lU=((1<<hW)-1&hX)+hU|0;lV=hV;lW=hW;lX=hX>>>(hW>>>0);lY=hY;lZ=hZ;S=6808}else if((S|0)==6706){S=0;cX=b[e+7328+((hc&1023)<<1)>>1]|0;cI=cX<<16>>16;if(cX<<16>>16>-1){l_=cI>>9;l$=cI&511}else{cX=10;I=cI;while(1){cI=cX+1|0;cM=b[e+9376+((hc>>>(cX>>>0)&1)+~I<<1)>>1]|0;cY=cM<<16>>16;if(cM<<16>>16<0){cX=cI;I=cY}else{l_=cI;l$=cY;break}}}I=hc>>>(l_>>>0);cX=g9-l_|0;if(l$>>>0<16){a[e+10532+ha|0]=l$&255;l0=cX;l1=l$;l2=ha+1|0;l3=hb;l4=I;l5=hd;l6=he;l7=hf;S=6689;break}if((l$|0)==16&(ha|0)==0){ea=cX;eb=16;ec=0;ed=hb;ee=I;ef=hd;eg=he;eh=hf;S=6712;continue L8796}cY=a[101960+(l$-16)|0]|0;if(cX>>>0<cY>>>0){kn=cX;ko=l$;kp=ha;kq=cY;kr=I;ks=hd;kt=he;ku=hf;S=6714;continue L8909}else{kv=cX;kw=l$;kx=ha;ky=cY;kz=I;kA=hd;kB=he;kC=hf;S=6721;continue L8909}}else if((S|0)==6692){S=0;I=b[e+7328+((g5&1023)<<1)>>1]|0;cY=I<<16>>16;if(I<<16>>16>-1){I=cY>>9;if((I|0)==0|g1>>>0<I>>>0){S=6698;break L8909}else{g9=g1;ha=g3;hb=g4;hc=g5;hd=g6;he=g7;hf=g8;S=6706;continue L8909}}if(g1>>>0>10){l8=10;l9=cY}else{S=6698;break L8909}while(1){ma=b[e+9376+((g5>>>(l8>>>0)&1)+~l9<<1)>>1]|0;if(ma<<16>>16>=0){g9=g1;ha=g3;hb=g4;hc=g5;hd=g6;he=g7;hf=g8;S=6706;continue L8909}if(g1>>>0<(l8+2|0)>>>0){break}else{l8=l8+1|0;l9=ma<<16>>16}}if(ma<<16>>16>-1){g9=g1;ha=g3;hb=g4;hc=g5;hd=g6;he=g7;hf=g8;S=6706;continue L8909}else{S=6698;break L8909}}else if((S|0)==6662){S=0;a[(d[1344+ih|0]|0)+(e+7040)|0]=ij&7;ly=ie-3|0;lz=ig;lA=ih+1|0;lB=ii;lC=ij>>>3;lD=ik;lE=il;lF=im;S=6653}else if((S|0)==6665){S=0;cY=c[kT>>2]|0;if((cY|0)<=-1){jM=kL;jN=kM;jO=kN;jP=kO;jQ=kP;jR=kQ;jS=kR;jT=kS;S=6752;continue L8909}yG(o|0,0,64);yG(e+64+(cY*3488|0)+288|0,0,3200);I=c[kT>>2]|0;cX=c[e+44+(I<<2)>>2]|0;if((cX|0)==0){mb=0;mc=0;md=0;me=0;mf=0;mg=0;mh=0;mi=0;mj=0;mk=0;ml=0;mm=0;mn=0;mo=0;mp=0;mq=0}else{cI=0;do{cM=o+(d[e+64+(cY*3488|0)+cI|0]<<2)|0;c[cM>>2]=(c[cM>>2]|0)+1;cI=cI+1|0;}while(cI>>>0<cX>>>0);mb=c[o+4>>2]|0;mc=c[o+8>>2]|0;md=c[o+12>>2]|0;me=c[o+16>>2]|0;mf=c[o+20>>2]|0;mg=c[o+24>>2]|0;mh=c[o+28>>2]|0;mi=c[o+32>>2]|0;mj=c[o+36>>2]|0;mk=c[o+40>>2]|0;ml=c[o+44>>2]|0;mm=c[o+48>>2]|0;mn=c[o+52>>2]|0;mo=c[o+56>>2]|0;mp=c[o+60>>2]|0;mq=cX}c[n+4>>2]=0;c[n>>2]=0;cI=mb<<1;c[n+8>>2]=cI;cM=mc+cI<<1;c[n+12>>2]=cM;cI=md+cM<<1;c[n+16>>2]=cI;cM=me+cI<<1;c[n+20>>2]=cM;cI=mf+cM<<1;c[n+24>>2]=cI;cM=mg+cI<<1;c[n+28>>2]=cM;cI=mh+cM<<1;c[n+32>>2]=cI;cM=mi+cI<<1;c[n+36>>2]=cM;cI=mj+cM<<1;c[n+40>>2]=cI;cM=mk+cI<<1;c[n+44>>2]=cM;cI=ml+cM<<1;c[n+48>>2]=cI;cM=mm+cI<<1;c[n+52>>2]=cM;cI=mn+cM<<1;c[n+56>>2]=cI;cM=mo+cI<<1;c[n+60>>2]=cM;cI=mp+cM<<1;c[n+64>>2]=cI;if((cI|0)!=65536&(mp+(mo+(mn+(mm+(ml+(mk+(mj+(mi+(mh+(mg+(mf+(me+(md+(mc+mb)))))))))))))|0)>>>0>1){f7=kL;f8=kM;f9=kN;ga=kO;gb=kP;gc=kQ;gd=kR;ge=kS;S=6671;continue L8796}if((mq|0)==0){mr=I}else{cI=-1;cM=0;while(1){cJ=a[e+64+(cY*3488|0)+cM|0]|0;cL=cJ&255;L8992:do{if(cJ<<24>>24==0){ms=cI}else{cN=n+(cL<<2)|0;cV=c[cN>>2]|0;c[cN>>2]=cV+1;cN=0;gw=cL;cU=cV;while(1){mt=cU&1|cN<<1;cV=gw-1|0;if((cV|0)==0){break}else{cN=mt;gw=cV;cU=cU>>>1}}if((cJ&255)<11){cU=(cL<<9|cM)&65535;if(mt>>>0>=1024){ms=cI;break}gw=1<<cL;cV=mt;while(1){b[e+64+(cY*3488|0)+288+(cV<<1)>>1]=cU;cW=cV+gw|0;if(cW>>>0<1024){cV=cW}else{ms=cI;break L8992}}}cV=e+64+(cY*3488|0)+288+((mt&1023)<<1)|0;gw=b[cV>>1]|0;if(gw<<16>>16==0){b[cV>>1]=cI&65535;mu=cI;mv=cI-2|0}else{mu=gw<<16>>16;mv=cI}gw=cN>>>9;cV=mu-(gw&1)|0;if((cJ&255)>11){cU=mv;cW=cL;gx=gw&4194303;gw=cV;while(1){gy=e+64+(cY*3488|0)+2336+(~gw<<1)|0;cZ=b[gy>>1]|0;if(cZ<<16>>16==0){b[gy>>1]=cU&65535;mw=cU;mx=cU-2|0}else{mw=cZ<<16>>16;mx=cU}cZ=cW-1|0;gy=gx>>>1;r=mw-(gy&1)|0;if(cZ>>>0>11){cU=mx;cW=cZ;gx=gy;gw=r}else{my=mx;mz=r;break}}}else{my=mv;mz=cV}b[e+64+(cY*3488|0)+2336+(~mz<<1)>>1]=cM&65535;ms=my}}while(0);cL=cM+1|0;cJ=c[kT>>2]|0;if(cL>>>0<(c[e+44+(cJ<<2)>>2]|0)>>>0){cI=ms;cM=cL}else{mr=cJ;break}}}if((mr|0)==2){l0=kL;l1=kM;l2=0;l3=kO;l4=kP;l5=kQ;l6=kR;l7=kS;S=6689}else{mA=kL;mB=kM;mC=kN;mD=kO;mE=kP;mF=kQ;mG=kR;mH=kS;mI=mr;S=6727}}else if((S|0)==6651){S=0;cM=iU<<24>>24;c[e+44+(iO<<2)>>2]=((1<<cM)-1&iQ)+(c[1200+(iO<<2)>>2]|0);kU=iM-cM|0;kV=iN;kW=iO+1|0;kX=iP;kY=iQ>>>(cM>>>0);kZ=iR;k_=iS;k$=iT;S=6642;continue L8909}else if((S|0)==6745){S=0;cM=b[e+352+((jc&1023)<<1)>>1]|0;cI=cM<<16>>16;if(cM<<16>>16>-1){mJ=cI>>9;mK=cI&511}else{cM=10;cY=cI;while(1){cI=cM+1|0;I=b[e+2400+((jc>>>(cM>>>0)&1)+~cY<<1)>>1]|0;cX=I<<16>>16;if(I<<16>>16<0){cM=cI;cY=cX}else{mJ=cI;mK=cX;break}}}cY=jc>>>(mJ>>>0);cM=i9-mJ|0;if(mK>>>0>255){lj=cM;lk=ja;ll=mK;lm=jb;ln=cY;lo=jd;lp=je;lq=jf;S=6768}else{eX=cM;eY=ja;eZ=mK;e_=jb;e$=cY;e0=jd;e1=je;e2=jf;S=6749;continue L8796}}else if((S|0)==6655){S=0;if(ic>>>0<q>>>0){S=6660;break L8909}else{dx=h6;dy=h7;dz=h8;dA=h9;dB=ia;dC=ib;dD=ic;dE=id;S=6656;continue L8796}}else if((S|0)==6731){S=0;cY=b[e+352+((i5&1023)<<1)>>1]|0;cM=cY<<16>>16;if(cY<<16>>16>-1){cY=cM>>9;if((cY|0)==0|i1>>>0<cY>>>0){S=6737;break L8909}else{i9=i1;ja=i2;jb=i4;jc=i5;jd=i6;je=i7;jf=i8;S=6745;continue L8909}}if(i1>>>0>10){mL=10;mM=cM}else{S=6737;break L8909}while(1){mN=b[e+2400+((i5>>>(mL>>>0)&1)+~mM<<1)>>1]|0;if(mN<<16>>16>=0){i9=i1;ja=i2;jb=i4;jc=i5;jd=i6;je=i7;jf=i8;S=6745;continue L8909}if(i1>>>0<(mL+2|0)>>>0){break}else{mL=mL+1|0;mM=mN<<16>>16}}if(mN<<16>>16>-1){i9=i1;ja=i2;jb=i4;jc=i5;jd=i6;je=i7;jf=i8;S=6745;continue L8909}else{S=6737;break L8909}}else if((S|0)==6714){S=0;if(kt>>>0<q>>>0){S=6719;break L8909}else{fB=kn;fC=ko;fD=kp;fE=kq;fF=kr;fG=ks;fH=kt;fI=ku;S=6715;continue L8796}}else if((S|0)==6830){S=0;cM=j0&7;jv=j0-cM|0;jw=j1;jx=0;jy=j2;jz=j3>>>(cM>>>0);jA=j4;jB=j5;jC=j6;S=6831;continue L8909}else if((S|0)==6831){S=0;if(jx>>>0>=4){ez=jv;eA=jw;eB=jx;eC=jy;eD=jz;eE=jA;eF=jB;eG=jC;S=6849;continue L8796}if((jv|0)==0){S=6842;break L8909}if(jv>>>0<8){j7=jv;j8=jw;j9=jx;ka=jy;kb=jz;kc=jA;kd=jB;ke=jC;S=6834;continue L8909}else{kf=jv;kg=jw;kh=jx;ki=jy;kj=jz;kk=jA;kl=jB;km=jC;S=6841;continue L8909}}else if((S|0)==6834){S=0;if(kd>>>0<q>>>0){S=6839;break L8909}else{fk=j7;fl=j8;fm=j9;fn=ka;fo=kb;fp=kc;fq=kd;fr=ke;S=6835;continue L8796}}else if((S|0)==6841){S=0;eq=kj&255;er=kf-8|0;es=kg;et=kh;eu=ki;ev=kj>>>8;ew=kk;ex=kl;ey=km;S=6848;continue L8796}else if((S|0)==6644){S=0;if(iK>>>0<q>>>0){S=6649;break L8909}else{fS=iE;fT=iF;fU=iG;fV=iH;fW=iI;fX=iJ;fY=iK;fZ=iL;S=6645;continue L8796}}else if((S|0)==6721){S=0;cM=(a[99664+(kw-16)|0]|0)+((1<<ky)-1&kz)|0;if((kw|0)==16){mO=a[kx-1+(e+10532)|0]|0}else{mO=0}yG(e+10532+kx|0,mO|0,cM|0);l0=kv-ky|0;l1=kw;l2=cM+kx|0;l3=ky;l4=kz>>>(ky>>>0);l5=kA;l6=kB;l7=kC;S=6689}else if((S|0)==6811){S=0;cM=kF-1|0;if((kF|0)==0){jM=kD;jN=kE;jO=cM;jP=kG;jQ=kH;jR=kI;jS=kJ;jT=kK;S=6752;continue L8909}else{gf=kD;gg=kE;gh=cM;gi=kG;gj=kH;gk=kI;gl=kJ;gm=kK;S=6812;continue L8796}}else if((S|0)==6820){S=0;if((c[e+20>>2]&1|0)==0){bm=k0;bn=k1;bo=k2;bp=k3;bq=k4;br=k5;bs=k6;bt=k7;S=6581;continue L8796}if((l&1|0)==0){ez=k0;eA=k1;eB=k2;eC=k3;eD=k4;eE=k5;eF=k6;eG=k7;S=6849;continue L8796}if(k0>>>0<(k0&7)>>>0){jU=k0;jV=k1;jW=k2;jX=k3;jY=k4;jZ=k5;j_=k6;j$=k7;S=6823;continue L8909}else{j0=k0;j1=k1;j2=k3;j3=k4;j4=k5;j5=k6;j6=k7;S=6830;continue L8909}}else if((S|0)==6823){S=0;if(j_>>>0<q>>>0){S=6828;break L8909}else{e3=jU;e4=jV;e5=jW;e6=jX;e7=jY;e8=jZ;e9=j_;fa=j$;S=6824;continue L8796}}}while(0);do{if((S|0)==6768){S=0;cM=ll&511;if((cM|0)==256){k0=lj;k1=lk;k2=256;k3=lm;k4=ln;k5=lo;k6=lp;k7=lq;S=6820;continue L8909}cY=cM-257|0;cX=c[1216+(cY<<2)>>2]|0;cI=c[1368+(cY<<2)>>2]|0;if((cM-265|0)>>>0>=20){lG=lj;lH=lk;lI=cI;lJ=cX;lK=ln;lL=lo;lM=lp;lN=lq;break}if(lj>>>0<cX>>>0){hg=lj;hh=lk;hi=cI;hj=cX;hk=ln;hl=lo;hm=lp;hn=lq;S=6771;continue L8909}else{ho=lj;hp=lk;hq=cI;hr=cX;hs=ln;ht=lo;hu=lp;hv=lq;S=6778;continue L8909}}else if((S|0)==6808){S=0;cX=lZ-h|0;if(!(lU>>>0<=cX>>>0|t^1)){bW=lT;bX=lU;bY=lV;bZ=lW;b_=lX;b$=cX;b0=lY;b1=lZ;S=6809;continue L8796}cI=h+(cX-lU&u)|0;if(((lZ>>>0>cI>>>0?lZ:cI)+lV|0)>>>0>s>>>0){kD=lT;kE=lU;kF=lV;kG=lW;kH=lX;kI=cX;kJ=lY;kK=lZ;S=6811;continue L8909}else{mP=cI;mQ=lV;mR=lZ}while(1){a[mR]=a[mP]|0;a[mR+1|0]=a[mP+1|0]|0;a[mR+2|0]=a[mP+2|0]|0;mS=mR+3|0;mT=mP+3|0;mU=mQ-3|0;if((mU|0)>2){mP=mT;mQ=mU;mR=mS}else{break}}if((mU|0)<=0){jM=lT;jN=lU;jO=mU;jP=lW;jQ=lX;jR=cX;jS=lY;jT=mS;S=6752;continue L8909}a[mS]=a[mT]|0;if((mU|0)>1){a[mR+4|0]=a[mP+4|0]|0}jM=lT;jN=lU;jO=mU;jP=lW;jQ=lX;jR=cX;jS=lY;jT=mR+mQ|0;S=6752;continue L8909}else if((S|0)==6689){S=0;cI=c[e+44>>2]|0;cM=c[e+48>>2]|0;cY=cM+cI|0;if(l2>>>0>=cY>>>0){if((cY|0)!=(l2|0)){dO=l0;dP=l1;dQ=l2;dR=l3;dS=l4;dT=l5;dU=l6;dV=l7;S=6725;continue L8796}cY=e+64|0;I=e+10532|0;yJ(cY|0,I|0,cI)|0;I=e+3552|0;cY=e+10532+cI|0;yJ(I|0,cY|0,cM)|0;mA=l0;mB=l1;mC=l2;mD=l3;mE=l4;mF=l5;mG=l6;mH=l7;mI=c[e+24>>2]|0;S=6727;break}if(l0>>>0>=15){g9=l0;ha=l2;hb=l3;hc=l4;hd=l5;he=l6;hf=l7;S=6706;continue L8909}if((q-l6|0)<2){g1=l0;g2=l1;g3=l2;g4=l3;g5=l4;g6=l5;g7=l6;g8=l7;S=6692;continue L8909}g9=l0+16|0;ha=l2;hb=l3;hc=d[l6]<<l0|l4|d[l6+1|0]<<l0+8;hd=l5;he=l6+2|0;hf=l7;S=6706;continue L8909}else if((S|0)==6653){S=0;cM=e+52|0;if(lA>>>0<(c[cM>>2]|0)>>>0){if(ly>>>0<3){h6=ly;h7=lz;h8=lA;h9=lB;ia=lC;ib=lD;ic=lE;id=lF;S=6655;continue L8909}else{ie=ly;ig=lz;ih=lA;ii=lB;ij=lC;ik=lD;il=lE;im=lF;S=6662;continue L8909}}else{c[cM>>2]=19;kL=ly;kM=lz;kN=lA;kO=lB;kP=lC;kQ=lD;kR=lE;kS=lF;kT=e+24|0;S=6665;continue L8909}}}while(0);if((S|0)==6727){S=0;cM=e+24|0;c[cM>>2]=mI-1;kL=mA;kM=mB;kN=mC;kO=mD;kP=mE;kQ=mF;kR=mG;kS=mH;kT=cM;S=6665;continue}if(lG>>>0>=15){gH=lG;gI=lI;gJ=lK;gK=lL;gL=lM;gM=lN;S=6795;continue}if((q-lM|0)<2){gz=lG;gA=lH;gB=lI;gC=lJ;gD=lK;gE=lL;gF=lM;gG=lN;S=6781;continue}gH=lG+16|0;gI=lI;gJ=d[lM]<<lG|lK|d[lM+1|0]<<lG+8;gK=lL;gL=lM+2|0;gM=lN;S=6795}if((S|0)==6787){S=0;if(gF>>>0>=q>>>0){K=gz;L=gA;M=gB;N=gC;O=gD;P=gE;Q=gF;R=gG;S=6788;continue}T=d[gF]|0;U=gz;V=gA;W=gB;X=gC;Y=gD;Z=gE;_=gF+1|0;$=gG;S=6793;continue}else if((S|0)==6698){S=0;if(g7>>>0>=q>>>0){aq=g1;ar=g2;as=g3;at=g4;au=g5;av=g6;aw=g7;ax=g8;S=6699;continue}ay=d[g7]|0;az=g1;aA=g2;aB=g3;aC=g4;aD=g5;aE=g6;aF=g7+1|0;aG=g8;S=6704;continue}else if((S|0)==6805){S=0;bN=d[hR]|0;bO=hL;bP=hM;bQ=hN;bR=hO;bS=hP;bT=hQ;bU=hR+1|0;bV=hS;S=6806;continue}else if((S|0)==6737){S=0;if(i7>>>0>=q>>>0){df=i1;dg=i2;dh=i3;di=i4;dj=i5;dk=i6;dl=i7;dm=i8;S=6738;continue}dn=d[i7]|0;dp=i1;dq=i2;dr=i3;ds=i4;dt=i5;du=i6;dv=i7+1|0;dw=i8;S=6743;continue}else if((S|0)==6660){S=0;dF=h6;dG=h7;dH=h8;dI=d[ic]|0;dJ=h9;dK=ia;dL=ib;dM=ic+1|0;dN=id;S=6661;continue}else if((S|0)==6828){S=0;fb=d[j_]|0;fc=jU;fd=jV;fe=jW;ff=jX;fg=jY;fh=jZ;fi=j_+1|0;fj=j$;S=6829;continue}else if((S|0)==6839){S=0;fs=d[kd]|0;ft=j7;fu=j8;fv=j9;fw=ka;fx=kb;fy=kc;fz=kd+1|0;fA=ke;S=6840;continue}else if((S|0)==6842){S=0;if(jB>>>0>=q>>>0){ei=0;ej=jw;ek=jx;el=jy;em=jz;en=jA;eo=jB;ep=jC;S=6843;continue}eq=d[jB]|0;er=0;es=jw;et=jx;eu=jy;ev=jz;ew=jA;ex=jB+1|0;ey=jC;S=6848;continue}else if((S|0)==6719){S=0;fJ=d[kt]|0;fK=kn;fL=ko;fM=kp;fN=kq;fO=kr;fP=ks;fQ=kt+1|0;fR=ku;S=6720;continue}else if((S|0)==6776){S=0;aP=d[hm]|0;aQ=hg;aR=hh;aS=hi;aT=hj;aU=hk;aV=hl;aW=hm+1|0;aX=hn;S=6777;continue}else if((S|0)==6649){S=0;f_=iE;f$=iF;f0=iG;f1=iH;f2=d[iK]|0;f3=iI;f4=iJ;f5=iK+1|0;f6=iL;S=6650;continue}}if((S|0)==6867){i=m;return v|0}S=e+28|0;iL=c[S>>2]|0;f6=iL&65535;iK=iL>>>16;if((gv|0)==(j|0)){mV=f6;mW=iK}else{gv=j;j=jD;iL=f6;f6=iK;iK=(jD>>>0)%5552|0;while(1){if(iK>>>0>7){jD=gv;f5=0;iJ=iL;f4=f6;while(1){iI=(d[jD]|0)+iJ|0;f3=iI+(d[jD+1|0]|0)|0;f2=f3+(d[jD+2|0]|0)|0;iH=f2+(d[jD+3|0]|0)|0;f1=iH+(d[jD+4|0]|0)|0;iG=f1+(d[jD+5|0]|0)|0;f0=iG+(d[jD+6|0]|0)|0;iF=f0+(d[jD+7|0]|0)|0;f$=iI+f4+f3+f2+iH+f1+iG+f0+iF|0;f0=f5+8|0;iG=jD+8|0;if((f0|7)>>>0<iK>>>0){jD=iG;f5=f0;iJ=iF;f4=f$}else{mX=iG;mY=f0;mZ=iF;m_=f$;break}}}else{mX=gv;mY=0;mZ=iL;m_=f6}if(mY>>>0<iK>>>0){f4=iK-mY|0;iJ=mX;f5=mY;jD=mZ;f$=m_;while(1){m$=(d[iJ]|0)+jD|0;m0=m$+f$|0;iF=f5+1|0;if(iF>>>0<iK>>>0){iJ=iJ+1|0;f5=iF;jD=m$;f$=m0}else{break}}m1=mX+f4|0;m2=m$;m3=m0}else{m1=mX;m2=mZ;m3=m_}f$=(m2>>>0)%65521|0;jD=(m3>>>0)%65521|0;if((j|0)==(iK|0)){mV=f$;mW=jD;break}else{gv=m1;j=j-iK|0;iL=f$;f6=jD;iK=5552}}}iK=mW<<16|mV;c[S>>2]=iK;if((gn|0)!=0){v=gn;i=m;return v|0}if((l&1|0)==0){v=0;i=m;return v|0}else{i=m;return((iK|0)==(c[e+16>>2]|0)?0:-2)|0}return 0}function mj(a){a=a|0;var b=0,d=0,e=0;do{if((a|0)==0){b=-2}else{d=a+28|0;e=c[d>>2]|0;if((e|0)==0){b=0;break}yz(e);c[d>>2]=0;b=0}}while(0);return b|0}function mk(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278482]|0;if((e|0)==(d|0)){i=b;return}f=c[278483]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278482]=e}else{if((f|0)==0){c[278483]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278484]|0;if((e&1|0)!=0){i=b;return}c[278484]=e|3;i=b;return}function ml(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278483]=0;c[278482]=0;c[278484]=4;return}d=fi(b|0)|0;b=c[278482]|0;do{if((b|0)==(d|0)){c[278482]=0;if((c[278483]|0)==0){break}return}else{if((c[278483]|0)!=(d|0)){return}c[278483]=0;if((b|0)==0){break}return}}while(0);b=c[278484]|0;if((b&1|0)==0){return}c[278484]=b&-6|4;return}function mm(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278466]|0;if((e|0)==(d|0)){i=b;return}f=c[278467]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278466]=e}else{if((f|0)==0){c[278467]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278468]|0;if((e&1|0)!=0){i=b;return}c[278468]=e|3;i=b;return}function mn(){var b=0,d=0,e=0;b=os(1)|0;do{if((a[b]|0)==0){c[278467]=0;c[278466]=0;c[278468]=4}else{d=fi(b|0)|0;e=c[278466]|0;if((e|0)==(d|0)){c[278466]=0;if((c[278467]|0)!=0){break}}else{if((c[278467]|0)!=(d|0)){break}c[278467]=0;if((e|0)!=0){break}}e=c[278468]|0;if((e&1|0)==0){break}c[278468]=e&-6|4}}while(0);if(!((c[278468]&1|0)==0&+g[3898]!=0.0)){return}xA();return}function mo(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278442]|0;if((e|0)==(d|0)){i=b;return}f=c[278443]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278442]=e}else{if((f|0)==0){c[278443]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278444]|0;if((e&1|0)!=0){i=b;return}c[278444]=e|3;i=b;return}function mp(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278443]=0;c[278442]=0;c[278444]=4;return}d=fi(b|0)|0;b=c[278442]|0;do{if((b|0)==(d|0)){c[278442]=0;if((c[278443]|0)==0){break}return}else{if((c[278443]|0)!=(d|0)){return}c[278443]=0;if((b|0)==0){break}return}}while(0);b=c[278444]|0;if((b&1|0)==0){return}c[278444]=b&-6|4;return}function mq(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278496]|0;if((e|0)==(d|0)){i=b;return}f=c[278497]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278496]=e}else{if((f|0)==0){c[278497]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278498]|0;if((e&1|0)!=0){i=b;return}c[278498]=e|3;i=b;return}function mr(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278497]=0;c[278496]=0;c[278498]=4;return}d=fi(b|0)|0;b=c[278496]|0;do{if((b|0)==(d|0)){c[278496]=0;if((c[278497]|0)==0){break}return}else{if((c[278497]|0)!=(d|0)){return}c[278497]=0;if((b|0)==0){break}return}}while(0);b=c[278498]|0;if((b&1|0)==0){return}c[278498]=b&-6|4;return}function ms(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278478]|0;if((e|0)==(d|0)){i=b;return}f=c[278479]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278478]=e}else{if((f|0)==0){c[278479]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278480]|0;if((e&1|0)!=0){i=b;return}c[278480]=e|3;i=b;return}function mt(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278479]=0;c[278478]=0;c[278480]=4;return}d=fi(b|0)|0;b=c[278478]|0;do{if((b|0)==(d|0)){c[278478]=0;if((c[278479]|0)==0){break}return}else{if((c[278479]|0)!=(d|0)){return}c[278479]=0;if((b|0)==0){break}return}}while(0);b=c[278480]|0;if((b&1|0)==0){return}c[278480]=b&-6|4;return}function mu(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278454]|0;if((e|0)==(d|0)){i=b;return}f=c[278455]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278454]=e}else{if((f|0)==0){c[278455]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278456]|0;if((e&1|0)!=0){i=b;return}c[278456]=e|3;i=b;return}function mv(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278455]=0;c[278454]=0;c[278456]=4;return}d=fi(b|0)|0;b=c[278454]|0;do{if((b|0)==(d|0)){c[278454]=0;if((c[278455]|0)==0){break}return}else{if((c[278455]|0)!=(d|0)){return}c[278455]=0;if((b|0)==0){break}return}}while(0);b=c[278456]|0;if((b&1|0)==0){return}c[278456]=b&-6|4;return}function mw(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278492]|0;if((e|0)==(d|0)){i=b;return}f=c[278493]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278492]=e}else{if((f|0)==0){c[278493]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278494]|0;if((e&1|0)!=0){i=b;return}c[278494]=e|3;i=b;return}function mx(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278493]=0;c[278492]=0;c[278494]=4;return}d=fi(b|0)|0;b=c[278492]|0;do{if((b|0)==(d|0)){c[278492]=0;if((c[278493]|0)==0){break}return}else{if((c[278493]|0)!=(d|0)){return}c[278493]=0;if((b|0)==0){break}return}}while(0);b=c[278494]|0;if((b&1|0)==0){return}c[278494]=b&-6|4;return}function my(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278500]|0;if((e|0)==(d|0)){i=b;return}f=c[278501]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278500]=e}else{if((f|0)==0){c[278501]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278502]|0;if((e&1|0)!=0){i=b;return}c[278502]=e|3;i=b;return}function mz(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278501]=0;c[278500]=0;c[278502]=4;return}d=fi(b|0)|0;b=c[278500]|0;do{if((b|0)==(d|0)){c[278500]=0;if((c[278501]|0)==0){break}return}else{if((c[278501]|0)!=(d|0)){return}c[278501]=0;if((b|0)==0){break}return}}while(0);b=c[278502]|0;if((b&1|0)==0){return}c[278502]=b&-6|4;return}function mA(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278470]|0;if((e|0)==(d|0)){i=b;return}f=c[278471]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278470]=e}else{if((f|0)==0){c[278471]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278472]|0;if((e&1|0)!=0){i=b;return}c[278472]=e|3;i=b;return}function mB(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278471]=0;c[278470]=0;c[278472]=4;return}d=fi(b|0)|0;b=c[278470]|0;do{if((b|0)==(d|0)){c[278470]=0;if((c[278471]|0)==0){break}return}else{if((c[278471]|0)!=(d|0)){return}c[278471]=0;if((b|0)==0){break}return}}while(0);b=c[278472]|0;if((b&1|0)==0){return}c[278472]=b&-6|4;return}function mC(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278474]|0;if((e|0)==(d|0)){i=b;return}f=c[278475]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278474]=e}else{if((f|0)==0){c[278475]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278476]|0;if((e&1|0)!=0){i=b;return}c[278476]=e|3;i=b;return}function mD(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278475]=0;c[278474]=0;c[278476]=4;return}d=fi(b|0)|0;b=c[278474]|0;do{if((b|0)==(d|0)){c[278474]=0;if((c[278475]|0)==0){break}return}else{if((c[278475]|0)!=(d|0)){return}c[278475]=0;if((b|0)==0){break}return}}while(0);b=c[278476]|0;if((b&1|0)==0){return}c[278476]=b&-6|4;return}function mE(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278462]|0;if((e|0)==(d|0)){i=b;return}f=c[278463]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278462]=e}else{if((f|0)==0){c[278463]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278464]|0;if((e&1|0)!=0){i=b;return}c[278464]=e|3;i=b;return}function mF(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278463]=0;c[278462]=0;c[278464]=4;return}d=fi(b|0)|0;b=c[278462]|0;do{if((b|0)==(d|0)){c[278462]=0;if((c[278463]|0)==0){break}return}else{if((c[278463]|0)!=(d|0)){return}c[278463]=0;if((b|0)==0){break}return}}while(0);b=c[278464]|0;if((b&1|0)==0){return}c[278464]=b&-6|4;return}function mG(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278458]|0;if((e|0)==(d|0)){i=b;return}f=c[278459]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278458]=e}else{if((f|0)==0){c[278459]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278460]|0;if((e&1|0)!=0){i=b;return}c[278460]=e|3;i=b;return}function mH(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278459]=0;c[278458]=0;c[278460]=4;return}d=fi(b|0)|0;b=c[278458]|0;do{if((b|0)==(d|0)){c[278458]=0;if((c[278459]|0)==0){break}return}else{if((c[278459]|0)!=(d|0)){return}c[278459]=0;if((b|0)==0){break}return}}while(0);b=c[278460]|0;if((b&1|0)==0){return}c[278460]=b&-6|4;return}function mI(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278450]|0;if((e|0)==(d|0)){i=b;return}f=c[278451]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278450]=e}else{if((f|0)==0){c[278451]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278452]|0;if((e&1|0)!=0){i=b;return}c[278452]=e|3;i=b;return}function mJ(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278451]=0;c[278450]=0;c[278452]=4;return}d=fi(b|0)|0;b=c[278450]|0;do{if((b|0)==(d|0)){c[278450]=0;if((c[278451]|0)==0){break}return}else{if((c[278451]|0)!=(d|0)){return}c[278451]=0;if((b|0)==0){break}return}}while(0);b=c[278452]|0;if((b&1|0)==0){return}c[278452]=b&-6|4;return}function mK(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278446]|0;if((e|0)==(d|0)){i=b;return}f=c[278447]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278446]=e}else{if((f|0)==0){c[278447]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278448]|0;if((e&1|0)!=0){i=b;return}c[278448]=e|3;i=b;return}function mL(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278447]=0;c[278446]=0;c[278448]=4;return}d=fi(b|0)|0;b=c[278446]|0;do{if((b|0)==(d|0)){c[278446]=0;if((c[278447]|0)==0){break}return}else{if((c[278447]|0)!=(d|0)){return}c[278447]=0;if((b|0)==0){break}return}}while(0);b=c[278448]|0;if((b&1|0)==0){return}c[278448]=b&-6|4;return}function mM(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278504]|0;if((e|0)==(d|0)){i=b;return}f=c[278505]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278504]=e}else{if((f|0)==0){c[278505]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278506]|0;if((e&1|0)!=0){i=b;return}c[278506]=e|3;i=b;return}function mN(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278505]=0;c[278504]=0;c[278506]=4;return}d=fi(b|0)|0;b=c[278504]|0;do{if((b|0)==(d|0)){c[278504]=0;if((c[278505]|0)==0){break}return}else{if((c[278505]|0)!=(d|0)){return}c[278505]=0;if((b|0)==0){break}return}}while(0);b=c[278506]|0;if((b&1|0)==0){return}c[278506]=b&-6|4;return}function mO(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278438]|0;if((e|0)==(d|0)){i=b;return}f=c[278439]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278438]=e}else{if((f|0)==0){c[278439]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278440]|0;if((e&1|0)!=0){i=b;return}c[278440]=e|3;i=b;return}function mP(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278439]=0;c[278438]=0;c[278440]=4;return}d=fi(b|0)|0;b=c[278438]|0;do{if((b|0)==(d|0)){c[278438]=0;if((c[278439]|0)==0){break}return}else{if((c[278439]|0)!=(d|0)){return}c[278439]=0;if((b|0)==0){break}return}}while(0);b=c[278440]|0;if((b&1|0)==0){return}c[278440]=b&-6|4;return}function mQ(){var b=0,d=0,e=0,f=0,g=0;b=i;d=os(1)|0;if((a[d]|0)==0){e=-1}else{e=fi(d|0)|0}d=c[278486]|0;if((e|0)==(d|0)){i=b;return}f=c[278487]|0;if((e|0)==(f|0)){i=b;return}do{if((d|0)==0){c[278486]=e}else{if((f|0)==0){c[278487]=e;break}oW(89536,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=b;return}}while(0);e=c[278488]|0;if((e&1|0)!=0){i=b;return}c[278488]=e|3;i=b;return}function mR(){var b=0,d=0;b=os(1)|0;if((a[b]|0)==0){c[278487]=0;c[278486]=0;c[278488]=4;return}d=fi(b|0)|0;b=c[278486]|0;do{if((b|0)==(d|0)){c[278486]=0;if((c[278487]|0)==0){break}return}else{if((c[278487]|0)!=(d|0)){return}c[278487]=0;if((b|0)==0){break}return}}while(0);b=c[278488]|0;if((b&1|0)==0){return}c[278488]=b&-6|4;return}function mS(){c[278490]=nE(os(1)|0)|0;return}function mT(){var a=0.0,b=0.0,d=0,e=0,f=0,i=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0;a=+h[2332];if((c[278452]&1|0)==0){b=a}else{b=a*+g[5670]}a=b;if((c[278448]&1|0)==0){b=a*+g[5404];d=c[278456]|0;e=d&1;f=(d&2|0)!=0;i=d&6;if((i|0)==2){j=(e|0)==0?0.0:.5}else{j=0.0}do{if((d&4|0)==0){if((i|0)!=0){k=j;break}k=(e|0)==0?0.0:1.0}else{if((i|0)!=6){k=f?j:0.0;break}k=(e|0)==0?.25:.75}}while(0);c[278456]=e;j=+g[642355]-b*k;g[642355]=j;e=c[278480]|0;f=e&1;i=(e&2|0)!=0;d=e&6;if((d|0)==2){l=(f|0)==0?0.0:.5}else{l=0.0}do{if((e&4|0)==0){if((d|0)!=0){m=l;break}m=(f|0)==0?0.0:1.0}else{if((d|0)!=6){m=i?l:0.0;break}m=(f|0)==0?.25:.75}}while(0);c[278480]=f;l=j+b*m;g[642355]=l;g[642355]=+qS(l)}if((c[278484]&1|0)!=0){xz();l=a*+g[5502];f=c[278494]|0;i=f&1;d=(f&2|0)!=0;e=f&6;if((e|0)==2){n=(i|0)==0?0.0:.5}else{n=0.0}do{if((f&4|0)==0){if((e|0)!=0){o=n;break}o=(i|0)==0?0.0:1.0}else{if((e|0)!=6){o=d?n:0.0;break}o=(i|0)==0?.25:.75}}while(0);c[278494]=i;n=+g[642354]-l*o;g[642354]=n;i=c[278502]|0;d=i&1;e=(i&2|0)!=0;f=i&6;if((f|0)==2){p=(d|0)==0?0.0:.5}else{p=0.0}do{if((i&4|0)==0){if((f|0)!=0){q=p;break}q=(d|0)==0?0.0:1.0}else{if((f|0)!=6){q=e?p:0.0;break}q=(d|0)==0?.25:.75}}while(0);c[278502]=d;g[642354]=n+l*q}d=c[278472]|0;e=d&1;f=(d&2|0)!=0;i=d&6;if((i|0)==2){r=(e|0)==0?0.0:.5}else{r=0.0}do{if((d&4|0)==0){if((i|0)!=0){s=r;break}s=(e|0)==0?0.0:1.0}else{if((i|0)!=6){s=f?r:0.0;break}s=(e|0)==0?.25:.75}}while(0);c[278472]=e;e=c[278476]|0;f=e&1;i=(e&2|0)!=0;d=e&6;if((d|0)==2){t=(f|0)==0?0.0:.5}else{t=0.0}do{if((e&4|0)==0){if((d|0)!=0){u=t;break}u=(f|0)==0?0.0:1.0}else{if((d|0)==6){u=(f|0)==0?.25:.75;break}else{u=i?t:0.0;break}}}while(0);c[278476]=f;t=a*+g[5502];a=+g[642354]-s*t+u*t;g[642354]=a;if(s!=0.0|u!=0.0){xz();v=+g[642354]}else{v=a}do{if(v>80.0){g[642354]=80.0}else{if(v>=-70.0){break}g[642354]=-70.0}}while(0);v=+g[642356];if(v>50.0){g[642356]=50.0;return}if(v>=-50.0){return}g[642356]=-50.0;return}function mU(a){a=a|0;var b=0.0,d=0,e=0,f=0,h=0,i=0.0,j=0.0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0.0,A=0.0;if((c[353150]|0)!=4){return}mT();yG(a|0,0,24);if((c[278448]&1|0)!=0){b=+g[5446];d=c[278456]|0;e=d&1;f=(d&2|0)!=0;h=d&6;if((h|0)==2){i=(e|0)==0?0.0:.5}else{i=0.0}do{if((d&4|0)==0){if((h|0)!=0){j=i;break}j=(e|0)==0?0.0:1.0}else{if((h|0)!=6){j=f?i:0.0;break}j=(e|0)==0?.25:.75}}while(0);c[278456]=e;e=a+16|0;g[e>>2]=+g[e>>2]+b*j;j=+g[5446];f=c[278480]|0;h=f&1;d=(f&2|0)!=0;k=f&6;if((k|0)==2){l=(h|0)==0?0.0:.5}else{l=0.0}do{if((f&4|0)==0){if((k|0)!=0){m=l;break}m=(h|0)==0?0.0:1.0}else{if((k|0)!=6){m=d?l:0.0;break}m=(h|0)==0?.25:.75}}while(0);c[278480]=h;g[e>>2]=+g[e>>2]-j*m}m=+g[5446];e=c[278460]|0;h=e&1;d=(e&2|0)!=0;k=e&6;if((k|0)==2){n=(h|0)==0?0.0:.5}else{n=0.0}do{if((e&4|0)==0){if((k|0)!=0){o=n;break}o=(h|0)==0?0.0:1.0}else{if((k|0)!=6){o=d?n:0.0;break}o=(h|0)==0?.25:.75}}while(0);c[278460]=h;h=a+16|0;g[h>>2]=+g[h>>2]+m*o;o=+g[5446];d=c[278464]|0;k=d&1;e=(d&2|0)!=0;f=d&6;if((f|0)==2){p=(k|0)==0?0.0:.5}else{p=0.0}do{if((d&4|0)==0){if((f|0)!=0){q=p;break}q=(k|0)==0?0.0:1.0}else{if((f|0)!=6){q=e?p:0.0;break}q=(k|0)==0?.25:.75}}while(0);c[278464]=k;g[h>>2]=+g[h>>2]-o*q;q=+g[5432];k=c[278444]|0;e=k&1;f=(k&2|0)!=0;d=k&6;if((d|0)==2){r=(e|0)==0?0.0:.5}else{r=0.0}do{if((k&4|0)==0){if((d|0)!=0){s=r;break}s=(e|0)==0?0.0:1.0}else{if((d|0)!=6){s=f?r:0.0;break}s=(e|0)==0?.25:.75}}while(0);c[278444]=e;e=a+20|0;g[e>>2]=+g[e>>2]+q*s;s=+g[5432];f=c[278498]|0;d=f&1;k=(f&2|0)!=0;t=f&6;if((t|0)==2){u=(d|0)==0?0.0:.5}else{u=0.0}do{if((f&4|0)==0){if((t|0)!=0){v=u;break}v=(d|0)==0?0.0:1.0}else{if((t|0)!=6){v=k?u:0.0;break}v=(d|0)==0?.25:.75}}while(0);c[278498]=d;g[e>>2]=+g[e>>2]-s*v;if((c[278484]&1|0)==0){v=+g[5558];d=c[278494]|0;k=d&1;t=(d&2|0)!=0;f=d&6;if((f|0)==2){w=(k|0)==0?0.0:.5}else{w=0.0}do{if((d&4|0)==0){if((f|0)!=0){x=w;break}x=(k|0)==0?0.0:1.0}else{if((f|0)!=6){x=t?w:0.0;break}x=(k|0)==0?.25:.75}}while(0);c[278494]=k;k=a+12|0;g[k>>2]=+g[k>>2]+v*x;x=+g[5656];t=c[278502]|0;f=t&1;d=(t&2|0)!=0;y=t&6;if((y|0)==2){z=(f|0)==0?0.0:.5}else{z=0.0}do{if((t&4|0)==0){if((y|0)!=0){A=z;break}A=(f|0)==0?0.0:1.0}else{if((y|0)!=6){A=d?z:0.0;break}A=(f|0)==0?.25:.75}}while(0);c[278502]=f;g[k>>2]=+g[k>>2]-x*A}if((c[278452]&1|0)==0){return}k=a+12|0;g[k>>2]=+g[5544]*+g[k>>2];g[h>>2]=+g[5544]*+g[h>>2];g[e>>2]=+g[5544]*+g[e>>2];return}function mV(a){a=a|0;var b=0,d=0,e=0,f=0.0;b=i;i=i+152|0;d=b|0;c[d+12>>2]=128;c[d+16>>2]=0;c[d+8>>2]=b+24;e=a;c[642245]=c[e>>2];c[2568984>>2]=c[e+4>>2];c[2568988>>2]=c[e+8>>2];c[2568992>>2]=c[e+12>>2];c[2568996>>2]=c[e+16>>2];c[2569e3>>2]=c[e+20>>2];nV(d,3);nY(d,+h[321192]);f=+g[642354];if((c[644543]|0)==666){n3(d,f)}else{n2(d,f)}f=+g[642355];if((c[644543]|0)==666){n3(d,f)}else{n2(d,f)}f=+g[642356];if((c[644543]|0)==666){n3(d,f)}else{n2(d,f)}nW(d,~~+g[a+12>>2]);nW(d,~~+g[a+16>>2]);nW(d,~~+g[a+20>>2]);a=c[278506]|0;e=(a&3|0)!=0|0;c[278506]=a&-3;a=c[278488]|0;c[278488]=a&-3;nV(d,(a&3|0)==0?e:e|2);nV(d,c[278490]|0);c[278490]=0;if((c[353697]|0)!=0){i=b;return}e=(c[642244]|0)+1|0;c[642244]=e;if((e|0)<3){i=b;return}if((r6(c[353705]|0,d)|0)!=-1){i=b;return}oW(95792,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;nf();i=b;return}function mW(){oE(93784,276);oE(92152,140);oE(90408,368);oE(88592,200);oE(86840,32);oE(84936,18);oE(82528,28);oE(80544,330);oE(78752,222);oE(77496,416);oE(76096,274);oE(74848,74);oE(73936,234);oE(72888,386);oE(72e3,414);oE(70696,486);oE(69144,522);oE(67888,272);oE(66896,12);oE(65912,92);oE(64992,476);oE(64200,452);oE(63360,278);oE(62680,172);oE(61968,472);oE(60960,76);oE(59712,462);oE(59160,380);oE(58656,410);oE(58088,518);oE(57552,156);oE(57056,102);oE(56656,160);oE(56176,422);oE(55600,210);return}function mX(a){a=a|0;var b=0,c=0.0,d=0,e=0.0,f=0.0,h=0.0,i=0,j=0.0;b=a+16|0;c=+g[b>>2];do{if(c>1.0){g[b>>2]=1.0;d=1;e=1.0}else{if(c>=0.0){d=0;e=c;break}g[b>>2]=0.0;d=1;e=0.0}}while(0);do{if(+g[5772]!=e){a=xu(~~(e*255.0))|0;if((a|0)>-1){c=+(a|0)/255.0;g[5772]=c;f=c}else{f=+g[5772]}c=+g[b>>2];if(c==f){h=c;i=7574;break}g[b>>2]=f;j=f}else{h=e;i=7574}}while(0);do{if((i|0)==7574){if((d|0)!=0){j=h;break}return}}while(0);pa(54960,j);return}function mY(){if(!(a[19600]&a[14800])){return}xr();c[29314]=a[14800]&1;a[14800]=0;return}function mZ(){if(!(a[19600]&a[23096]&(c[29314]|0)!=0)){return}xs(a[635032]|0);a[14800]=1;return}function m_(b,e){b=b|0;e=e|0;var f=0,h=0,j=0;f=i;if(!(a[19600]|0)){i=f;return}do{if(!(a[23096]|0)){a[23096]=0;if((xt(1083112)|0)==0){a[23096]=1;break}if(a[23096]|0){break}i=f;return}}while(0);h=a[627336+(b&255)|0]|0;b=h&255;if(h<<24>>24==0|(h&255)>(d[1083112]|0)){oX(77192,(j=i,i=i+8|0,c[j>>2]=b,j)|0);i=j;i=f;return}if((xj(h)|0)==0){oW(65664,(j=i,i=i+8|0,c[j>>2]=b,j)|0);i=j;i=f;return}do{if(a[14800]|0){if((a[635032]|0)==h<<24>>24){i=f;return}if(!(a[19600]|0)){break}xq();c[29314]=0;a[14800]=0}}while(0);if((xk(h)|0)==0){c[158760]=e;a[635032]=h;a[14800]=1}if(+g[5772]!=0.0){i=f;return}if(!(a[19600]&a[14800])){i=f;return}xr();c[29314]=a[14800]&1;a[14800]=0;i=f;return}function m$(){var b=0;if(!(a[19600]&a[14800])){return}b=c[669424]|0;if((b|0)>=(eU(0)|0)){return}c[669424]=(eU(0)|0)+2;if((xl(a[635032]|0)|0)!=0){return}a[14800]=0;if((c[158760]|0)==0){return}m_(a[635032]|0,1);return}function m0(){var b=0,d=0,e=0,f=0,g=0;b=i;if((c[353150]|0)==0){d=-1;i=b;return d|0}if((ob(57920)|0)!=0){d=-1;i=b;return d|0}oE(52424,366);e=xm()|0;if((e|0)==0){f=0}else{d=e;i=b;return d|0}do{a[627336+f|0]=f&255;f=f+1|0;}while((f|0)<100);a[18488]=1;a[19600]=1;oW(48704,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;a[23096]=0;if((xt(1083112)|0)==0){g=1}else{oW(44488,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;g=0}a[23096]=g;pb(26904);d=0;i=b;return d|0}function m1(){var b=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0;b=i;if((oq()|0)<2){i=b;return}e=os(1)|0;if((yM(e|0,40312)|0)==0){a[19600]=1;i=b;return}if((yM(e|0,36928)|0)==0){if(a[19600]&a[14800]){xq();c[29314]=0;a[14800]=0}a[19600]=0;i=b;return}if((yM(e|0,107184)|0)==0){a[19600]=1;if(a[14800]|0){xq();c[29314]=0;a[14800]=0;f=0}else{f=0}do{a[627336+f|0]=f&255;f=f+1|0;}while((f|0)<100);a[23096]=0;if((xt(1083112)|0)!=0){i=b;return}a[23096]=1;i=b;return}if((yM(e|0,103632)|0)==0){f=(oq()|0)-2|0;if((f|0)<1){j=1}else{k=1;while(1){l=k+1|0;a[627336+k|0]=(nE(os(l)|0)|0)&255;if((l|0)>(f|0)){break}else{k=l}}i=b;return}do{k=d[627336+j|0]|0;if((k|0)!=(j|0)){oW(100704,(m=i,i=i+16|0,c[m>>2]=j,c[m+8>>2]=k,m)|0);i=m}j=j+1|0;}while((j|0)<100);i=b;return}if((yM(e|0,99032)|0)==0){if(!(a[19600]|0)){i=b;return}xp();i=b;return}do{if(!(a[23096]|0)){a[23096]=0;if((xt(1083112)|0)==0){a[23096]=1;break}if(a[23096]|0){break}oW(97128,(m=i,i=i+1|0,i=i+7>>3<<3,c[m>>2]=0,m)|0);i=m;i=b;return}}while(0);if((yM(e|0,94760)|0)==0){m_((nE(os(2)|0)|0)&255,0);i=b;return}if((yM(e|0,93032)|0)==0){m_((nE(os(2)|0)|0)&255,1);i=b;return}if((yM(e|0,91384)|0)==0){if(!(a[19600]&a[14800])){i=b;return}xq();c[29314]=0;a[14800]=0;i=b;return}if((yM(e|0,89496)|0)==0){if(!(a[19600]&a[14800])){i=b;return}xr();c[29314]=a[14800]&1;a[14800]=0;i=b;return}if((yM(e|0,87832)|0)==0){if(!(a[19600]&(c[29314]|0)!=0)){i=b;return}xs(a[635032]|0);a[14800]=1;i=b;return}if((yM(e|0,86088)|0)==0){do{if(a[14800]|0){if(!(a[19600]|0)){break}xq();c[29314]=0;a[14800]=0;n=7683}else{n=7683}}while(0);do{if((n|0)==7683){if(!(a[19600]|0)){break}xo()}}while(0);a[23096]=0;i=b;return}if((yM(e|0,83600)|0)!=0){i=b;return}oW(81360,(m=i,i=i+8|0,c[m>>2]=d[1083112]|0,m)|0);i=m;do{if(a[14800]|0){e=d[635032]|0;oW(79520,(m=i,i=i+16|0,c[m>>2]=(c[158760]|0)!=0?77968:76712,c[m+8>>2]=e,m)|0);i=m}else{if((c[29314]|0)==0){break}e=d[635032]|0;oW(75272,(m=i,i=i+16|0,c[m>>2]=(c[158760]|0)!=0?77968:76712,c[m+8>>2]=e,m)|0);i=m}}while(0);oW(74400,(m=i,i=i+8|0,h[m>>3]=+g[6730],m)|0);i=m;i=b;return}function m2(){if(!(a[18488]|0)){return}if(a[19600]&a[14800]){xq();c[29314]=0;a[14800]=0}xn();a[18488]=0;return}function m3(b,d,e,f,h){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;j=i;k=x_()|0;l=c[e+4>>2]|0;if((l|0)!=6){w1(43320,(m=i,i=i+24|0,c[m>>2]=d,c[m+8>>2]=l,c[m+16>>2]=6,m)|0);i=m}l=fN[c[b>>2]&63]()|0;n=e+68|0;o=x1(l+112+((c[n>>2]|0)*36|0)|0,h)|0;c[158762]=o+l;c[d+80>>2]=c[e+76>>2];c[(c[158762]|0)+24>>2]=c[e+48>>2];c[(c[158762]|0)+40>>2]=c[e+52>>2];c[(c[158762]|0)+44>>2]=c[e+56>>2];p=c[158762]|0;if((c[p+44>>2]|0)>480){w1(91048,(m=i,i=i+16|0,c[m>>2]=d,c[m+8>>2]=480,m)|0);i=m;q=c[158762]|0}else{q=p}c[q+48>>2]=c[e+60>>2];q=c[158762]|0;p=c[q+48>>2]|0;if((p|0)<1){w1(74232,(m=i,i=i+8|0,c[m>>2]=d,m)|0);i=m;r=c[158762]|0;s=r;t=c[r+48>>2]|0}else{s=q;t=p}if((t|0)>2048){w1(63312,(m=i,i=i+8|0,c[m>>2]=d,m)|0);i=m;u=c[158762]|0}else{u=s}c[u+52>>2]=c[e+64>>2];u=c[158762]|0;if((c[u+52>>2]|0)<1){w1(56528,(m=i,i=i+8|0,c[m>>2]=d,m)|0);i=m;v=c[158762]|0}else{v=u}c[v+56>>2]=c[n>>2];g[(c[158762]|0)+60>>2]=+g[e+80>>2]*.09090909090909091;c[d+76>>2]=c[e+72>>2];c[d+72>>2]=c[(c[158762]|0)+56>>2];g[c[158762]>>2]=+g[e+8>>2];g[(c[158762]|0)+12>>2]=+g[e+20>>2];g[(c[158762]|0)+4>>2]=+g[e+12>>2];g[(c[158762]|0)+16>>2]=+g[e+24>>2];g[(c[158762]|0)+8>>2]=+g[e+16>>2];g[(c[158762]|0)+20>>2]=+g[e+28>>2];n=e+84|0;e=c[158762]|0;v=c[e+24>>2]|0;if((v|0)<1){w1(39536,(m=i,i=i+16|0,c[m>>2]=110936,c[m+8>>2]=v,m)|0);i=m;w=c[158762]|0}else{w=e}e=c[w+40>>2]|0;if((e&3|0)==0){x=w;y=e}else{w1(36352,(m=i,i=i+8|0,c[m>>2]=110936,m)|0);i=m;e=c[158762]|0;x=e;y=c[e+40>>2]|0}e=ab(c[x+44>>2]|0,y)|0;y=x1(v<<3,h)|0;x=y;w=c[158762]|0;c[w+28>>2]=y-w;c[154334]=0;if((v|0)>0){w=0;y=n;u=0;while(1){s=(c[y>>2]|0)==0;t=x+(w<<3)|0;c[t>>2]=u;do{if(s){c[x+(w<<3)+4>>2]=1;p=y+4|0;q=c[154334]|0;c[618368+(q<<2)>>2]=p;g[617344+(q<<2)>>2]=999.0;r=q+1|0;c[154334]=r;z=p+e|0;A=r}else{r=c[y+4>>2]|0;p=x+(w<<3)+4|0;c[p>>2]=r;q=y+8|0;if((r|0)<=0){z=q;A=c[154334]|0;break}r=q;q=0;B=c[154334]|0;do{C=+g[r>>2];g[617344+(B<<2)>>2]=C;if(C>0.0){D=B}else{w1(43616,(m=i,i=i+8|0,c[m>>2]=110960,m)|0);i=m;D=c[154334]|0}B=D+1|0;c[154334]=B;r=r+4|0;q=q+1|0;E=c[p>>2]|0;}while((q|0)<(E|0));q=r;if((E|0)>0){F=q;G=0}else{z=q;A=B;break}while(1){c[618368+((c[t>>2]|0)+G<<2)>>2]=F;q=F+e|0;H=G+1|0;if((H|0)<(c[p>>2]|0)){F=q;G=H}else{z=q;A=B;break}}}}while(0);I=z;t=w+1|0;if((t|0)<(v|0)){w=t;y=I;u=A}else{break}}J=I;K=A<<2}else{J=n;K=0}n=x2(K)|0;K=c[158762]|0;c[K+32>>2]=n-K;K=c[154334]<<2;yJ(n|0,617344,K)|0;K=fO[c[b+4>>2]&15](f|0,c[158762]|0,c[154334]|0,618368)|0;n=c[158762]|0;c[n+36>>2]=K-n;n=J;J=c[158762]|0;K=J+48|0;A=c[K>>2]|0;if((A|0)>0){I=0;while(1){c[557840+(I*12|0)>>2]=c[n+(I*12|0)>>2];c[557844+(I*12|0)>>2]=c[n+(I*12|0)+4>>2];c[557848+(I*12|0)>>2]=c[n+(I*12|0)+8>>2];u=I+1|0;y=c[K>>2]|0;if((u|0)<(y|0)){I=u}else{L=y;break}}}else{L=A}A=n+(L*12|0)|0;if((c[J+52>>2]|0)>0){L=d|0;n=0;I=J;while(1){c[117656+(n<<4)>>2]=c[A+(n<<4)>>2];K=c[A+(n<<4)+4>>2]|0;c[117660+(n<<4)>>2]=K;y=c[I+48>>2]|0;if(!((K|0)>-1&(K|0)<(y|0))){w1(51552,(m=i,i=i+32|0,c[m>>2]=110984,c[m+8>>2]=K,c[m+16>>2]=y,c[m+24>>2]=L,m)|0);i=m}y=c[A+(n<<4)+8>>2]|0;c[117664+(n<<4)>>2]=y;K=c[(c[158762]|0)+48>>2]|0;if(!((y|0)>-1&(y|0)<(K|0))){w1(51552,(m=i,i=i+32|0,c[m>>2]=110984,c[m+8>>2]=y,c[m+16>>2]=K,c[m+24>>2]=L,m)|0);i=m}K=c[A+(n<<4)+12>>2]|0;c[117668+(n<<4)>>2]=K;y=c[158762]|0;u=c[y+48>>2]|0;if((K|0)>-1&(K|0)<(u|0)){M=y}else{w1(51552,(m=i,i=i+32|0,c[m>>2]=110984,c[m+8>>2]=K,c[m+16>>2]=u,c[m+24>>2]=L,m)|0);i=m;M=c[158762]|0}u=n+1|0;if((u|0)<(c[M+52>>2]|0)){n=u;I=M}else{N=M;break}}}else{N=J}J=c[N+56>>2]|0;if((J|0)<1){w1(47768,(m=i,i=i+16|0,c[m>>2]=110984,c[m+8>>2]=J,m)|0);i=m;c[158238]=0;O=0}else{c[158238]=0;N=A+(c[(c[158762]|0)+52>>2]<<4)|0;A=0;while(1){M=N+4|0;if((c[N>>2]|0)==0){I=M;n=c[158762]|0;L=n+76+(A*36|0)+20|0;u=N+12|0;yP(L|0,u|0,16)|0;a[n+76+(A*36|0)+35|0]=0;c[n+76+(A*36|0)>>2]=c[158238];c[n+76+(A*36|0)+4>>2]=1;a[n+76+(A*36|0)+8|0]=a[M]|0;a[n+76+(A*36|0)+12|0]=a[N+8|0]|0;a[n+76+(A*36|0)+9|0]=a[I+1|0]|0;a[n+76+(A*36|0)+13|0]=a[I+5|0]|0;a[n+76+(A*36|0)+10|0]=a[I+2|0]|0;a[n+76+(A*36|0)+14|0]=a[I+6|0]|0;I=N+28|0;n=c[158238]|0;c[630904+(n<<2)>>2]=I;g[632960+(n<<2)>>2]=999.0;c[158238]=n+1;P=I+(c[(c[158762]|0)+48>>2]<<2)|0}else{I=M;n=c[158762]|0;u=c[M>>2]|0;c[n+76+(A*36|0)>>2]=c[158238];c[n+76+(A*36|0)+4>>2]=u;a[n+76+(A*36|0)+8|0]=a[N+8|0]|0;a[n+76+(A*36|0)+12|0]=a[N+12|0]|0;a[n+76+(A*36|0)+9|0]=a[I+5|0]|0;a[n+76+(A*36|0)+13|0]=a[I+9|0]|0;a[n+76+(A*36|0)+10|0]=a[I+6|0]|0;a[n+76+(A*36|0)+14|0]=a[I+10|0]|0;M=I+12+(u<<2)|0;L=n+76+(A*36|0)+20|0;K=I+12+(u+2<<2)|0;yP(L|0,K|0,16)|0;a[n+76+(A*36|0)+35|0]=0;if((u|0)>0){n=0;K=M;L=c[158238]|0;while(1){c[630904+(L<<2)>>2]=K+24;C=+g[I+12+(n<<2)>>2];g[632960+(L<<2)>>2]=C;if(C>0.0){Q=L}else{w1(43616,(m=i,i=i+8|0,c[m>>2]=111008,m)|0);i=m;Q=c[158238]|0}y=Q+1|0;c[158238]=y;w=K+24+(c[(c[158762]|0)+48>>2]<<2)|0;v=n+1|0;if((v|0)<(u|0)){n=v;K=w;L=y}else{R=w;break}}}else{R=M}P=R}L=A+1|0;if((L|0)<(J|0)){N=P;A=L}else{break}}O=c[158238]|0}c[(c[158762]|0)+64>>2]=O;c[d+68>>2]=2;g[d+92>>2]=-16.0;g[d+88>>2]=-16.0;g[d+84>>2]=-16.0;g[d+104>>2]=16.0;g[d+100>>2]=16.0;g[d+96>>2]=16.0;O=x2(c[(c[158762]|0)+64>>2]<<2)|0;A=O;P=c[158762]|0;c[P+68>>2]=O-P;P=c[158762]|0;if((c[P+64>>2]|0)>0){O=0;while(1){g[A+(O<<2)>>2]=+g[632960+(O<<2)>>2];N=O+1|0;J=c[158762]|0;if((N|0)<(c[J+64>>2]|0)){O=N}else{S=J;break}}}else{S=P}fr[c[b+8>>2]&15](f,S,117656,557840,630904);S=(x_()|0)-k|0;f=d+388|0;ye(f,l,S-l|0,h)|0;h=c[f>>2]|0;if((h|0)==0){i=j;return}f=h+(-l|0)|0;yJ(f|0,o|0,S)|0;x3(k);i=j;return}function m4(){pb(22976);pb(22808);pb(22920);pb(23032);pb(22864);return}function m5(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0.0,m=0.0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0;a=i;i=i+192|0;b=a|0;d=a+56|0;e=a+112|0;f=a+144|0;h=a+176|0;j=e|0;k=f|0;rc(2569416,j,k,a+128|0);l=+g[5748];m=+g[5734];g[644660]=+g[157352]- +g[j>>2]*l- +g[k>>2]*m;k=e+4|0;g[644661]=+g[157353]- +g[k>>2]*l- +g[f+4>>2]*m;g[644662]=+g[157354]+ +g[5706];f=a+160|0;q7(629408,4096.0,j,f);n=h|0;yG(d|0,0,52);yu((c[644470]|0)+208|0,0,0.0,1.0,629408,f,d)|0;m=+g[d+24>>2];f=h+4|0;l=+g[d+28>>2];o=h+8|0;p=+g[d+20>>2]- +g[157352];g[n>>2]=p;q=m- +g[157353];g[f>>2]=q;m=l- +g[157354];g[o>>2]=m;l=p*+g[j>>2]+q*+g[k>>2]+m*+g[e+8>>2];g[157355]=(-0.0- +Y(+(m/(l<1.0?1.0:l))))/3.141592653589793*180.0;if(+g[5720]==0.0){r=+g[644660];g[157352]=r;s=+g[644661];g[157353]=s;t=+g[644662];g[157354]=t;i=a;return}yG(b|0,0,52);yu((c[644470]|0)+208|0,0,0.0,1.0,629408,2578640,b)|0;g[n>>2]=+g[b+20>>2];g[f>>2]=+g[b+24>>2];g[o>>2]=+g[b+28>>2];if(+rd(n)==0.0){r=+g[644660];g[157352]=r;s=+g[644661];g[157353]=s;t=+g[644662];g[157354]=t;i=a;return}g[644660]=+g[n>>2];g[644661]=+g[f>>2];g[644662]=+g[o>>2];r=+g[644660];g[157352]=r;s=+g[644661];g[157353]=s;t=+g[644662];g[157354]=t;i=a;return}function m6(){var a=0,b=0,d=0.0,e=0.0,f=0;a=i;if((c[353697]|0)==0){i=a;return}aS(c[353700]|0)|0;c[353697]=0;c[353700]=0;c[353150]=1;if((c[353698]|0)==0){i=a;return}c[353698]=0;b=(c[278812]|0)-(c[353702]|0)-1|0;d=+h[1153]- +g[353703];e=d!=0.0?d:1.0;oW(87256,(f=i,i=i+24|0,c[f>>2]=b,h[f+8>>3]=e,h[f+16>>3]=+(b|0)/e,f)|0);i=f;i=a;return}function m7(){var a=0.0,b=0.0,c=0,d=0,e=0.0,f=0,i=0.0;a=+h[321194];b=a- +h[321195];c=2566960;d=1;e=a;while(1){do{if(+g[c+20>>2]>=e){f=c+16|0;a=+g[f>>2];if(a==0.0){break}i=a-b*+g[c+24>>2];g[f>>2]=i;if(i>=0.0){break}g[f>>2]=0.0}}while(0);if((d|0)>=32){break}c=c+36|0;d=d+1|0;e=+h[321194]}return}function m8(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;if((c[353697]|0)==0){j=r4(c[353705]|0)|0;if((j-1|0)>>>0>1){k=j;i=b;return k|0}else{l=j}while(1){m=c[169348]|0;if((m|0)!=1){break}if((a[c[169346]|0]|0)!=1){break}oW(87736,(n=i,i=i+1|0,i=i+7>>3<<3,c[n>>2]=0,n)|0);i=n;j=r4(c[353705]|0)|0;if((j-1|0)>>>0>1){k=j;o=7831;break}else{l=j}}if((o|0)==7831){i=b;return k|0}if((c[353696]|0)==0){k=l;i=b;return k|0}o=e;c[d>>2]=m;a5(d|0,4,1,c[353700]|0)|0;g[e>>2]=+g[642354];a5(o|0,4,1,c[353700]|0)|0;g[e>>2]=+g[642355];a5(o|0,4,1,c[353700]|0)|0;g[e>>2]=+g[642356];a5(o|0,4,1,c[353700]|0)|0;a5(c[169346]|0,c[169348]|0,1,c[353700]|0)|0;a_(c[353700]|0)|0;k=l;i=b;return k|0}do{if((c[353150]|0)==4){if((c[353698]|0)==0){if(+h[321194]>+h[321192]){break}else{k=0}i=b;return k|0}l=c[278812]|0;if((l|0)==(c[353701]|0)){k=0;i=b;return k|0}c[353701]=l;if((l|0)!=((c[353702]|0)+1|0)){break}g[353703]=+h[1153]}}while(0);eh(677392,4,1,c[353700]|0)|0;g[642351]=+g[642348];g[642352]=+g[642349];g[642353]=+g[642350];l=f;eh(l|0,4,1,c[353700]|0)|0;g[642348]=+g[f>>2];eh(l|0,4,1,c[353700]|0)|0;g[642349]=+g[f>>2];eh(l|0,4,1,c[353700]|0)|0;g[642350]=+g[f>>2];f=c[169348]|0;if((f|0)>32768){w1(36648,(n=i,i=i+1|0,i=i+7>>3<<3,c[n>>2]=0,n)|0);i=n;p=c[169348]|0}else{p=f}if((eh(c[169346]|0,p|0,1,c[353700]|0)|0)==1){k=1;i=b;return k|0}if((c[353697]|0)==0){k=0;i=b;return k|0}aS(c[353700]|0)|0;c[353697]=0;c[353700]=0;c[353150]=1;if((c[353698]|0)==0){k=0;i=b;return k|0}c[353698]=0;p=(c[278812]|0)-(c[353702]|0)-1|0;q=+h[1153]- +g[353703];r=q!=0.0?q:1.0;oW(87256,(n=i,i=i+24|0,c[n>>2]=p,h[n+8>>3]=r,h[n+16>>3]=+(p|0)/r,n)|0);i=n;k=0;i=b;return k|0}function m9(){var a=0,b=0,d=0,e=0,f=0,h=0;a=i;i=i+16|0;b=a|0;d=a+8|0;if((c[353058]|0)!=1){i=a;return}if((c[353696]|0)==0){oW(72472,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e;i=a;return}else{nT(677376);nV(677376,2);f=b;h=d;c[b>>2]=c[169348];b=c[353700]|0;a5(f|0,4,1,b|0)|0;g[d>>2]=+g[642354];b=c[353700]|0;a5(h|0,4,1,b|0)|0;g[d>>2]=+g[642355];b=c[353700]|0;a5(h|0,4,1,b|0)|0;g[d>>2]=+g[642356];d=c[353700]|0;a5(h|0,4,1,d|0)|0;d=c[169346]|0;h=c[169348]|0;b=c[353700]|0;a5(d|0,h|0,1,b|0)|0;b=c[353700]|0;a_(b|0)|0;b=c[353700]|0;aS(b|0)|0;c[353700]=0;c[353696]=0;oW(71296,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e;i=a;return}}function na(){var a=0,b=0,d=0,e=0,f=0,g=0;a=i;i=i+128|0;if((c[353058]|0)!=1){i=a;return}b=oq()|0;if((b-2|0)>>>0>1&(b|0)!=4){oW(61496,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}if((bw(os(1)|0,55456)|0)!=0){oW(50896,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}if((b|0)==2&(c[353150]|0)>>>0>1){oW(47016,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}if((b|0)==4){e=fi(os(3)|0)|0;oW(42688,(d=i,i=i+8|0,c[d>>2]=c[353699],d)|0);i=d;f=e}else{f=-1}e=a|0;g=os(1)|0;cl(e|0,38840,(d=i,i=i+16|0,c[d>>2]=1411672,c[d+8>>2]=g,d)|0)|0;i=d;if((b|0)>2){b=os(2)|0;g=oh(108896,(d=i,i=i+8|0,c[d>>2]=b,d)|0)|0;i=d;oy(g,1)}n9(e,105656);oW(102440,(d=i,i=i+8|0,c[d>>2]=e,d)|0);i=d;g=dc(e|0,100104)|0;c[353700]=g;if((g|0)==0){oW(98512,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}else{c[353699]=f;en(g|0,96328,(d=i,i=i+8|0,c[d>>2]=f,d)|0)|0;i=d;c[353696]=1;i=a;return}}function nb(){var a=0,b=0,d=0;a=i;i=i+256|0;if((c[353058]|0)!=1){i=a;return}if((oq()|0)!=2){oW(94272,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}nf();d=a|0;yQ(d|0,os(1)|0)|0;n9(d,105656);oW(92544,(b=i,i=i+8|0,c[b>>2]=d,b)|0);i=b;od(d,1414800)|0;if((c[353700]|0)==0){oW(98512,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;c[353663]=-1;i=a;return}c[353697]=1;c[353150]=2;c[353699]=0;b=0;L10402:while(1){while(1){d=bT(c[353700]|0)|0;if((d|0)==10){break L10402}else if((d|0)==45){b=1;continue L10402}c[353699]=d-48+((c[353699]|0)*10|0)}}if((b|0)==0){i=a;return}c[353699]=-(c[353699]|0);i=a;return}function nc(a){a=a|0;var b=0,d=0;b=xZ(20)|0;d=b;if((b|0)==0){return d|0}c[b>>2]=0;c[b+4>>2]=0;c[b+8>>2]=-1;c[b+16>>2]=0;vl();oj(d,2659312,a,105656,1);return d|0}function nd(){var a=0,b=0;a=i;if((c[353058]|0)!=1){i=a;return}if((oq()|0)==2){nb();c[353698]=1;c[353702]=c[278812];c[353701]=-1;i=a;return}else{oW(88984,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}}function ne(){var a=0,b=0,d=0,e=0;if((c[46140]|0)==0){p6()}nA();yG(2568976,0,9200);nT(1414824);yG(2501424,0,65536);yG(1960752,0,540672);yG(2566960,0,1152);yG(1956400,0,4352);c[644471]=2501424;a=0;b=2501424;while(1){d=a+1|0;c[b+(a<<4)+12>>2]=b+(d<<4);e=c[644471]|0;if((d|0)<4095){a=d;b=e}else{break}}c[e+65532>>2]=0;return}function nf(){var a=0,b=0;a=i;vF(1);g[1184]=0.0;c[642319]=0;xb(c[278818]|0);do{if((c[353697]|0)==0){if((c[353150]|0)>>>0<=1){break}if((c[353696]|0)!=0){m9()}oX(92368,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;nT(1414824);nV(1414824,2);b=c[353705]|0;r6(b,1414824)|0;nT(1414824);r3(c[353705]|0);c[353150]=1;if((c[46140]|0)==0){break}p_(0)}else{m6()}}while(0);c[353697]=0;c[353698]=0;c[353704]=0;i=a;return}function ng(){nf();if((c[46140]|0)==0){return}p_(0);return}function nh(a){a=a|0;var b=0,d=0,e=0;b=i;if((c[353150]|0)==0|(c[353697]|0)!=0){i=b;return}nf();d=r0(a)|0;c[353705]=d;if((d|0)==0){qa(90696,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e}oX(88832,(e=i,i=i+8|0,c[e>>2]=a,e)|0);i=e;c[353663]=-1;c[353150]=2;c[353704]=0;i=b;return}function ni(){var a=0,b=0,d=0;a=i;oX(87080,(b=i,i=i+8|0,c[b>>2]=c[353704],b)|0);i=b;d=c[353704]|0;if((d|0)==3){nV(1414824,4);n_(1414824,77608);yb();c[353150]=3;i=a;return}else if((d|0)==4){vf();c[353150]=4;i=a;return}else if((d|0)==1){nV(1414824,4);n_(1414824,85184);i=a;return}else if((d|0)==2){nV(1414824,4);n0(1414824,82688,(b=i,i=i+8|0,c[b>>2]=c[5527],b)|0);i=b;nV(1414824,4);d=~~+g[5600];n0(1414824,80680,(b=i,i=i+16|0,c[b>>2]=d>>4,c[b+8>>2]=d&15,b)|0);i=b;nV(1414824,4);n0(1414824,78912,(b=i,i=i+8|0,c[b>>2]=1412604,b)|0);i=b;i=a;return}else{i=a;return}}function nj(){var b=0,d=0,e=0,f=0,g=0;b=i;i=i+1024|0;d=b|0;if((c[353663]|0)==-1){i=b;return}ve();e=c[353663]|0;do{if((a[1414656+(e<<4)|0]|0)==0|(e|0)==8){c[353663]=0;if((a[1414656]|0)!=0){f=0;break}oW(76216,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;c[353663]=-1;i=b;return}else{f=e}}while(0);e=d|0;cl(e|0,74976,(g=i,i=i+8|0,c[g>>2]=1414656+(f<<4),g)|0)|0;i=g;ow(e);c[353663]=(c[353663]|0)+1;i=b;return}function nk(){var a=0,b=0,d=0,e=0,f=0,j=0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0;a=i;if((c[644472]|0)>0){b=1960752;d=0}else{i=a;return}while(1){oW(74040,(e=i,i=i+8|0,c[e>>2]=d,e)|0);i=e;f=c[b+136>>2]|0;if((f|0)==0){oW(72968,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e}else{j=c[b+140>>2]|0;k=+g[b+112>>2];l=+g[b+116>>2];m=+g[b+120>>2];n=+g[b+124>>2];o=+g[b+128>>2];p=+g[b+132>>2];oW(72120,(e=i,i=i+64|0,c[e>>2]=f,c[e+8>>2]=j,h[e+16>>3]=k,h[e+24>>3]=l,h[e+32>>3]=m,h[e+40>>3]=n,h[e+48>>3]=o,h[e+56>>3]=p,e)|0);i=e}e=d+1|0;if((e|0)<(c[644472]|0)){b=b+264|0;d=e}else{break}}i=a;return}function nl(a){a=a|0;var b=0,d=0,e=0,f=0,i=0,j=0.0,k=0;L10488:do{if((a|0)!=0){b=0;d=2566960;while(1){e=d|0;if((c[e>>2]|0)==(a|0)){break}f=b+1|0;if((f|0)<32){b=f;d=d+36|0}else{break L10488}}yG(d|0,0,32);c[d+32>>2]=20040;c[e>>2]=a;i=d;return i|0}}while(0);j=+h[321194];e=0;b=2566960;while(1){if(+g[b+20>>2]<j){k=7950;break}f=e+1|0;if((f|0)<32){e=f;b=b+36|0}else{k=7952;break}}if((k|0)==7952){yG(2566960,0,32);c[641748]=20040;c[641740]=a;i=2566960;return i|0}else if((k|0)==7950){yG(b|0,0,32);c[b+32>>2]=20040;c[b>>2]=a;i=b;return i|0}return 0}function nm(){var a=0,d=0,e=0,f=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0.0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0;a=i;i=i+80|0;d=a|0;e=a+16|0;f=a+32|0;j=a+48|0;k=a+64|0;l=+h[321192];m=+h[321193];n=l-m;do{if(n!=0.0){if(+g[5516]!=0.0|(c[353698]|0)!=0|(c[46140]|0)!=0){o=7959;break}if(n>.1){p=l+-.1;h[321193]=p;q=.10000000149011612;r=p}else{q=n;r=m}p=+h[321194];s=(p-r)/q;if(s<0.0){if(s>=-.01){t=0.0;u=p;break}h[321194]=r;t=0.0;u=r;break}if(s<=1.0){t=s;u=p;break}if(s<=1.01){t=1.0;u=p;break}h[321194]=l;t=1.0;u=l}else{o=7959}}while(0);if((o|0)==7959){h[321194]=l;t=1.0;u=l}c[489098]=0;l=+g[642360];g[642363]=l+t*(+g[642357]-l);l=+g[642361];g[642364]=l+t*(+g[642358]-l);l=+g[642362];g[642365]=l+t*(+g[642359]-l);if((c[353697]|0)!=0){l=+g[642351];r=+g[642348]-l;do{if(r>180.0){v=r+-360.0}else{if(r>=-180.0){v=r;break}v=r+360.0}}while(0);g[642354]=l+t*v;v=+g[642352];l=+g[642349]-v;do{if(l>180.0){w=l+-360.0}else{if(l>=-180.0){w=l;break}w=l+360.0}}while(0);g[642355]=v+t*w;w=+g[642353];v=+g[642350]-w;do{if(v>180.0){x=v+-360.0}else{if(v>=-180.0){x=v;break}x=v+360.0}}while(0);g[642356]=w+t*x}x=+qS(u*100.0);if((c[644472]|0)<=1){i=a;return}y=e|0;z=e+4|0;A=e+8|0;e=f|0;f=j|0;j=k|0;k=1;B=1961016;while(1){C=B+136|0;do{if((c[C>>2]|0)==0){if((c[B>>2]|0)==0){break}uc(B)}else{if(+h[B+56>>3]!=+h[321192]){c[C>>2]=0;b[B+188>>1]=0;b[B+190>>1]=0;g[B+224>>2]=0.0;g[B+228>>2]=0.0;g[B+256>>2]=0.0;g[B+260>>2]=0.0;break}D=B+112|0;g[y>>2]=+g[D>>2];E=B+116|0;g[z>>2]=+g[E>>2];F=B+120|0;g[A>>2]=+g[F>>2];G=B|0;u=+g[B+64>>2];if((c[G>>2]|0)==0){H=B+76|0;w=u- +g[H>>2];g[d>>2]=w;I=B+80|0;v=+g[B+68>>2]- +g[I>>2];J=d+4|0;g[J>>2]=v;K=B+84|0;l=+g[B+72>>2]- +g[K>>2];L=d+8|0;g[L>>2]=l;r=l>100.0|l<-100.0?1.0:v>100.0|v<-100.0?1.0:w>100.0|w<-100.0?1.0:t;g[D>>2]=+g[H>>2]+r*w;w=+g[B+100>>2];v=+g[B+88>>2]-w;do{if(v>180.0){M=v+-360.0}else{if(v>=-180.0){M=v;break}M=v+360.0}}while(0);g[B+124>>2]=w+r*M;g[E>>2]=+g[I>>2]+r*+g[J>>2];v=+g[B+104>>2];l=+g[B+92>>2]-v;do{if(l>180.0){N=l+-360.0}else{if(l>=-180.0){N=l;break}N=l+360.0}}while(0);g[B+128>>2]=v+r*N;g[F>>2]=+g[K>>2]+r*+g[L>>2];l=+g[B+108>>2];w=+g[B+96>>2]-l;do{if(w>180.0){O=w+-360.0}else{if(w>=-180.0){O=w;break}O=w+360.0}}while(0);g[B+132>>2]=l+r*O}else{g[D>>2]=u;g[E>>2]=+g[B+68>>2];g[F>>2]=+g[B+72>>2];g[B+124>>2]=+g[B+88>>2];g[B+128>>2]=+g[B+92>>2];g[B+132>>2]=+g[B+96>>2]}if((c[(c[C>>2]|0)+80>>2]&8|0)!=0){g[B+128>>2]=x}L=B+164|0;K=c[L>>2]|0;if((K&1|0)==0){P=K}else{uB(B);P=c[L>>2]|0}if((P&2|0)==0){Q=P}else{K=0;J=2566960;while(1){R=J|0;if((c[R>>2]|0)==(k|0)){o=7995;break}I=K+1|0;if((I|0)<32){K=I;J=J+36|0}else{o=7993;break}}do{if((o|0)==7995){o=0;yG(J|0,0,32);c[J+32>>2]=20040;c[R>>2]=k;S=J}else if((o|0)==7993){o=0;u=+h[321194];K=0;I=2566960;while(1){if(+g[I+20>>2]<u){o=7998;break}H=K+1|0;if((H|0)<32){K=H;I=I+36|0}else{o=8e3;break}}if((o|0)==7998){o=0;yG(I|0,0,32);c[I+32>>2]=20040;c[I>>2]=k;S=I;break}else if((o|0)==8e3){o=0;yG(2566960,0,32);c[641748]=20040;c[641740]=k;S=2566960;break}}}while(0);J=S+4|0;g[J>>2]=+g[D>>2];g[S+8>>2]=+g[E>>2];g[S+12>>2]=+g[F>>2]+16.0;rc(B+124|0,e,f,j);q7(J,18.0,e,J);g[S+16>>2]=+(((aQ()|0)&31)+200|0);g[S+28>>2]=32.0;g[S+20>>2]=+h[321194]+.1;c[S+32>>2]=20040;Q=c[L>>2]|0}if((Q&4|0)==0){T=Q}else{J=0;K=2566960;while(1){U=K|0;if((c[U>>2]|0)==(k|0)){o=8005;break}H=J+1|0;if((H|0)<32){J=H;K=K+36|0}else{o=8003;break}}do{if((o|0)==8003){o=0;u=+h[321194];J=0;H=2566960;while(1){if(+g[H+20>>2]<u){o=8008;break}V=J+1|0;if((V|0)<32){J=V;H=H+36|0}else{o=8010;break}}if((o|0)==8010){o=0;yG(2566960,0,32);c[641748]=20040;c[641740]=k;W=2566960;break}else if((o|0)==8008){o=0;yG(H|0,0,32);c[H+32>>2]=20040;c[H>>2]=k;W=H;break}}else if((o|0)==8005){o=0;yG(K|0,0,32);c[K+32>>2]=20040;c[U>>2]=k;W=K}}while(0);g[W+4>>2]=+g[D>>2];g[W+8>>2]=+g[E>>2];g[W+12>>2]=+g[F>>2]+16.0;g[W+16>>2]=+(((aQ()|0)&31)+400|0);g[W+20>>2]=+h[321194]+.001;c[W+32>>2]=20040;T=c[L>>2]|0}if((T&8|0)==0){X=T}else{K=0;J=2566960;while(1){Y=J|0;if((c[Y>>2]|0)==(k|0)){o=8015;break}I=K+1|0;if((I|0)<32){K=I;J=J+36|0}else{o=8013;break}}do{if((o|0)==8013){o=0;u=+h[321194];K=0;I=2566960;while(1){if(+g[I+20>>2]<u){o=8018;break}V=K+1|0;if((V|0)<32){K=V;I=I+36|0}else{o=8020;break}}if((o|0)==8020){o=0;yG(2566960,0,32);c[641748]=20040;c[641740]=k;Z=2566960;break}else if((o|0)==8018){o=0;yG(I|0,0,32);c[I+32>>2]=20040;c[I>>2]=k;Z=I;break}}else if((o|0)==8015){o=0;yG(J|0,0,32);c[J+32>>2]=20040;c[Y>>2]=k;Z=J}}while(0);g[Z+4>>2]=+g[D>>2];g[Z+8>>2]=+g[E>>2];g[Z+12>>2]=+g[F>>2];g[Z+16>>2]=+(((aQ()|0)&31)+200|0);g[Z+20>>2]=+h[321194]+.001;c[Z+32>>2]=20040;X=c[L>>2]|0}do{if((X&192|0)==192){J=0;K=2566960;while(1){_=K|0;if((c[_>>2]|0)==(k|0)){o=8025;break}H=J+1|0;if((H|0)<32){J=H;K=K+36|0}else{o=8023;break}}do{if((o|0)==8025){o=0;yG(K|0,0,32);c[K+32>>2]=20040;c[_>>2]=k;$=K}else if((o|0)==8023){o=0;u=+h[321194];J=0;I=2566960;while(1){if(+g[I+20>>2]<u){o=8028;break}H=J+1|0;if((H|0)<32){J=H;I=I+36|0}else{o=8030;break}}if((o|0)==8028){o=0;yG(I|0,0,32);c[I+32>>2]=20040;c[I>>2]=k;$=I;break}else if((o|0)==8030){o=0;yG(2566960,0,32);c[641748]=20040;c[641740]=k;$=2566960;break}}}while(0);g[$+4>>2]=+g[D>>2];g[$+8>>2]=+g[E>>2];g[$+12>>2]=+g[F>>2];g[$+16>>2]=+(((aQ()|0)&31)+200|0);g[$+20>>2]=+h[321194]+.001;c[$+32>>2]=20088}else{if((X&64|0)!=0){K=0;J=2566960;while(1){aa=J|0;if((c[aa>>2]|0)==(k|0)){o=8035;break}H=K+1|0;if((H|0)<32){K=H;J=J+36|0}else{o=8033;break}}do{if((o|0)==8035){o=0;yG(J|0,0,32);c[J+32>>2]=20040;c[aa>>2]=k;ab=J}else if((o|0)==8033){o=0;u=+h[321194];K=0;H=2566960;while(1){if(+g[H+20>>2]<u){o=8038;break}V=K+1|0;if((V|0)<32){K=V;H=H+36|0}else{o=8040;break}}if((o|0)==8038){o=0;yG(H|0,0,32);c[H+32>>2]=20040;c[H>>2]=k;ab=H;break}else if((o|0)==8040){o=0;yG(2566960,0,32);c[641748]=20040;c[641740]=k;ab=2566960;break}}}while(0);g[ab+4>>2]=+g[D>>2];g[ab+8>>2]=+g[E>>2];g[ab+12>>2]=+g[F>>2];g[ab+16>>2]=+(((aQ()|0)&31)+200|0);g[ab+20>>2]=+h[321194]+.001;c[ab+32>>2]=20056;break}if((X&128|0)==0){break}else{ac=0;ad=2566960}while(1){ae=ad|0;if((c[ae>>2]|0)==(k|0)){o=8045;break}J=ac+1|0;if((J|0)<32){ac=J;ad=ad+36|0}else{o=8043;break}}do{if((o|0)==8043){o=0;u=+h[321194];J=0;K=2566960;while(1){if(+g[K+20>>2]<u){o=8048;break}I=J+1|0;if((I|0)<32){J=I;K=K+36|0}else{o=8050;break}}if((o|0)==8048){o=0;yG(K|0,0,32);c[K+32>>2]=20040;c[K>>2]=k;af=K;break}else if((o|0)==8050){o=0;yG(2566960,0,32);c[641748]=20040;c[641740]=k;af=2566960;break}}else if((o|0)==8045){o=0;yG(ad|0,0,32);c[ad+32>>2]=20040;c[ae>>2]=k;af=ad}}while(0);g[af+4>>2]=+g[D>>2];g[af+8>>2]=+g[E>>2];g[af+12>>2]=+g[F>>2];g[af+16>>2]=+(((aQ()|0)&31)+200|0);g[af+20>>2]=+h[321194]+.001;c[af+32>>2]=20072}}while(0);L=c[(c[C>>2]|0)+80>>2]|0;do{if((L&4|0)==0){if((L&32|0)!=0){uK(y,D,4);break}if((L&16|0)!=0){uK(y,D,3);break}if((L&64|0)!=0){uK(y,D,5);break}if((L&1|0)==0){if((L&2|0)!=0){uK(y,D,1);break}if((L&128|0)==0){break}uK(y,D,6);break}uK(y,D,0);J=0;H=2566960;while(1){ag=H|0;if((c[ag>>2]|0)==(k|0)){o=8064;break}I=J+1|0;if((I|0)<32){J=I;H=H+36|0}else{o=8062;break}}do{if((o|0)==8062){o=0;u=+h[321194];J=0;I=2566960;while(1){if(+g[I+20>>2]<u){o=8067;break}V=J+1|0;if((V|0)<32){J=V;I=I+36|0}else{o=8069;break}}if((o|0)==8067){o=0;yG(I|0,0,32);c[I+32>>2]=20040;c[I>>2]=k;ah=I;break}else if((o|0)==8069){o=0;yG(2566960,0,32);c[641748]=20040;c[641740]=k;ah=2566960;break}}else if((o|0)==8064){o=0;yG(H|0,0,32);c[H+32>>2]=20040;c[ag>>2]=k;ah=H}}while(0);g[ah+4>>2]=+g[D>>2];g[ah+8>>2]=+g[E>>2];g[ah+12>>2]=+g[F>>2];g[ah+16>>2]=200.0;g[ah+20>>2]=+h[321194]+.01}else{uK(y,D,2)}}while(0);c[G>>2]=0;D=c[489098]|0;if(!(((k|0)!=(c[644467]|0)|+g[5762]!=0.0)&(D|0)<1024)){break}F=1415664+(D*264|0)|0;E=B;yJ(F|0,E|0,264)|0;c[489098]=D+1}}while(0);C=k+1|0;if((C|0)<(c[644472]|0)){k=C;B=B+264|0}else{break}}i=a;return}function nn(){var a=0,b=0.0,d=0,e=0;a=i;b=+h[321194];h[321195]=b;h[321194]=+h[2332]+b;do{d=m8()|0;if((d|0)==0){break}else if((d|0)==(-1|0)){qa(70880,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e}g[642392]=+h[1153];ny();}while((c[353150]|0)>>>0>1);if(+g[5460]==0.0){nm();nI();i=a;return 0}oW(69312,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e;nm();nI();i=a;return 0}function no(){var a=0,b=0,d=0,e=0;a=i;i=i+24|0;b=a|0;d=c[353150]|0;if(d>>>0<2){i=a;return}if((d|0)==4){mU(b);xJ(b);mV(b)}if((c[353697]|0)!=0){nT(1414824);i=a;return}if((c[353710]|0)==0){i=a;return}if((r7(c[353705]|0)|0)==0){oX(68040,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e;i=a;return}if((r5(c[353705]|0,1414824)|0)==-1){qa(67040,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e}nT(1414824);i=a;return}function np(){n4(1414824,1024);mW();nz();pb(22104);pb(22384);pb(21712);pb(22216);pb(22608);pb(21768);pb(22160);pb(21600);pb(21992);pb(22664);pb(21824);pb(22048);pb(15576);pb(15520);pb(3824);pb(15400);pb(15264);pb(15456);pb(15320);oE(66024,152);oE(65136,94);oE(64296,344);oE(63560,60);oE(62736,110);oK(62736,20);oE(62112,180);oK(62112,20);oE(61184,42);return}function nq(){var a=0,b=0,d=0,e=0.0,f=0.0,h=0,j=0,k=0,l=0,m=0,n=0;a=i;i=i+16|0;b=a|0;d=nL()|0;if((d&1|0)==0){e=255.0}else{e=+(nL()|0)}if((d&2|0)==0){f=1.0}else{f=+(nL()|0)*.015625}do{if((c[644543]|0)==666){if((d&8|0)==0){h=8131;break}j=(nM()|0)&65535;k=nL()|0;l=j}else{h=8131}}while(0);if((h|0)==8131){h=nM()|0;k=h&7;l=h>>3}h=c[644543]|0;do{if((h|0)==666){if((d&16|0)==0){m=nL()|0;break}else{m=(nM()|0)&65535;break}}else if((h|0)==10001|(h|0)==10002){m=(nM()|0)&65535}else if((h|0)==15|(h|0)==1e4){m=nL()|0}else{qa(64120,(n=i,i=i+16|0,c[n>>2]=111760,c[n+8>>2]=h,n)|0);i=n;m=0}}while(0);if((l|0)>2048){qa(103360,(n=i,i=i+8|0,c[n>>2]=l,n)|0);i=n}n=b|0;g[n>>2]=+nQ();g[b+4>>2]=+nQ();g[b+8>>2]=+nQ();vJ(l,k,c[2573668+(m<<2)>>2]|0,n,e/255.0,f);i=a;return}function nr(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0,k=0.0;a=i;i=i+8216|0;if((c[353697]|c[46140]|0)!=0){i=a;return}b=a|0;c[b>>2]=c[169344];c[b+4>>2]=c[169345];c[b+8>>2]=c[169346];c[b+12>>2]=c[169347];c[b+16>>2]=c[169348];d=c[169346]|0;e=c[169348]|0;f=a+24|0;yJ(f|0,d|0,e)|0;do{e=m8()|0;if((e|0)==1){qa(83608,(h=i,i=i+8|0,c[h>>2]=111888,h)|0);i=h;j=8146}else if((e|0)==2){j=8146}else if((e|0)==0){break}else{qa(60328,(h=i,i=i+8|0,c[h>>2]=111888,h)|0);i=h}do{if((j|0)==8146){j=0;if((nL()|0)==1){break}qa(69928,(h=i,i=i+8|0,c[h>>2]=111888,h)|0);i=h}}while(0);}while((e|0)!=0);c[169344]=c[b>>2];c[169345]=c[b+4>>2];c[169346]=c[b+8>>2];c[169347]=c[b+12>>2];c[169348]=c[b+16>>2];b=c[169346]|0;j=c[169348]|0;yJ(b|0,f|0,j)|0;k=+wZ();if(k- +g[28102]<5.0){i=a;return}g[28102]=k;oW(54544,(h=i,i=i+1|0,i=i+7>>3<<3,c[h>>2]=0,h)|0);i=h;nV(1414824,1);r5(c[353705]|0,1414824)|0;nT(1414824);i=a;return}function ns(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+131072|0;d=b|0;e=b+65536|0;oX(50184,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;ne();g=nN()|0;if(!((g|0)==15|(g|0)==666|(g|0)==1e4|(g|0)==10001|(g|0)==10002)){oW(46296,(f=i,i=i+8|0,c[f>>2]=g,f)|0);i=f;i=b;return}c[644543]=g;g=nL()|0;c[644468]=g;if((g-1|0)>>>0>15){oW(41992,(f=i,i=i+8|0,c[f>>2]=g,f)|0);i=f;i=b;return}c[644542]=x1(g*16428|0,38312)|0;c[644469]=nL()|0;g=nP()|0;bR(2577828,40,108272,(f=i,i=i+8|0,c[f>>2]=g,f)|0)|0;i=f;oW(105024,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;oW(102008,(f=i,i=i+16|0,c[f>>2]=2,c[f+8>>2]=2577828,f)|0);i=f;oW(99704,(f=i,i=i+8|0,c[f>>2]=c[644543],f)|0);i=f;yG(2569572,0,4096);g=nP()|0;L10785:do{if((a[g]|0)==0){h=1}else{j=1;k=g;while(1){l=c[644543]|0;if((l|0)==15){m=256}else if((l|0)==1e4|(l|0)==10001|(l|0)==10002|(l|0)==666){m=1024}else{m=0}if((j|0)==(m|0)){break}n=d+(j<<6)|0;bR(n|0,64,108272,(f=i,i=i+8|0,c[f>>2]=k,f)|0)|0;i=f;rS(n);n=j+1|0;o=nP()|0;if((a[o]|0)==0){h=n;break L10785}else{j=n;k=o}}if((l|0)==15){p=256}else if((l|0)==1e4|(l|0)==10001|(l|0)==10002|(l|0)==666){p=1024}else{p=0}qa(98080,(f=i,i=i+8|0,c[f>>2]=p,f)|0);i=f;i=b;return}}while(0);yG(2573668,0,4096);p=nP()|0;L10800:do{if((a[p]|0)==0){q=1}else{l=1;m=p;while(1){r=c[644543]|0;if((r|0)==15|(r|0)==1e4){s=256}else if((r|0)==10001|(r|0)==10002|(r|0)==666){s=1024}else{s=0}if((r|0)==10001|(r|0)==666){t=1024}else if((r|0)==15|(r|0)==1e4|(r|0)==10002){t=256}else{t=0}do{if(s>>>0>t>>>0){if((r|0)==15|(r|0)==1e4){u=256;break}else if((r|0)==10001|(r|0)==10002|(r|0)==666){u=1024;break}else{u=0;break}}else{if((r|0)==10001|(r|0)==666){u=1024;break}else if((r|0)==15|(r|0)==1e4|(r|0)==10002){u=256;break}else{u=0;break}}}while(0);if((l|0)==(u|0)){break}g=e+(l<<6)|0;bR(g|0,64,108272,(f=i,i=i+8|0,c[f>>2]=m,f)|0)|0;i=f;vH(g);g=l+1|0;k=nP()|0;if((a[k]|0)==0){q=g;break L10800}else{l=g;m=k}}if((r|0)==10001|(r|0)==10002|(r|0)==666){v=1024}else if((r|0)==15|(r|0)==1e4){v=256}else{v=0}if((r|0)==15|(r|0)==1e4|(r|0)==10002){w=256}else if((r|0)==10001|(r|0)==666){w=1024}else{w=0}do{if(v>>>0>w>>>0){if((r|0)==15|(r|0)==1e4){x=256;break}else if((r|0)==10001|(r|0)==10002|(r|0)==666){x=1024;break}else{x=0;break}}else{if((r|0)==15|(r|0)==1e4|(r|0)==10002){x=256;break}else if((r|0)==10001|(r|0)==666){x=1024;break}else{x=0;break}}}while(0);qa(95872,(f=i,i=i+8|0,c[f>>2]=x,f)|0);i=f;i=b;return}}while(0);x=n5(d+64|0)|0;bR(2577764,64,108272,(f=i,i=i+8|0,c[f>>2]=x,f)|0)|0;i=f;n7(2577764);L10843:do{if((h|0)>1){x=1;while(1){y=d+(x<<6)|0;r=rG(y,0)|0;c[2569572+(x<<2)>>2]=r;if((r|0)==0){break}nr();x=x+1|0;if((x|0)>=(h|0)){break L10843}}oW(93792,(f=i,i=i+8|0,c[f>>2]=y,f)|0);i=f;i=b;return}}while(0);vM();if((q|0)>1){f=1;do{c[2573668+(f<<2)>>2]=vE(e+(f<<6)|0)|0;nr();f=f+1|0;}while((f|0)<(q|0))}vN();q=c[642394]|0;c[644470]=q;c[490222]=q;ur();x0();c[159948]=0;i=b;return}
function r6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;if((a|0)==0){e=-1;i=d;return e|0}if((c[a+32>>2]|0)!=0){oW(102392,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;e=-1;i=d;return e|0}h[1884]=+wZ();f=a+44|0;g=fL[c[(c[f>>2]|0)+36>>2]&63](a,b)|0;if((g|0)!=1){e=g;i=d;return e|0}if((c[f>>2]|0)==15144){e=1;i=d;return e|0}c[29408]=(c[29408]|0)+1;e=1;i=d;return e|0}function r7(a){a=a|0;var b=0;if((a|0)==0){b=0;return b|0}if((c[a+32>>2]|0)!=0){b=0;return b|0}h[1884]=+wZ();b=fv[c[(c[a+44>>2]|0)+40>>2]&127](a)|0;return b|0}function r8(a,b){a=a|0;b=+b;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0,w=0,x=0,y=0,z=0;d=i;i=i+128|0;e=d|0;f=d+64|0;g=c[45876]|0;c[278816]=g;j=c[45874]|0;if((j|0)>0){k=g;g=0;l=0;m=j;while(1){j=c[k+24>>2]|0;do{if((j|0)==0){n=3094}else{if((c[k>>2]|0)==0){n=3094;break}o=j+44|0;if((c[o>>2]|0)!=15144){c[e+(g<<2)>>2]=0;c[f+(g<<2)>>2]=0;p=l+1|0;q=k;r=m;break}do{if((c[j+32>>2]|0)==0){h[1884]=+wZ();if((fL[c[(c[o>>2]|0)+32>>2]&63](j,a)|0)!=1){break}if((c[o>>2]|0)==15144){break}c[220094]=(c[220094]|0)+1}else{oW(105616,(s=i,i=i+8|0,c[s>>2]=110360,s)|0);i=s}}while(0);c[e+(g<<2)>>2]=1;c[f+(g<<2)>>2]=1;p=l;q=c[278816]|0;r=c[45874]|0}}while(0);if((n|0)==3094){n=0;c[e+(g<<2)>>2]=1;c[f+(g<<2)>>2]=1;p=l;q=k;r=m}j=g+1|0;o=q+33032|0;c[278816]=o;if((j|0)<(r|0)){k=o;g=j;l=p;m=r}else{t=p;break}}}else{t=0}u=+wZ();p=t;while(1){if((p|0)==0){v=0;n=3123;break}t=c[45876]|0;c[278816]=t;if((c[45874]|0)>0){r=t;t=0;m=0;while(1){l=e+(t<<2)|0;do{if((c[l>>2]|0)==0){g=c[r+24>>2]|0;do{if((g|0)==0){w=0;n=3110}else{if((c[g+32>>2]|0)!=0){w=g;n=3110;break}h[1884]=+wZ();if((fv[c[(c[g+44>>2]|0)+40>>2]&127](g)|0)==0){w=c[(c[278816]|0)+24>>2]|0;n=3110;break}c[l>>2]=1;k=c[(c[278816]|0)+24>>2]|0;if((k|0)==0){break}if((c[k+32>>2]|0)!=0){oW(105616,(s=i,i=i+8|0,c[s>>2]=110360,s)|0);i=s;break}h[1884]=+wZ();q=k+44|0;if((fL[c[(c[q>>2]|0)+32>>2]&63](k,a)|0)!=1){break}if((c[q>>2]|0)==15144){break}c[220094]=(c[220094]|0)+1}}while(0);if((n|0)==3110){n=0;r4(w)|0}x=m+1|0}else{g=f+(t<<2)|0;if((c[g>>2]|0)!=0){x=m;break}q=c[r+24>>2]|0;do{if((q|0)==0){y=0;n=3118}else{if((c[q+32>>2]|0)!=0){y=q;n=3118;break}h[1884]=+wZ();if((fv[c[(c[q+44>>2]|0)+40>>2]&127](q)|0)==0){y=c[(c[278816]|0)+24>>2]|0;n=3118;break}else{c[g>>2]=1;break}}}while(0);if((n|0)==3118){n=0;r4(y)|0}x=m+1|0}}while(0);l=t+1|0;g=(c[278816]|0)+33032|0;c[278816]=g;if((l|0)<(c[45874]|0)){r=g;t=l;m=x}else{z=x;break}}}else{z=0}if(+wZ()-u>b){v=z;n=3124;break}else{p=z}}if((n|0)==3124){i=d;return v|0}else if((n|0)==3123){i=d;return v|0}return 0}function r9(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0;b=i;d=ob(100088)|0;if((d|0)==0){e=ob(98496)|0;if((e|0)!=0){f=e;g=3127}}else{f=d;g=3127}do{if((g|0)==3127){if(f>>>0<((c[353050]|0)-1|0)>>>0){c[28092]=nE(c[(c[353048]|0)+(f+1<<2)>>2]|0)|0;break}else{w1(96336,(j=i,i=i+8|0,c[j>>2]=110376,j)|0);i=j;break}}}while(0);c[169350]=c[28092];f=(ob(94312)|0)!=0;g=(c[353150]|0)==0;if(f|g){c[274558]=1}c[169342]=(c[45875]|0)+(g&1^1);h[1884]=+wZ();if((c[169342]|0)>0){g=0;do{f=x1(65704,92584)|0;c[f>>2]=c[169352];c[169352]=f;c[f+32>>2]=1;g=g+1|0;}while((g|0)<(c[169342]|0))}n4(677376,32768);pb(15088);pb(18536);oE(90960,404);oE(89032,482);oE(87352,304);oE(85408,282);if((c[3770]|0)>0){g=0;f=0;while(1){c[169354]=15144+(f*60|0);d=fN[c[15152+(f*60|0)>>2]&63]()|0;do{if((d|0)==-1){k=g}else{e=g+1|0;c[(c[169354]|0)+4>>2]=1;c[(c[169354]|0)+56>>2]=d;if((c[274558]|0)==0){k=e;break}fs[c[(c[169354]|0)+12>>2]&255](1);k=e}}while(0);d=f+1|0;if((d|0)<(c[3770]|0)){g=k;f=d}else{l=k;break}}}else{l=0}if((c[353150]|l|0)==0){w1(82840,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j}if((a[677440]|0)==0){i=b;return}oX(80880,(j=i,i=i+8|0,c[j>>2]=677440,j)|0);i=j;i=b;return}function sa(){return}function sb(){var a=0,b=0,d=0,e=0,f=0;a=i;if((oq()|0)!=2){oW(66160,(b=i,i=i+8|0,c[b>>2]=(c[274558]|0)!=0,b)|0);i=b;i=a;return}c[274558]=(nE(os(1)|0)|0)!=0;b=c[3770]|0;if((b|0)>0){d=0;e=b}else{i=a;return}while(1){c[169354]=15144+(d*60|0);if((c[15148+(d*60|0)>>2]|0)==0){f=e}else{fs[c[15156+(d*60|0)>>2]&255](c[274558]|0);f=c[3770]|0}b=d+1|0;if((b|0)<(f|0)){d=b;e=f}else{break}}i=a;return}function sc(){var a=0,b=0,d=0,e=0,f=0,h=0;a=i;if((oq()|0)!=2){oW(74184,(b=i,i=i+8|0,c[b>>2]=c[45874],b)|0);i=b;i=a;return}if((c[46140]|0)!=0){oW(73168,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}d=nE(os(1)|0)|0;e=(d|0)<1?1:d;d=c[45875]|0;if((e|0)>(d|0)){oW(72304,(b=i,i=i+8|0,c[b>>2]=d,b)|0);i=b;f=d}else{f=e}e=(f|0)==1;d=c[274558]|0;if(e&(d|0)!=0){ov(76384,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;h=c[274558]|0}else{h=d}if(!((f|0)<2|(h|0)!=0)){ov(75112,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b}c[45874]=f;if(e){o9(71096,69424);o9(68192,69424);i=a;return}if(+g[5344]!=0.0){o9(71096,69424);i=a;return}else{o9(71096,67208);i=a;return}}function sd(){var a=0,b=0,d=0;a=i;if((oq()|0)!=2){oW(79144,(b=i,i=i+8|0,c[b>>2]=c[169350],b)|0);i=b;i=a;return}d=nE(os(1)|0)|0;if((d-1|0)>>>0>65533){oW(77728,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}c[28092]=d;c[169350]=d;if((c[274558]|0)==0){i=a;return}ov(76384,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;ov(75112,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}function se(){var a=0,b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0;a=i;h[1884]=+wZ();b=c[169358]|0;if((b|0)!=0){d=b;do{b=d+32|0;if((c[b>>2]|0)==0){h[1884]=+wZ();fs[c[(c[d+44>>2]|0)+48>>2]&255](d);e=c[169358]|0;do{if((e|0)==(d|0)){f=d|0;c[169358]=c[f>>2];g=f}else{f=e;while(1){if((f|0)==0){j=3197;break}k=f|0;l=c[k>>2]|0;if((l|0)==(d|0)){j=3196;break}else{f=l}}if((j|0)==3196){j=0;f=d|0;c[k>>2]=c[f>>2];g=f;break}else if((j|0)==3197){j=0;w1(50816,(f=i,i=i+8|0,c[f>>2]=110408,f)|0);i=f;g=d|0;break}}}while(0);c[g>>2]=c[169352];c[169352]=d;c[b>>2]=1}d=c[d>>2]|0;}while((d|0)!=0)}d=c[3770]|0;if((d|0)>0){m=0;n=d}else{i=a;return}while(1){c[169354]=15144+(m*60|0);if((c[15148+(m*60|0)>>2]|0)==1){fQ[c[15196+(m*60|0)>>2]&1023]();c[(c[169354]|0)+4>>2]=0;o=c[3770]|0}else{o=n}d=m+1|0;if((d|0)<(o|0)){m=d;n=o}else{break}}i=a;return}function sf(){var a=0,b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0;a=i;b=c[3770]|0;if((b|0)>0){d=0;e=b;while(1){c[169354]=15144+(d*60|0);do{if((c[886]|d|0)==0){f=e}else{if((c[15148+(d*60|0)>>2]|0)==0){f=e;break}fs[c[15160+(d*60|0)>>2]&255](0);f=c[3770]|0}}while(0);b=d+1|0;if((b|0)<(f|0)){d=b;e=f}else{break}}}if((c[153844]|0)==0){f=c[153846]|0;if((f|0)<(c[278830]|0)){e=f;while(1){d=c[1114572+(e*88|0)>>2]|0;b=1114504+(e*88|0)|0;g=1114520+(e*88|0)|0;if((d|0)==0){oW(62816,(j=i,i=i+16|0,c[j>>2]=b,c[j+8>>2]=g,j)|0);i=j}else{k=c[1114568+(e*88|0)>>2]|0;oW(63616,(j=i,i=i+32|0,c[j>>2]=b,c[j+8>>2]=g,c[j+16>>2]=k,c[j+24>>2]=d,j)|0);i=j}d=e+1|0;if((d|0)<(c[278830]|0)){e=d}else{l=d;break}}}else{l=f}c[153846]=l}m=+wZ();if(m- +h[436]>=1.5){do{if((c[153844]|0)==0){if((c[278830]|0)==0){oW(64392,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;break}else{oW(65264,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;break}}}while(0);c[153848]=0;c[153844]=0;c[886]=1;i=a;return}m=+wZ()+.1;h[441]=m;j=0;l=635016;while(1){f=c[l>>2]|0;if((f|0)==0){n=0;break}if(+h[f+8>>3]<m){j=f;l=f|0}else{n=f;break}}if((j|0)==0){c[880]=c[158754];c[158754]=3520;i=a;return}else{c[880]=n;c[j>>2]=3520;i=a;return}}function sg(){var a=0,b=0,d=0,e=0,f=0.0,g=0;a=c[3770]|0;if((a|0)>0){b=0;d=a;while(1){c[169354]=15144+(b*60|0);do{if((c[886]|b|0)==0){e=d}else{if((c[15148+(b*60|0)>>2]|0)==0){e=d;break}fs[c[15160+(b*60|0)>>2]&255](1);e=c[3770]|0}}while(0);a=b+1|0;if((a|0)<(e|0)){b=a;d=e}else{break}}}f=+wZ();if(f- +h[436]>=.5){return}f=+wZ()+.75;h[438]=f;e=0;d=635016;while(1){b=c[d>>2]|0;if((b|0)==0){g=0;break}if(+h[b+8>>3]<f){e=b;d=b|0}else{g=b;break}}if((e|0)==0){c[874]=c[158754];c[158754]=3496;return}else{c[874]=g;c[e>>2]=3496;return}}function sh(){var a=0,b=0,d=0,e=0.0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0;a=c[49322]|0;b=c[(c[157712]|0)+112>>2]|0;d=a+(b+176)|0;e=+qS(+g[d>>2]);f=+g[a+(b+436)>>2];h=+g[a+(b+440)>>2];if(e==f){return}i=f-e;do{if(f>e){if(i<180.0){j=i;break}j=i+-360.0}else{if(i>-180.0){j=i;break}j=i+360.0}}while(0);do{if(j>0.0){if(j<=h){k=j;break}k=h}else{i=-0.0-h;if(j>=i){k=j;break}k=i}}while(0);g[d>>2]=+qS(e+k);return}function si(){var a=0,b=0;a=i;tk(75080,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}function sj(){var a=0;a=c[157712]|0;rc((c[157708]|0)+16|0,a+236|0,a+260|0,a+248|0);return}function sk(){var a=0,b=0,d=0;a=c[49322]|0;b=c[157708]|0;d=c[b+16>>2]|0;g[a+(d+136)>>2]=+g[b+28>>2];g[a+(d+140)>>2]=+g[b+32>>2];g[a+(d+144)>>2]=+g[b+36>>2];yn(a+d|0,0);return}function sl(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0;a=i;b=c[49322]|0;d=c[157708]|0;e=c[d+16>>2]|0;f=b+e|0;h=ti(c[d+28>>2]|0)|0;d=c[46184]|0;L4382:do{if((d|0)==0){j=0;k=3271}else{l=184736;m=0;n=d;while(1){if((cS(n|0,h|0)|0)==0){o=m;break L4382}p=m+1|0;q=l+4|0;r=c[q>>2]|0;if((r|0)==0){j=p;k=3271;break}else{l=q;m=p;n=r}}}}while(0);if((k|0)==3271){tk(70784,(k=i,i=i+8|0,c[k>>2]=h,k)|0);i=k;o=j}c[b+(e+212)>>2]=to(h)|0;s=+(o|0);g[b+(e+96)>>2]=s;e=c[188832+(~~s<<2)>>2]|0;if((e|0)==0){tf(f,117584,117584);i=a;return}else{tf(f,e+84|0,e+96|0);i=a;return}}function sm(){var a=0;a=c[157708]|0;tf((c[49322]|0)+(c[a+16>>2]|0)|0,a+28|0,a+40|0);return}function sn(){var a=0.0;a=+((aQ()|0)&32767|0)/32767.0;g[(c[157708]|0)+4>>2]=a;return}function so(){var a=0,b=0,d=0,e=0,f=0,j=0,k=0.0,l=0;a=i;b=c[157708]|0;d=(c[49322]|0)+(c[b+16>>2]|0)|0;e=~~+g[b+28>>2];f=ti(c[b+40>>2]|0)|0;b=c[157708]|0;j=~~(+g[b+52>>2]*255.0);k=+g[b+64>>2];if(j>>>0>255){w1(82736,(l=i,i=i+16|0,c[l>>2]=110208,c[l+8>>2]=j,l)|0);i=l}if(k<0.0|k>4.0){w1(80840,(l=i,i=i+16|0,c[l>>2]=110208,h[l+8>>3]=k,l)|0);i=l}if(e>>>0<=7){v$(d,e,f,j,k);i=a;return}w1(79104,(l=i,i=i+16|0,c[l>>2]=110208,c[l+8>>2]=e,l)|0);i=l;v$(d,e,f,j,k);i=a;return}function sp(){var a=0,b=0.0,d=0.0,e=0.0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0;a=c[157708]|0;b=+g[a+16>>2];d=+g[a+20>>2];e=+g[a+24>>2];f=+R(+(b*b+d*d+e*e));if(f==0.0){h=0.0;i=0.0;j=0.0}else{k=1.0/f;h=b*k;i=d*k;j=e*k}g[a+4>>2]=h;g[(c[157708]|0)+8>>2]=i;g[(c[157708]|0)+12>>2]=j;return}function sq(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;a[2668888]=0;d=0;e=511;while(1){if((d|0)>=(c[157724]|0)){break}f=ti(c[(c[157708]|0)+((d*3|0)+4<<2)>>2]|0)|0;g=yF(f|0)|0;ev(2668888,f|0,e|0)|0;f=e-g|0;if((f|0)<0){h=3295;break}else{d=d+1|0;e=f}}if((h|0)==3295){oX(50600,(j=i,i=i+8|0,c[j>>2]=110320,j)|0);i=j}h=ti(c[(c[157598]|0)+16>>2]|0)|0;oW(85312,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=2668888,j)|0);i=j;tw((c[49322]|0)+(c[(c[157712]|0)+112>>2]|0)|0);qa(87240,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;i=b;return}function sr(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;a[2668888]=0;d=0;e=511;while(1){if((d|0)>=(c[157724]|0)){break}f=ti(c[(c[157708]|0)+((d*3|0)+4<<2)>>2]|0)|0;g=yF(f|0)|0;ev(2668888,f|0,e|0)|0;f=e-g|0;if((f|0)<0){h=3300;break}else{d=d+1|0;e=f}}if((h|0)==3300){oX(50600,(j=i,i=i+8|0,c[j>>2]=110320,j)|0);i=j}h=ti(c[(c[157598]|0)+16>>2]|0)|0;oW(88928,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=2668888,j)|0);i=j;h=(c[49322]|0)+(c[(c[157712]|0)+112>>2]|0)|0;tw(h);tr(h);qa(87240,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;i=b;return}function ss(){var a=0,b=0.0,d=0.0,e=0.0;a=c[157708]|0;b=+g[a+16>>2];d=+g[a+20>>2];e=+g[a+24>>2];g[a+4>>2]=+R(+(b*b+d*d+e*e));return}function st(){var a=0,b=0.0,d=0.0,e=0.0,f=0.0;a=c[157708]|0;b=+g[a+20>>2];d=+g[a+16>>2];do{if(b==0.0&d==0.0){e=0.0}else{f=+(~~(+Z(+b,+d)*180.0/3.141592653589793)|0);if(f>=0.0){e=f;break}e=f+360.0}}while(0);g[a+4>>2]=e;return}function su(){var a=0;a=tp()|0;c[(c[157708]|0)+4>>2]=a-(c[49322]|0);return}function sv(){tr((c[49322]|0)+(c[(c[157708]|0)+16>>2]|0)|0);return}function sw(){var a=0;oW(77696,(a=i,i=i+1|0,i=i+7>>3<<3,c[a>>2]=0,a)|0);i=a;ca()}function sx(){var a=0,b=0,d=0,e=0,f=0,h=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0;a=i;i=i+56|0;b=a|0;d=c[157708]|0;yt(b,d+16|0,117584,117584,d+28|0,~~+g[d+40>>2],(c[49322]|0)+(c[d+52>>2]|0)|0);d=c[b+4>>2]|0;e=c[b+8>>2]|0;f=c[b+12>>2]|0;h=+g[b+16>>2];j=+g[b+20>>2];k=+g[b+24>>2];l=+g[b+28>>2];m=+g[b+32>>2];n=+g[b+36>>2];o=+g[b+40>>2];p=+g[b+44>>2];q=c[b+48>>2]|0;g[(c[157712]|0)+272>>2]=+((c[b>>2]|0)>>>0>>>0);g[(c[157712]|0)+276>>2]=+(d>>>0>>>0);g[(c[157712]|0)+280>>2]=h;g[(c[157712]|0)+320>>2]=+(f>>>0>>>0);g[(c[157712]|0)+316>>2]=+(e>>>0>>>0);g[(c[157712]|0)+284>>2]=j;g[(c[157712]|0)+288>>2]=k;g[(c[157712]|0)+292>>2]=l;g[(c[157712]|0)+296>>2]=m;g[(c[157712]|0)+300>>2]=n;g[(c[157712]|0)+304>>2]=o;g[(c[157712]|0)+308>>2]=p;if((q|0)==0){c[(c[157712]|0)+312>>2]=0;i=a;return}else{c[(c[157712]|0)+312>>2]=q-(c[49322]|0);i=a;return}}function sy(){var a=0,b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=i;i=i+32|0;b=a|0;d=a+16|0;e=c[46146]|0;if(+h[23072]- +h[23074]<.1){f=e}else{j=c[45874]|0;k=(j|0)>(e|0)?e:j;e=(k|0)>1?k:1;k=(e|0)==(j|0)?1:e+1|0;l=(k|0)==(j+1|0)?1:k;k=tq(l)|0;L4443:do{if((l|0)==(e|0)){m=e;n=k}else{j=l;o=k;while(1){do{if((c[o>>2]|0)==0){if(+g[o+288>>2]<=0.0){break}if((~~+g[o+400>>2]&128|0)==0){m=j;n=o;break L4443}}}while(0);p=j+1|0;q=(p|0)==((c[45874]|0)+1|0)?1:p;p=tq(q)|0;if((q|0)==(e|0)){m=e;n=p;break}else{j=q;o=p}}}}while(0);e=b|0;g[e>>2]=+g[n+136>>2]+ +g[n+344>>2];g[b+4>>2]=+g[n+140>>2]+ +g[n+348>>2];g[b+8>>2]=+g[n+144>>2]+ +g[n+352>>2];c[46150]=rB(c[46183]|0,e)|0;c[46146]=m;h[23074]=+h[23072];f=m}m=tq(f)|0;do{if((c[m>>2]|0)==0){if(+g[m+288>>2]<=0.0){break}f=rC(c[46183]|0,c[46150]|0)|0;e=c[49322]|0;n=c[(c[157712]|0)+112>>2]|0;b=d|0;g[b>>2]=+g[e+(n+136)>>2]+ +g[e+(n+344)>>2];g[d+4>>2]=+g[e+(n+140)>>2]+ +g[e+(n+348)>>2];g[d+8>>2]=+g[e+(n+144)>>2]+ +g[e+(n+352)>>2];n=rB(c[46183]|0,b)|0;b=(n-(c[(c[46183]|0)+140>>2]|0)>>6)-1|0;do{if((b|0)>=0){if((c[f+4+(b>>5<<2)>>2]&1<<(b&31)|0)==0){break}c[651348]=(c[651348]|0)+1;c[(c[157708]|0)+4>>2]=m-(c[49322]|0);i=a;return}}while(0);c[651344]=(c[651344]|0)+1;c[(c[157708]|0)+4>>2]=0;i=a;return}}while(0);c[(c[157708]|0)+4>>2]=0;i=a;return}function sz(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=i;b=tx((c[49322]|0)+(c[(c[157708]|0)+16>>2]|0)|0)|0;d=c[157708]|0;e=c[d+28>>2]|0;f=ti(c[d+40>>2]|0)|0;if((f|0)==0){tk(90848,(d=i,i=i+8|0,c[d>>2]=110336,d)|0);i=d}d=b+1|0;L4467:do{if((d|0)<(c[49320]|0)){b=d;L4468:while(1){g=tq(b)|0;do{if((c[g>>2]|0)==0){h=ti(c[g+96+(e<<2)>>2]|0)|0;if((h|0)==0){break}if((cS(h|0,f|0)|0)==0){break L4468}}}while(0);b=b+1|0;if((b|0)>=(c[49320]|0)){break L4467}}c[(c[157708]|0)+4>>2]=g-(c[49322]|0);i=a;return}}while(0);c[(c[157708]|0)+4>>2]=0;i=a;return}function sA(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;if((c[49323]|0)!=0){tk(96200,(d=i,i=i+8|0,c[d>>2]=110248,d)|0);i=d}e=ti(c[(c[157708]|0)+16>>2]|0)|0;f=c[157708]|0;c[f+4>>2]=c[f+16>>2];if((a[e]|0)<33){tk(92464,(d=i,i=i+8|0,c[d>>2]=110184,d)|0);i=d}f=c[73915]|0;L4485:do{if((f|0)==15){g=0;while(1){if((g|0)>=256){break L4485}h=192928+(g<<2)|0;j=c[h>>2]|0;if((j|0)==0){k=h;l=3372;break L4485}if((cS(j|0,e|0)|0)==0){break}else{g=g+1|0}}i=b;return}else if((f|0)==1e4){g=0;while(1){if((g|0)>=256){break L4485}j=192928+(g<<2)|0;h=c[j>>2]|0;if((h|0)==0){k=j;l=3372;break L4485}if((cS(h|0,e|0)|0)==0){break}else{g=g+1|0}}i=b;return}else{g=0;while(1){if((f|0)==15|(f|0)==1e4){m=256}else if((f|0)==10001|(f|0)==10002|(f|0)==666){m=1024}else{m=0}if((f|0)==10001|(f|0)==666){n=1024}else if((f|0)==15|(f|0)==1e4|(f|0)==10002){n=256}else{n=0}do{if(m>>>0>n>>>0){if((f|0)==10001|(f|0)==10002|(f|0)==666){o=1024;break}else if((f|0)==15|(f|0)==1e4){o=256;break}else{o=0;break}}else{if((f|0)==10001|(f|0)==666){o=1024;break}else if((f|0)==15|(f|0)==1e4|(f|0)==10002){o=256;break}else{o=0;break}}}while(0);if((g|0)>=(o|0)){break L4485}h=192928+(g<<2)|0;j=c[h>>2]|0;if((j|0)==0){k=h;l=3372;break L4485}if((cS(j|0,e|0)|0)==0){break}else{g=g+1|0}}i=b;return}}while(0);if((l|0)==3372){c[k>>2]=e;i=b;return}if((f|0)==10001|(f|0)==10002|(f|0)==666){p=1024}else if((f|0)==15|(f|0)==1e4){p=256}else{p=0}if((f|0)==10001|(f|0)==666){q=1024}else if((f|0)==15|(f|0)==1e4|(f|0)==10002){q=256}else{q=0}do{if(p>>>0>q>>>0){if((f|0)==15|(f|0)==1e4){r=256;break}else if((f|0)==10001|(f|0)==10002|(f|0)==666){r=1024;break}else{r=0;break}}else{if((f|0)==15|(f|0)==1e4|(f|0)==10002){r=256;break}else if((f|0)==10001|(f|0)==666){r=1024;break}else{r=0;break}}}while(0);tk(94160,(d=i,i=i+16|0,c[d>>2]=110248,c[d+8>>2]=r,d)|0);i=d;i=b;return}function sB(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;if((c[49323]|0)!=0){tk(96200,(d=i,i=i+8|0,c[d>>2]=110272,d)|0);i=d}e=ti(c[(c[157708]|0)+16>>2]|0)|0;f=c[157708]|0;c[f+4>>2]=c[f+16>>2];if((a[e]|0)<33){tk(92464,(d=i,i=i+8|0,c[d>>2]=110184,d)|0);i=d}f=c[73915]|0;L4549:do{if((f|0)==1e4){g=0;while(1){if((g|0)>=1024){break L4549}h=184736+(g<<2)|0;j=c[h>>2]|0;if((j|0)==0){k=g;l=h;m=3410;break L4549}if((cS(j|0,e|0)|0)==0){break}else{g=g+1|0}}i=b;return}else if((f|0)==15){g=0;while(1){if((g|0)>=256){break L4549}j=184736+(g<<2)|0;h=c[j>>2]|0;if((h|0)==0){k=g;l=j;m=3410;break L4549}if((cS(h|0,e|0)|0)==0){break}else{g=g+1|0}}i=b;return}else{g=0;while(1){if((f|0)==15){n=256}else if((f|0)==1e4|(f|0)==10001|(f|0)==10002|(f|0)==666){n=1024}else{n=0}if((g|0)>=(n|0)){break L4549}h=184736+(g<<2)|0;j=c[h>>2]|0;if((j|0)==0){k=g;l=h;m=3410;break L4549}if((cS(j|0,e|0)|0)==0){break}else{g=g+1|0}}i=b;return}}while(0);if((m|0)==3410){c[l>>2]=e;c[188832+(k<<2)>>2]=rG(e,1)|0;i=b;return}if((f|0)==1e4|(f|0)==10001|(f|0)==10002|(f|0)==666){o=1024}else if((f|0)==15){o=256}else{o=0}tk(94160,(d=i,i=i+16|0,c[d>>2]=110272,c[d+8>>2]=o,d)|0);i=d;i=b;return}function sC(){var a=0,b=0,d=0,e=0,f=0;a=i;b=tx((c[49322]|0)+(c[(c[157708]|0)+16>>2]|0)|0)|0;if((b|0)<1|(b|0)>(c[45874]|0)){tk(98416,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d}e=ti(c[(c[157708]|0)+28>>2]|0)|0;f=c[278816]|0;c[278816]=(c[45876]|0)+((b-1|0)*33032|0);p4(108720,(d=i,i=i+8|0,c[d>>2]=e,d)|0);i=d;c[278816]=f;i=a;return}function sD(){var a=0,b=0,d=0,e=0,f=0.0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=i;i=i+16|0;b=a|0;d=c[49322]|0;e=c[157708]|0;f=+g[e+28>>2];if((c[49320]|0)<=1){h=d;j=d;k=e;l=h;m=j;n=l-m|0;o=k+4|0;p=o;c[p>>2]=n;i=a;return}q=b|0;r=d;s=1;t=d+(c[157718]|0)|0;while(1){d=t;do{if((c[t>>2]|0)==0){if(+g[t+132>>2]==0.0){u=r;break}g[q>>2]=+g[e+16>>2]-(+g[t+136>>2]+(+g[t+228>>2]+ +g[t+240>>2])*.5);g[b+4>>2]=+g[e+20>>2]-(+g[t+140>>2]+(+g[t+232>>2]+ +g[t+244>>2])*.5);g[b+8>>2]=+g[e+24>>2]-(+g[t+144>>2]+(+g[t+236>>2]+ +g[t+248>>2])*.5);if(+rd(q)>f){u=r;break}c[t+336>>2]=r-(c[49322]|0);u=d}else{u=r}}while(0);d=s+1|0;if((d|0)<(c[49320]|0)){r=u;s=d;t=t+(c[157718]|0)|0}else{break}}h=u;j=c[49322]|0;k=c[157708]|0;l=h;m=j;n=l-m|0;o=k+4|0;p=o;c[p>>2]=n;i=a;return}function sE(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;a[2668888]=0;d=0;e=511;while(1){if((d|0)>=(c[157724]|0)){break}f=ti(c[(c[157708]|0)+((d*3|0)+4<<2)>>2]|0)|0;g=yF(f|0)|0;ev(2668888,f|0,e|0)|0;f=e-g|0;if((f|0)<0){h=3439;break}else{d=d+1|0;e=f}}if((h|0)==3439){oX(50600,(j=i,i=i+8|0,c[j>>2]=110320,j)|0);i=j}p3(108720,(j=i,i=i+8|0,c[j>>2]=2668888,j)|0);i=j;i=b;return}function sF(){c[157600]=1;return}function sG(){c[157600]=0;return}function sH(){var a=0,b=0.0,d=0.0;a=c[157708]|0;b=+g[a+16>>2];d=b;if(b>0.0){g[a+4>>2]=+(~~(d+.5)|0);return}else{g[a+4>>2]=+(~~(d+-.5)|0);return}}function sI(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=tx((c[49322]|0)+(c[(c[157708]|0)+16>>2]|0)|0)|0;a[2668888]=0;e=1;f=511;while(1){if((e|0)>=(c[157724]|0)){break}g=ti(c[(c[157708]|0)+((e*3|0)+4<<2)>>2]|0)|0;h=yF(g|0)|0;ev(2668888,g|0,f|0)|0;g=f-h|0;if((g|0)<0){j=3452;break}else{e=e+1|0;f=g}}if((j|0)==3452){oX(50600,(k=i,i=i+8|0,c[k>>2]=110320,k)|0);i=k}if((d|0)<1|(d|0)>(c[45874]|0)){oW(55120,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k;i=b;return}else{k=(c[45876]|0)+((d-1|0)*33032|0)+64|0;nU(k,8);n_(k,2668888);i=b;return}}function sJ(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;a[2668888]=0;d=0;e=511;while(1){if((d|0)>=(c[157724]|0)){break}f=ti(c[(c[157708]|0)+((d*3|0)+4<<2)>>2]|0)|0;g=yF(f|0)|0;ev(2668888,f|0,e|0)|0;f=e-g|0;if((f|0)<0){h=3462;break}else{d=d+1|0;e=f}}if((h|0)==3462){oX(50600,(j=i,i=i+8|0,c[j>>2]=110320,j)|0);i=j}oX(108720,(j=i,i=i+8|0,c[j>>2]=2668888,j)|0);i=j;i=b;return}function sK(){var a=0,b=0.0,d=0,e=0,f=0.0;a=i;b=+g[(c[157708]|0)+16>>2];d=~~b;if(b==+(d|0)){cl(630440,102224,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e}else{f=b;cl(630440,99960,(e=i,i=i+8|0,h[e>>3]=f,e)|0)|0;i=e}e=to(630440)|0;c[(c[157708]|0)+4>>2]=e;i=a;return}function sL(){var a=0,b=0,d=0.0,e=0.0,f=0;a=i;b=c[157708]|0;d=+g[b+20>>2];e=+g[b+24>>2];cl(630440,105504,(f=i,i=i+24|0,h[f>>3]=+g[b+16>>2],h[f+8>>3]=d,h[f+16>>3]=e,f)|0)|0;i=f;f=to(630440)|0;c[(c[157708]|0)+4>>2]=f;i=a;return}function sM(){tB();return}function sN(){tA(tx((c[49322]|0)+(c[(c[157708]|0)+16>>2]|0)|0)|0);return}function sO(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0.0,k=0.0,l=0.0,m=0;a=i;i=i+16|0;b=a|0;d=c[49322]|0;e=(c[157712]|0)+112|0;f=c[e>>2]|0;h=c[157708]|0;if((~~+g[d+(f+400)>>2]&515|0)==0){g[h+4>>2]=0.0;i=a;return}else{j=+g[h+28>>2];k=+g[h+16>>2]*3.141592653589793*2.0/360.0;l=j;h=b|0;g[h>>2]=l*+T(+k);g[b+4>>2]=l*+U(+k);g[b+8>>2]=0.0;b=c[157598]|0;m=c[e>>2]|0;k=+((wf(d+f|0,h,1)|0)>>>0>>>0);g[(c[157708]|0)+4>>2]=k;c[157598]=b;c[(c[157712]|0)+112>>2]=m;i=a;return}}function sP(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0;a=i;i=i+72|0;b=a|0;d=a+16|0;e=c[49322]|0;f=c[(c[157712]|0)+112>>2]|0;h=e+f|0;j=e+(f+136)|0;k=b|0;g[k>>2]=+g[j>>2];l=e+(f+140)|0;g[b+4>>2]=+g[l>>2];m=e+(f+144)|0;g[b+8>>2]=+g[m>>2]+-256.0;yt(d,j,e+(f+228)|0,e+(f+240)|0,k,0,h);n=+g[d+20>>2];o=+g[d+24>>2];p=+g[d+28>>2];k=c[d+48>>2]|0;do{if(+g[d+16>>2]!=1.0){if((c[d>>2]|0)!=0){break}g[j>>2]=n;g[l>>2]=o;g[m>>2]=p;yn(h,0);b=e+(f+400)|0;g[b>>2]=+(~~+g[b>>2]|512|0);c[e+(f+284)>>2]=k-(c[49322]|0);g[(c[157708]|0)+4>>2]=1.0;i=a;return}}while(0);g[(c[157708]|0)+4>>2]=0.0;i=a;return}function sQ(){var a=0,b=0,d=0,e=0,f=0,h=0,i=0,j=0;a=c[157708]|0;b=~~+g[a+16>>2];d=ti(c[a+28>>2]|0)|0;c[197024+(b<<2)>>2]=d;if((c[49323]|0)!=1){return}a=c[45874]|0;if((a|0)<=0){return}e=c[45876]|0;f=0;h=a;while(1){if((c[e>>2]|0)==0){if((c[e+4>>2]|0)==0){i=h}else{j=3489}}else{j=3489}if((j|0)==3489){j=0;a=e+64|0;nU(a,12);nU(a,b);n_(a,d);i=c[45874]|0}a=f+1|0;if((a|0)<(i|0)){e=e+33032|0;f=a;h=i}else{break}}return}function sR(){var a=0;a=c[157708]|0;g[a+4>>2]=+P(+(+g[a+16>>2]));return}function sS(){var a=0;a=c[157708]|0;g[a+4>>2]=+aa(+(+g[a+16>>2]));return}function sT(){var a=0.0;a=+((we((c[49322]|0)+(c[(c[157708]|0)+16>>2]|0)|0)|0)>>>0>>>0);g[(c[157708]|0)+4>>2]=a;return}function sU(){var a=0.0;a=+(yr((c[157708]|0)+16|0)|0);g[(c[157708]|0)+4>>2]=a;return}function sV(){var a=0;a=c[157708]|0;g[a+4>>2]=+Q(+(+g[a+16>>2]));return}function sW(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0.0,y=0.0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,G=0.0,H=0,I=0.0,J=0.0,K=0.0,L=0;a=i;i=i+160|0;b=a|0;d=a+16|0;e=a+32|0;f=a+48|0;h=a+104|0;j=c[49322]|0;k=c[(c[157708]|0)+16>>2]|0;l=j+k|0;m=l;n=j+(k+136)|0;o=b|0;g[o>>2]=+g[n>>2];p=j+(k+140)|0;q=b+4|0;g[q>>2]=+g[p>>2];r=j+(k+144)|0;s=b+8|0;g[s>>2]=+g[r>>2]+20.0;b=c[157712]|0;t=d|0;g[t>>2]=+g[b+236>>2];u=d+4|0;g[u>>2]=+g[b+240>>2];v=d+8|0;g[v>>2]=+g[b+244>>2];b=e|0;q7(o,2048.0,t,b);yt(f,o,117584,117584,b,0,m);d=c[f+48>>2]|0;L4671:do{if((d|0)!=0){if(+g[d+332>>2]!=2.0){break}do{if(+g[478]!=0.0){w=+g[j+(k+408)>>2];if(w<=0.0){break}if(w==+g[d+408>>2]){break L4671}}}while(0);g[(c[157708]|0)+4>>2]=+g[(c[157712]|0)+236>>2];g[(c[157708]|0)+8>>2]=+g[(c[157712]|0)+240>>2];g[(c[157708]|0)+12>>2]=+g[(c[157712]|0)+244>>2];i=a;return}}while(0);w=+g[t>>2];x=+g[u>>2];y=+g[v>>2];do{if((c[49320]|0)>1){d=j+(k+408)|0;f=e+4|0;z=e+8|0;A=h+48|0;B=0;C=1;D=+g[686];E=(c[49322]|0)+(c[157718]|0)|0;while(1){F=E;L4684:do{if(+g[E+332>>2]!=2.0|(E|0)==(l|0)){G=D;H=B}else{do{if(+g[478]!=0.0){I=+g[d>>2];if(I<=0.0){break}if(I==+g[E+408>>2]){G=D;H=B;break L4684}}}while(0);I=+g[E+136>>2]+(+g[E+228>>2]+ +g[E+240>>2])*.5;g[b>>2]=I;J=+g[E+140>>2]+(+g[E+232>>2]+ +g[E+244>>2])*.5;g[f>>2]=J;K=+g[E+144>>2]+(+g[E+236>>2]+ +g[E+248>>2])*.5;g[z>>2]=K;g[t>>2]=I- +g[o>>2];g[u>>2]=J- +g[q>>2];g[v>>2]=K- +g[s>>2];+q1(t);L=c[157712]|0;K=+g[t>>2]*+g[L+236>>2]+ +g[u>>2]*+g[L+240>>2]+ +g[v>>2]*+g[L+244>>2];if(K<D){G=D;H=B;break}yt(h,o,117584,117584,b,0,m);L=(c[A>>2]|0)==(F|0);G=L?K:D;H=L?F:B}}while(0);F=C+1|0;if((F|0)<(c[49320]|0)){B=H;C=F;D=G;E=E+(c[157718]|0)|0}else{break}}if((H|0)==0){break}D=+g[H+136>>2]- +g[n>>2];g[t>>2]=D;K=+g[H+140>>2]- +g[p>>2];g[u>>2]=K;J=+g[H+144>>2]- +g[r>>2];g[v>>2]=J;E=c[157712]|0;C=E+236|0;q9(C,D*+g[C>>2]+K*+g[E+240>>2]+J*+g[E+244>>2],b);E=e+8|0;g[E>>2]=+g[v>>2];+q1(b);g[(c[157708]|0)+4>>2]=+g[b>>2];g[(c[157708]|0)+8>>2]=+g[e+4>>2];g[(c[157708]|0)+12>>2]=+g[E>>2];i=a;return}}while(0);g[(c[157708]|0)+4>>2]=w;g[(c[157708]|0)+8>>2]=x;g[(c[157708]|0)+12>>2]=y;i=a;return}function sX(){var a=0.0;a=+o7(ti(c[(c[157708]|0)+16>>2]|0)|0);g[(c[157708]|0)+4>>2]=a;return}function sY(){var a=0,b=0,d=0;a=i;b=ti(c[(c[157708]|0)+16>>2]|0)|0;ov(108720,(d=i,i=i+8|0,c[d>>2]=b,d)|0);i=d;i=a;return}function sZ(){var a=0,b=0,d=0,e=0;a=tx((c[49322]|0)+(c[(c[157708]|0)+16>>2]|0)|0)|0;while(1){b=a+1|0;if((b|0)==(c[49320]|0)){d=3526;break}e=tq(b)|0;if((c[e>>2]|0)==0){d=3528;break}else{a=b}}if((d|0)==3528){c[(c[157708]|0)+4>>2]=e-(c[49322]|0);return}else if((d|0)==3526){c[(c[157708]|0)+4>>2]=0;return}}function s_(){var a=0;a=c[157708]|0;v_(a+16|0,a+28|0,~~+g[a+40>>2],~~+g[a+52>>2]);return}function s$(){var a=0,b=0.0,d=0.0,e=0.0,f=0.0,h=0.0,i=0.0,j=0.0;a=c[157708]|0;b=+g[a+20>>2];d=+g[a+16>>2];do{if(b==0.0&d==0.0){e=+g[a+24>>2]>0.0?90.0:270.0;f=0.0}else{h=+(~~(+Z(+b,+d)*180.0/3.141592653589793)|0);if(h<0.0){i=h+360.0}else{i=h}h=+R(+(d*d+b*b));j=+(~~(+Z(+(+g[a+24>>2]),+h)*180.0/3.141592653589793)|0);if(j>=0.0){e=j;f=i;break}e=j+360.0;f=i}}while(0);g[a+4>>2]=e;g[(c[157708]|0)+8>>2]=f;g[(c[157708]|0)+12>>2]=0.0;return}function s0(){var a=0,b=0,d=0,e=0,f=0;a=i;b=~~+g[(c[157708]|0)+16>>2];if((b|0)==0){d=197296}else if((b|0)==3){d=262872}else if((b|0)==1){e=tx((c[49322]|0)+(c[(c[157712]|0)+324>>2]|0)|0)|0;if((e|0)<1|(e|0)>(c[45874]|0)){tk(42440,(f=i,i=i+8|0,c[f>>2]=109536,f)|0);i=f}d=(c[45876]|0)+((e-1|0)*33032|0)+64|0}else if((b|0)==2){d=230084}else{tk(38696,(f=i,i=i+8|0,c[f>>2]=109536,f)|0);i=f;d=0}nV(d,~~+g[(c[157708]|0)+28>>2]);i=a;return}function s1(){var a=0;a=c[157708]|0;c[a+4>>2]=c[a+16>>2];return}function s2(){var a=0,b=0,d=0,e=0,f=0;a=i;b=~~+g[(c[157708]|0)+16>>2];if((b|0)==1){d=tx((c[49322]|0)+(c[(c[157712]|0)+324>>2]|0)|0)|0;if((d|0)<1|(d|0)>(c[45874]|0)){tk(42440,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e}f=(c[45876]|0)+((d-1|0)*33032|0)+64|0}else if((b|0)==0){f=197296}else if((b|0)==2){f=230084}else if((b|0)==3){f=262872}else{tk(38696,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e;f=0}nU(f,~~+g[(c[157708]|0)+28>>2]);i=a;return}function s3(){var a=0,b=0,d=0,e=0;a=i;b=~~+g[(c[157708]|0)+16>>2];if((b|0)==0){d=197296}else if((b|0)==2){d=230084}else if((b|0)==3){d=262872}else if((b|0)==1){b=tx((c[49322]|0)+(c[(c[157712]|0)+324>>2]|0)|0)|0;if((b|0)<1|(b|0)>(c[45874]|0)){tk(42440,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e}d=(c[45876]|0)+((b-1|0)*33032|0)+64|0}else{tk(38696,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e;d=0}nW(d,~~+g[(c[157708]|0)+28>>2]);i=a;return}function s4(){var a=0,b=0,d=0,e=0,f=0;a=i;b=~~+g[(c[157708]|0)+16>>2];if((b|0)==2){d=230084}else if((b|0)==1){e=tx((c[49322]|0)+(c[(c[157712]|0)+324>>2]|0)|0)|0;if((e|0)<1|(e|0)>(c[45874]|0)){tk(42440,(f=i,i=i+8|0,c[f>>2]=109536,f)|0);i=f}d=(c[45876]|0)+((e-1|0)*33032|0)+64|0}else if((b|0)==0){d=197296}else if((b|0)==3){d=262872}else{tk(38696,(f=i,i=i+8|0,c[f>>2]=109536,f)|0);i=f;d=0}nX(d,~~+g[(c[157708]|0)+28>>2]);i=a;return}function s5(){var a=0,b=0,d=0,e=0,f=0;a=i;b=~~+g[(c[157708]|0)+16>>2];if((b|0)==1){d=tx((c[49322]|0)+(c[(c[157712]|0)+324>>2]|0)|0)|0;if((d|0)<1|(d|0)>(c[45874]|0)){tk(42440,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e}f=(c[45876]|0)+((d-1|0)*33032|0)+64|0}else if((b|0)==0){f=197296}else if((b|0)==3){f=262872}else if((b|0)==2){f=230084}else{tk(38696,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e;f=0}n1(f,+g[(c[157708]|0)+28>>2]);i=a;return}function s6(){var a=0,b=0,d=0,e=0,f=0;a=i;b=~~+g[(c[157708]|0)+16>>2];if((b|0)==1){d=tx((c[49322]|0)+(c[(c[157712]|0)+324>>2]|0)|0)|0;if((d|0)<1|(d|0)>(c[45874]|0)){tk(42440,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e}f=(c[45876]|0)+((d-1|0)*33032|0)+64|0}else if((b|0)==0){f=197296}else if((b|0)==2){f=230084}else if((b|0)==3){f=262872}else{tk(38696,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e;f=0}n2(f,+g[(c[157708]|0)+28>>2]);i=a;return}function s7(){var a=0,b=0,d=0,e=0,f=0;a=i;b=~~+g[(c[157708]|0)+16>>2];if((b|0)==1){d=tx((c[49322]|0)+(c[(c[157712]|0)+324>>2]|0)|0)|0;if((d|0)<1|(d|0)>(c[45874]|0)){tk(42440,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e}f=(c[45876]|0)+((d-1|0)*33032|0)+64|0}else if((b|0)==0){f=197296}else if((b|0)==3){f=262872}else if((b|0)==2){f=230084}else{tk(38696,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e;f=0}n_(f,ti(c[(c[157708]|0)+28>>2]|0)|0);i=a;return}function s8(){var a=0,b=0,d=0,e=0,f=0;a=i;b=~~+g[(c[157708]|0)+16>>2];if((b|0)==1){d=tx((c[49322]|0)+(c[(c[157712]|0)+324>>2]|0)|0)|0;if((d|0)<1|(d|0)>(c[45874]|0)){tk(42440,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e}f=(c[45876]|0)+((d-1|0)*33032|0)+64|0}else if((b|0)==0){f=197296}else if((b|0)==3){f=262872}else if((b|0)==2){f=230084}else{tk(38696,(e=i,i=i+8|0,c[e>>2]=109536,e)|0);i=e;f=0}nW(f,tx((c[49322]|0)+(c[(c[157708]|0)+28>>2]|0)|0)|0);i=a;return}function s9(){var a=0,b=0,d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[49322]|0;b=c[(c[157708]|0)+16>>2]|0;d=a+b|0;e=a+(b+212)|0;do{if((c[73915]|0)==666){f=((v7(ti(c[e>>2]|0)|0)|0)&65280|0)!=0;h=f&1;i=a+(b+216)|0;if((~~+g[i>>2]&65280|0)==0){if(f){j=h}else{k=i;l=3611;break}}else{j=h|2}nV(262872,43);nV(262872,j);m=j;n=i}else{k=a+(b+216)|0;l=3611}}while(0);if((l|0)==3611){nV(262872,20);m=0;n=k}v4(262872,v7(ti(c[e>>2]|0)|0)|0,m);nV(262872,~~+g[n>>2]);nV(262872,~~+g[a+(b+404)>>2]);nV(262872,~~+g[a+(b+220)>>2]);n1(262872,+g[a+(b+136)>>2]);n2(262872,+g[a+(b+172)>>2]);n1(262872,+g[a+(b+140)>>2]);n2(262872,+g[a+(b+176)>>2]);n1(262872,+g[a+(b+144)>>2]);n2(262872,+g[a+(b+180)>>2]);tr(d);return}function ta(){var a=0,b=0,d=0;a=i;if((c[45878]|0)!=0){i=a;return}c[45878]=1;b=ti(c[(c[157708]|0)+16>>2]|0)|0;ov(46760,(d=i,i=i+8|0,c[d>>2]=b,d)|0);i=d;i=a;return}function tb(){var a=0;a=ti(c[(c[157708]|0)+16>>2]|0)|0;o9(a,ti(c[(c[157708]|0)+28>>2]|0)|0);return}function tc(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=tx((c[49322]|0)+(c[(c[157708]|0)+16>>2]|0)|0)|0;a[2668888]=0;e=1;f=511;while(1){if((e|0)>=(c[157724]|0)){break}g=ti(c[(c[157708]|0)+((e*3|0)+4<<2)>>2]|0)|0;h=yF(g|0)|0;ev(2668888,g|0,f|0)|0;g=f-h|0;if((g|0)<0){j=3622;break}else{e=e+1|0;f=g}}if((j|0)==3622){oX(50600,(k=i,i=i+8|0,c[k>>2]=110320,k)|0);i=k}if((d|0)<1|(d|0)>(c[45874]|0)){oW(55120,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k;i=b;return}else{k=(c[45876]|0)+((d-1|0)*33032|0)+64|0;nU(k,26);n_(k,2668888);i=b;return}}function td(){var a=0,b=0,d=0,e=0,f=0.0,h=0.0,j=0,k=0,l=0,m=0,n=0,o=0;a=i;b=c[157708]|0;d=ti(c[b+28>>2]|0)|0;e=c[157708]|0;f=+g[e+40>>2];h=+g[e+52>>2];e=c[48232]|0;L4829:do{if((e|0)!=0){j=192928;k=0;l=e;while(1){if((cS(l|0,d|0)|0)==0){break}m=j+4|0;n=c[m>>2]|0;if((n|0)==0){break L4829}else{j=m;k=k+1|0;l=n}}l=(k|0)>255;if((c[73915]|0)==666&l){nV(262872,44)}else{nV(262872,29)}n1(262872,+g[b+16>>2]);n1(262872,+g[b+20>>2]);n1(262872,+g[b+24>>2]);j=c[73915]|0;do{if((j|0)==666){if(l){nW(262872,k);break}else{nV(262872,k);break}}else if((j|0)==15|(j|0)==1e4|(j|0)==10002){nV(262872,k)}else if((j|0)==10001){nW(262872,k)}else{qa(61008,(o=i,i=i+16|0,c[o>>2]=110296,c[o+8>>2]=j,o)|0);i=o}}while(0);nV(262872,~~(f*255.0));nV(262872,~~(h*64.0));i=a;return}}while(0);oW(70784,(o=i,i=i+8|0,c[o>>2]=d,o)|0);i=o;i=a;return}function te(){var a=0,b=0,d=0,e=0;a=i;b=tx((c[49322]|0)+(c[(c[157708]|0)+16>>2]|0)|0)|0;if((b|0)<1|(b|0)>(c[45874]|0)){tk(84992,(d=i,i=i+8|0,c[d>>2]=110224,d)|0);i=d}d=c[45876]|0;e=b-1|0;g[(c[157712]|0)+172>>2]=+g[d+(e*33032|0)+32960>>2];g[(c[157712]|0)+176>>2]=+g[d+(e*33032|0)+32964>>2];g[(c[157712]|0)+180>>2]=+g[d+(e*33032|0)+32968>>2];g[(c[157712]|0)+184>>2]=+g[d+(e*33032|0)+32972>>2];g[(c[157712]|0)+188>>2]=+g[d+(e*33032|0)+32976>>2];g[(c[157712]|0)+192>>2]=+g[d+(e*33032|0)+32980>>2];g[(c[157712]|0)+196>>2]=+g[d+(e*33032|0)+32984>>2];g[(c[157712]|0)+200>>2]=+g[d+(e*33032|0)+32988>>2];g[(c[157712]|0)+204>>2]=+g[d+(e*33032|0)+32992>>2];g[(c[157712]|0)+208>>2]=+g[d+(e*33032|0)+32996>>2];g[(c[157712]|0)+212>>2]=+g[d+(e*33032|0)+33e3>>2];g[(c[157712]|0)+216>>2]=+g[d+(e*33032|0)+33004>>2];g[(c[157712]|0)+220>>2]=+g[d+(e*33032|0)+33008>>2];g[(c[157712]|0)+224>>2]=+g[d+(e*33032|0)+33012>>2];g[(c[157712]|0)+228>>2]=+g[d+(e*33032|0)+33016>>2];g[(c[157712]|0)+232>>2]=+g[d+(e*33032|0)+33020>>2];i=a;return}function tf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0.0,m=0,n=0.0,o=0.0,p=0.0,q=0.0;e=i;if(+g[b>>2]>+g[d>>2]){tk(76328,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f}h=b+4|0;j=d+4|0;if(+g[h>>2]>+g[j>>2]){tk(76328,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f}k=b+8|0;l=+g[k>>2];m=d+8|0;n=+g[m>>2];if(l>n){tk(76328,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;o=+g[k>>2];p=+g[m>>2]}else{o=l;p=n}n=+g[h>>2];l=+g[d>>2];q=+g[j>>2];g[a+228>>2]=+g[b>>2];g[a+232>>2]=n;g[a+236>>2]=o;g[a+240>>2]=l;g[a+244>>2]=q;g[a+248>>2]=p;g[a+252>>2]=+g[d>>2]- +g[b>>2];g[a+256>>2]=+g[j>>2]- +g[h>>2];g[a+260>>2]=+g[m>>2]- +g[k>>2];yn(a,0);i=e;return}function tg(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a|0;f=b[e>>1]|0;do{if((f&65535)<66){oW(50760,(g=i,i=i+8|0,c[g>>2]=c[13712+((f&65535)<<2)>>2],g)|0);i=g;h=b[e>>1]|0;j=yF(c[13712+((h&65535)<<2)>>2]|0)|0;if((j|0)<10){k=j}else{l=h;break}do{oW(49952,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;k=k+1|0;}while((k|0)<10);l=b[e>>1]|0}else{l=f}}while(0);do{if((l<<16>>16|0)==61){oW(49200,(g=i,i=i+8|0,c[g>>2]=b[a+2>>1]|0,g)|0);i=g}else if((l<<16>>16|0)==49|(l<<16>>16|0)==50){f=tt(b[a+2>>1]|0)|0;e=b[a+4>>1]|0;oW(49536,(g=i,i=i+16|0,c[g>>2]=f,c[g+8>>2]=e,g)|0);i=g}else{e=b[a+2>>1]|0;if(((l&65535)-31|0)>>>0<6){f=tt(e<<16>>16)|0;oW(48864,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;f=tv(b[a+4>>1]|0)|0;oW(48864,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g;break}if(e<<16>>16!=0){f=tt(e<<16>>16)|0;oW(48864,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g}f=b[a+4>>1]|0;if(f<<16>>16!=0){e=tt(f<<16>>16)|0;oW(48864,(g=i,i=i+8|0,c[g>>2]=e,g)|0);i=g}e=b[a+6>>1]|0;if(e<<16>>16==0){break}f=tv(e<<16>>16)|0;oW(48864,(g=i,i=i+8|0,c[g>>2]=f,g)|0);i=g}}while(0);oW(48584,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=d;return}function th(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=i;b=c[157720]|0;if((b|0)==0){oW(48312,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}e=c[157598]|0;c[630580+(b<<3)>>2]=e;if((b|0)>-1){f=b;g=e}else{i=a;return}while(1){if((g|0)==0){oW(48048,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d}else{e=c[g+20>>2]|0;do{if((e|0)>-1){b=c[157606]|0;if((b-1|0)>(e|0)){h=(c[157608]|0)+e|0;break}else{j=c[159946]|0;k=b;l=3685;break}}else{b=c[159946]|0;if((e|0)<(-b|0)){j=b;k=c[157606]|0;l=3685;break}else{h=c[(c[157604]|0)+(~e<<2)>>2]|0;break}}}while(0);if((l|0)==3685){l=0;qa(40520,(d=i,i=i+32|0,c[d>>2]=110144,c[d+8>>2]=e,c[d+16>>2]=-j,c[d+24>>2]=k-2,d)|0);i=d;h=2659232}b=c[g+16>>2]|0;do{if((b|0)>-1){m=c[157606]|0;if((m-1|0)>(b|0)){n=(c[157608]|0)+b|0;break}else{o=c[159946]|0;p=m;l=3693;break}}else{m=c[159946]|0;if((b|0)<(-m|0)){o=m;p=c[157606]|0;l=3693;break}else{n=c[(c[157604]|0)+(~b<<2)>>2]|0;break}}}while(0);if((l|0)==3693){l=0;qa(40520,(d=i,i=i+32|0,c[d>>2]=110144,c[d+8>>2]=b,c[d+16>>2]=-o,c[d+24>>2]=p-2,d)|0);i=d;n=2659232}oW(47656,(d=i,i=i+16|0,c[d>>2]=h,c[d+8>>2]=n,d)|0);i=d}e=f-1|0;if((f|0)<=0){break}f=e;g=c[630580+(e<<3)>>2]|0}i=a;return}function ti(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;do{if((a|0)>-1){d=c[157606]|0;if((d-1|0)>(a|0)){e=(c[157608]|0)+a|0;i=b;return e|0}else{if((a|0)<0){f=3706;break}g=c[159946]|0;h=d;break}}else{f=3706}}while(0);do{if((f|0)==3706){d=c[159946]|0;if((a|0)<(-d|0)){g=d;h=c[157606]|0;break}e=c[(c[157604]|0)+(~a<<2)>>2]|0;i=b;return e|0}}while(0);qa(40520,(f=i,i=i+32|0,c[f>>2]=110144,c[f+8>>2]=a,c[f+16>>2]=-g,c[f+24>>2]=h-2,f)|0);i=f;e=2659232;i=b;return e|0}function tj(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=i;b=c[157544]|0;if((b|0)==0){i=a;return}else{d=0;e=b}while(1){b=c[e+36>>2]|0;if((b|0)<=0){f=3736;break}g=c[157714]|0;h=0;j=0;k=0;while(1){l=c[g+(k*36|0)+12>>2]|0;if((l|0)>(j|0)){m=l;n=g+(k*36|0)|0}else{m=j;n=h}l=k+1|0;if((l|0)<(b|0)){h=n;j=m;k=l}else{break}}if((n|0)==0){f=3734;break}k=n+12|0;if((d|0)<10){j=c[k>>2]|0;h=c[n+16>>2]|0;do{if((h|0)>-1){b=c[157606]|0;if((b-1|0)>(h|0)){o=(c[157608]|0)+h|0;break}else{p=c[159946]|0;q=b;f=3730;break}}else{b=c[159946]|0;if((h|0)<(-b|0)){p=b;q=c[157606]|0;f=3730;break}else{o=c[(c[157604]|0)+(~h<<2)>>2]|0;break}}}while(0);if((f|0)==3730){f=0;qa(40520,(r=i,i=i+32|0,c[r>>2]=110144,c[r+8>>2]=h,c[r+16>>2]=-p,c[r+24>>2]=q-2,r)|0);i=r;o=2659232}oW(47344,(r=i,i=i+16|0,c[r>>2]=j,c[r+8>>2]=o,r)|0);i=r}c[k>>2]=0;d=d+1|0;e=c[157544]|0}if((f|0)==3736){i=a;return}else if((f|0)==3734){i=a;return}}function tk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+4112|0;e=d|0;f=e;c[f>>2]=b;c[f+4>>2]=0;f=d+16|0;bV(f|0,4096,a|0,e|0)|0;tg((c[157642]|0)+(c[157596]<<3)|0);th();oW(46864,(e=i,i=i+8|0,c[e>>2]=f,e)|0);i=e;c[157720]=0;qa(46088,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e;i=d;return}function tl(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=c[157720]|0;c[630576+(f<<3)>>2]=c[157596];c[630580+(f<<3)>>2]=c[157598];g=f+1|0;c[157720]=g;if((g|0)>31){tk(45448,(h=i,i=i+1|0,i=i+7>>3<<3,c[h>>2]=0,h)|0);i=h}g=c[b+8>>2]|0;if(((c[270932]|0)+g|0)>2048){tk(45008,(h=i,i=i+1|0,i=i+7>>3<<3,c[h>>2]=0,h)|0);i=h}if((g|0)>0){h=b+4|0;f=c[157708]|0;j=c[270932]|0;k=0;while(1){c[1083736+(j+k<<2)>>2]=c[f+((c[h>>2]|0)+k<<2)>>2];l=k+1|0;if((l|0)<(g|0)){k=l}else{m=j;break}}}else{m=c[270932]|0}c[270932]=m+g;g=b+24|0;m=c[g>>2]|0;if((m|0)<=0){c[157598]=b;n=b|0;o=c[n>>2]|0;p=o-1|0;i=e;return p|0}j=0;k=c[b+4>>2]|0;h=m;while(1){m=b+28+j|0;if((a[m]|0)==0){q=k;r=h}else{f=(j*3|0)+4|0;l=0;s=k;do{t=c[157708]|0;c[t+(s<<2)>>2]=c[t+(f+l<<2)>>2];s=s+1|0;l=l+1|0;}while((l|0)<(d[m]|0));q=s;r=c[g>>2]|0}m=j+1|0;if((m|0)<(r|0)){j=m;k=q;h=r}else{break}}c[157598]=b;n=b|0;o=c[n>>2]|0;p=o-1|0;i=e;return p|0}function tm(d){d=d|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0.0;f=i;if((d|0)==0){h=3758}else{if((c[(c[157544]|0)+36>>2]|0)<=(d|0)){h=3758}}if((h|0)==3758){j=c[(c[157712]|0)+112>>2]|0;if((j|0)!=0){tw((c[49322]|0)+j|0)}qa(44040,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k}j=(c[157714]|0)+(d*36|0)|0;c[157600]=0;d=c[157720]|0;l=tl(j)|0;j=999999;L5008:while(1){m=l+1|0;n=c[157642]|0;o=n+(m<<3)|0;p=n+(m<<3)+2|0;q=b[p>>1]|0;r=c[157708]|0;s=r+(q<<2)|0;t=n+(m<<3)+4|0;u=b[t>>1]|0;v=r+(u<<2)|0;w=b[n+(m<<3)+6>>1]|0;n=r+(w<<2)|0;if((j|0)==0){tk(43800,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k}if((j|0)<50001&((j|0)%5e3|0|0)==0){oX(43408,(k=i,i=i+16|0,c[k>>2]=110160,c[k+8>>2]=j,k)|0);i=k}x=(c[157598]|0)+12|0;c[x>>2]=(c[x>>2]|0)+1;c[157596]=m;if((c[157600]|0)!=0){tg(o)}x=e[o>>1]|0;L5019:do{switch(x|0){case 1:{g[n>>2]=+g[s>>2]*+g[v>>2];y=m;break};case 3:{g[n>>2]=+g[s>>2]*+g[v>>2];g[r+(w+1<<2)>>2]=+g[s>>2]*+g[r+(u+1<<2)>>2];g[r+(w+2<<2)>>2]=+g[s>>2]*+g[r+(u+2<<2)>>2];y=m;break};case 10:{g[n>>2]=+(+g[s>>2]==+g[v>>2]|0);y=m;break};case 11:{do{if(+g[s>>2]==+g[v>>2]){if(+g[r+(q+1<<2)>>2]!=+g[r+(u+1<<2)>>2]){z=0.0;break}z=+(+g[r+(q+2<<2)>>2]==+g[r+(u+2<<2)>>2]|0)}else{z=0.0}}while(0);g[n>>2]=z;y=m;break};case 63:{if(+g[s>>2]!=0.0){A=1.0}else{A=+(+g[v>>2]!=0.0|0)}g[n>>2]=A;y=m;break};case 12:{o=c[s>>2]|0;do{if((o|0)>-1){B=c[157606]|0;if((B-1|0)>(o|0)){C=(c[157608]|0)+o|0;break}else{D=c[159946]|0;E=B;h=3821;break}}else{B=c[159946]|0;if((o|0)<(-B|0)){D=B;E=c[157606]|0;h=3821;break}else{C=c[(c[157604]|0)+(~o<<2)>>2]|0;break}}}while(0);if((h|0)==3821){h=0;qa(40520,(k=i,i=i+32|0,c[k>>2]=110144,c[k+8>>2]=o,c[k+16>>2]=-D,c[k+24>>2]=E-2,k)|0);i=k;C=2659232}B=c[v>>2]|0;do{if((B|0)>-1){F=c[157606]|0;if((F-1|0)>(B|0)){G=(c[157608]|0)+B|0;break}else{H=c[159946]|0;I=F;h=3829;break}}else{F=c[159946]|0;if((B|0)<(-F|0)){H=F;I=c[157606]|0;h=3829;break}else{G=c[(c[157604]|0)+(~B<<2)>>2]|0;break}}}while(0);if((h|0)==3829){h=0;qa(40520,(k=i,i=i+32|0,c[k>>2]=110144,c[k+8>>2]=B,c[k+16>>2]=-H,c[k+24>>2]=I-2,k)|0);i=k;G=2659232}g[n>>2]=+((cS(C|0,G|0)|0)==0|0);y=m;break};case 2:{g[n>>2]=+g[s>>2]*+g[v>>2]+ +g[r+(q+1<<2)>>2]*+g[r+(u+1<<2)>>2]+ +g[r+(q+2<<2)>>2]*+g[r+(u+2<<2)>>2];y=m;break};case 62:{if(+g[s>>2]!=0.0){J=+(+g[v>>2]!=0.0|0)}else{J=0.0}g[n>>2]=J;y=m;break};case 45:{do{if(+g[s>>2]!=0.0){K=0.0}else{if(+g[r+(q+1<<2)>>2]!=0.0){K=0.0;break}K=+(+g[r+(q+2<<2)>>2]==0.0|0)}}while(0);g[n>>2]=K;y=m;break};case 46:{B=c[s>>2]|0;if((B|0)==0){L=1.0}else{do{if((B|0)>-1){o=c[157606]|0;if((o-1|0)>(B|0)){M=(c[157608]|0)+B|0;break}if((B|0)<0){h=3801;break}N=c[159946]|0;O=o;h=3804}else{h=3801}}while(0);do{if((h|0)==3801){h=0;o=c[159946]|0;if((B|0)<(-o|0)){N=o;O=c[157606]|0;h=3804;break}else{M=c[(c[157604]|0)+(~B<<2)>>2]|0;break}}}while(0);if((h|0)==3804){h=0;qa(40520,(k=i,i=i+32|0,c[k>>2]=110144,c[k+8>>2]=B,c[k+16>>2]=-N,c[k+24>>2]=O-2,k)|0);i=k;M=2659232}L=+((a[M]|0)==0|0)}g[n>>2]=L;y=m;break};case 4:{g[n>>2]=+g[v>>2]*+g[s>>2];g[r+(w+1<<2)>>2]=+g[v>>2]*+g[r+(q+1<<2)>>2];g[r+(w+2<<2)>>2]=+g[v>>2]*+g[r+(q+2<<2)>>2];y=m;break};case 65:{g[n>>2]=+(~~+g[v>>2]|~~+g[s>>2]|0);y=m;break};case 5:{g[n>>2]=+g[s>>2]/+g[v>>2];y=m;break};case 30:{o=c[49322]|0;F=o;P=c[s>>2]|0;if((F+P|0)==(o|0)&(c[49323]|0)==1){tk(43008,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k;Q=c[49322]|0}else{Q=o}c[n>>2]=F+(P+96)+(c[v>>2]<<2)-Q;y=m;break};case 24:case 28:case 27:case 26:case 29:{c[n>>2]=c[(c[49322]|0)+((c[s>>2]|0)+96)+(c[v>>2]<<2)>>2];y=m;break};case 25:{P=(c[49322]|0)+((c[s>>2]|0)+96)|0;F=c[v>>2]|0;g[n>>2]=+g[P+(F<<2)>>2];g[r+(w+1<<2)>>2]=+g[P+(F+1<<2)>>2];g[r+(w+2<<2)>>2]=+g[P+(F+2<<2)>>2];y=m;break};case 50:{if((c[s>>2]|0)!=0){y=m;break L5019}y=(b[t>>1]|0)+l|0;break};case 49:{if((c[s>>2]|0)==0){y=m;break L5019}y=(b[t>>1]|0)+l|0;break};case 51:case 52:case 53:case 54:case 55:case 56:case 57:case 58:case 59:{c[157724]=x-51;F=s;P=c[F>>2]|0;if((P|0)==0){tk(42632,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k;R=c[F>>2]|0}else{R=P}P=(c[157714]|0)+(R*36|0)|0;F=c[P>>2]|0;if((F|0)>=0){y=tl(P)|0;break L5019}P=-F|0;if((c[3494]|0)<=(P|0)){tk(41704,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k}fQ[c[(c[3496]|0)+(P<<2)>>2]&1023]();y=m;break};case 7:{g[n>>2]=+g[s>>2]+ +g[v>>2];g[r+(w+1<<2)>>2]=+g[r+(q+1<<2)>>2]+ +g[r+(u+1<<2)>>2];g[r+(w+2<<2)>>2]=+g[r+(q+2<<2)>>2]+ +g[r+(u+2<<2)>>2];y=m;break};case 18:{g[n>>2]=+((c[s>>2]|0)!=(c[v>>2]|0)|0);y=m;break};case 19:{g[n>>2]=+((c[s>>2]|0)!=(c[v>>2]|0)|0);y=m;break};case 44:{g[n>>2]=+(+g[s>>2]==0.0|0);y=m;break};case 23:{g[n>>2]=+(+g[s>>2]>+g[v>>2]|0);y=m;break};case 47:{P=c[49322]|0;g[n>>2]=+((P+(c[s>>2]|0)|0)==(P|0)|0);y=m;break};case 64:{g[n>>2]=+(~~+g[v>>2]&~~+g[s>>2]|0);y=m;break};case 8:{g[n>>2]=+g[s>>2]- +g[v>>2];y=m;break};case 48:{g[n>>2]=+((c[s>>2]|0)==0|0);y=m;break};case 20:{g[n>>2]=+(+g[s>>2]<=+g[v>>2]|0);y=m;break};case 13:{g[n>>2]=+((c[s>>2]|0)==(c[v>>2]|0)|0);y=m;break};case 61:{y=(b[p>>1]|0)+l|0;break};case 15:{g[n>>2]=+(+g[s>>2]!=+g[v>>2]|0);y=m;break};case 14:{g[n>>2]=+((c[s>>2]|0)==(c[v>>2]|0)|0);y=m;break};case 16:{do{if(+g[s>>2]!=+g[v>>2]){S=1.0}else{if(+g[r+(q+1<<2)>>2]!=+g[r+(u+1<<2)>>2]){S=1.0;break}S=+(+g[r+(q+2<<2)>>2]!=+g[r+(u+2<<2)>>2]|0)}}while(0);g[n>>2]=S;y=m;break};case 0:case 43:{B=c[157708]|0;g[B+4>>2]=+g[B+(b[p>>1]<<2)>>2];B=c[157708]|0;g[B+8>>2]=+g[B+((b[p>>1]|0)+1<<2)>>2];B=c[157708]|0;g[B+12>>2]=+g[B+((b[p>>1]|0)+2<<2)>>2];if((c[157720]|0)<1){w1(44664,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k}B=c[(c[157598]|0)+8>>2]|0;P=(c[270932]|0)-B|0;c[270932]=P;if((P|0)<0){tk(44360,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k}if((B|0)>0){P=0;do{c[(c[157708]|0)+((c[(c[157598]|0)+4>>2]|0)+P<<2)>>2]=c[1083736+((c[270932]|0)+P<<2)>>2];P=P+1|0;}while((P|0)<(B|0))}B=(c[157720]|0)-1|0;c[157720]=B;c[157598]=c[630580+(B<<3)>>2];if((B|0)==(d|0)){break L5008}else{y=c[630576+(B<<3)>>2]|0}break};case 22:{g[n>>2]=+(+g[s>>2]<+g[v>>2]|0);y=m;break};case 6:{g[n>>2]=+g[s>>2]+ +g[v>>2];y=m;break};case 17:{B=c[s>>2]|0;do{if((B|0)>-1){P=c[157606]|0;if((P-1|0)>(B|0)){T=(c[157608]|0)+B|0;break}else{U=c[159946]|0;V=P;h=3845;break}}else{P=c[159946]|0;if((B|0)<(-P|0)){U=P;V=c[157606]|0;h=3845;break}else{T=c[(c[157604]|0)+(~B<<2)>>2]|0;break}}}while(0);if((h|0)==3845){h=0;qa(40520,(k=i,i=i+32|0,c[k>>2]=110144,c[k+8>>2]=B,c[k+16>>2]=-U,c[k+24>>2]=V-2,k)|0);i=k;T=2659232}P=c[v>>2]|0;do{if((P|0)>-1){F=c[157606]|0;if((F-1|0)>(P|0)){W=(c[157608]|0)+P|0;break}else{X=c[159946]|0;Y=F;h=3853;break}}else{F=c[159946]|0;if((P|0)<(-F|0)){X=F;Y=c[157606]|0;h=3853;break}else{W=c[(c[157604]|0)+(~P<<2)>>2]|0;break}}}while(0);if((h|0)==3853){h=0;qa(40520,(k=i,i=i+32|0,c[k>>2]=110144,c[k+8>>2]=P,c[k+16>>2]=-X,c[k+24>>2]=Y-2,k)|0);i=k;W=2659232}g[n>>2]=+(cS(T|0,W|0)|0);y=m;break};case 21:{g[n>>2]=+(+g[s>>2]>=+g[v>>2]|0);y=m;break};case 31:case 34:case 35:case 33:case 36:{c[v>>2]=c[s>>2];y=m;break};case 32:{g[v>>2]=+g[s>>2];g[r+(u+1<<2)>>2]=+g[r+(q+1<<2)>>2];g[r+(u+2<<2)>>2]=+g[r+(q+2<<2)>>2];y=m;break};case 37:case 40:case 41:case 39:case 42:{c[(c[49322]|0)+(c[v>>2]|0)>>2]=c[s>>2];y=m;break};case 38:{B=c[49322]|0;F=c[v>>2]|0;g[B+F>>2]=+g[s>>2];g[B+(F+4)>>2]=+g[r+(q+1<<2)>>2];g[B+(F+8)>>2]=+g[r+(q+2<<2)>>2];y=m;break};case 9:{g[n>>2]=+g[s>>2]- +g[v>>2];g[r+(w+1<<2)>>2]=+g[r+(q+1<<2)>>2]- +g[r+(u+1<<2)>>2];g[r+(w+2<<2)>>2]=+g[r+(q+2<<2)>>2]- +g[r+(u+2<<2)>>2];y=m;break};case 60:{F=c[49322]|0;B=c[157712]|0;o=c[B+112>>2]|0;g[F+(o+280)>>2]=+g[B+124>>2]+.1;Z=+g[s>>2];B=F+(o+216)|0;if(Z!=+g[B>>2]){g[B>>2]=Z}c[F+(o+272)>>2]=c[v>>2];y=m;break};default:{tk(41256,(k=i,i=i+8|0,c[k>>2]=x,k)|0);i=k;y=m}}}while(0);l=y;j=j-1|0}i=f;return}function tn(){var a=0;a=c[157604]|0;if((a|0)!=0){xY(a);c[157604]=0}c[157602]=0;c[159946]=0;return}function to(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a-(c[157608]|0)|0;do{if((b|0)>=0){if((b|0)>((c[157606]|0)-2|0)){break}else{d=b}return d|0}}while(0);b=c[159946]|0;e=c[157604]|0;f=0;while(1){if((f|0)>=(b|0)){break}if((c[e+(f<<2)>>2]|0)==(a|0)){g=3899;break}else{f=f+1|0}}if((g|0)==3899){d=~f;return d|0}if((b|0)==(c[157602]|0)){f=b+256|0;c[157602]=f;g=x$(e,f<<2)|0;c[157604]=g;h=c[159946]|0;i=g}else{h=b;i=e}c[i+(h<<2)>>2]=a;a=c[159946]|0;c[159946]=a+1;d=~a;return d|0}function tp(){var a=0,b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=i;b=(c[45874]|0)+1|0;d=c[49320]|0;L5199:do{if((b|0)<(d|0)){e=b;while(1){if(!((e|0)>-1&(c[49321]|0)>(e|0))){w1(61272,(f=i,i=i+16|0,c[f>>2]=111400,c[f+8>>2]=e,f)|0);i=f}j=c[49322]|0;k=ab(c[157718]|0,e)|0;l=j+k|0;m=l;if((c[m>>2]|0)!=0){n=+g[j+(k+92)>>2];if(n<2.0){break}if(+h[23072]-n>.5){break}}o=e+1|0;p=c[49320]|0;if((o|0)<(p|0)){e=o}else{q=o;r=p;break L5199}}yG(j+(k+96)|0,0,c[(c[157544]|0)+56>>2]<<2|0);c[m>>2]=0;s=l;t=s;i=a;return t|0}else{q=b;r=d}}while(0);if((q|0)==2048){w1(84584,(f=i,i=i+8|0,c[f>>2]=111384,f)|0);i=f;u=c[49320]|0}else{u=r}c[49320]=u+1;if(!((q|0)>-1&(c[49321]|0)>(q|0))){w1(61272,(f=i,i=i+16|0,c[f>>2]=111400,c[f+8>>2]=q,f)|0);i=f}f=c[49322]|0;u=ab(c[157718]|0,q)|0;q=f+u|0;yG(f+(u+96)|0,0,c[(c[157544]|0)+56>>2]<<2|0);c[q>>2]=0;s=q;t=s;i=a;return t|0}function tq(a){a=a|0;var b=0,d=0,e=0;b=i;if(!((a|0)>-1&(c[49321]|0)>(a|0))){w1(61272,(d=i,i=i+16|0,c[d>>2]=111400,c[d+8>>2]=a,d)|0);i=d}d=c[49322]|0;e=d+(ab(c[157718]|0,a)|0)|0;i=b;return e|0}function tr(a){a=a|0;ym(a);c[a>>2]=1;c[a+212>>2]=0;g[a+332>>2]=0.0;g[a+96>>2]=0.0;g[a+404>>2]=0.0;g[a+220>>2]=0.0;g[a+216>>2]=0.0;g[a+136>>2]=+g[29396];g[a+140>>2]=+g[29397];g[a+144>>2]=+g[29398];g[a+172>>2]=+g[29396];g[a+176>>2]=+g[29397];g[a+180>>2]=+g[29398];g[a+280>>2]=-1.0;g[a+132>>2]=0.0;g[a+92>>2]=+h[23072];return}function ts(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=0;while(1){if((d|0)>=2){f=0;g=3931;break}if((cS(b|0,1140172+(d*68|0)|0)|0)==0){g=3930;break}else{d=d+1|0}}do{if((g|0)==3930){h=c[1140168+(d*68|0)>>2]|0}else if((g|0)==3931){while(1){g=0;if((f|0)>=(c[(c[157544]|0)+28>>2]|0)){i=0;break}j=c[157716]|0;if((cS(ti(c[j+(f<<3)+4>>2]|0)|0,b|0)|0)==0){g=3933;break}else{f=f+1|0;g=3931}}if((g|0)==3933){i=j+(f<<3)|0}if((yF(b|0)|0)>>>0>=64){h=i;break}k=c[667370]|0;c[1140168+(k*68|0)>>2]=i;yQ(1140172+(k*68|0)|0,b|0)|0;c[667370]=c[667370]^1;h=i}}while(0);if((h|0)==0){l=0;return l|0}l=a+96+((e[h+2>>1]|0)<<2)|0;return l|0}function tt(b){b=b|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;f=c[157708]|0;g=c[(c[157544]|0)+20>>2]|0;h=c[157710]|0;j=0;while(1){if((j|0)>=(g|0)){k=3945;break}if((e[h+(j<<3)+2>>1]|0|0)==(b|0)){k=3944;break}else{j=j+1|0}}do{if((k|0)==3944){g=h+(j<<3)|0;if((g|0)==0){k=3945;break}tu(e[g>>1]|0,f+(b<<2)|0);g=ti(c[h+(j<<3)+4>>2]|0)|0;bR(2668632,128,60720,(l=i,i=i+24|0,c[l>>2]=b,c[l+8>>2]=g,c[l+16>>2]=2668376,l)|0)|0;i=l}}while(0);if((k|0)==3945){bR(2668632,128,70416,(l=i,i=i+8|0,c[l>>2]=b,l)|0)|0;i=l}l=yF(2668632)|0;while(1){b=2668632+(yF(2668632)|0)|0;x=32;a[b]=x&255;x=x>>8;a[b+1|0]=x&255;if((l|0)<20){l=l+1|0}else{break}}i=d;return 2668632}function tu(a,b){a=a|0;b=b|0;var d=0,f=0,j=0,k=0,l=0,m=0.0,n=0.0;d=i;f=a&-32769;switch(f|0){case 2:{bR(2668376,128,47640,(j=i,i=i+8|0,h[j>>3]=+g[b>>2],j)|0)|0;i=j;i=d;return};case 0:{bR(2668376,128,49936,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;i=d;return};case 4:{a=c[49322]|0;k=(a+(c[b>>2]|0)-a|0)/(c[157718]|0)|0;if(!((k|0)>-1&(k|0)<(c[49320]|0))){w1(59824,(j=i,i=i+8|0,c[j>>2]=110344,j)|0);i=j}bR(2668376,128,48552,(j=i,i=i+8|0,c[j>>2]=k,j)|0)|0;i=j;i=d;return};case 1:{k=ti(c[b>>2]|0)|0;bR(2668376,128,38648,(j=i,i=i+8|0,c[j>>2]=k,j)|0)|0;i=j;i=d;return};case 6:{k=ti(c[(c[157714]|0)+((c[b>>2]|0)*36|0)+16>>2]|0)|0;bR(2668376,128,48296,(j=i,i=i+8|0,c[j>>2]=k,j)|0)|0;i=j;i=d;return};case 5:{k=c[b>>2]|0;a=c[157716]|0;l=0;while(1){if((e[a+(l<<3)+2>>1]|0|0)==(k|0)){break}else{l=l+1|0}}k=ti(c[a+(l<<3)+4>>2]|0)|0;bR(2668376,128,48024,(j=i,i=i+8|0,c[j>>2]=k,j)|0)|0;i=j;i=d;return};case 7:{bR(2668376,128,46848,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;i=d;return};case 3:{m=+g[b+4>>2];n=+g[b+8>>2];bR(2668376,128,47272,(j=i,i=i+24|0,h[j>>3]=+g[b>>2],h[j+8>>3]=m,h[j+16>>3]=n,j)|0)|0;i=j;i=d;return};default:{bR(2668376,128,48832,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;i=d;return}}}function tv(b){b=b|0;var d=0,f=0,g=0,h=0,j=0,k=0;d=i;f=c[(c[157544]|0)+20>>2]|0;g=c[157710]|0;h=0;while(1){if((h|0)>=(f|0)){j=3978;break}if((e[g+(h<<3)+2>>1]|0|0)==(b|0)){j=3977;break}else{h=h+1|0}}do{if((j|0)==3977){if((g+(h<<3)|0)==0){j=3978;break}f=ti(c[g+(h<<3)+4>>2]|0)|0;bR(2668760,128,50544,(k=i,i=i+16|0,c[k>>2]=b,c[k+8>>2]=f,k)|0)|0;i=k}}while(0);if((j|0)==3978){bR(2668760,128,70416,(k=i,i=i+8|0,c[k>>2]=b,k)|0)|0;i=k}k=yF(2668760)|0;while(1){b=2668760+(yF(2668760)|0)|0;x=32;a[b]=x&255;x=x>>8;a[b+1|0]=x&255;if((k|0)<20){k=k+1|0}else{break}}i=d;return 2668760}function tw(d){d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;if((c[d>>2]|0)!=0){oW(46696,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=f;return}h=(d-(c[49322]|0)|0)/(c[157718]|0)|0;if(!((h|0)>-1&(h|0)<(c[49320]|0))){w1(59824,(g=i,i=i+8|0,c[g>>2]=110344,g)|0);i=g}oW(42352,(g=i,i=i+8|0,c[g>>2]=h,g)|0);i=g;if((c[(c[157544]|0)+28>>2]|0)<=1){i=f;return}h=d+96|0;d=1;do{j=c[157716]|0;k=ti(c[j+(d<<3)+4>>2]|0)|0;do{if((a[k+((yF(k|0)|0)-2)|0]|0)!=95){l=h+(e[j+(d<<3)+2>>1]<<2)|0;m=l;n=j+(d<<3)|0;o=c[1168+((b[n>>1]&32767)<<2)>>2]|0;p=0;while(1){if((p|0)>=(o|0)){break}if((c[m+(p<<2)>>2]|0)==0){p=p+1|0}else{break}}if((p|0)==(o|0)){break}oW(38648,(g=i,i=i+8|0,c[g>>2]=k,g)|0);i=g;m=yF(k|0)|0;if((m|0)<15){q=m;do{q=q+1|0;oW(54824,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;}while((q|0)<15)}tu(e[n>>1]|0,l);oW(108680,(g=i,i=i+8|0,c[g>>2]=2668376,g)|0);i=g}}while(0);d=d+1|0;}while((d|0)<(c[(c[157544]|0)+28>>2]|0));i=f;return}function tx(a){a=a|0;var b=0,d=0;b=i;d=(a-(c[49322]|0)|0)/(c[157718]|0)|0;if((d|0)>-1&(d|0)<(c[49320]|0)){i=b;return d|0}w1(59824,(a=i,i=i+8|0,c[a>>2]=110344,a)|0);i=a;i=b;return d|0}function ty(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;a5(105464,2,1,d|0)|0;if((c[f>>2]|0)!=0){a5(102136,2,1,d|0)|0;i=g;return}if((c[(c[157544]|0)+28>>2]|0)>1){h=f+96|0;f=1;do{j=c[157716]|0;k=ti(c[j+(f<<3)+4>>2]|0)|0;do{if((a[k+((yF(k|0)|0)-2)|0]|0)!=95){l=h+(e[j+(f<<3)+2>>1]<<2)|0;m=l;n=j+(f<<3)|0;o=c[1168+((b[n>>1]&32767)<<2)>>2]|0;p=0;while(1){if((p|0)>=(o|0)){break}if((c[m+(p<<2)>>2]|0)==0){p=p+1|0}else{break}}if((p|0)==(o|0)){break}en(d|0,99872,(m=i,i=i+8|0,c[m>>2]=k,m)|0)|0;i=m;tz(e[n>>1]|0,l);en(d|0,98312,(m=i,i=i+8|0,c[m>>2]=2668504,m)|0)|0;i=m}}while(0);f=f+1|0;}while((f|0)<(c[(c[157544]|0)+28>>2]|0))}a5(102136,2,1,d|0)|0;i=g;return}function tz(a,b){a=a|0;b=b|0;var d=0,f=0,j=0,k=0,l=0.0,m=0.0,n=0;d=i;f=a&-32769;switch(f|0){case 4:{a=c[49322]|0;j=(a+(c[b>>2]|0)-a|0)/(c[157718]|0)|0;if(!((j|0)>-1&(j|0)<(c[49320]|0))){w1(59824,(k=i,i=i+8|0,c[k>>2]=110344,k)|0);i=k}bR(2668504,128,50736,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;i=d;return};case 0:{bR(2668504,128,49936,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0)|0;i=k;i=d;return};case 1:{j=ti(c[b>>2]|0)|0;bR(2668504,128,38648,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;i=d;return};case 3:{l=+g[b+4>>2];m=+g[b+8>>2];bR(2668504,128,49168,(k=i,i=i+24|0,h[k>>3]=+g[b>>2],h[k+8>>3]=l,h[k+16>>3]=m,k)|0)|0;i=k;i=d;return};case 2:{bR(2668504,128,49512,(k=i,i=i+8|0,h[k>>3]=+g[b>>2],k)|0)|0;i=k;i=d;return};case 5:{j=c[b>>2]|0;a=c[157716]|0;n=0;while(1){if((e[a+(n<<3)+2>>1]|0|0)==(j|0)){break}else{n=n+1|0}}j=ti(c[a+(n<<3)+4>>2]|0)|0;bR(2668504,128,38648,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;i=d;return};case 6:{j=ti(c[(c[157714]|0)+((c[b>>2]|0)*36|0)+16>>2]|0)|0;bR(2668504,128,38648,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;i=d;return};default:{bR(2668504,128,48832,(k=i,i=i+8|0,c[k>>2]=f,k)|0)|0;i=k;i=d;return}}}function tA(a){a=a|0;var b=0,d=0;b=i;if(!((a|0)>-1&(c[49321]|0)>(a|0))){w1(61272,(d=i,i=i+16|0,c[d>>2]=111400,c[d+8>>2]=a,d)|0);i=d}d=c[49322]|0;tw(d+(ab(c[157718]|0,a)|0)|0);i=b;return}function tB(){var a=0,b=0,d=0,e=0;a=i;oW(96160,(b=i,i=i+8|0,c[b>>2]=c[49320],b)|0);i=b;if((c[49320]|0)>0){d=0}else{i=a;return}do{if((c[49321]|0)<=(d|0)){w1(61272,(b=i,i=i+16|0,c[b>>2]=111400,c[b+8>>2]=d,b)|0);i=b}e=c[49322]|0;tw(e+(ab(c[157718]|0,d)|0)|0);d=d+1|0;}while((d|0)<(c[49320]|0));i=a;return}function tC(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;a5(105464,2,1,a|0)|0;d=c[157544]|0;if((c[d+20>>2]|0)>0){f=0;g=d}else{h=a5(102136,2,1,a|0)|0;i=b;return}while(1){d=c[157710]|0;j=e[d+(f<<3)>>1]|0;do{if((j&32768|0)==0){k=g}else{l=j&32767;if((l-1|0)>>>0>1&(l|0)!=4){k=g;break}m=ti(c[d+(f<<3)+4>>2]|0)|0;en(a|0,99872,(n=i,i=i+8|0,c[n>>2]=m,n)|0)|0;i=n;tz(l,(c[157708]|0)+((e[d+(f<<3)+2>>1]|0)<<2)|0);en(a|0,98312,(n=i,i=i+8|0,c[n>>2]=2668504,n)|0)|0;i=n;k=c[157544]|0}}while(0);d=f+1|0;if((d|0)<(c[k+20>>2]|0)){f=d;g=k}else{break}}h=a5(102136,2,1,a|0)|0;i=b;return}function tD(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+64|0;f=oa(d)|0;if((a[1410640]|0)==125){i=e;return}d=e|0;g=f;do{if((g|0)==0){w1(94032,(h=i,i=i+8|0,c[h>>2]=111336,h)|0);i=h}yQ(d|0,1410640)|0;f=oa(g)|0;if((f|0)==0){w1(94032,(h=i,i=i+8|0,c[h>>2]=111336,h)|0);i=h}if((a[1410640]|0)==125){w1(92408,(h=i,i=i+8|0,c[h>>2]=111336,h)|0);i=h;j=0}else{j=0}while(1){if((j|0)>=(c[(c[157544]|0)+20>>2]|0)){k=4073;break}l=c[157710]|0;if((cS(ti(c[l+(j<<3)+4>>2]|0)|0,d|0)|0)==0){k=4072;break}else{j=j+1|0}}do{if((k|0)==4072){k=0;m=l+(j<<3)|0;if((m|0)==0){k=4073;break}if((tE(c[157708]|0,b[m>>1]|0,b[l+(j<<3)+2>>1]|0)|0)!=0){break}qa(88880,(h=i,i=i+8|0,c[h>>2]=111336,h)|0);i=h}}while(0);if((k|0)==4073){k=0;oW(90728,(h=i,i=i+8|0,c[h>>2]=d,h)|0);i=h}g=oa(f)|0;}while((a[1410640]|0)!=125);i=e;return}function tE(b,d,f){b=b|0;d=d|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;i=i+128|0;j=h|0;k=b;b=f&65535;f=k+(b<<2)|0;switch(d&32767|0){case 5:{d=0;while(1){if((d|0)>=(c[(c[157544]|0)+28>>2]|0)){break}l=c[157716]|0;if((cS(ti(c[l+(d<<3)+4>>2]|0)|0,1410640)|0)==0){m=4099;break}else{d=d+1|0}}do{if((m|0)==4099){if((l+(d<<3)|0)==0){break}c[f>>2]=c[(c[157708]|0)+(e[l+(d<<3)+2>>1]<<2)>>2];n=1;i=h;return n|0}}while(0);oW(51368,(o=i,i=i+8|0,c[o>>2]=1410640,o)|0);i=o;n=0;i=h;return n|0};case 4:{d=fi(1410640)|0;if(!((d|0)>-1&(c[49321]|0)>(d|0))){w1(61272,(o=i,i=i+16|0,c[o>>2]=111400,c[o+8>>2]=d,o)|0);i=o}l=c[49322]|0;c[f>>2]=l+(ab(c[157718]|0,d)|0)-l;n=1;i=h;return n|0};case 2:{g[f>>2]=+yE(1410640);n=1;i=h;return n|0};case 1:{l=yF(1410640)|0;d=l+1|0;p=x2(d)|0;if((d|0)>0){q=0;r=p;while(1){s=a[1410640+q|0]|0;do{if(s<<24>>24==92&(q|0)<(l|0)){t=q+1|0;u=r+1|0;if((a[1410640+t|0]|0)==110){a[r]=10;v=u;w=t;break}else{a[r]=92;v=u;w=t;break}}else{a[r]=s;v=r+1|0;w=q}}while(0);s=w+1|0;if((s|0)<(d|0)){q=s;r=v}else{break}}}c[f>>2]=to(p)|0;n=1;i=h;return n|0};case 3:{p=j|0;yQ(p|0,1410640)|0;j=p;while(1){v=a[j]|0;if((v<<24>>24|0)==32|(v<<24>>24|0)==0){break}j=j+1|0}a[j]=0;g[f>>2]=+yE(p);p=j+1|0;j=p;while(1){v=a[j]|0;if((v<<24>>24|0)==32|(v<<24>>24|0)==0){break}j=j+1|0}a[j]=0;g[k+(b+1<<2)>>2]=+yE(p);p=j+1|0;j=p;while(1){v=a[j]|0;if((v<<24>>24|0)==32|(v<<24>>24|0)==0){break}j=j+1|0}a[j]=0;g[k+(b+2<<2)>>2]=+yE(p);n=1;i=h;return n|0};case 6:{p=0;while(1){if((p|0)>=(c[(c[157544]|0)+36>>2]|0)){break}x=c[157714]|0;if((cS(ti(c[x+(p*36|0)+16>>2]|0)|0,1410640)|0)==0){m=4104;break}else{p=p+1|0}}do{if((m|0)==4104){b=x+(p*36|0)|0;if((b|0)==0){break}c[f>>2]=(b-(c[157714]|0)|0)/36|0;n=1;i=h;return n|0}}while(0);oW(51104,(o=i,i=i+8|0,c[o>>2]=1410640,o)|0);i=o;n=0;i=h;return n|0};default:{n=1;i=h;return n|0}}return 0}function tF(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+288|0;g=f|0;if((c[49322]|0)!=(e|0)){yG(e+96|0,0,c[(c[157544]|0)+56>>2]<<2|0)}h=oa(d)|0;if((a[1410640]|0)==125){c[e>>2]=1;j=h;i=f;return j|0}d=g|0;k=e+96|0;e=f+256|0;l=h;while(1){if((l|0)==0){w1(94032,(m=i,i=i+8|0,c[m>>2]=111352,m)|0);i=m}if((cS(1410640,87104)|0)==0){a[1410640]=a[85200]|0;a[1410641|0]=a[85201|0]|0;a[1410642|0]=a[85202|0]|0;a[1410643|0]=a[85203|0]|0;a[1410644|0]=a[85204|0]|0;a[1410645|0]=a[85205|0]|0;a[1410646|0]=a[85206|0]|0;n=1}else{n=0}if((cS(1410640,82704)|0)==0){yJ(1410640,80752,10)|0}yQ(d|0,1410640)|0;h=yF(d|0)|0;L5490:do{if((h|0)!=0){o=h;do{o=o-1|0;p=g+o|0;if((a[p]|0)!=32){break L5490}a[p]=0;}while((o|0)!=0)}}while(0);h=oa(l)|0;if((h|0)==0){w1(94032,(m=i,i=i+8|0,c[m>>2]=111352,m)|0);i=m}if((a[1410640]|0)==125){w1(92408,(m=i,i=i+8|0,c[m>>2]=111352,m)|0);i=m}L5501:do{if((a[d]|0)!=95){o=0;while(1){if((o|0)>=(c[(c[157544]|0)+28>>2]|0)){break}q=c[157716]|0;if((cS(ti(c[q+(o<<3)+4>>2]|0)|0,d|0)|0)==0){r=4143;break}else{o=o+1|0}}do{if((r|0)==4143){r=0;p=q+(o<<3)|0;if((p|0)==0){break}if((n|0)!=0){yQ(e|0,1410640)|0;cl(1410640,77616,(m=i,i=i+8|0,c[m>>2]=e,m)|0)|0;i=m}if((tE(k,b[p>>1]|0,b[q+(o<<3)+2>>1]|0)|0)!=0){break L5501}qa(88880,(m=i,i=i+8|0,c[m>>2]=111352,m)|0);i=m;break L5501}}while(0);oW(78968,(m=i,i=i+8|0,c[m>>2]=d,m)|0);i=m}}while(0);o=oa(h)|0;if((a[1410640]|0)==125){j=o;break}else{l=o}}i=f;return j|0}function tG(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;g[(c[157712]|0)+124>>2]=+h[23072];e=oa(b)|0;if((e|0)==0){f=0;oX(72984,(j=i,i=i+8|0,c[j>>2]=f,j)|0);i=j;i=d;return}else{k=0;l=0;m=e}L5518:while(1){e=k;b=m;L5520:while(1){if((a[1410640]|0)!=123){w1(76256,(j=i,i=i+16|0,c[j>>2]=111368,c[j+8>>2]=1410640,j)|0);i=j}if((e|0)==0){if((c[49321]|0)<=0){w1(61272,(j=i,i=i+16|0,c[j>>2]=111400,c[j+8>>2]=0,j)|0);i=j}n=c[49322]|0}else{n=tp()|0}o=tF(b,n)|0;do{if(+g[5066]!=0.0){if((~~+g[n+452>>2]&2048|0)!=0){p=4165;break L5520}}else{q=c[352264]|0;if((q|0)==1){if((~~+g[n+452>>2]&512|0)==0){break}else{p=4172;break L5520}}else if((q|0)==0){if((~~+g[n+452>>2]&256|0)==0){break}else{p=4172;break L5520}}else{if((q|0)<=1){break}if((~~+g[n+452>>2]&1024|0)==0){break}else{p=4172;break L5520}}}}while(0);q=c[n+208>>2]|0;L5541:do{if((q|0)==0){oW(75e3,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;tw(n);ym(n);c[n>>2]=1;c[n+212>>2]=0;g[n+332>>2]=0.0;g[n+96>>2]=0.0;g[n+404>>2]=0.0;g[n+220>>2]=0.0;g[n+216>>2]=0.0;g[n+136>>2]=+g[29396];g[n+140>>2]=+g[29397];g[n+144>>2]=+g[29398];g[n+172>>2]=+g[29396];g[n+176>>2]=+g[29397];g[n+180>>2]=+g[29398];g[n+280>>2]=-1.0;g[n+132>>2]=0.0;g[n+92>>2]=+h[23072]}else{r=ti(q)|0;s=0;while(1){if((s|0)>=(c[(c[157544]|0)+36>>2]|0)){break}t=c[157714]|0;if((cS(ti(c[t+(s*36|0)+16>>2]|0)|0,r|0)|0)==0){p=4179;break}else{s=s+1|0}}do{if((p|0)==4179){p=0;r=t+(s*36|0)|0;if((r|0)==0){break}c[(c[157712]|0)+112>>2]=n-(c[49322]|0);tm((r-(c[157714]|0)|0)/36|0);break L5541}}while(0);oW(74056,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;tw(n);ym(n);c[n>>2]=1;c[n+212>>2]=0;g[n+332>>2]=0.0;g[n+96>>2]=0.0;g[n+404>>2]=0.0;g[n+220>>2]=0.0;g[n+216>>2]=0.0;g[n+136>>2]=+g[29396];g[n+140>>2]=+g[29397];g[n+144>>2]=+g[29398];g[n+172>>2]=+g[29396];g[n+176>>2]=+g[29397];g[n+180>>2]=+g[29398];g[n+280>>2]=-1.0;g[n+132>>2]=0.0;g[n+92>>2]=+h[23072]}}while(0);q=oa(o)|0;if((q|0)==0){f=l;p=4185;break L5518}else{e=n;b=q}}if((p|0)==4172){p=0;ym(n);c[n>>2]=1;c[n+212>>2]=0;g[n+332>>2]=0.0;g[n+96>>2]=0.0;g[n+404>>2]=0.0;g[n+220>>2]=0.0;g[n+216>>2]=0.0;g[n+136>>2]=+g[29396];g[n+140>>2]=+g[29397];g[n+144>>2]=+g[29398];g[n+172>>2]=+g[29396];g[n+176>>2]=+g[29397];g[n+180>>2]=+g[29398];g[n+280>>2]=-1.0;g[n+132>>2]=0.0;g[n+92>>2]=+h[23072]}else if((p|0)==4165){p=0;ym(n);c[n>>2]=1;c[n+212>>2]=0;g[n+332>>2]=0.0;g[n+96>>2]=0.0;g[n+404>>2]=0.0;g[n+220>>2]=0.0;g[n+216>>2]=0.0;g[n+136>>2]=+g[29396];g[n+140>>2]=+g[29397];g[n+144>>2]=+g[29398];g[n+172>>2]=+g[29396];g[n+176>>2]=+g[29397];g[n+180>>2]=+g[29398];g[n+280>>2]=-1.0;g[n+132>>2]=0.0;g[n+92>>2]=+h[23072]}b=l+1|0;e=oa(o)|0;if((e|0)==0){f=b;p=4184;break}else{k=n;l=b;m=e}}if((p|0)==4184){oX(72984,(j=i,i=i+8|0,c[j>>2]=f,j)|0);i=j;i=d;return}else if((p|0)==4185){oX(72984,(j=i,i=i+8|0,c[j>>2]=f,j)|0);i=j;i=d;return}}function tH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0.0,j=0.0;e=a+4|0;f=b+4|0;g=c[157329]|0;if((c[e>>2]|0)<(c[f>>2]|0)){h=c[b>>2]|0;i=+((c[a>>2]|0)-h|0);j=+(g-h|0)/i;c[d>>2]=~~(+(h|0)+j*i+.5);h=c[f>>2]|0;c[d+4>>2]=~~(+(h|0)+j*+((c[e>>2]|0)-h|0)+.5);h=c[b+8>>2]|0;c[d+8>>2]=~~(+(h|0)+j*+((c[a+8>>2]|0)-h|0)+.5);h=c[b+12>>2]|0;c[d+12>>2]=~~(+(h|0)+j*+((c[a+12>>2]|0)-h|0)+.5);h=c[b+16>>2]|0;c[d+16>>2]=~~(+(h|0)+j*+((c[a+16>>2]|0)-h|0)+.5);h=c[b+20>>2]|0;c[d+20>>2]=~~(+(h|0)+j*+((c[a+20>>2]|0)-h|0)+.5);return}else{h=c[a>>2]|0;j=+((c[b>>2]|0)-h|0);i=+(g-h|0)/j;c[d>>2]=~~(+(h|0)+i*j+.5);h=c[e>>2]|0;c[d+4>>2]=~~(+(h|0)+i*+((c[f>>2]|0)-h|0)+.5);h=c[a+8>>2]|0;c[d+8>>2]=~~(+(h|0)+i*+((c[b+8>>2]|0)-h|0)+.5);h=c[a+12>>2]|0;c[d+12>>2]=~~(+(h|0)+i*+((c[b+12>>2]|0)-h|0)+.5);h=c[a+16>>2]|0;c[d+16>>2]=~~(+(h|0)+i*+((c[b+16>>2]|0)-h|0)+.5);h=c[a+20>>2]|0;c[d+20>>2]=~~(+(h|0)+i*+((c[b+20>>2]|0)-h|0)+.5);return}}function tI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0.0,j=0.0;e=a+4|0;f=b+4|0;g=c[157336]|0;if((c[e>>2]|0)<(c[f>>2]|0)){h=c[b>>2]|0;i=+((c[a>>2]|0)-h|0);j=+(g-h|0)/i;c[d>>2]=~~(+(h|0)+j*i+.5);h=c[f>>2]|0;c[d+4>>2]=~~(+(h|0)+j*+((c[e>>2]|0)-h|0)+.5);h=c[b+8>>2]|0;c[d+8>>2]=~~(+(h|0)+j*+((c[a+8>>2]|0)-h|0)+.5);h=c[b+12>>2]|0;c[d+12>>2]=~~(+(h|0)+j*+((c[a+12>>2]|0)-h|0)+.5);h=c[b+16>>2]|0;c[d+16>>2]=~~(+(h|0)+j*+((c[a+16>>2]|0)-h|0)+.5);h=c[b+20>>2]|0;c[d+20>>2]=~~(+(h|0)+j*+((c[a+20>>2]|0)-h|0)+.5);return}else{h=c[a>>2]|0;j=+((c[b>>2]|0)-h|0);i=+(g-h|0)/j;c[d>>2]=~~(+(h|0)+i*j+.5);h=c[e>>2]|0;c[d+4>>2]=~~(+(h|0)+i*+((c[f>>2]|0)-h|0)+.5);h=c[a+8>>2]|0;c[d+8>>2]=~~(+(h|0)+i*+((c[b+8>>2]|0)-h|0)+.5);h=c[a+12>>2]|0;c[d+12>>2]=~~(+(h|0)+i*+((c[b+12>>2]|0)-h|0)+.5);h=c[a+16>>2]|0;c[d+16>>2]=~~(+(h|0)+i*+((c[b+16>>2]|0)-h|0)+.5);h=c[a+20>>2]|0;c[d+20>>2]=~~(+(h|0)+i*+((c[b+20>>2]|0)-h|0)+.5);return}}function tJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0.0,k=0;e=a+4|0;f=c[e>>2]|0;g=b+4|0;h=c[g>>2]|0;i=c[157330]|0;if((f|0)<(h|0)){j=+(i-h|0)/+(f-h|0);k=c[b>>2]|0;c[d>>2]=~~(+(k|0)+j*+((c[a>>2]|0)-k|0)+.5);k=c[g>>2]|0;c[d+4>>2]=~~(+(k|0)+j*+((c[e>>2]|0)-k|0)+.5);k=c[b+8>>2]|0;c[d+8>>2]=~~(+(k|0)+j*+((c[a+8>>2]|0)-k|0)+.5);k=c[b+12>>2]|0;c[d+12>>2]=~~(+(k|0)+j*+((c[a+12>>2]|0)-k|0)+.5);k=c[b+16>>2]|0;c[d+16>>2]=~~(+(k|0)+j*+((c[a+16>>2]|0)-k|0)+.5);k=c[b+20>>2]|0;c[d+20>>2]=~~(+(k|0)+j*+((c[a+20>>2]|0)-k|0)+.5);return}else{j=+(i-f|0)/+(h-f|0);f=c[a>>2]|0;c[d>>2]=~~(+(f|0)+j*+((c[b>>2]|0)-f|0)+.5);f=c[e>>2]|0;c[d+4>>2]=~~(+(f|0)+j*+((c[g>>2]|0)-f|0)+.5);f=c[a+8>>2]|0;c[d+8>>2]=~~(+(f|0)+j*+((c[b+8>>2]|0)-f|0)+.5);f=c[a+12>>2]|0;c[d+12>>2]=~~(+(f|0)+j*+((c[b+12>>2]|0)-f|0)+.5);f=c[a+16>>2]|0;c[d+16>>2]=~~(+(f|0)+j*+((c[b+16>>2]|0)-f|0)+.5);f=c[a+20>>2]|0;c[d+20>>2]=~~(+(f|0)+j*+((c[b+20>>2]|0)-f|0)+.5);return}}function tK(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;a[1140172]=0;a[1140240]=0;e=ok(72184)|0;c[157544]=e;if((e|0)==0){w1(71e3,(f=i,i=i+8|0,c[f>>2]=110128,f)|0);i=f}oX(69360,(f=i,i=i+8|0,c[f>>2]=(c[352950]|0)/1024|0,f)|0);i=f;b[315444]=oI(c[157544]|0,c[352950]|0)|0;e=c[157544]|0;g=c[e>>2]|0;if((g|0)==6){h=e}else{w1(68088,(f=i,i=i+16|0,c[f>>2]=g,c[f+8>>2]=6,f)|0);i=f;h=c[157544]|0}if((c[h+4>>2]|0)==5927){j=h}else{w1(67104,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;j=c[157544]|0}h=j;c[157714]=h+(c[j+32>>2]|0);g=j+40|0;c[157608]=h+(c[g>>2]|0);h=c[j+44>>2]|0;c[157606]=h;if(((c[g>>2]|0)+h|0)>=(c[352950]|0)){qa(66072,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f}tn();h=c[157544]|0;g=h;c[157710]=g+(c[h+16>>2]|0);j=g+(c[h+24>>2]|0)|0;c[157716]=j;c[157642]=g+(c[h+8>>2]|0);e=g+(c[h+48>>2]|0)|0;c[157712]=e;c[157708]=e;c[157718]=(c[h+56>>2]<<2)+96;if((c[h+28>>2]|0)>0){k=0;l=h;m=j}else{i=d;return}while(1){if((b[m+(k<<3)>>1]|0)<0){w1(65176,(f=i,i=i+8|0,c[f>>2]=110128,f)|0);i=f;n=c[157544]|0}else{n=l}j=k+1|0;if((j|0)>=(c[n+28>>2]|0)){break}k=j;l=n;m=c[157716]|0}i=d;return}function tL(){oE(64344,430);oE(63576,372);oE(62760,24);oE(62144,62);pb(14952);pb(19304);pb(4064);pb(4008);pb(3952);pb(3896);pb(4808);pb(5032);pb(4976);pb(4920);pb(4864);return}function tM(){var a=0,b=0,d=0;a=i;b=nE(os(1)|0)|0;if(!((b|0)>-1&(b|0)<(c[49320]|0))){oW(51744,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;i=a;return}if((c[49321]|0)<=(b|0)){w1(61272,(d=i,i=i+16|0,c[d>>2]=111400,c[d+8>>2]=b,d)|0);i=d}d=c[49322]|0;tw(d+(ab(c[157718]|0,b)|0)|0);i=a;return}function tN(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=i;b=c[49320]|0;if((b|0)>0){d=0;e=0;f=0;h=0;j=0;while(1){if((c[49321]|0)<=(d|0)){w1(61272,(k=i,i=i+16|0,c[k>>2]=111400,c[k+8>>2]=d,k)|0);i=k}l=c[49322]|0;m=ab(c[157718]|0,d)|0;do{if((c[l+m>>2]|0)==0){n=e+1|0;o=(+g[l+(m+132)>>2]!=0.0)+h|0;p=((c[l+(m+212)>>2]|0)!=0)+f|0;if(+g[l+(m+128)>>2]!=4.0){q=j;r=o;s=p;t=n;break}q=j+1|0;r=o;s=p;t=n}else{q=j;r=h;s=f;t=e}}while(0);m=d+1|0;l=c[49320]|0;if((m|0)<(l|0)){d=m;e=t;f=s;h=r;j=q}else{u=t;v=s;w=r;x=q;y=l;break}}}else{u=0;v=0;w=0;x=0;y=b}oW(53536,(k=i,i=i+8|0,c[k>>2]=y,k)|0);i=k;oW(52928,(k=i,i=i+8|0,c[k>>2]=u,k)|0);i=k;oW(52536,(k=i,i=i+8|0,c[k>>2]=v,k)|0);i=k;oW(52304,(k=i,i=i+8|0,c[k>>2]=w,k)|0);i=k;oW(52024,(k=i,i=i+8|0,c[k>>2]=x,k)|0);i=k;i=a;return}function tO(){return 112248}function tP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0.0,k=0;e=a+4|0;f=c[e>>2]|0;g=b+4|0;h=c[g>>2]|0;i=c[157337]|0;if((f|0)<(h|0)){j=+(i-h|0)/+(f-h|0);k=c[b>>2]|0;c[d>>2]=~~(+(k|0)+j*+((c[a>>2]|0)-k|0)+.5);k=c[g>>2]|0;c[d+4>>2]=~~(+(k|0)+j*+((c[e>>2]|0)-k|0)+.5);k=c[b+8>>2]|0;c[d+8>>2]=~~(+(k|0)+j*+((c[a+8>>2]|0)-k|0)+.5);k=c[b+12>>2]|0;c[d+12>>2]=~~(+(k|0)+j*+((c[a+12>>2]|0)-k|0)+.5);k=c[b+16>>2]|0;c[d+16>>2]=~~(+(k|0)+j*+((c[a+16>>2]|0)-k|0)+.5);k=c[b+20>>2]|0;c[d+20>>2]=~~(+(k|0)+j*+((c[a+20>>2]|0)-k|0)+.5);return}else{j=+(i-f|0)/+(h-f|0);f=c[a>>2]|0;c[d>>2]=~~(+(f|0)+j*+((c[b>>2]|0)-f|0)+.5);f=c[e>>2]|0;c[d+4>>2]=~~(+(f|0)+j*+((c[g>>2]|0)-f|0)+.5);f=c[a+8>>2]|0;c[d+8>>2]=~~(+(f|0)+j*+((c[b+8>>2]|0)-f|0)+.5);f=c[a+12>>2]|0;c[d+12>>2]=~~(+(f|0)+j*+((c[b+12>>2]|0)-f|0)+.5);f=c[a+16>>2]|0;c[d+16>>2]=~~(+(f|0)+j*+((c[b+16>>2]|0)-f|0)+.5);f=c[a+20>>2]|0;c[d+20>>2]=~~(+(f|0)+j*+((c[b+20>>2]|0)-f|0)+.5);return}}function tQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+16|0;f=e|0;g=a|0;h=(c[g>>2]|0)==0;j=b+(c[a+4>>2]<<5)|0;yJ(1401648,j|0,32)|0;do{if(h){do{if((c[g>>2]|0)==0){if((c[350418]&32|0)==0){break}c[350414]=(c[350414]|0)+(c[157529]|0)}}while(0);j=b+(c[a+8>>2]<<5)|0;yJ(1401680,j|0,32)|0;do{if((c[g>>2]|0)==0){if((c[350426]&32|0)==0){break}c[350422]=(c[350422]|0)+(c[157529]|0)}}while(0);j=b+(c[a+12>>2]<<5)|0;yJ(1401712,j|0,32)|0;if((c[g>>2]|0)!=0){break}if((c[350434]&32|0)==0){break}c[350430]=(c[350430]|0)+(c[157529]|0)}else{j=b+(c[a+8>>2]<<5)|0;yJ(1401680,j|0,32)|0;j=b+(c[a+12>>2]<<5)|0;yJ(1401712,j|0,32)|0}}while(0);b=c[350426]|c[350418]|c[350434];do{if((b&16|0)==0){k=b;l=0;m=3}else{h=d+((c[a+4>>2]|0)*12|0)|0;c[660636]=c[h>>2];c[660637]=c[h+4>>2];c[660638]=c[h+8>>2];h=d+((c[a+8>>2]|0)*12|0)|0;c[660639]=c[h>>2];c[2642560>>2]=c[h+4>>2];c[2642564>>2]=c[h+8>>2];h=d+((c[a+12>>2]|0)*12|0)|0;c[660642]=c[h>>2];c[2642572>>2]=c[h+4>>2];c[2642576>>2]=c[h+8>>2];h=tR(1401648,1401904,16,3,70)|0;if((h|0)==0){i=e;return}else{k=c[350490]|c[350482]|c[350498];l=1;m=h;break}}}while(0);do{if((k&1|0)==0){n=l;o=m}else{a=l^1;d=tR(1401648+(l<<8)|0,1401648+(a<<8)|0,1,m,78)|0;if((d|0)!=0){n=a;o=d;break}i=e;return}}while(0);do{if((k&4|0)==0){p=n;q=o}else{m=n^1;l=tR(1401648+(n<<8)|0,1401648+(m<<8)|0,4,o,10)|0;if((l|0)!=0){p=m;q=l;break}i=e;return}}while(0);do{if((k&8|0)==0){r=p;s=q}else{o=p^1;n=tR(1401648+(p<<8)|0,1401648+(o<<8)|0,8,q,88)|0;if((n|0)!=0){r=o;s=n;break}i=e;return}}while(0);do{if((k&2|0)==0){t=r;u=s}else{q=r^1;p=tR(1401648+(r<<8)|0,1401648+(q<<8)|0,2,s,20)|0;if((p|0)!=0){t=q;u=p;break}i=e;return}}while(0);if((u|0)>0){s=c[157329]|0;r=c[157330]|0;k=c[157337]|0;p=c[157336]|0;q=0;do{n=1401648+(t<<8)+(q<<5)|0;o=c[n>>2]|0;do{if((o|0)<(s|0)){c[n>>2]=s}else{if((o|0)<=(p|0)){break}c[n>>2]=p}}while(0);n=1401648+(t<<8)+(q<<5)+4|0;o=c[n>>2]|0;do{if((o|0)<(r|0)){c[n>>2]=r}else{if((o|0)<=(k|0)){break}c[n>>2]=k}}while(0);c[1401648+(t<<8)+(q<<5)+24>>2]=0;q=q+1|0;}while((q|0)<(u|0))}c[f>>2]=c[g>>2];c[157525]=f;c[157526]=1401648+(t<<8);c[f+4>>2]=0;t=u-1|0;if((t|0)>1){u=f+8|0;g=f+12|0;f=1;do{c[u>>2]=f;f=f+1|0;c[g>>2]=f;ps();}while((f|0)<(t|0))}c[157525]=0;i=e;return}function tR(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((e|0)<=0){g=0;return g|0}h=0;i=e-1|0;j=0;while(1){k=a+(i<<5)|0;l=c[a+(i<<5)+24>>2]&d;m=a+(j<<5)|0;n=c[a+(j<<5)+24>>2]&d;o=(n|0)!=0;do{if((l|0)==0|o^1){if((l|0)==(n|0)){p=h}else{q=b+(h<<5)|0;fP[f&127](k,m,q);r=b+(h<<5)+24|0;c[r>>2]=0;s=c[q>>2]|0;if((s|0)<(c[157329]|0)){c[r>>2]=1;t=1}else{t=0}q=c[b+(h<<5)+4>>2]|0;if((q|0)<(c[157330]|0)){u=t|2;c[r>>2]=u;v=u}else{v=t}if((s|0)>(c[157336]|0)){s=v|4;c[r>>2]=s;w=s}else{w=v}if((q|0)>(c[157337]|0)){c[r>>2]=w|8}p=h+1|0}if(o){x=p;break}r=b+(p<<5)|0;q=m;yJ(r|0,q|0,32)|0;x=p+1|0}else{x=h}}while(0);m=j+1|0;if((m|0)<(e|0)){h=x;i=j;j=m}else{g=x;break}}return g|0}function tS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0;e=i;i=i+16|0;f=e|0;h=a-1401648>>5;j=2642544+(h*12|0)|0;k=b-1401648>>5;l=2642544+(k*12|0)|0;if((c[a+4>>2]|0)<(c[b+4>>2]|0)){m=+g[2642552+(k*12|0)>>2];n=(5.0-m)/(+g[2642552+(h*12|0)>>2]-m);m=+g[l>>2];g[f>>2]=m+n*(+g[j>>2]-m);m=+g[2642548+(k*12|0)>>2];g[f+4>>2]=m+n*(+g[2642548+(h*12|0)>>2]-m);g[f+8>>2]=5.0;o=c[b+8>>2]|0;c[d+8>>2]=~~(+(o|0)+n*+((c[a+8>>2]|0)-o|0));o=c[b+12>>2]|0;c[d+12>>2]=~~(+(o|0)+n*+((c[a+12>>2]|0)-o|0));o=c[b+16>>2]|0;c[d+16>>2]=~~(+(o|0)+n*+((c[a+16>>2]|0)-o|0))}else{n=+g[2642552+(h*12|0)>>2];m=(5.0-n)/(+g[2642552+(k*12|0)>>2]-n);n=+g[j>>2];g[f>>2]=n+m*(+g[l>>2]-n);n=+g[2642548+(h*12|0)>>2];g[f+4>>2]=n+m*(+g[2642548+(k*12|0)>>2]-n);g[f+8>>2]=5.0;k=c[a+8>>2]|0;c[d+8>>2]=~~(+(k|0)+m*+((c[b+8>>2]|0)-k|0));k=c[a+12>>2]|0;c[d+12>>2]=~~(+(k|0)+m*+((c[b+12>>2]|0)-k|0));k=c[a+16>>2]|0;c[d+16>>2]=~~(+(k|0)+m*+((c[b+16>>2]|0)-k|0))}tU(d,f);f=c[d>>2]|0;if((f|0)<(c[157329]|0)){k=d+24|0;c[k>>2]=c[k>>2]|1}k=c[d+4>>2]|0;if((k|0)<(c[157330]|0)){b=d+24|0;c[b>>2]=c[b>>2]|2}if((f|0)>(c[157336]|0)){f=d+24|0;c[f>>2]=c[f>>2]|4}if((k|0)<=(c[157337]|0)){i=e;return}k=d+24|0;c[k>>2]=c[k>>2]|8;i=e;return}function tT(a,b){a=a|0;b=b|0;var e=0,f=0,h=0,i=0,j=0,k=0.0,l=0;if((c[157516]|0)<=0){return}e=0;f=b;b=a;a=c[157514]|0;while(1){h=a|0;i=a+1|0;j=a+2|0;k=1.0/(+g[664779]+(+g[664776]*+(d[h]|0|0)+ +g[664777]*+(d[i]|0|0)+ +g[664778]*+(d[j]|0|0)));c[b+20>>2]=~~k;c[b>>2]=~~(+g[6948]+k*(+g[664771]+(+g[664768]*+(d[h]|0|0)+ +g[664769]*+(d[i]|0|0)+ +g[664770]*+(d[j]|0|0))));c[b+4>>2]=~~(+g[6944]+k*(+g[664775]+(+g[664772]*+(d[h]|0|0)+ +g[664773]*+(d[i]|0|0)+ +g[664774]*+(d[j]|0|0))));c[b+8>>2]=c[f+4>>2];c[b+12>>2]=c[f+8>>2];c[b+24>>2]=c[f>>2];j=d[a+3|0]|0;k=+g[11344+(j*12|0)>>2]*+g[157392]+ +g[11348+(j*12|0)>>2]*+g[157393]+ +g[11352+(j*12|0)>>2]*+g[157394];j=c[157520]|0;if(k<0.0){i=~~(k*+g[2570])+j|0;l=(i|0)<0?0:i}else{l=j}c[b+16>>2]=l;j=e+1|0;if((j|0)<(c[157516]|0)){e=j;f=f+12|0;b=b+32|0;a=a+4|0}else{break}}return}function tU(a,b){a=a|0;b=b|0;var d=0.0;d=1.0/+g[b+8>>2];c[a+20>>2]=~~(d*+g[2]);c[a>>2]=~~(+g[6948]+d*+g[b>>2]*+g[6946]);c[a+4>>2]=~~(+g[6944]+d*+g[b+4>>2]*+g[6942]);return}function tV(a){a=a|0;var b=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;b=i;i=i+800|0;e=b|0;f=b+96|0;h=b+608|0;j=a+176|0;c[j>>2]=0;k=c[a+136>>2]|0;c[158756]=k;l=rQ(k)|0;tW(a,l,0);k=c[a+140>>2]|0;if((k|0)>=(c[l+56>>2]|0)|(k|0)<0){a=c[158756]|0;oX(70280,(m=i,i=i+16|0,c[m>>2]=k,c[m+8>>2]=a,m)|0);i=m;n=0}else{n=k}k=l+76|0;o=+((d[k+(n*36|0)+8|0]|0)>>>0);g[e+36>>2]=o;g[e+24>>2]=o;g[e+12>>2]=o;g[e>>2]=o;p=+((d[k+(n*36|0)+12|0]|0)>>>0);g[e+84>>2]=p;g[e+72>>2]=p;g[e+60>>2]=p;g[e+48>>2]=p;p=+((d[k+(n*36|0)+9|0]|0)>>>0);g[e+76>>2]=p;g[e+64>>2]=p;g[e+40>>2]=p;g[e+4>>2]=p;q=+((d[k+(n*36|0)+13|0]|0)>>>0);g[e+88>>2]=q;g[e+52>>2]=q;g[e+28>>2]=q;g[e+16>>2]=q;q=+((d[k+(n*36|0)+10|0]|0)>>>0);g[e+68>>2]=q;g[e+56>>2]=q;g[e+20>>2]=q;g[e+8>>2]=q;r=+((d[k+(n*36|0)+14|0]|0)>>>0);g[e+92>>2]=r;g[e+80>>2]=r;g[e+44>>2]=r;g[e+32>>2]=r;r=+g[664768];s=+g[664769];t=+g[664770];u=+g[664771];v=+g[664772];w=+g[664773];x=+g[664774];y=+g[664775];z=+g[664776];A=+g[664777];B=+g[664778];C=+g[664779];n=0;k=0;m=1;a=9999;D=o;o=p;p=q;while(1){g[h+(n*12|0)>>2]=u+(D*r+o*s+p*t);g[h+(n*12|0)+4>>2]=y+(D*v+o*w+p*x);q=C+(D*z+o*A+p*B);g[h+(n*12|0)+8>>2]=q;if(q<5.0){c[f+(n<<5)+24>>2]=16;E=a;F=m;G=1}else{if(q<+(a|0)){H=~~q}else{H=a}c[f+(n<<5)+24>>2]=0;E=H;F=0;G=k}I=n+1|0;if((I|0)>=8){break}n=I;k=G;m=F;a=E;D=+g[e+(I*12|0)>>2];o=+g[e+(I*12|0)+4>>2];p=+g[e+(I*12|0)+8>>2]}if((F|0)!=0){J=0;i=b;return J|0}F=(G|0)!=0;do{if(F){G=8;e=0;while(1){a=c[27800+(e<<3)>>2]|0;m=c[27804+(e<<3)>>2]|0;if((c[f+(a<<5)+24>>2]|0)==(c[f+(m<<5)+24>>2]|0)){K=G}else{p=+g[h+(a*12|0)+8>>2];o=(5.0-p)/(+g[h+(m*12|0)+8>>2]-p);p=+g[h+(a*12|0)>>2];g[h+(G*12|0)>>2]=p+o*(+g[h+(m*12|0)>>2]-p);p=+g[h+(a*12|0)+4>>2];g[h+(G*12|0)+4>>2]=p+o*(+g[h+(m*12|0)+4>>2]-p);g[h+(G*12|0)+8>>2]=5.0;c[f+(G<<5)+24>>2]=0;K=G+1|0}m=e+1|0;if((m|0)<12){G=K;e=m}else{break}}if((K|0)>0){L=K;break}else{J=0}i=b;return J|0}else{L=8}}while(0);p=+g[18];o=+g[20];D=+g[8];B=+g[10];A=+g[157339];z=+g[157340];C=+g[157347];x=+g[157348];K=0;e=0;G=15;while(1){if((c[f+(K<<5)+24>>2]&16|0)==0){w=1.0/+g[h+(K*12|0)+8>>2];v=o+w*+g[h+(K*12|0)>>2]*p;y=B+w*+g[h+(K*12|0)+4>>2]*D;m=v<A|0;a=y<z?m|2:m;m=v>C?a|4:a;a=y>x?m|8:m;M=a&G;N=a|e}else{M=G;N=e}a=K+1|0;if((a|0)<(L|0)){K=a;e=N;G=M}else{break}}if((M|0)!=0){J=0;i=b;return J|0}if(+g[2712]!=0.0){J=1;i=b;return J|0}M=(N|0)==0&(F&1^1);c[j>>2]=M;if((M|0)==0){J=1;i=b;return J|0}if(+(E|0)<=+g[3338]+ +g[l+60>>2]*+g[2572]){J=1;i=b;return J|0}c[j>>2]=M|2;J=1;i=b;return J|0}function tW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,j=0,k=0,l=0.0,m=0.0,n=0,o=0.0,p=0.0,q=0,r=0,s=0,t=0;d=i;i=i+128|0;e=d|0;f=d+48|0;j=d+96|0;k=d+112|0;do{if(+g[2698]!=0.0){l=+g[a+256>>2];m=+g[a+260>>2];if(l==m){n=4374;break}o=(+h[321194]-m)/(m-l);do{if(o>=1.0|o>0.0){if(o>=1.0){p=1.0;break}p=o}else{p=0.0}}while(0);if((a|0)==2577896){n=4374;break}q=a+232|0;o=+g[a+244>>2]- +g[q>>2];r=k|0;g[r>>2]=o;l=+g[a+248>>2]- +g[a+236>>2];s=k+4|0;g[s>>2]=l;m=+g[a+252>>2]- +g[a+240>>2];t=k+8|0;g[t>>2]=m;do{if(o>180.0){g[r>>2]=o+-360.0}else{if(o>=-180.0){break}g[r>>2]=o+360.0}}while(0);do{if(l>180.0){g[s>>2]=l+-360.0}else{if(l>=-180.0){break}g[s>>2]=l+360.0}}while(0);do{if(m>180.0){g[t>>2]=m+-360.0}else{if(m>=-180.0){break}g[t>>2]=m+360.0}}while(0);t=j|0;q7(q,p,r,t);g[t>>2]=-0.0- +g[t>>2]}else{n=4374}}while(0);if((n|0)==4374){g[j+8>>2]=+g[a+132>>2];g[j>>2]=-0.0- +g[a+124>>2];g[j+4>>2]=+g[a+128>>2]}rc(j|0,2659152,2659136,2659120);g[665034]=+g[b>>2];g[665039]=+g[b+4>>2];g[665044]=+g[b+8>>2];g[665037]=+g[b+12>>2];g[665041]=+g[b+16>>2];g[665045]=+g[b+20>>2];g[f>>2]=+g[664788];g[f+4>>2]=-0.0- +g[664784];g[f+8>>2]=+g[664780];g[f+16>>2]=+g[664789];g[f+20>>2]=-0.0- +g[664785];g[f+24>>2]=+g[664781];g[f+32>>2]=+g[664790];g[f+36>>2]=-0.0- +g[664786];g[f+40>>2]=+g[664782];g[f+12>>2]=-0.0- +g[169390];g[f+28>>2]=-0.0- +g[169391];g[f+44>>2]=-0.0- +g[169392];b=e|0;ra(f|0,2660136,b);g[665022]=+g[29328];g[665023]=+g[29329];g[665024]=+g[29330];g[665026]=+g[29324];g[665027]=+g[29325];g[665028]=+g[29326];q8(2660104);g[665030]=+g[29332];g[665031]=+g[29333];g[665032]=+g[29334];ra(2660088,b,2659072);if((c|0)==0){i=d;return}p=+g[6946]*4.656612873077393e-10;m=+g[6942]*4.656612873077393e-10;g[664768]=+g[664768]*p;g[664772]=+g[664772]*m;g[664776]=+g[664776]*4.656612873077393e-10;g[664769]=+g[664769]*p;g[664773]=+g[664773]*m;g[664777]=+g[664777]*4.656612873077393e-10;g[664770]=+g[664770]*p;g[664774]=+g[664774]*m;g[664778]=+g[664778]*4.656612873077393e-10;g[664771]=+g[664771]*p;g[664775]=+g[664775]*m;g[664779]=+g[664779]*4.656612873077393e-10;i=d;return}function tX(){return 8}function tY(e,f){e=e|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0,z=0,A=0,B=0.0,C=0.0,D=0,E=0.0,F=0.0,G=0.0,H=0.0,I=0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;j=i;i=i+90144|0;c[157518]=(c[157518]|0)+1;k=j+31&-32;l=j+65568|0;m=rQ(c[e+136>>2]|0)|0;n=m;o=c[e+148>>2]|0;if((o|0)>=(c[m+24>>2]|0)|(o|0)<0){oX(50464,(p=i,i=i+16|0,c[p>>2]=110056,c[p+8>>2]=o,p)|0);i=p;q=0}else{q=o}o=m+(c[m+28>>2]|0)|0;r=m+40|0;s=c[r>>2]|0;c[664806]=s;t=c[o+(q<<3)>>2]|0;u=c[o+(q<<3)+4>>2]|0;if((u|0)>1){q=(uv(m+(c[m+32>>2]|0)+(t<<2)|0,u,+h[321194]+ +g[e+152>>2])|0)+t|0;v=q;w=c[664806]|0}else{v=t;w=s}s=m+44|0;t=c[s>>2]|0;q=c[m+36>>2]|0;c[157522]=m+(q+(ab(ab(c[r>>2]|0,v)|0,t)|0));c[157523]=w;c[157529]=w>>>1<<16;c[157524]=c[s>>2];s=e+176|0;tW(e,n,c[s>>2]|0);w=c[f>>2]|0;t=(w|0)<5?16e3:255-w<<6;c[157520]=(t|0)<5?5:t;x=+(c[f+4>>2]|0);g[2570]=x<0.0?0.0:x*64.0;t=f+8|0;f=c[t>>2]|0;g[157392]=+g[f>>2]*+g[664788]+ +g[f+4>>2]*+g[664789]+ +g[f+8>>2]*+g[664790];f=c[t>>2]|0;g[157393]=-0.0-(+g[f>>2]*+g[664784]+ +g[f+4>>2]*+g[664785]+ +g[f+8>>2]*+g[664786]);f=c[t>>2]|0;g[157394]=+g[f>>2]*+g[664780]+ +g[f+4>>2]*+g[664781]+ +g[f+8>>2]*+g[664782];f=c[e+140>>2]|0;if((f|0)>=(c[m+56>>2]|0)|(f|0)<0){oX(54752,(p=i,i=i+16|0,c[p>>2]=110080,c[p+8>>2]=f,p)|0);i=p;y=0}else{y=f}f=c[n+76+(y*36|0)>>2]|0;t=c[n+76+(y*36|0)+4>>2]|0;y=(t|0)>1;if(y){w=m+(c[m+68>>2]|0)+(f<<2)|0;z=(uv(w,t,+h[321194]+ +g[e+152>>2])|0)+f|0;A=w}else{z=f;A=0}do{if(+g[2712]!=0.0){x=+g[e+196>>2];B=+g[e+192>>2];C=x-B;if(x<B|C>1.0|(e|0)==2577896){D=4412;break}do{if(y){f=t-1|0;B=+g[A+(f<<2)>>2];E=+h[321194]+ +g[e+152>>2];F=E-B*+(~~(E/B)|0);w=0;while(1){if((w|0)>=(f|0)){break}if(+g[A+(w<<2)>>2]>F){break}else{w=w+1|0}}v=n+76+((b[e+190>>1]|0)*36|0)|0;r=(c[v>>2]|0)+w&65535;b[e+186>>1]=r;if((w|0)==0){q=(c[v>>2]|0)+f&65535;b[e+184>>1]=q;G=F;H=+g[A>>2];I=q;J=r;break}else{q=r-1&65535;b[e+184>>1]=q;B=+g[A+(w-1<<2)>>2];G=F-B;H=+g[A+(w<<2)>>2]-B;I=q;J=r;break}}else{r=c[n+76+((b[e+190>>1]|0)*36|0)>>2]&65535;b[e+186>>1]=r;q=c[n+76+((b[e+188>>1]|0)*36|0)>>2]&65535;b[e+184>>1]=q;G=+h[321194]-x;H=C;I=q;J=r}}while(0);C=G/H;if(C<1.0){K=C<=0.0?0.0:C}else{K=1.0}r=~~(K*4194304.0);q=4194304-r|0;v=m+(c[m+72>>2]|0)|0;u=m+48|0;o=c[u>>2]|0;L=v+((ab(o,I<<16>>16)|0)<<2)|0;M=v+((ab(o,J<<16>>16)|0)<<2)|0;if((o|0)<=0){N=2660184;break}o=M;v=K<.5?L:M;M=0;O=L;L=2660184;while(1){P=ab(d[O|0]|0,q)|0;a[L|0]=((ab(d[o|0]|0,r)|0)+P|0)>>>22&255;P=ab(d[O+1|0]|0,q)|0;a[L+1|0]=((ab(d[o+1|0]|0,r)|0)+P|0)>>>22&255;P=ab(d[O+2|0]|0,q)|0;a[L+2|0]=((ab(d[o+2|0]|0,r)|0)+P|0)>>>22&255;a[L+3|0]=a[v+3|0]|0;P=M+1|0;if((P|0)<(c[u>>2]|0)){o=o+4|0;v=v+4|0;M=P;O=O+4|0;L=L+4|0}else{N=2660184;break}}}else{D=4412}}while(0);if((D|0)==4412){D=m+(c[m+72>>2]|0)|0;c[157514]=D;N=D+((ab(c[m+48>>2]|0,z)|0)<<2)|0}c[157514]=N;N=e+144|0;if((c[N>>2]|0)==0){w1(60632,(p=i,i=i+8|0,c[p>>2]=110104,p)|0);i=p}do{if((c[s>>2]|0)==3){p=(c[2602]|0)!=0;c[157528]=p&1;if(!p){break}pp()}else{c[157528]=0}}while(0);c[664796]=c[N>>2];g[2]=(e|0)==2577896?6442450944.0:2147483648.0;e=c[m-8>>2]|0;if((c[s>>2]|0)!=0){c[157516]=c[m+48>>2];tT(k,m+e|0);if((c[157528]|0)!=0){po(k,c[157516]|0)}c[157526]=k;c[157525]=m+(c[m-4>>2]|0);c[157527]=c[m+52>>2];ps();i=j;return}s=c[m+48>>2]|0;c[157516]=s;if((s|0)>0){s=l;N=k;p=m+e|0;e=0;z=c[157514]|0;while(1){D=z|0;J=z+1|0;I=z+2|0;n=s|0;g[n>>2]=+g[664771]+(+g[664768]*+(d[D]|0)+ +g[664769]*+(d[J]|0)+ +g[664770]*+(d[I]|0));A=s+4|0;g[A>>2]=+g[664775]+(+g[664772]*+(d[D]|0)+ +g[664773]*+(d[J]|0)+ +g[664774]*+(d[I]|0));t=s+8|0;g[t>>2]=+g[664779]+(+g[664776]*+(d[D]|0)+ +g[664777]*+(d[J]|0)+ +g[664778]*+(d[I]|0));c[N+8>>2]=c[p+4>>2];c[N+12>>2]=c[p+8>>2];I=c[p>>2]|0;J=N+24|0;c[J>>2]=I;D=d[z+3|0]|0;K=+g[11344+(D*12|0)>>2]*+g[157392]+ +g[11348+(D*12|0)>>2]*+g[157393]+ +g[11352+(D*12|0)>>2]*+g[157394];D=c[157520]|0;if(K<0.0){y=~~(K*+g[2570])+D|0;Q=(y|0)<0?0:y}else{Q=D}c[N+16>>2]=Q;K=+g[t>>2];do{if(K<5.0){c[J>>2]=I|16}else{H=1.0/K;c[N+20>>2]=~~(H*+g[2]);t=~~(+g[6948]+H*+g[n>>2]*+g[6946]);c[N>>2]=t;D=~~(+g[6944]+H*+g[A>>2]*+g[6942]);c[N+4>>2]=D;if((t|0)<(c[157329]|0)){y=I|1;c[J>>2]=y;R=y}else{R=I}if((D|0)<(c[157330]|0)){y=R|2;c[J>>2]=y;S=y}else{S=R}if((t|0)>(c[157336]|0)){t=S|4;c[J>>2]=t;T=t}else{T=S}if((D|0)<=(c[157337]|0)){break}c[J>>2]=T|8}}while(0);J=e+1|0;I=(c[157514]|0)+4|0;c[157514]=I;if((J|0)<(c[157516]|0)){s=s+12|0;N=N+32|0;p=p+12|0;e=J;z=I}else{break}}}c[157527]=1;z=m+52|0;if((c[z>>2]|0)<=0){i=j;return}e=m+(c[m-4>>2]|0)|0;m=0;while(1){p=c[k+(c[e+4>>2]<<5)+24>>2]|0;N=c[k+(c[e+8>>2]<<5)+24>>2]|0;s=c[k+(c[e+12>>2]<<5)+24>>2]|0;do{if((p&31&N&s|0)==0){if(((N|p|s)&31|0)==0){c[157526]=k;c[157525]=e;ps();break}else{tQ(e,k,l);break}}}while(0);s=m+1|0;if((s|0)<(c[z>>2]|0)){e=e+16|0;m=s}else{break}}i=j;return}function tZ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=ab(c[b+44>>2]|0,c[b+40>>2]|0)|0;b=x2(ab(a,d)|0)|0;if((d|0)>0){f=0;g=b}else{return b|0}while(1){h=c[e+(f<<2)>>2]|0;yJ(g|0,h|0,a)|0;h=f+1|0;if((h|0)<(d|0)){f=h;g=g+a|0}else{break}}return b|0}function t_(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=b+64|0;g=b+48|0;h=x2(ab(c[a>>2]<<2,c[g>>2]|0)|0)|0;i=b;c[b+72>>2]=h-i;if((c[a>>2]|0)>0){j=h;h=0;k=c[g>>2]|0;while(1){l=j|0;m=c[f+(h<<2)>>2]|0;n=k<<2;yJ(l|0,m|0,n)|0;n=c[g>>2]|0;m=h+1|0;if((m|0)<(c[a>>2]|0)){j=j+(n<<2)|0;h=m;k=n}else{o=n;break}}}else{o=c[g>>2]|0}k=x2(o*12|0)|0;o=k;c[b-112+104>>2]=k-i;if((c[g>>2]|0)>0){p=0}else{q=b+52|0;r=c[q>>2]|0;s=r<<4;t=x2(s)|0;u=t;v=u-i|0;w=b-112+108|0;x=w;c[x>>2]=v;y=d;z=c[q>>2]|0;A=z<<4;yJ(t|0,y|0,A)|0;return}do{c[o+(p*12|0)>>2]=c[e+(p*12|0)>>2];c[o+(p*12|0)+4>>2]=c[e+(p*12|0)+4>>2]<<16;c[o+(p*12|0)+8>>2]=c[e+(p*12|0)+8>>2]<<16;p=p+1|0;}while((p|0)<(c[g>>2]|0));q=b+52|0;r=c[q>>2]|0;s=r<<4;t=x2(s)|0;u=t;v=u-i|0;w=b-112+108|0;x=w;c[x>>2]=v;y=d;z=c[q>>2]|0;A=z<<4;yJ(t|0,y|0,A)|0;return}function t$(a){a=a|0;var b=0,c=0,d=0,e=0.0,f=0.0,h=0.0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0;b=i;i=i+120|0;c=b|0;d=b+40|0;e=+g[a+128>>2]*3.141592653589793*2.0/360.0;f=+U(+e);h=+T(+e);j=c|0;k=c|0;g[k>>2]=h;l=c+4|0;g[l>>2]=f;m=c+8|0;g[m>>2]=0.0;n=c+12|0;g[n>>2]=-0.0-f;o=c+16|0;g[o>>2]=h;p=c+20|0;g[p>>2]=0.0;q=c+24|0;g[q>>2]=0.0;r=c+28|0;g[r>>2]=0.0;s=c+32|0;g[s>>2]=1.0;h=+g[a+124>>2]*3.141592653589793*2.0/360.0;f=+U(+h);e=+T(+h);g[d>>2]=e;g[d+4>>2]=0.0;g[d+8>>2]=-0.0-f;g[d+12>>2]=0.0;g[d+16>>2]=1.0;g[d+20>>2]=0.0;g[d+24>>2]=f;g[d+28>>2]=0.0;g[d+32>>2]=e;c=b+80|0;qV(d|0,j,c);e=+g[a+132>>2]*3.141592653589793*2.0/360.0;f=+U(+e);h=+T(+e);g[k>>2]=1.0;g[l>>2]=0.0;g[m>>2]=0.0;g[n>>2]=0.0;g[o>>2]=h;g[p>>2]=f;g[q>>2]=0.0;g[r>>2]=-0.0-f;g[s>>2]=h;qV(j,c,1402336);h=+g[169390];f=+g[169391];e=+g[169392];t=+g[350584];u=+g[350585];v=+g[350586];g[169390]=h*t+f*u+e*v;w=+g[350587];x=+g[350588];y=+g[350589];g[169391]=h*w+f*x+e*y;z=+g[350590];A=+g[350591];B=+g[350592];g[169392]=h*z+f*A+e*B;e=+g[29332];f=+g[29333];h=+g[29334];g[29332]=e*t+f*u+h*v;g[29333]=e*w+f*x+h*y;g[29334]=e*z+f*A+h*B;h=+g[29328];f=+g[29329];e=+g[29330];g[29328]=h*t+f*u+e*v;g[29329]=h*w+f*x+e*y;g[29330]=h*z+f*A+e*B;e=+g[29324];f=+g[29325];h=+g[29326];g[29324]=e*t+f*u+h*v;g[29325]=e*w+f*x+h*y;g[29326]=e*z+f*A+h*B;uy();i=b;return}function t0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+18e3|0;e=d+6e3|0;f=c[b+116>>2]|0;g=c[b+156>>2]|0;if((f|0)<=0){i=d;return}h=d|0;j=e|0;k=a+180|0;l=b+188|0;m=(c[b+180>>2]|0)+((c[b+112>>2]|0)*92|0)|0;b=0;while(1){if((c[m+4>>2]|0)!=16){c[158770]=h;c[158772]=j;c[159942]=0;c[159940]=0;n=m+44|0;c[159942]=c[n>>2];if((c[n>>2]|0)>0){o=m+40|0;p=c[l>>2]|0;q=0;while(1){r=c[p+((c[o>>2]|0)+q<<2)>>2]|0;if((r|0)>0){s=c[157400]|0;c[e+(q*12|0)>>2]=s+((c[g+(r*12|0)>>2]|0)*12|0);c[e+(q*12|0)+4>>2]=s+((c[g+(r*12|0)+4>>2]|0)*12|0)}else{s=-r|0;r=c[157400]|0;c[e+(q*12|0)>>2]=r+((c[g+(s*12|0)+4>>2]|0)*12|0);c[e+(q*12|0)+4>>2]=r+((c[g+(s*12|0)>>2]|0)*12|0)}s=q+1|0;c[e+(q*12|0)+8>>2]=e+(s*12|0);if((s|0)<(c[n>>2]|0)){q=s}else{t=q;break}}}else{t=-1}c[e+(t*12|0)+8>>2]=0;t1(a,j,c[k>>2]|0,m)}q=b+1|0;if((q|0)<(f|0)){m=m+92|0;b=q}else{break}}i=d;return}function t1(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0,P=0,Q=0,R=0;h=i;i=i+8|0;j=h|0;k=j+4|0;c[k>>2]=0;l=j|0;c[l>>2]=0;a[15256]=0;m=c[e+40>>2]|0;n=+g[m>>2];o=+g[m+4>>2];p=+g[m+8>>2];q=+g[m+12>>2]-(+g[157466]*n+ +g[157467]*o+ +g[157468]*p);r=n*+g[350584]+o*+g[350585]+p*+g[350586];s=n*+g[350587]+o*+g[350588]+p*+g[350589];t=n*+g[350590]+o*+g[350591]+p*+g[350592];do{if((d|0)==0){u=4489}else{m=d;v=0;L5944:while(1){w=m+8|0;x=c[w>>2]|0;y=c[m>>2]|0;z=y|0;A=y+4|0;B=y+8|0;p=r*+g[z>>2]+s*+g[A>>2]+t*+g[B>>2]-q;C=p<=0.0|0;D=c[m+4>>2]|0;E=D|0;F=D+4|0;G=D+8|0;o=r*+g[E>>2]+s*+g[F>>2]+t*+g[G>>2]-q;H=o>0.0;I=H&1^1;do{if((I|0)==(C|0)){J=j+(C<<2)|0;c[w>>2]=c[J>>2];c[J>>2]=m;K=v}else{J=c[159940]|0;if((J|0)>499){u=4512;break L5944}n=p/(p-o);c[159940]=J+1;L=c[158770]|0;M=L+(J*12|0)|0;N=+g[z>>2];g[M>>2]=N+n*(+g[E>>2]-N);N=+g[A>>2];g[L+(J*12|0)+4>>2]=N+n*(+g[F>>2]-N);N=+g[B>>2];g[L+(J*12|0)+8>>2]=N+n*(+g[G>>2]-N);J=c[159942]|0;if((J|0)>998){u=4482;break L5944}L=c[158772]|0;O=L+(J*12|0)|0;P=j+(C<<2)|0;c[L+(J*12|0)+8>>2]=c[P>>2];c[P>>2]=O;c[O>>2]=y;c[L+(J*12|0)+4>>2]=M;J=(c[159942]|0)+1|0;L=c[158772]|0;O=L+(J*12|0)|0;P=j+(I<<2)|0;c[L+(J*12|0)+8>>2]=c[P>>2];c[P>>2]=O;c[O>>2]=M;c[L+(J*12|0)+4>>2]=D;c[159942]=(c[159942]|0)+2;if(H){c[158766]=M;a[15256]=1;K=1;break}else{c[158764]=M;a[15256]=1;K=1;break}}}while(0);if((x|0)==0){u=4488;break}else{m=x;v=K}}if((u|0)==4512){i=h;return}else if((u|0)==4488){if(!K){u=4489;break}v=c[159942]|0;if((v|0)<=998){m=c[158772]|0;H=m+(v*12|0)|0;c[m+(v*12|0)+8>>2]=c[l>>2];c[l>>2]=H;c[H>>2]=c[158764];c[m+(v*12|0)+4>>2]=c[158766];v=(c[159942]|0)+1|0;m=c[158772]|0;D=m+(v*12|0)|0;c[m+(v*12|0)+8>>2]=c[k>>2];c[k>>2]=D;c[D>>2]=c[158766];c[m+(v*12|0)+4>>2]=c[158764];c[159942]=(c[159942]|0)+2;Q=H;break}oW(97560,(R=i,i=i+1|0,i=i+7>>3<<3,c[R>>2]=0,R)|0);i=R;i=h;return}else if((u|0)==4482){oW(97560,(R=i,i=i+1|0,i=i+7>>3<<3,c[R>>2]=0,R)|0);i=R;i=h;return}}}while(0);if((u|0)==4489){Q=c[l>>2]|0}do{if((Q|0)!=0){l=c[e+44>>2]|0;if((c[l+4>>2]|0)!=(c[157258]|0)){break}u=c[l>>2]|0;if((u|0)>=0){t1(b,Q,l,f);break}if((u|0)==-2){break}c[157504]=c[l+56>>2];t9(b,Q,f)}}while(0);Q=c[k>>2]|0;if((Q|0)==0){i=h;return}k=c[e+48>>2]|0;if((c[k+4>>2]|0)!=(c[157258]|0)){i=h;return}e=c[k>>2]|0;if((e|0)>=0){t1(b,Q,k,f);i=h;return}if((e|0)==-2){i=h;return}c[157504]=c[k+56>>2];t9(b,Q,f);i=h;return}function t2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[b+116>>2]|0;if((e|0)<=0){return}f=a+180|0;g=(c[b+180>>2]|0)+((c[b+112>>2]|0)*92|0)|0;b=0;while(1){if((c[g+4>>2]|0)!=16){c[157502]=c[(c[f>>2]|0)+56>>2];t8(a,g,d)}h=b+1|0;if((h|0)<(e|0)){g=g+92|0;b=h}else{break}}return}function t3(){var a=0;g[169390]=+g[157424];g[169391]=+g[157425];g[169392]=+g[157426];a=c[157224]|0;c[157400]=c[a+148>>2];t4(c[a+164>>2]|0);return}function t4(a){a=a|0;var b=0,e=0,f=0,h=0,i=0.0,j=0,k=0;b=c[a>>2]|0;if((b|0)==-2){return}else{e=a;f=b}while(1){if((c[e+4>>2]|0)!=(c[157258]|0)){h=4546;break}if((c[e+8>>2]|0)==16){h=4543;break}if((f|0)<0){h=4527;break}b=c[e+40>>2]|0;a=d[b+16|0]|0;if((a|0)==2){i=+g[169392]- +g[b+12>>2]}else if((a|0)==1){i=+g[169391]- +g[b+12>>2]}else if((a|0)==0){i=+g[169390]- +g[b+12>>2]}else{i=+g[169390]*+g[b>>2]+ +g[169391]*+g[b+4>>2]+ +g[169392]*+g[b+8>>2]- +g[b+12>>2]}b=i<0.0|0;t4(c[e+44+(b<<2)>>2]|0);a=c[e+56>>2]|0;if((a|0)!=0){j=(c[(c[644470]|0)+180>>2]|0)+((c[e+52>>2]|0)*92|0)|0;k=a;while(1){do{if((c[j>>2]|0)==(c[157258]|0)){a=c[j+4>>2]|0;if((a|0)==16){break}t8(628760,j,a)}}while(0);a=k-1|0;if((a|0)==0){break}j=j+92|0;k=a}c[157502]=(c[157502]|0)+1}k=c[e+44+((b^1)<<2)>>2]|0;j=c[k>>2]|0;if((j|0)==-2){h=4545;break}else{e=k;f=j}}if((h|0)==4545){return}else if((h|0)==4546){return}else if((h|0)==4543){return}else if((h|0)==4527){c[e+56>>2]=c[157502];c[157502]=(c[157502]|0)+1;return}}function t5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0,G=0,H=0.0,I=0.0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;d=i;i=i+32|0;e=d|0;f=d+16|0;if((c[157464]|0)==0){h=e|0;g[h>>2]=+g[a>>2]- +g[169390];j=e+4|0;g[j>>2]=+g[a+4>>2]- +g[169391];k=e+8|0;g[k>>2]=+g[a+8>>2]- +g[169392];a=f|0;uu(h,a);l=f+8|0;m=+g[l>>2];if(m<.01){g[l>>2]=.009999999776482582;n=.009999999776482582}else{n=m}m=1.0/n;n=+g[20]+m*+g[18]*+g[a>>2];o=+g[157341];p=n<o?o:n;n=+g[157345];o=+g[10]-m*+g[8]*+g[f+4>>2];q=+g[157342];r=o<q?q:o;o=+g[157346];q=r>o?o:r;s=q;t=p>n?n:p;u=m;v=~~+aa(+q);w=h;x=j;y=k;z=a;A=l}else{s=+g[2536];t=+g[2538];u=+g[2664];v=c[157508]|0;w=e|0;x=e+4|0;y=e+8|0;z=f|0;A=f+8|0}g[w>>2]=+g[b>>2]- +g[169390];g[x>>2]=+g[b+4>>2]- +g[169391];g[y>>2]=+g[b+8>>2]- +g[169392];uu(w,z);q=+g[A>>2];if(q<.01){g[A>>2]=.009999999776482582;B=.009999999776482582}else{B=q}q=1.0/B;g[2664]=q;B=+g[20]+q*+g[18]*+g[z>>2];g[2538]=B;m=+g[157341];if(B<m){g[2538]=m;C=m}else{C=B}B=+g[157345];if(C>B){g[2538]=B}B=+g[10]- +g[8]*q*+g[f+4>>2];g[2536]=B;C=+g[157342];if(B<C){g[2536]=C;D=C}else{D=B}B=+g[157346];if(D>B){g[2536]=B;E=B}else{E=D}D=q>u?q:u;if(D>+g[2634]){g[2634]=D}if((c[157440]|0)!=0){i=d;return}c[157470]=1;f=~~+aa(+E);c[157508]=f;if((v|0)==(f|0)){if((c[651322]|0)==2147483647){i=d;return}c[651322]=c[2750]|-2147483648;i=d;return}z=c[350618]|0;c[350618]=z+36;c[z+32>>2]=c[157398];g[z+28>>2]=D;A=c[157508]|0;if((v|0)>(f|0)){c[z+16>>2]=0;c[z+20>>2]=(c[139456]|0)-(c[139454]|0)>>6;D=+g[2538];E=+g[2536];u=(t-D)/(s-E);F=v;G=A;H=u;I=D+(+(A|0)-E)*u;J=0}else{f=(c[139456]|0)-(c[139454]|0)>>6;c[z+16>>2]=f;c[z+20>>2]=0;u=(+g[2538]-t)/(+g[2536]-s);F=A;G=v;H=u;I=t+(+(v|0)-s)*u;J=f}f=F-1|0;c[z+4>>2]=~~(H*1048576.0);F=~~(I*1048576.0+1048575.0);v=z|0;c[v>>2]=F;A=c[157343]|0;if((F|0)<(A|0)){c[v>>2]=A;K=A}else{K=F}F=c[157344]|0;if((K|0)>(F|0)){c[v>>2]=F;L=F}else{L=K}K=((J|0)!=0)+L|0;L=672568+(G<<2)|0;G=c[L>>2]|0;do{if((G|0)==0){M=4578}else{if((c[G>>2]|0)<(K|0)){N=G}else{M=4578;break}while(1){O=N+12|0;J=c[O>>2]|0;if((J|0)==0){P=0;break}if((c[J>>2]|0)<(K|0)){N=J}else{P=J;break}}c[z+12>>2]=P;c[O>>2]=z}}while(0);if((M|0)==4578){c[z+12>>2]=G;c[L>>2]=z}L=622536+(f<<2)|0;c[z+24>>2]=c[L>>2];c[L>>2]=z;i=d;return}function t6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0.0,l=0,m=0.0,n=0,o=0.0,p=0,q=0.0,r=0,s=0.0,t=0,u=0.0,v=0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0,D=0;f=i;i=i+16|0;h=f|0;L6089:do{if((e|0)!=0){j=b|0;k=+g[j>>2];l=b+4|0;m=+g[l>>2];n=b+8|0;o=+g[n>>2];p=d|0;q=+g[p>>2];r=d+4|0;s=+g[r>>2];t=d+8|0;u=+g[t>>2];v=e;while(1){w=+g[v>>2];x=+g[v+4>>2];y=+g[v+8>>2];z=+g[v+12>>2];A=k*w+m*x+o*y-z;B=w*q+x*s+y*u-z;if(A<0.0){break}if(B<0.0){C=4592;break}D=c[v+20>>2]|0;if((D|0)==0){break L6089}else{v=D}}if((C|0)==4592){c[651322]=2147483647;u=A/(A-B);s=+g[j>>2];g[h>>2]=s+u*(+g[p>>2]-s);s=+g[l>>2];g[h+4>>2]=s+u*(+g[r>>2]-s);s=+g[n>>2];g[h+8>>2]=s+u*(+g[t>>2]-s);do{if((a[v+24|0]|0)==0){if((a[v+25|0]|0)==0){break}c[157322]=1;D=h;c[157314]=c[D>>2];c[157315]=c[D+4>>2];c[157316]=c[D+8>>2]}else{c[157462]=1;D=h;c[157454]=c[D>>2];c[157455]=c[D+4>>2];c[157456]=c[D+8>>2]}}while(0);t6(b,h,c[v+20>>2]|0);i=f;return}if(B<0.0){if((c[157462]|0)!=0){i=f;return}c[651322]=c[2750]|-2147483648;i=f;return}c[157464]=0;c[651322]=2147483647;s=A/(A-B);u=+g[j>>2];g[h>>2]=u+s*(+g[p>>2]-u);u=+g[l>>2];g[h+4>>2]=u+s*(+g[r>>2]-u);u=+g[n>>2];g[h+8>>2]=u+s*(+g[t>>2]-u);do{if((a[v+24|0]|0)==0){if((a[v+25|0]|0)==0){break}c[157322]=1;D=h;c[157318]=c[D>>2];c[157319]=c[D+4>>2];c[157320]=c[D+8>>2]}else{c[157462]=1;D=h;c[157458]=c[D>>2];c[157459]=c[D+4>>2];c[157460]=c[D+8>>2]}}while(0);t6(h,d,c[v+20>>2]|0);i=f;return}}while(0);t5(b,d);i=f;return}function t7(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;L6120:while(1){a=b|0;d=(c[a>>2]|0)+(c[b+4>>2]|0)|0;c[a>>2]=d;a=c[b+8>>2]|0;do{if((d|0)<(c[a>>2]|0)){e=b;f=a}else{g=c[b+12>>2]|0;h=g|0;i=(c[h>>2]|0)+(c[g+4>>2]|0)|0;c[h>>2]=i;h=c[g+8>>2]|0;if((i|0)<(c[h>>2]|0)){e=g;f=h;break}h=c[g+12>>2]|0;g=h|0;i=(c[g>>2]|0)+(c[h+4>>2]|0)|0;c[g>>2]=i;g=c[h+8>>2]|0;if((i|0)<(c[g>>2]|0)){e=h;f=g;break}g=c[h+12>>2]|0;h=g|0;i=(c[h>>2]|0)+(c[g+4>>2]|0)|0;c[h>>2]=i;h=c[g+8>>2]|0;if((i|0)<(c[h>>2]|0)){e=g;f=h;break}b=c[g+12>>2]|0;continue L6120}}while(0);if((e|0)==1402536){j=4624;break}a=e+12|0;d=c[a>>2]|0;g=e+8|0;c[d+8>>2]=f;c[(c[g>>2]|0)+12>>2]=c[a>>2];h=c[e>>2]|0;i=c[g>>2]|0;do{i=c[i+8>>2]|0;}while((c[i>>2]|0)>(h|0));h=i+12|0;k=c[h>>2]|0;c[a>>2]=k;c[g>>2]=i;c[k+8>>2]=e;c[h>>2]=e;if((d|0)==1402392){j=4625;break}else{b=d}}if((j|0)==4625){return}else if((j|0)==4624){return}}function t8(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0;f=i;i=i+32|0;h=f|0;j=f+16|0;if((c[139456]|0)>>>0>=(c[139458]|0)>>>0){c[157420]=(c[157420]|0)+1;i=f;return}k=d+44|0;l=c[k>>2]|0;if(((c[350618]|0)+((l+4|0)*36|0)|0)>>>0>=(c[350620]|0)>>>0){c[157422]=(c[157422]|0)+l;i=f;return}c[651350]=(c[651350]|0)+1;if((e&8|0)==0){m=0}else{c[29366]=0;m=117444}if((e&4|0)==0){n=m}else{c[29359]=m;n=117416}if((e&2|0)==0){o=n}else{c[29352]=n;o=117388}if((e&1|0)==0){p=o}else{c[29345]=o;p=117360}c[157470]=0;g[2634]=0.0;c[157440]=0;a[15240]=0;a[15248]=0;o=b+136|0;e=c[(c[o>>2]|0)+156>>2]|0;c[157464]=0;do{if((c[k>>2]|0)>0){n=d+40|0;m=0;do{l=c[(c[(c[o>>2]|0)+188>>2]|0)+((c[n>>2]|0)+m<<2)>>2]|0;L6160:do{if((l|0)>0){q=e+(l*12|0)|0;c[157398]=q;do{if((c[278434]|0)==0){r=c[e+(l*12|0)+8>>2]|0;if((r|0)<0){if((r&2147483647|0)!=(c[2750]|0)){break}}else{s=c[157480]|0;if(((c[350618]|0)-s|0)>>>0<=r>>>0){break}t=s;if((c[t+(r+32)>>2]|0)!=(q|0)){break}s=t+(r+16)|0;u=(c[139456]|0)-(c[139454]|0)>>6;if((c[s>>2]|0)==0){c[s>>2]=u}else{c[t+(r+20)>>2]=u}v=+g[t+(r+28)>>2];if(v>+g[2634]){g[2634]=v}c[157470]=1}c[157464]=0;break L6160}}while(0);c[651322]=(c[350618]|0)-(c[157480]|0);c[157322]=0;c[157462]=0;r=c[157400]|0;t6(r+((c[q>>2]|0)*12|0)|0,r+((c[e+(l*12|0)+4>>2]|0)*12|0)|0,p);c[(c[157398]|0)+8>>2]=c[651322];if((c[157462]|0)!=0){a[15248]=1}if((c[157322]|0)!=0){a[15240]=1}c[157464]=1}else{r=-l|0;t=e+(r*12|0)|0;c[157398]=t;do{if((c[278434]|0)==0){u=c[e+(r*12|0)+8>>2]|0;if((u|0)<0){if((u&2147483647|0)!=(c[2750]|0)){break}}else{s=c[157480]|0;if(((c[350618]|0)-s|0)>>>0<=u>>>0){break}w=s;if((c[w+(u+32)>>2]|0)!=(t|0)){break}s=w+(u+16)|0;x=(c[139456]|0)-(c[139454]|0)>>6;if((c[s>>2]|0)==0){c[s>>2]=x}else{c[w+(u+20)>>2]=x}v=+g[w+(u+28)>>2];if(v>+g[2634]){g[2634]=v}c[157470]=1}c[157464]=0;break L6160}}while(0);c[651322]=(c[350618]|0)-(c[157480]|0);c[157322]=0;c[157462]=0;q=c[157400]|0;t6(q+((c[e+(r*12|0)+4>>2]|0)*12|0)|0,q+((c[t>>2]|0)*12|0)|0,p);c[(c[157398]|0)+8>>2]=c[651322];if((c[157462]|0)!=0){a[15248]=1}if((c[157322]|0)!=0){a[15240]=1}c[157464]=1}}while(0);m=m+1|0;}while((m|0)<(c[k>>2]|0));if(!(a[15248]|0)){break}c[157398]=j;c[157464]=0;t6(629816,629832,c[p+20>>2]|0)}}while(0);if(a[15240]|0){c[157398]=j;c[157464]=0;c[157440]=1;t6(629256,629272,c[29352]|0)}if((c[157470]|0)==0){i=f;return}c[157390]=(c[157390]|0)+1;c[(c[139456]|0)+28>>2]=d;g[(c[139456]|0)+36>>2]=+g[2634];c[(c[139456]|0)+24>>2]=c[d+36>>2];c[(c[139456]|0)+40>>2]=c[278434];c[(c[139456]|0)+20>>2]=0;c[(c[139456]|0)+32>>2]=b;b=c[157502]|0;c[157502]=b+1;c[(c[139456]|0)+12>>2]=b;c[(c[139456]|0)+8>>2]=0;b=c[d+32>>2]|0;d=b|0;j=h|0;uu(d,j);v=1.0/(+g[b+12>>2]-(+g[169390]*+g[d>>2]+ +g[169391]*+g[b+4>>2]+ +g[169392]*+g[b+8>>2]));g[(c[139456]|0)+48>>2]=v*+g[j>>2]*+g[16];g[(c[139456]|0)+52>>2]=v*+g[6]*(-0.0- +g[h+4>>2]);j=c[139456]|0;g[j+44>>2]=v*+g[h+8>>2]- +g[20]*+g[j+48>>2]- +g[10]*+g[j+52>>2];c[139456]=(c[139456]|0)+64;i=f;return}function t9(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0;f=i;i=i+32|0;h=f|0;j=f+16|0;if((c[139456]|0)>>>0>=(c[139458]|0)>>>0){c[157420]=(c[157420]|0)+1;i=f;return}k=c[e+44>>2]|0;if(((c[350618]|0)+((k+4|0)*36|0)|0)>>>0>=(c[350620]|0)>>>0){c[157422]=(c[157422]|0)+k;i=f;return}c[651350]=(c[651350]|0)+1;c[157398]=j;k=e+4|0;l=c[k>>2]|0;if((l&8|0)==0){m=0;n=l}else{c[29366]=0;m=117444;n=c[k>>2]|0}if((n&4|0)==0){o=m;p=n}else{c[29359]=m;o=117416;p=c[k>>2]|0}if((p&2|0)==0){q=o;r=p}else{c[29352]=o;q=117388;r=c[k>>2]|0}if((r&1|0)==0){s=q}else{c[29345]=q;s=117360}c[157470]=0;g[2634]=0.0;c[157440]=0;a[15240]=0;a[15248]=0;c[157464]=0;do{if((d|0)!=0){q=d;do{c[157322]=0;c[157462]=0;t6(c[q>>2]|0,c[q+4>>2]|0,s);if((c[157462]|0)!=0){a[15248]=1}if((c[157322]|0)!=0){a[15240]=1}q=c[q+8>>2]|0;}while((q|0)!=0);if(a[15248]|0){c[157398]=j;t6(629816,629832,c[s+20>>2]|0)}if(!(a[15240]|0)){break}c[157398]=j;c[157440]=1;t6(629256,629272,c[29352]|0)}}while(0);if((c[157470]|0)==0){i=f;return}c[157390]=(c[157390]|0)+1;c[(c[139456]|0)+28>>2]=e;g[(c[139456]|0)+36>>2]=+g[2634];c[(c[139456]|0)+24>>2]=c[e+36>>2];c[(c[139456]|0)+40>>2]=1;c[(c[139456]|0)+20>>2]=0;c[(c[139456]|0)+32>>2]=b;c[(c[139456]|0)+12>>2]=c[157504];c[(c[139456]|0)+8>>2]=0;b=c[e+32>>2]|0;e=b|0;j=h|0;uu(e,j);t=1.0/(+g[b+12>>2]-(+g[169390]*+g[e>>2]+ +g[169391]*+g[b+4>>2]+ +g[169392]*+g[b+8>>2]));g[(c[139456]|0)+48>>2]=t*+g[j>>2]*+g[16];g[(c[139456]|0)+52>>2]=t*+g[6]*(-0.0- +g[h+4>>2]);j=c[139456]|0;g[j+44>>2]=t*+g[h+8>>2]- +g[20]*+g[j+48>>2]- +g[10]*+g[j+52>>2];c[139456]=(c[139456]|0)+64;i=f;return}function ua(){var a=0,b=0,d=0,e=0;a=c[157480]|0;c[350618]=a;c[350620]=a+((c[157436]|0)*36|0);a=c[139454]|0;c[139456]=a+128;c[a+72>>2]=0;c[(c[139454]|0)+88>>2]=64;c[(c[139454]|0)+76>>2]=2147483647;c[157502]=0;a=c[157325]|0;b=c[157335]|0;if((a|0)>=(b|0)){return}d=a+1|0;e=((b|0)>(d|0)?b:d)-a<<2;yG(622536+(a<<2)|0,0,e|0);yG(672568+(a<<2)|0,0,e|0);return}function ub(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0.0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0,A=0,B=0,C=0,D=0;b=c[a+20>>2]|0;if((b|0)==0){return}d=c[139454]|0;e=d+(b<<6)|0;f=d+(b<<6)+20|0;h=c[f>>2]|0;c[f>>2]=h+1;if((h|0)!=0){return}h=d+(b<<6)+40|0;if((c[h>>2]|0)!=0){c[157512]=(c[157512]|0)+1}f=c[(c[139454]|0)+64>>2]|0;i=c[d+(b<<6)+12>>2]|0;j=c[f+12>>2]|0;L6273:do{if((i|0)<(j|0)){k=c[a>>2]|0;l=4737}else{m=c[h>>2]|0;if((m|0)!=0&(i|0)==(j|0)){n=a|0;o=c[n>>2]|0;p=+(o-1048575|0)*9.5367431640625e-7;q=d+(b<<6)+44|0;r=+g[4842];s=d+(b<<6)+52|0;t=d+(b<<6)+48|0;u=+g[t>>2];v=+g[q>>2]+r*+g[s>>2]+p*u;w=+g[f+48>>2];x=+g[f+44>>2]+r*+g[f+52>>2]+p*w;if(v*.99>=x){k=o;l=4737;break}if(v*1.01<x|u<w){y=r;z=n;A=q;B=s;C=t}else{k=o;l=4737;break}}else{y=+g[4842];z=a|0;A=d+(b<<6)+44|0;B=d+(b<<6)+52|0;C=d+(b<<6)+48|0}o=f;t=m;while(1){m=c[o>>2]|0;s=c[m+12>>2]|0;if((i|0)>(s|0)){o=m;t=t;continue}if((i|0)!=(s|0)){D=m;break L6273}if((t|0)==0){o=m;t=0;continue}r=+((c[z>>2]|0)-1048575|0)*9.5367431640625e-7;w=+g[C>>2];u=+g[A>>2]+y*+g[B>>2]+r*w;x=+g[m+48>>2];v=+g[m+44>>2]+y*+g[m+52>>2]+r*x;if(u*.99>=v){D=m;break L6273}if(u*1.01<v|w<x){o=m;t=t}else{D=m;break}}}}while(0);if((l|0)==4737){l=k>>20;k=f+16|0;if((l|0)>(c[k>>2]|0)){B=c[145626]|0;c[145626]=B+16;A=c[k>>2]|0;c[B>>2]=A;c[B+8>>2]=l-A;c[B+4>>2]=c[352266];A=f+8|0;c[B+12>>2]=c[A>>2];c[A>>2]=B}c[d+(b<<6)+16>>2]=l;D=f}c[e>>2]=D;f=D+4|0;c[d+(b<<6)+4>>2]=c[f>>2];c[c[f>>2]>>2]=e;c[f>>2]=e;return}function uc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a+156|0;a=c[b>>2]|0;if((a|0)==0){c[b>>2]=0;return}else{d=a}while(1){a=(c[d>>2]|0)+44|0;while(1){e=c[a>>2]|0;if((e|0)==0){break}if((e|0)==(d|0)){f=4749;break}else{a=e+4|0}}if((f|0)==4749){f=0;c[a>>2]=c[d+4>>2]}e=d+12|0;g=c[e>>2]|0;c[e>>2]=c[644471];c[644471]=d;if((g|0)==0){break}else{d=g}}c[b>>2]=0;return}function ud(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[157512]=0;a=c[139454]|0;b=a+64|0;c[a+68>>2]=b;c[(c[139454]|0)+64>>2]=b;c[(c[139454]|0)+80>>2]=c[350622];b=c[350627]|0;if((b|0)!=1402392){a=b;do{b=c[a+16>>2]|0;if((b|0)==0){d=4766}else{e=c[139454]|0;f=e+(b<<6)|0;g=e+(b<<6)+20|0;h=(c[g>>2]|0)-1|0;c[g>>2]=h;if((h|0)==0){if((c[e+(b<<6)+40>>2]|0)!=0){c[157512]=(c[157512]|0)-1}if((c[(c[139454]|0)+64>>2]|0)==(f|0)){h=c[a>>2]>>20;g=e+(b<<6)+16|0;if((h|0)>(c[g>>2]|0)){i=c[145626]|0;c[145626]=i+16;j=c[g>>2]|0;c[i>>2]=j;c[i+8>>2]=h-j;c[i+4>>2]=c[352266];j=e+(b<<6)+8|0;c[i+12>>2]=c[j>>2];c[j>>2]=i}i=f|0;c[(c[i>>2]|0)+16>>2]=h;k=i}else{k=f|0}f=e+(b<<6)+4|0;c[c[f>>2]>>2]=c[k>>2];c[(c[k>>2]|0)+4>>2]=c[f>>2]}if((c[a+20>>2]|0)!=0){d=4766}}if((d|0)==4766){d=0;ub(a)}a=c[a+12>>2]|0;}while((a|0)!=1402392)}a=c[(c[139454]|0)+64>>2]|0;d=c[350596]|0;k=a+16|0;if((d|0)>(c[k>>2]|0)){f=c[145626]|0;c[145626]=f+16;b=c[k>>2]|0;c[f>>2]=b;c[f+8>>2]=d-b;c[f+4>>2]=c[352266];b=a+8|0;c[f+12>>2]=c[b>>2];c[b>>2]=f;l=a}else{l=a}do{c[l+20>>2]=0;l=c[l>>2]|0;}while((l|0)!=((c[139454]|0)+64|0));return}function ue(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=i;i=i+48032|0;b=a+31&-32;c[270776]=b+(3e3-(c[157326]|0)<<4);c[145626]=b;d=c[157324]<<20;c[350624]=d;c[350622]=d>>20;c[350625]=0;c[350626]=0;c[350627]=1402392;c[350628]=0;c[350629]=1;d=c[157334]<<20;c[350598]=d|1048575;c[350596]=d>>20;c[350599]=0;c[350600]=1402496;c[350601]=1402536;c[350602]=1;c[350603]=0;c[350634]=-1;c[350635]=0;c[350637]=1402432;c[350636]=1402392;c[350608]=2147483647;c[350610]=1402536;d=(c[157335]|0)-1|0;e=c[157325]|0;c[352266]=e;g[4842]=+(e|0);c[(c[139454]|0)+84>>2]=1;f=c[672568+(e<<2)>>2]|0;h=(f|0)!=0;if((e|0)<(d|0)){j=e;e=f;k=h;while(1){if(k){l=e;m=c[350627]|0;while(1){n=l+12|0;o=c[n>>2]|0;p=c[l>>2]|0;L6342:do{if((c[m>>2]|0)<(p|0)){q=m;while(1){r=c[q+12>>2]|0;if((c[r>>2]|0)>=(p|0)){s=r;break L6342}t=c[r+12>>2]|0;if((c[t>>2]|0)>=(p|0)){s=t;break L6342}r=c[t+12>>2]|0;if((c[r>>2]|0)>=(p|0)){s=r;break L6342}t=c[r+12>>2]|0;if((c[t>>2]|0)<(p|0)){q=t}else{s=t;break}}}else{s=m}}while(0);c[n>>2]=s;p=s+8|0;c[l+8>>2]=c[p>>2];c[(c[p>>2]|0)+12>>2]=l;c[p>>2]=l;if((o|0)==0){break}else{l=o;m=s}}}ud();if((c[145626]|0)>>>0>(c[270776]|0)>>>0){pi();m=c[139454]|0;l=m+64|0;if(l>>>0<(c[139456]|0)>>>0){p=m;m=l;while(1){c[p+72>>2]=0;l=m+64|0;if(l>>>0<(c[139456]|0)>>>0){p=m;m=l}else{break}}}c[145626]=b}m=c[622536+(j<<2)>>2]|0;if((m|0)!=0){p=m;do{m=p+8|0;l=p+12|0;c[(c[l>>2]|0)+8>>2]=c[m>>2];c[(c[m>>2]|0)+12>>2]=c[l>>2];p=c[p+24>>2]|0;}while((p|0)!=0)}p=c[350627]|0;if((p|0)!=1402392){t7(p)}p=j+1|0;c[352266]=p;g[4842]=+(p|0);c[(c[139454]|0)+84>>2]=1;l=c[672568+(p<<2)>>2]|0;m=(l|0)!=0;if((p|0)<(d|0)){j=p;e=l;k=m}else{u=l;v=m;break}}}else{u=f;v=h}if(!v){ud();pi();i=a;return}v=u;u=c[350627]|0;while(1){h=v+12|0;f=c[h>>2]|0;k=c[v>>2]|0;L6370:do{if((c[u>>2]|0)<(k|0)){e=u;while(1){j=c[e+12>>2]|0;if((c[j>>2]|0)>=(k|0)){w=j;break L6370}d=c[j+12>>2]|0;if((c[d>>2]|0)>=(k|0)){w=d;break L6370}j=c[d+12>>2]|0;if((c[j>>2]|0)>=(k|0)){w=j;break L6370}d=c[j+12>>2]|0;if((c[d>>2]|0)<(k|0)){e=d}else{w=d;break}}}else{w=u}}while(0);c[h>>2]=w;k=w+8|0;c[v+8>>2]=c[k>>2];c[(c[k>>2]|0)+12>>2]=v;c[k>>2]=v;if((f|0)==0){break}else{v=f;u=w}}ud();pi();i=a;return}function uf(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0.0,m=0,n=0,o=0;d=i;e=c[b>>2]|0;if((e|0)==-2){i=d;return}else{f=b;h=e}while(1){if((h|0)<0){j=4803;break}e=c[f+40>>2]|0;b=a[e+16|0]|0;k=b&255;do{if((b&255)<3){l=+g[e+12>>2];if(l<=+g[629888+(k<<2)>>2]){m=1;j=4815;break}n=l>=+g[629904+(k<<2)>>2]?2:3;j=4812}else{n=rb(629888,629904,e)|0;j=4812}}while(0);if((j|0)==4812){j=0;if(!((n|0)!=3|(c[157396]|0)!=0)){c[157396]=f}if((n&1|0)==0){o=n}else{m=n;j=4815}}if((j|0)==4815){j=0;uf(c[f+44>>2]|0);o=m}if((o&2|0)==0){j=4821;break}e=c[f+48>>2]|0;k=c[e>>2]|0;if((k|0)==-2){j=4819;break}else{f=e;h=k}}if((j|0)==4819){i=d;return}else if((j|0)==4803){if((c[157396]|0)==0){c[157396]=f}h=c[644471]|0;if((h|0)==0){oW(97e3,(o=i,i=i+1|0,i=i+7>>3<<3,c[o>>2]=0,o)|0);i=o;i=d;return}else{o=h+12|0;c[644471]=c[o>>2];c[h+8>>2]=c[157530];c[c[274572]>>2]=h;c[274572]=o;c[o>>2]=0;c[h>>2]=f;o=f+44|0;c[h+4>>2]=c[o>>2];c[o>>2]=h;i=d;return}}else if((j|0)==4821){i=d;return}}function ug(b){b=b|0;var d=0,e=0,f=0,h=0,i=0,j=0.0,k=0,l=0;if((c[b+4>>2]|0)==(c[157258]|0)){d=b}else{return}L6412:while(1){if((c[d+8>>2]|0)==16){e=4845;break}f=c[d>>2]|0;if((f|0)<0){e=4827;break}b=c[d+40>>2]|0;h=a[b+16|0]|0;i=h&255;do{if((h&255)<3){j=+g[b+12>>2];if(j<=+g[629888+(i<<2)>>2]){e=4836;break}k=j>=+g[629904+(i<<2)>>2]?2:3;e=4833}else{k=rb(629888,629904,b)|0;e=4833}}while(0);do{if((e|0)==4833){e=0;if((k|0)==3){e=4834;break L6412}if((k&1|0)!=0){e=4836;break}l=d+48|0}}while(0);if((e|0)==4836){e=0;l=d+44|0}b=c[l>>2]|0;if((c[b+4>>2]|0)==(c[157258]|0)){d=b}else{e=4843;break}}if((e|0)==4843){return}else if((e|0)==4834){c[157396]=d;return}else if((e|0)==4845){return}else if((e|0)==4827){if((f|0)==-2){return}c[157396]=d;return}}function uh(a){a=a|0;var b=0,d=0,e=0,f=0;b=a+136|0;if((c[b>>2]|0)==0){return}c[157530]=a;c[274572]=a+156;c[157396]=0;d=a+112|0;g[157472]=+g[d>>2]+ +g[(c[b>>2]|0)+84>>2];e=a+116|0;g[157473]=+g[e>>2]+ +g[(c[b>>2]|0)+88>>2];f=a+120|0;g[157474]=+g[f>>2]+ +g[(c[b>>2]|0)+92>>2];g[157476]=+g[d>>2]+ +g[(c[b>>2]|0)+96>>2];g[157477]=+g[e>>2]+ +g[(c[b>>2]|0)+100>>2];g[157478]=+g[f>>2]+ +g[(c[b>>2]|0)+104>>2];uf(c[(c[644470]|0)+164>>2]|0);c[a+180>>2]=c[157396];return}function ui(){var b=0,d=0,e=0;b=~~(+h[321194]*10.0);d=0;do{e=c[1956400+(d*68|0)>>2]|0;if((e|0)==0){c[1407984+(d<<2)>>2]=256}else{c[1407984+(d<<2)>>2]=((a[((b|0)%(e|0)|0)+(1956404+(d*68|0))|0]|0)*22|0)-2134}d=d+1|0;}while((d|0)<64);return}function uj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0.0,f=0,h=0,i=0.0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0;e=+g[1034];f=(c[642381]|0)==0;h=f?d:0;i=(f?e<100.0?e:100.0:100.0)/100.0;d=e>=120.0|f^1;f=a+12|0;j=(d?0:-h|0)+(c[f>>2]|0)|0;k=a+8|0;a=~~(i*+(c[k>>2]|0));l=b+8|0;c[l>>2]=a;if((a|0)<96){e=96.0/+(c[k>>2]|0);c[l>>2]=96;m=e;n=96}else{m=i;n=a}a=n&-8;c[l>>2]=a;l=~~(m*+(c[f>>2]|0));n=b+12|0;c[n>>2]=l;o=c[f>>2]|0;do{if(d){if((l|0)<=(o|0)){p=l;break}c[n>>2]=o;p=o}else{f=o-h|0;if((l|0)<=(f|0)){p=l;break}c[n>>2]=f;p=f}}while(0);l=p&-2;c[n>>2]=l;c[b>>2]=((c[k>>2]|0)-a|0)/2|0;if(d){c[b+4>>2]=0;return}else{c[b+4>>2]=(j-l|0)/2|0;return}}function uk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a>>2]|0;if((d|0)==0){i=b;return}else{e=a;f=d}L6468:while(1){d=f;while(1){g=c[d+8>>2]|0;a=c[(c[g+136>>2]|0)+68>>2]|0;if(a>>>0<3){break}w1(103872,(h=i,i=i+16|0,c[h>>2]=109984,c[h+8>>2]=a,h)|0);i=h;h=c[e>>2]|0;if((h|0)==0){j=4879;break L6468}else{d=h}}h=g+160|0;a=c[2750]|0;if((c[h>>2]|0)!=(a|0)&(c[489098]|0)<1024){c[h>>2]=a;a=c[489098]|0;c[489098]=a+1;h=1415664+(a*264|0)|0;a=g;yJ(h|0,a|0,264)|0}a=d+4|0;h=c[a>>2]|0;if((h|0)==0){j=4878;break}else{e=a;f=h}}if((j|0)==4878){i=b;return}else if((j|0)==4879){i=b;return}}function ul(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,i=0,j=0,k=0.0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[d>>2]|0)<0){return}e=a+4|0;f=a+8|0;h=a+12|0;i=a+16|0;j=d;do{d=c[j+40>>2]|0;k=+g[e>>2]*+g[d>>2]+ +g[f>>2]*+g[d+4>>2]+ +g[h>>2]*+g[d+8>>2]- +g[d+12>>2];l=+g[i>>2];do{if(k>l){m=j+44|0}else{if(k<-0.0-l){m=j+48|0;break}d=j+56|0;if((c[d>>2]|0)!=0){n=(c[(c[644470]|0)+180>>2]|0)+((c[j+52>>2]|0)*92|0)|0;o=0;while(1){p=n+76|0;q=n+80|0;if((c[p>>2]|0)==(c[157500]|0)){r=c[q>>2]|0}else{c[q>>2]=0;c[p>>2]=c[157500];r=0}c[n+80>>2]=r|b;p=o+1|0;if(p>>>0<(c[d>>2]|0)>>>0){n=n+92|0;o=p}else{break}}}ul(a,b,c[j+44>>2]|0);m=j+48|0}}while(0);j=c[m>>2]|0;}while((c[j>>2]|0)>=0);return}function um(){var a=0,b=0,d=0;c[157500]=(c[2750]|0)+1;a=0;b=2566960;while(1){do{if(+g[b+20>>2]>=+h[321194]){if(+g[b+16>>2]==0.0){break}ul(b,1<<a,c[(c[644470]|0)+164>>2]|0)}}while(0);d=a+1|0;if((d|0)>=32){break}a=d;b=b+36|0}return}function un(e,f,h){e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;j=i;i=i+16|0;k=j|0;if((c[e>>2]|0)<0){l=-1;i=j;return l|0}m=c[e+40>>2]|0;n=a[m+16|0]|0;o=n&255;if((n&255)<3){p=+g[m+12>>2];q=+g[f+(o<<2)>>2]-p;r=+g[h+(o<<2)>>2]-p}else{p=+g[m>>2];s=+g[m+4>>2];t=+g[m+8>>2];u=+g[m+12>>2];q=+g[f>>2]*p+ +g[f+4>>2]*s+ +g[f+8>>2]*t-u;r=p*+g[h>>2]+s*+g[h+4>>2]+t*+g[h+8>>2]-u}m=q<0.0;o=m&1;if(!(r<0.0^m)){l=un(c[e+44+(o<<2)>>2]|0,f,h)|0;i=j;return l|0}u=q/(q-r);r=+g[f>>2];q=r+u*(+g[h>>2]-r);m=k|0;g[m>>2]=q;r=+g[f+4>>2];t=r+u*(+g[h+4>>2]-r);g[k+4>>2]=t;r=+g[f+8>>2];s=r+u*(+g[h+8>>2]-r);g[k+8>>2]=s;k=un(c[e+44+(o<<2)>>2]|0,f,m)|0;f=(k|0)>-1;if(f){l=f?k:-1;i=j;return l|0}k=c[e+56>>2]|0;L6527:do{if((k|0)!=0){f=(c[(c[644470]|0)+180>>2]|0)+((c[e+52>>2]|0)*92|0)|0;n=0;L6529:while(1){do{if((c[f+36>>2]&32|0)==0){v=c[f+72>>2]|0;w=~~(+g[v+12>>2]+(q*+g[v>>2]+t*+g[v+4>>2]+s*+g[v+8>>2]));x=~~(+g[v+28>>2]+(q*+g[v+16>>2]+t*+g[v+20>>2]+s*+g[v+24>>2]));v=b[f+64>>1]|0;if((w|0)<(v|0)){break}y=b[f+66>>1]|0;if((x|0)<(y|0)){break}z=w-v|0;A=x-y|0;B=b[f+68>>1]|0;if((z|0)>(B|0)){break}C=b[f+70>>1]|0;if((A|0)<=(C|0)){break L6529}}}while(0);y=n+1|0;if(y>>>0<k>>>0){f=f+92|0;n=y}else{break L6527}}n=c[f+88>>2]|0;if((n|0)==0){l=0;i=j;return l|0}y=(B>>4)+1|0;x=(ab(y,A>>4)|0)+(z>>4)|0;v=a[f+84|0]|0;do{if(v<<24>>24==-1){D=0}else{w=ab(d[n+x|0]|0,c[1407984+((v&255)<<2)>>2]|0)|0;E=ab((C>>4)+1|0,y)|0;F=x+E|0;G=a[f+85|0]|0;if(G<<24>>24==-1){D=w;break}H=(ab(d[n+F|0]|0,c[1407984+((G&255)<<2)>>2]|0)|0)+w|0;w=F+E|0;F=a[f+86|0]|0;if(F<<24>>24==-1){D=H;break}G=(ab(d[n+w|0]|0,c[1407984+((F&255)<<2)>>2]|0)|0)+H|0;H=a[f+87|0]|0;if(H<<24>>24==-1){D=G;break}D=(ab(d[n+(w+E)|0]|0,c[1407984+((H&255)<<2)>>2]|0)|0)+G|0}}while(0);l=D>>8;i=j;return l|0}}while(0);l=un(c[e+44+((o^1)<<2)>>2]|0,m,h)|0;i=j;return l|0}function uo(a){a=a|0;var b=0,d=0,e=0,f=0,h=0;b=i;i=i+16|0;d=b|0;e=c[644470]|0;if((c[e+380>>2]|0)==0){f=255;i=b;return f|0}h=d|0;g[h>>2]=+g[a>>2];g[d+4>>2]=+g[a+4>>2];g[d+8>>2]=+g[a+8>>2]+-8194.0;d=un(c[e+164>>2]|0,a,h)|0;h=(d|0)==-1?0:d;d=c[157360]|0;f=(h|0)<(d|0)?d:h;i=b;return f|0}function up(){var b=0,d=0,e=0,f=0,g=0,h=0;b=x1(400,90608)|0;c[157438]=b;c[b+20>>2]=16;c[(c[157438]|0)+16>>2]=16;c[(c[157438]|0)+44>>2]=60;b=c[157438]|0;c[b+48>>2]=(c[b+44>>2]|0)+256;b=c[157438]|0;c[b+52>>2]=(c[b+48>>2]|0)+64;b=c[157438]|0;c[b+56>>2]=(c[b+52>>2]|0)+16;b=c[157438]|0;d=0;e=b+(c[b+44>>2]|0)|0;while(1){b=(d|0)<8;f=0;g=e;while(1){a[g]=(b^(f|0)<8^1)<<31>>31;h=f+1|0;if((h|0)<16){f=h;g=g+1|0}else{break}}g=d+1|0;if((g|0)<16){d=g;e=e+16|0}else{break}}e=c[157438]|0;d=0;g=e+(c[e+48>>2]|0)|0;while(1){e=(d|0)<4;f=0;b=g;while(1){a[b]=(e^(f|0)<4^1)<<31>>31;h=f+1|0;if((h|0)<8){f=h;b=b+1|0}else{break}}b=d+1|0;if((b|0)<8){d=b;g=g+8|0}else{break}}g=c[157438]|0;d=0;b=g+(c[g+52>>2]|0)|0;while(1){g=(d|0)<2;f=0;e=b;while(1){a[e]=(g^(f|0)<2^1)<<31>>31;h=f+1|0;if((h|0)<4){f=h;e=e+1|0}else{break}}e=d+1|0;if((e|0)<4){d=e;b=b+4|0}else{break}}b=c[157438]|0;d=0;e=b+(c[b+56>>2]|0)|0;while(1){b=(d|0)<1;f=0;g=e;while(1){a[g]=(b^(f|0)<1^1)<<31>>31;h=f+1|0;if((h|0)<2){f=h;g=g+1|0}else{break}}g=d+1|0;if((g|0)<2){d=g;e=e+2|0}else{break}}return}function uq(){var b=0,d=0.0;b=0;do{d=+U(+(+(b|0)*3.14159*2.0*.0078125));c[619392+(b<<2)>>2]=~~(d*8.0*65536.0+524288.0);c[1112712+(b<<2)>>2]=~~(d*3.0+3.0);b=b+1|0;}while((b|0)<256);oE(88784,348);oE(87024,296);pb(11120);pb(10224);pb(10888);pb(11288);pb(10072);pb(11232);pb(11064);pb(11176);pb(13288);pb(10424);pb(10480);pb(10832);pb(10776);pb(10664);pb(10720);pb(10944);pb(10160);pb(13472);pb(11008);pb(10296);pb(10544);pb(10352);pb(10600);pb(13360);pb(13416);pa(85088,3.0e3);pa(82648,1500.0);a[117384]=1;a[117413]=1;a[117468]=0;a[117440]=0;a[117412]=0;a[117469]=0;a[117441]=0;a[117385]=0;g[157350]=.5;g[157351]=.5;uA();pk();return}function ur(){var b=0,d=0,e=0;yG(628760,0,264);b=c[644470]|0;c[157224]=b;if((c[b+136>>2]|0)>0){d=0;e=b;do{c[(c[e+140>>2]|0)+(d<<6)+44>>2]=0;d=d+1|0;e=c[644470]|0;}while((d|0)<(c[e+136>>2]|0))}c[157260]=0;uw();e=~~+g[2640];d=(e|0)>1500;b=d?e:1500;c[157506]=b;if(d){d=x1(b<<6,80656)|0;b=d;c[139456]=b;c[139458]=b+(c[157506]<<6);a[10216]=0;c[139454]=d-64;sa()}else{a[10216]=1}c[157444]=0;c[157442]=0;d=~~+g[2654];c[157436]=(d|0)<3e3?3e3:d;c[157496]=0;c[157262]=0;return}function us(b,d,e){b=b|0;d=d|0;e=+e;var f=0.0,h=0.0,i=0.0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0;c[157262]=1;uj(b,629296,d);f=+V(+(+g[157358]/360.0*3.141592653589793))*2.0;g[157349]=f;d=c[157324]|0;h=+(d|0);g[157339]=h;g[157341]=h+-.5;c[157343]=(d<<20|524288)-1;b=c[157325]|0;i=+(b|0);g[157340]=i;g[157342]=i+-.5;j=c[157326]|0;k=j+d|0;c[157334]=k;c[157344]=(k<<20|524288)-1;l=+(k|0);g[157347]=l;g[157345]=l+-.5;g[157338]=l+-.99;k=c[157327]|0;m=k+b|0;c[157335]=m;l=+(m|0);g[157348]=l;g[157346]=l+-.5;l=+g[3336];m=~~(h*l);c[157329]=m;n=~~(i*l);c[157330]=n;i=+(j|0);o=~~(i*l);c[157331]=o;h=+(k|0);k=~~(h*l);c[157332]=k;c[157336]=o+m;c[157337]=k+n;g[3702]=e;p=+g[157350];g[22]=p;q=+g[157351];g[12]=q;r=f/(i*e/h);g[72]=r;s=+(d|0)+i*.5+-.5;g[20]=s;g[6948]=l*s;s=+(b|0)+h*.5+-.5;g[10]=s;g[6944]=l*s;s=i/f;g[18]=s;g[6946]=s*l;g[16]=1.0/s;i=s*e;g[8]=i;g[6942]=i*l;g[6]=1.0/i;i=+(j-6|0)/f;g[14]=i;g[4]=i*e;g[155128]=-1.0/(p*f);g[155129]=0.0;g[155130]=1.0;a[620528]=5;g[155133]=1.0/((1.0-p)*f);g[155134]=0.0;g[155135]=1.0;a[620548]=5;g[155138]=0.0;g[155139]=-1.0/(q*r);g[155140]=1.0;a[620568]=5;g[155143]=0.0;g[155144]=1.0/((1.0-q)*r);g[155145]=1.0;a[620588]=5;+q1(620512);+q1(620532);+q1(620552);+q1(620572);r=+R(+(+(ab(c[157327]|0,c[157326]|0)|0)/48640.0));q=r*(2.0/+g[157349]);g[3338]=+g[3344]*q;g[2572]=+g[3358]*q;pn();return}function ut(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0.0,R=0.0,S=0,T=0,U=0,V=0,W=0.0,X=0.0,Y=0.0,Z=0.0,_=0,$=0,aa=0,ab=0,ac=0.0,ad=0.0,ae=0.0,af=0,ag=0,ah=0,ai=0.0,aj=0.0,ak=0.0,al=0.0,am=0.0,an=0,ao=0,ap=0,aq=0,ar=0;b=i;i=i+268168|0;d=b|0;e=b+16|0;f=b+32|0;j=b+48|0;k=b+64|0;l=b+108104|0;if(((x_()|0)&3|0)!=0){w1(78880,(m=i,i=i+1|0,i=i+7>>3<<3,c[m>>2]=0,m)|0);i=m}c[157256]=b+204168;uz();n=c[157260]|0;if((n|0)!=(c[157428]|0)&+g[2670]==0.0){c[157258]=(c[157258]|0)+1;c[157428]=n;o=1}else{o=0}p=rC(c[644470]|0,n)|0;n=p|0;q=c[n>>2]|0;if((q|0)>0){r=c[p+4>>2]|0;if((r|0)==0){s=0;t=4973}else{u=0;v=r;t=4975}}else{s=0;t=4973}L6603:do{if((t|0)==4973){while(1){t=0;r=s+32|0;if((r|0)>=(q|0)){break L6603}w=c[p+4+(r>>5<<2)>>2]|0;if((w|0)==0){s=r;t=4973}else{u=r;v=w;t=4975;break}}}}while(0);L6607:do{if((t|0)==4975){s=(v|0)==0?-1:yS(v|0)|0;w=s+u|0;r=v&~(1<<s);if((w|0)>=(q|0)){break}if(o){x=r;y=w}else{s=r;r=w;while(1){w=(c[(c[644470]|0)+140>>2]|0)+(r+1<<6)+44|0;if((c[w>>2]|0)!=0){uk(w)}do{if((s|0)==0){w=r+32|0;z=w&-32;A=c[n>>2]|0;if((z|0)<(A|0)){B=c[p+4+(w>>5<<2)>>2]|0;if((B|0)==0){C=z}else{D=z;E=B;F=A;break}}else{C=z}while(1){z=C+32|0;if((z|0)>=(A|0)){break L6607}B=c[p+4+(z>>5<<2)>>2]|0;if((B|0)==0){C=z}else{D=z;E=B;F=A;break}}}else{D=r;E=s;F=c[n>>2]|0}}while(0);A=(E|0)==0?-1:yS(E|0)|0;B=A+(D&-32)|0;if((B|0)>=(F|0)){break L6607}s=E&~(1<<A);r=B}}while(1){r=y+1|0;s=c[(c[644470]|0)+140>>2]|0;B=s+(r<<6)|0;A=s+(r<<6)+44|0;if((c[A>>2]|0)!=0){uk(A)}A=s+(r<<6)+52|0;do{if((c[A>>2]|0)>0){z=c[s+(r<<6)+48>>2]|0;c[c[z>>2]>>2]=c[157258];if((c[A>>2]|0)>1){G=z;H=1}else{break}do{G=G+4|0;H=H+1|0;c[c[G>>2]>>2]=c[157258];}while((H|0)<(c[A>>2]|0))}}while(0);A=B;do{r=A+4|0;s=c[157258]|0;if((c[r>>2]|0)==(s|0)){break}c[r>>2]=s;A=c[A+36>>2]|0;}while((A|0)!=0);do{if((x|0)==0){A=y+32|0;B=A&-32;s=c[n>>2]|0;if((B|0)<(s|0)){r=c[p+4+(A>>5<<2)>>2]|0;if((r|0)==0){I=B}else{J=B;K=r;L=s;break}}else{I=B}while(1){B=I+32|0;if((B|0)>=(s|0)){break L6607}r=c[p+4+(B>>5<<2)>>2]|0;if((r|0)==0){I=B}else{J=B;K=r;L=s;break}}}else{J=y;K=x;L=c[n>>2]|0}}while(0);s=(K|0)==0?-1:yS(K|0)|0;r=s+(J&-32)|0;if((r|0)>=(L|0)){break L6607}x=K&~(1<<s);y=r}}}while(0);y=c[157224]|0;K=c[y+164>>2]|0;c[K+8>>2]=15;x=y+180|0;y=K;L6651:while(1){L6653:do{if((c[y+4>>2]|0)==(c[157258]|0)){K=y+8|0;L=c[K>>2]|0;L6655:do{if((L|0)!=0){J=y+12|0;n=y+24|0;do{if((L&1|0)==0){M=L;t=5011}else{I=rb(J,n,117360)|0;if((I|0)==2){break}else if((I|0)==1){I=c[K>>2]&-2;c[K>>2]=I;M=I;t=5011;break}else{M=c[K>>2]|0;t=5011;break}}}while(0);L6662:do{if((t|0)==5011){t=0;do{if((M&2|0)==0){N=M}else{I=rb(J,n,117388)|0;if((I|0)==1){p=c[K>>2]&-3;c[K>>2]=p;N=p;break}else if((I|0)==2){break L6662}else{N=c[K>>2]|0;break}}}while(0);do{if((N&4|0)==0){O=N}else{I=rb(J,n,117416)|0;if((I|0)==1){p=c[K>>2]&-5;c[K>>2]=p;O=p;break}else if((I|0)==2){break L6662}else{O=c[K>>2]|0;break}}}while(0);if((O&8|0)==0){break L6655}I=rb(J,n,117444)|0;if((I|0)==2){break}else if((I|0)!=1){break L6655}c[K>>2]=c[K>>2]&-9;break L6655}}while(0);c[K>>2]=16;P=y;t=5035;break L6653}}while(0);if((c[y>>2]|0)<0){P=y;t=5035;break}L=y+56|0;L6681:do{if((c[L>>2]|0)!=0){n=1;J=(c[x>>2]|0)+((c[y+52>>2]|0)*92|0)|0;while(1){I=J+4|0;c[I>>2]=c[K>>2];p=J+8|0;H=J+20|0;do{if((c[K>>2]&1|0)==0){t=5019}else{G=rb(p,H,117360)|0;if((G|0)==2){t=5017;break}else if((G|0)!=1){t=5019;break}c[I>>2]=c[I>>2]&-2;t=5019}}while(0);L6688:do{if((t|0)==5019){t=0;do{if((c[K>>2]&2|0)!=0){G=rb(p,H,117388)|0;if((G|0)==2){t=5017;break L6688}else if((G|0)!=1){break}c[I>>2]=c[I>>2]&-3}}while(0);do{if((c[K>>2]&4|0)!=0){G=rb(p,H,117416)|0;if((G|0)==2){t=5017;break L6688}else if((G|0)!=1){break}c[I>>2]=c[I>>2]&-5}}while(0);do{if((c[K>>2]&8|0)!=0){G=rb(p,H,117444)|0;if((G|0)==2){t=5017;break L6688}else if((G|0)!=1){break}c[I>>2]=c[I>>2]&-9}}while(0);G=c[J+32>>2]|0;E=a[G+16|0]|0;if((E&255)<3){Q=+g[629408+((E&255)<<2)>>2]- +g[G+12>>2]}else{Q=+g[157352]*+g[G>>2]+ +g[157353]*+g[G+4>>2]+ +g[157354]*+g[G+8>>2]- +g[G+12>>2]}R=Q;if((c[J+36>>2]&2|0)==0){if(R>=.01){break}c[I>>2]=16;break}else{if(R<=-.01){break}c[I>>2]=16;break}}}while(0);if((t|0)==5017){t=0;c[I>>2]=16}if(n>>>0>=(c[L>>2]|0)>>>0){break L6681}n=n+1|0;J=J+92|0}}}while(0);L=y+44|0;J=c[L>>2]|0;if((c[J>>2]|0)==-2){S=y;t=5033;break}c[J+8>>2]=c[K>>2];T=L;t=5032}else{P=y;t=5035}}while(0);L6717:while(1){if((t|0)==5035){t=0;L=c[P+36>>2]|0;if((L|0)==0){break L6651}if((P|0)==(c[L+44>>2]|0)){S=L;t=5033;continue}else{U=L;V=P}while(1){if((V|0)!=(c[U+48>>2]|0)){S=U;t=5033;continue L6717}L=c[U+36>>2]|0;if((L|0)==0){break L6651}else{V=U;U=L}}}else if((t|0)==5032){t=0;y=c[T>>2]|0;continue L6651}else if((t|0)==5033){t=0;K=S+48|0;L=c[K>>2]|0;if((c[L>>2]|0)==-2){P=S;t=5035;continue}c[L+8>>2]=c[S+8>>2];T=K;t=5032;continue}}}wH();if(!((c[157224]|0)!=0&(c[644470]|0)!=0)){w1(74952,(m=i,i=i+8|0,c[m>>2]=110024,m)|0);i=m}c[157480]=k+31&-32;if(a[10216]|0){k=l+31&-32;c[139458]=k+(c[157506]<<6);c[139454]=k-64;sa()}ua();t3();k=f;if(+g[2812]!=0.0){Q=+g[169390];R=+g[169391];W=+g[169392];c[278434]=1;c[157500]=c[2750];if((c[489098]|0)>0){l=f|0;m=f+4|0;T=f+8|0;S=j|0;P=j+4|0;y=j+8|0;U=0;do{V=1415664+(U*264|0)|0;x=c[1415800+(U*264|0)>>2]|0;L6740:do{if((c[x+68>>2]|0)==0){O=1415776+(U*264|0)|0;X=+g[O>>2];g[l>>2]=X+ +g[x+84>>2];N=1415780+(U*264|0)|0;Y=+g[N>>2];g[m>>2]=Y+ +g[x+88>>2];M=1415784+(U*264|0)|0;Z=+g[M>>2];g[T>>2]=Z+ +g[x+92>>2];g[S>>2]=X+ +g[x+96>>2];g[P>>2]=Y+ +g[x+100>>2];g[y>>2]=Z+ +g[x+104>>2];do{if(+g[1415788+(U*264|0)>>2]!=0.0){t=5069}else{if(+g[1415792+(U*264|0)>>2]!=0.0){t=5069;break}if(+g[1415796+(U*264|0)>>2]!=0.0){t=5069;break}K=rb(l,S,117360)|0;if((K|0)==3){_=1}else if((K|0)==2){break L6740}else{_=0}K=rb(l,S,117388)|0;if((K|0)==3){$=_|2}else if((K|0)==2){break L6740}else{$=_}K=rb(l,S,117416)|0;if((K|0)==3){aa=$|4}else if((K|0)==2){break L6740}else{aa=$}K=rb(l,S,117444)|0;if((K|0)==2){break L6740}else if((K|0)!=3){ab=aa;break}ab=aa|8}}while(0);do{if((t|0)==5069){t=0;ac=+g[x+108>>2];ad=-0.0-ac;ae=X*+g[29340]+Y*+g[29341]+Z*+g[29342]- +g[29343];if(ae<=ad){break L6740}K=ae<=ac|0;ae=X*+g[29347]+Y*+g[29348]+Z*+g[29349]- +g[29350];if(ae<=ad){break L6740}L=ae>ac?K:K|2;ae=X*+g[29354]+Y*+g[29355]+Z*+g[29356]- +g[29357];if(ae<=ad){break L6740}K=ae>ac?L:L|4;ae=X*+g[29361]+Y*+g[29362]+Z*+g[29363]- +g[29364];if(ae<=ad){break L6740}if(ae>ac){ab=K;break}ab=K|8}}while(0);if((ab|0)==16){break}Z=+g[O>>2];g[157466]=Z;Y=+g[N>>2];g[157467]=Y;X=+g[M>>2];g[157468]=X;g[169390]=+g[157424]-Z;g[169391]=+g[157425]-Y;g[169392]=+g[157426]-X;c[157400]=c[x+148>>2];t$(V);K=x+112|0;if((c[K>>2]|0)!=0){L=x+164|0;J=x+216|0;n=0;do{H=2566960+(n*36|0)|0;do{if(+g[2566980+(n*36|0)>>2]>=+h[321194]){if(+g[2566976+(n*36|0)>>2]==0.0){break}ul(H,1<<n,(c[L>>2]|0)+((c[J>>2]|0)*60|0)|0)}}while(0);n=n+1|0;}while((n|0)<32)}c[157396]=0;g[157472]=+g[l>>2];g[157473]=+g[m>>2];g[157474]=+g[T>>2];g[157476]=+g[S>>2];g[157477]=+g[P>>2];g[157478]=+g[y>>2];ug(c[(c[644470]|0)+164>>2]|0);n=x+116|0;if((c[n>>2]|0)>0){J=(ab&1|0)==0;L=(c[x+180>>2]|0)+((c[K>>2]|0)*92|0)|0;M=0;while(1){N=L+4|0;c[N>>2]=ab;O=L+8|0;H=L+20|0;do{if(J){af=ab;t=5096}else{p=rb(O,H,117360)|0;if((p|0)==2){t=5094;break}else if((p|0)==1){p=c[N>>2]&-2;c[N>>2]=p;af=p;t=5096;break}else{af=c[N>>2]|0;t=5096;break}}}while(0);L6783:do{if((t|0)==5096){t=0;do{if((af&2|0)==0){ag=af}else{p=rb(O,H,117388)|0;if((p|0)==2){t=5094;break L6783}else if((p|0)==1){p=c[N>>2]&-3;c[N>>2]=p;ag=p;break}else{ag=c[N>>2]|0;break}}}while(0);do{if((ag&4|0)==0){ah=ag}else{I=rb(O,H,117416)|0;if((I|0)==2){t=5094;break L6783}else if((I|0)==1){I=c[N>>2]&-5;c[N>>2]=I;ah=I;break}else{ah=c[N>>2]|0;break}}}while(0);do{if((ah&8|0)!=0){I=rb(O,H,117444)|0;if((I|0)==2){t=5094;break L6783}else if((I|0)!=1){break}c[N>>2]=c[N>>2]&-9}}while(0);I=c[L+32>>2]|0;p=a[I+16|0]|0;if((p&255)<3){ai=+g[677560+((p&255)<<2)>>2]- +g[I+12>>2]}else{ai=+g[169390]*+g[I>>2]+ +g[169391]*+g[I+4>>2]+ +g[169392]*+g[I+8>>2]- +g[I+12>>2]}X=ai;if((c[L+36>>2]&2|0)==0){if(X>=.01){break}c[N>>2]=16;break}else{if(X<=-.01){break}c[N>>2]=16;break}}}while(0);if((t|0)==5094){t=0;c[N>>2]=16}H=M+1|0;if((H|0)<(c[n>>2]|0)){L=L+92|0;M=H}else{break}}}M=c[157396]|0;if((M|0)!=0){L=1415844+(U*264|0)|0;c[L>>2]=M;if((c[M>>2]|0)>-1){t0(V,x)}else{t2(V,x,ab)}c[L>>2]=0}g[29332]=+g[660142];g[29333]=+g[660143];g[29334]=+g[660144];g[29324]=+g[660134];g[29325]=+g[660135];g[29326]=+g[660136];g[29328]=+g[660138];g[29329]=+g[660139];g[29330]=+g[660140];g[169390]=Q;g[169391]=R;g[169392]=W;uy()}}while(0);U=U+1|0;}while((U|0)<(c[489098]|0))}c[278434]=0}ue();c[k>>2]=c[28074];c[k+4>>2]=c[28075];c[k+8>>2]=c[28076];if(+g[2812]!=0.0&(c[489098]|0)>0){U=e|0;ab=e+4|0;t=e+8|0;e=d|0;ah=d+4|0;ag=f|0;af=d+8|0;y=j|0;P=j+4|0;S=j+8|0;T=0;do{m=1415664+(T*264|0)|0;l=c[(c[1415800+(T*264|0)>>2]|0)+68>>2]|0;do{if((l|0)==1){W=+g[1415776+(T*264|0)>>2];g[157466]=W;R=+g[1415780+(T*264|0)>>2];g[157467]=R;Q=+g[1415784+(T*264|0)>>2];g[157468]=Q;g[169390]=+g[157424]-W;g[169391]=+g[157425]-R;g[169392]=+g[157426]-Q;uS(m)}else if((l|0)==2){if(+g[2698]!=0.0){Q=+g[1415892+(T*264|0)>>2];R=(+h[321194]-Q)/(Q- +g[1415888+(T*264|0)>>2]);do{if(R>=1.0|R>0.0){if(R>=1.0){aj=1.0;break}aj=R}else{aj=0.0}}while(0);aa=1415864+(T*264|0)|0;g[U>>2]=+g[1415876+(T*264|0)>>2]- +g[aa>>2];g[ab>>2]=+g[1415880+(T*264|0)>>2]- +g[1415868+(T*264|0)>>2];g[t>>2]=+g[1415884+(T*264|0)>>2]- +g[1415872+(T*264|0)>>2];q7(aa,aj,U,629864);ak=+g[157466];al=+g[157467];am=+g[157468]}else{R=+g[1415776+(T*264|0)>>2];g[157466]=R;Q=+g[1415780+(T*264|0)>>2];g[157467]=Q;W=+g[1415784+(T*264|0)>>2];g[157468]=W;ak=R;al=Q;am=W}g[169390]=+g[157424]-ak;g[169391]=+g[157425]-al;g[169392]=+g[157426]-am;if((tV(m)|0)==0){break}aa=1415776+(T*264|0)|0;$=uo(aa)|0;c[e>>2]=$;c[ah>>2]=$;c[af>>2]=ag;$=1415780+(T*264|0)|0;_=1415784+(T*264|0)|0;x=0;do{do{if(+g[2566980+(x*36|0)>>2]>=+h[321194]){g[y>>2]=+g[aa>>2]- +g[2566964+(x*36|0)>>2];g[P>>2]=+g[$>>2]- +g[2566968+(x*36|0)>>2];g[S>>2]=+g[_>>2]- +g[2566972+(x*36|0)>>2];W=+g[2566976+(x*36|0)>>2];Q=W- +rd(y);if(Q<=0.0){break}c[e>>2]=~~(Q+ +(c[e>>2]|0))}}while(0);x=x+1|0;}while((x|0)<32);x=c[e>>2]|0;if((x|0)>128){c[e>>2]=128;an=128}else{an=x}if(((c[ah>>2]|0)+an|0)>192){c[ah>>2]=192-an}tY(m,d)}}while(0);T=T+1|0;}while((T|0)<(c[489098]|0))}c[k>>2]=c[28074];c[k+4>>2]=c[28075];c[k+8>>2]=c[28076];do{if(!(+g[2770]==0.0|+g[5762]!=0.0)){if((c[642266]&524288|0)!=0|(c[642251]|0)<1|(c[644508]|0)==0){break}am=+g[644502];g[157466]=am;al=+g[644503];g[157467]=al;ak=+g[644504];g[157468]=ak;g[169390]=+g[157424]-am;g[169391]=+g[157425]-al;g[169392]=+g[157426]-ak;g[29336]=+g[29324];g[29337]=+g[29325];g[29338]=+g[29326];q8(117344);k=uo(2578008)|0;T=(k|0)<24?24:k;c[2532]=T;c[2533]=T;T=j|0;k=j+4|0;d=j+8|0;an=0;do{ak=+g[2566976+(an*36|0)>>2];do{if(ak!=0.0){if(+g[2566980+(an*36|0)>>2]<+h[321194]){break}g[T>>2]=+g[644502]- +g[2566964+(an*36|0)>>2];g[k>>2]=+g[644503]- +g[2566968+(an*36|0)>>2];g[d>>2]=+g[644504]- +g[2566972+(an*36|0)>>2];al=ak- +rd(T);if(al<=0.0){break}c[2532]=~~(al+ +(c[2532]|0))}}while(0);an=an+1|0;}while((an|0)<32);an=c[2532]|0;if((an|0)>128){c[2532]=128;ao=128}else{ao=an}if(((c[2533]|0)+ao|0)>192){c[2533]=192-ao}c[2534]=f;tY(2577896,10128)}}while(0);uP();if((c[157498]|0)==0){ap=c[157260]|0;aq=ap|0;ar=c[aq>>2]|0;xO(ar);wG();i=b;return}pw();ap=c[157260]|0;aq=ap|0;ar=c[aq>>2]|0;xO(ar);wG();i=b;return}function uu(a,b){a=a|0;b=b|0;var c=0,d=0;c=a+4|0;d=a+8|0;g[b>>2]=+g[a>>2]*+g[29328]+ +g[c>>2]*+g[29329]+ +g[d>>2]*+g[29330];g[b+4>>2]=+g[a>>2]*+g[29324]+ +g[c>>2]*+g[29325]+ +g[d>>2]*+g[29326];g[b+8>>2]=+g[a>>2]*+g[29332]+ +g[c>>2]*+g[29333]+ +g[d>>2]*+g[29334];return}function uv(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0.0,f=0.0,h=0;d=b-1|0;e=+g[a+(d<<2)>>2];f=c-e*+(~~(c/e)|0);b=0;while(1){if((b|0)>=(d|0)){h=5169;break}if(+g[a+(b<<2)>>2]>f){h=5170;break}else{b=b+1|0}}if((h|0)==5169){return b|0}else if((h|0)==5170){return b|0}return 0}function uw(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[158776]|0;c[350540]=a;c[664792]=0;b=c[157432]|0;if((b|0)>0){d=0;e=a;while(1){f=d+1|0;c[e+(d*44|0)+16>>2]=e+(f*44|0);g=c[157432]|0;h=c[158776]|0;if((f|0)<(g|0)){d=f;e=h}else{i=g;j=h;break}}}else{i=b;j=a}c[j+((i-1|0)*44|0)+16>>2]=0;return}function ux(){var a=0,b=0,d=0.0,e=0.0,f=0,j=0,k=0,l=0,m=0,n=0,o=0.0;a=i;i=i+24|0;b=a|0;d=+g[157356];e=+wZ();f=b|0;j=b+4|0;k=b+8|0;l=b+12|0;m=b+16|0;n=0;do{g[157356]=+(n|0)*.0078125*360.0;xd();ut();xe();c[f>>2]=c[157324];c[j>>2]=c[157325];c[k>>2]=c[157326];c[l>>2]=c[157327];c[m>>2]=0;xc(b);n=n+1|0;}while((n|0)<128);o=+wZ()-e;oW(94448,(n=i,i=i+16|0,h[n>>3]=o,h[n+8>>3]=128.0/o,n)|0);i=n;g[157356]=+(~~d|0);i=a;return}function uy(){var b=0,c=0.0,d=0.0,e=0.0,f=0.0,h=0.0,i=0.0,j=0;if(+g[2684]!=0.0){return}else{b=0}do{c=+g[620520+(b*20|0)>>2];d=-0.0- +g[620512+(b*20|0)>>2];e=+g[620516+(b*20|0)>>2];f=+g[29328]*d+e*+g[29324]+c*+g[29332];h=+g[29329]*d+e*+g[29325]+c*+g[29333];i=+g[29330]*d+e*+g[29326]+c*+g[29334];j=117360+(b*28|0)|0;g[j>>2]=f;g[117364+(b*28|0)>>2]=h;g[117368+(b*28|0)>>2]=i;g[117372+(b*28|0)>>2]=f*+g[169390]+h*+g[169391]+i*+g[169392];a[117377+(b*28|0)|0]=(qW(j)|0)&255;b=b+1|0;}while((b|0)<4);return}function uz(){var a=0,b=0,d=0,e=0.0,f=0.0,h=0.0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0.0;a=i;i=i+24|0;b=a|0;if((c[644468]|0)>1){o9(54680,50400);o9(46520,50400);o9(42272,50400);o9(38568,50400)}d=~~+g[3326];c[157360]=(d|0)<0?0:d;e=+g[2740];if(e!=+g[28078]){g[28078]=e;pE()}ui();c[2750]=(c[2750]|0)+1;e=+g[157352];g[169390]=e;f=+g[157353];g[169391]=f;h=+g[157354];g[169392]=h;g[157424]=e;g[157425]=f;g[157426]=h;rc(629420,117328,117312,117296);c[157428]=c[157260];d=rB(c[644470]|0,629696)|0;c[157260]=d;j=c[157498]|0;c[157496]=j;if(+g[2522]!=0.0){k=(c[d>>2]|0)<-2}else{k=0}d=k&1;c[157498]=d;if((d|0)!=(j|0)|(c[157262]|0)!=0){do{if(k){j=c[29381]|0;d=c[29390]|0;l=c[29382]|0;if(!((j|0)>(d|0)|(l|0)>(c[29391]|0))){c[b>>2]=0;c[b+4>>2]=0;c[b+8>>2]=j;c[b+12>>2]=l;us(b,c[155534]|0,+g[29383]);break}h=+(j|0);f=+(l|0);e=+(d|0);if(h>e){m=f*(e/h);n=e}else{m=f;n=h}e=+(c[29391]|0);if(m>e){o=e;p=n*(e/e)}else{o=m;p=n}c[b>>2]=0;c[b+4>>2]=0;c[b+8>>2]=~~p;c[b+12>>2]=~~o;us(b,~~(+(c[155534]|0)*(o/f)),+g[29383]*(o/p)*(h/f))}else{c[b>>2]=0;c[b+4>>2]=0;c[b+8>>2]=c[29381];c[b+12>>2]=c[29382];us(b,c[155534]|0,+g[29383])}}while(0);c[157262]=0}uy();g[660142]=+g[29332];g[660143]=+g[29333];g[660144]=+g[29334];g[660138]=+g[29328];g[660139]=+g[29329];g[660140]=+g[29330];g[660134]=+g[29324];g[660135]=+g[29325];g[660136]=+g[29326];g[660146]=+g[169390];g[660147]=+g[169391];g[660148]=+g[169392];uQ();c[157510]=0;c[651350]=0;c[157390]=0;c[157494]=0;c[157518]=0;c[157420]=0;c[157422]=0;pg();i=a;return}function uA(){var a=0,b=0,d=0;a=ob(93920)|0;do{if((a|0)==0){c[157432]=2048;b=2048}else{d=nE(c[(c[353048]|0)+(a+1<<2)>>2]|0)|0;c[157432]=d;if((d|0)>=512){b=d;break}c[157432]=512;b=512}}while(0);c[158776]=x1(b*44|0,103640)|0;return}function uB(a){a=a|0;var b=0,d=0,e=0,f=0.0,i=0.0,j=0.0,k=0,l=0,m=0.0,n=0.0,o=0;if(+g[660150]==0.0){b=0;do{g[2640600+(b<<2)>>2]=+((aQ()|0)&255|0)*.01;b=b+1|0;}while((b|0)<486)}b=a+112|0;d=a+116|0;e=a+120|0;a=0;while(1){f=+h[321194];i=f*+g[2640600+(a*12|0)>>2];j=f*+g[2640604+(a*12|0)>>2];f=+T(+j);k=c[350540]|0;if((k|0)==0){l=5212;break}m=+U(+j);j=+T(+i);n=f*+U(+i);o=k+16|0;c[350540]=c[o>>2];c[o>>2]=c[664792];c[664792]=k;g[k+36>>2]=+h[321194]+.01;g[k+12>>2]=111.0;c[k+40>>2]=4;g[k>>2]=+g[b>>2]+ +g[11344+(a*12|0)>>2]*64.0+f*j*+g[6754];g[k+4>>2]=+g[d>>2]+ +g[11348+(a*12|0)>>2]*64.0+n*+g[6754];g[k+8>>2]=+g[e>>2]+ +g[11352+(a*12|0)>>2]*64.0+ +g[6754]*(-0.0-m);k=a+1|0;if((k|0)<162){a=k}else{l=5211;break}}if((l|0)==5212){return}else if((l|0)==5211){return}}function uC(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;a=i;i=i+152|0;b=a|0;d=a+8|0;e=a+24|0;bR(e|0,128,83840,(f=i,i=i+8|0,c[f>>2]=184604,f)|0)|0;i=f;od(e,b)|0;if((c[b>>2]|0)==0){oW(70120,(f=i,i=i+8|0,c[f>>2]=e,f)|0);i=f;i=a;return}oW(60552,(f=i,i=i+8|0,c[f>>2]=e,f)|0);i=f;e=d|0;h=d+4|0;j=d+8|0;d=d_(c[b>>2]|0,54664,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=h,c[f+16>>2]=j,f)|0)|0;i=f;L6948:do{if((d|0)==3){k=0;while(1){l=k+1|0;m=c[350540]|0;if((m|0)==0){break}n=m+16|0;c[350540]=c[n>>2];c[n>>2]=c[664792];c[664792]=m;g[m+36>>2]=99999.0;g[m+12>>2]=+(k&15^15|0);c[m+40>>2]=0;g[m+20>>2]=+g[29396];g[m+24>>2]=+g[29397];g[m+28>>2]=+g[29398];g[m>>2]=+g[e>>2];g[m+4>>2]=+g[h>>2];g[m+8>>2]=+g[j>>2];m=d_(c[b>>2]|0,54664,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=h,c[f+16>>2]=j,f)|0)|0;i=f;if((m|0)==3){k=l}else{o=l;break L6948}}oW(50368,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;o=l}else{o=0}}while(0);aS(c[b>>2]|0)|0;oW(46504,(f=i,i=i+8|0,c[f>>2]=o,f)|0);i=f;i=a;return}function uD(){var a=0,b=0,c=0,d=0;a=i;i=i+32|0;b=a|0;c=a+16|0;d=b|0;g[d>>2]=+nQ();g[b+4>>2]=+nQ();g[b+8>>2]=+nQ();b=c|0;g[b>>2]=+(nK()|0)*.0625;g[c+4>>2]=+(nK()|0)*.0625;g[c+8>>2]=+(nK()|0)*.0625;c=nL()|0;uE(d,b,nL()|0,(c|0)==255?1024:c);i=a;return}function uE(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,i=0,j=0,k=0,l=0,m=0.0;f=c[350540]|0;if(!((e|0)>0&(f|0)!=0)){return}i=d&-8;if((e|0)==1024){j=0;k=f}else{d=1;l=f;while(1){f=l+16|0;c[350540]=c[f>>2];c[f>>2]=c[664792];c[664792]=l;m=+h[321194];g[l+36>>2]=m+ +((aQ()|0)%5|0|0)*.1;g[l+12>>2]=+((aQ()|0)&7|i|0);c[l+40>>2]=2;m=+g[a>>2];g[l>>2]=m+ +(((aQ()|0)&15)-8|0);g[l+20>>2]=+g[b>>2]*15.0;m=+g[a+4>>2];g[l+4>>2]=m+ +(((aQ()|0)&15)-8|0);g[l+24>>2]=+g[b+4>>2]*15.0;m=+g[a+8>>2];g[l+8>>2]=m+ +(((aQ()|0)&15)-8|0);g[l+28>>2]=+g[b+8>>2]*15.0;f=c[350540]|0;if(!((d|0)<(e|0)&(f|0)!=0)){break}d=d+1|0;l=f}return}do{l=k+16|0;c[350540]=c[l>>2];c[l>>2]=c[664792];c[664792]=k;g[k+36>>2]=+h[321194]+5.0;g[k+12>>2]=+(c[2510]|0);g[k+32>>2]=+((aQ()|0)&3|0);l=k+40|0;if((j&1|0)==0){c[l>>2]=5;m=+g[a>>2];g[k>>2]=m+ +(((aQ()|0)%32|0)-16|0);g[k+20>>2]=+(((aQ()|0)%512|0)-256|0);m=+g[a+4>>2];g[k+4>>2]=m+ +(((aQ()|0)%32|0)-16|0);g[k+24>>2]=+(((aQ()|0)%512|0)-256|0);m=+g[a+8>>2];g[k+8>>2]=m+ +(((aQ()|0)%32|0)-16|0);g[k+28>>2]=+(((aQ()|0)%512|0)-256|0)}else{c[l>>2]=4;m=+g[a>>2];g[k>>2]=m+ +(((aQ()|0)%32|0)-16|0);g[k+20>>2]=+(((aQ()|0)%512|0)-256|0);m=+g[a+4>>2];g[k+4>>2]=m+ +(((aQ()|0)%32|0)-16|0);g[k+24>>2]=+(((aQ()|0)%512|0)-256|0);m=+g[a+8>>2];g[k+8>>2]=m+ +(((aQ()|0)%32|0)-16|0);g[k+28>>2]=+(((aQ()|0)%512|0)-256|0)}j=j+1|0;k=c[350540]|0;}while((j|0)<1024&(k|0)!=0);return}function uF(a){a=a|0;var b=0,d=0,e=0,f=0.0;b=c[350540]|0;if((b|0)==0){return}else{d=0;e=b}do{b=e+16|0;c[350540]=c[b>>2];c[b>>2]=c[664792];c[664792]=e;g[e+36>>2]=+h[321194]+5.0;g[e+12>>2]=+(c[2510]|0);g[e+32>>2]=+((aQ()|0)&3|0);b=e+40|0;if((d&1|0)==0){c[b>>2]=5;f=+g[a>>2];g[e>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+20>>2]=+(((aQ()|0)%512|0)-256|0);f=+g[a+4>>2];g[e+4>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+24>>2]=+(((aQ()|0)%512|0)-256|0);f=+g[a+8>>2];g[e+8>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+28>>2]=+(((aQ()|0)%512|0)-256|0)}else{c[b>>2]=4;f=+g[a>>2];g[e>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+20>>2]=+(((aQ()|0)%512|0)-256|0);f=+g[a+4>>2];g[e+4>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+24>>2]=+(((aQ()|0)%512|0)-256|0);f=+g[a+8>>2];g[e+8>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+28>>2]=+(((aQ()|0)%512|0)-256|0)}d=d+1|0;e=c[350540]|0;}while((d|0)<1024&(e|0)!=0);return}function uG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,i=0,j=0.0;e=c[350540]|0;if((e|0)==0){return}else{f=0;i=e}do{e=i+16|0;c[350540]=c[e>>2];c[e>>2]=c[664792];c[664792]=i;g[i+36>>2]=+h[321194]+.3;g[i+12>>2]=+(((f|0)%(d|0)|0)+b|0);c[i+40>>2]=6;j=+g[a>>2];g[i>>2]=j+ +(((aQ()|0)%32|0)-16|0);g[i+20>>2]=+(((aQ()|0)%512|0)-256|0);j=+g[a+4>>2];g[i+4>>2]=j+ +(((aQ()|0)%32|0)-16|0);g[i+24>>2]=+(((aQ()|0)%512|0)-256|0);j=+g[a+8>>2];g[i+8>>2]=j+ +(((aQ()|0)%32|0)-16|0);g[i+28>>2]=+(((aQ()|0)%512|0)-256|0);f=f+1|0;i=c[350540]|0;}while((f|0)<512&(i|0)!=0);return}function uH(a){a=a|0;var b=0,d=0,e=0,f=0.0;b=c[350540]|0;if((b|0)==0){return}else{d=0;e=b}do{b=e+16|0;c[350540]=c[b>>2];c[b>>2]=c[664792];c[664792]=e;f=+h[321194]+1.0;g[e+36>>2]=f+ +((aQ()|0)&8|0)*.05;b=e+40|0;if((d&1|0)==0){c[b>>2]=7;g[e+12>>2]=+(((aQ()|0)%6|0)+150|0);f=+g[a>>2];g[e>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+20>>2]=+(((aQ()|0)%512|0)-256|0);f=+g[a+4>>2];g[e+4>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+24>>2]=+(((aQ()|0)%512|0)-256|0);f=+g[a+8>>2];g[e+8>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+28>>2]=+(((aQ()|0)%512|0)-256|0)}else{c[b>>2]=6;g[e+12>>2]=+(((aQ()|0)%6|0)+66|0);f=+g[a>>2];g[e>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+20>>2]=+(((aQ()|0)%512|0)-256|0);f=+g[a+4>>2];g[e+4>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+24>>2]=+(((aQ()|0)%512|0)-256|0);f=+g[a+8>>2];g[e+8>>2]=f+ +(((aQ()|0)%32|0)-16|0);g[e+28>>2]=+(((aQ()|0)%512|0)-256|0)}d=d+1|0;e=c[350540]|0;}while((d|0)<1024&(e|0)!=0);return}function uI(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0;b=i;i=i+16|0;d=b|0;e=d|0;f=d+4|0;j=d+8|0;d=a+4|0;k=a+8|0;l=-16;L6999:while(1){m=l<<3;n=-16;do{o=c[350540]|0;if((o|0)==0){p=5263;break L6999}q=o+16|0;c[350540]=c[q>>2];c[q>>2]=c[664792];c[664792]=o;r=+h[321194]+2.0;g[o+36>>2]=r+ +((aQ()|0)&31|0)*.02;g[o+12>>2]=+((aQ()|0)&7|224|0);c[o+40>>2]=1;r=+((aQ()|0)&7|n<<3|0);g[e>>2]=r;g[f>>2]=+((aQ()|0)&7|m|0);g[j>>2]=256.0;g[o>>2]=+g[a>>2]+r;g[o+4>>2]=+g[d>>2]+ +g[f>>2];r=+g[k>>2];g[o+8>>2]=r+ +((aQ()|0)&63|0);+q1(e);q9(e,+(((aQ()|0)&63)+50|0),o+20|0);n=n+1|0;}while((n|0)<16);n=l+1|0;if((n|0)<16){l=n}else{p=5264;break}}if((p|0)==5263){i=b;return}else if((p|0)==5264){i=b;return}}function uJ(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0,p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0;b=i;i=i+16|0;d=b|0;e=d|0;f=d+4|0;j=d+8|0;d=a+4|0;k=a+8|0;l=-16;L7009:while(1){m=+(l<<3|0);n=+(l|0);o=-16;do{p=+(o<<3|0);q=+(o|0);r=-24;do{s=c[350540]|0;if((s|0)==0){t=5274;break L7009}u=s+16|0;c[350540]=c[u>>2];c[u>>2]=c[664792];c[664792]=s;v=+h[321194]+.2;g[s+36>>2]=v+ +((aQ()|0)&7|0)*.02;g[s+12>>2]=+(((aQ()|0)&7)+7|0);c[s+40>>2]=1;g[e>>2]=p;g[f>>2]=m;g[j>>2]=+(r<<3|0);v=n+ +g[a>>2];g[s>>2]=v+ +((aQ()|0)&3|0);v=q+ +g[d>>2];g[s+4>>2]=v+ +((aQ()|0)&3|0);v=+(r|0)+ +g[k>>2];g[s+8>>2]=v+ +((aQ()|0)&3|0);+q1(e);q9(e,+(((aQ()|0)&63)+50|0),s+20|0);r=r+4|0;}while((r|0)<32);o=o+4|0;}while((o|0)<16);o=l+4|0;if((o|0)<16){l=o}else{t=5273;break}}if((t|0)==5273){i=b;return}else if((t|0)==5274){i=b;return}}function uK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0;e=i;i=i+16|0;f=e|0;j=f|0;g[j>>2]=+g[b>>2]- +g[a>>2];k=a+4|0;l=f+4|0;g[l>>2]=+g[b+4>>2]- +g[k>>2];m=a+8|0;n=f+8|0;g[n>>2]=+g[b+8>>2]- +g[m>>2];o=+q1(j);b=(d|0)<128;f=b?d:d-128|0;p=b?3.0:1.0;if(o<=0.0){i=e;return}b=(f|0)==3;q=o;while(1){o=q-p;d=c[350540]|0;if((d|0)==0){r=5293;break}s=d+16|0;c[350540]=c[s>>2];c[s>>2]=c[664792];c[664792]=d;s=d+20|0;g[s>>2]=+g[29396];t=d+24|0;g[t>>2]=+g[29397];g[d+28>>2]=+g[29398];u=d+36|0;g[u>>2]=+h[321194]+2.0;L7028:do{switch(f|0){case 0:{v=+((aQ()|0)&3|0);g[d+32>>2]=v;g[d+12>>2]=+(c[9976+(~~v<<2)>>2]|0);c[d+40>>2]=3;g[d>>2]=+g[a>>2]+ +(((aQ()|0)%6|0)-3|0);g[d+4>>2]=+g[k>>2]+ +(((aQ()|0)%6|0)-3|0);g[d+8>>2]=+g[m>>2]+ +(((aQ()|0)%6|0)-3|0);w=o;break};case 6:{g[d+12>>2]=+((aQ()|0)&3|152|0);c[d+40>>2]=0;g[u>>2]=+h[321194]+.3;g[d>>2]=+g[a>>2]+ +(((aQ()|0)&15)-8|0);g[d+4>>2]=+g[k>>2]+ +(((aQ()|0)&15)-8|0);g[d+8>>2]=+g[m>>2]+ +(((aQ()|0)&15)-8|0);w=o;break};case 4:{c[d+40>>2]=1;g[d+12>>2]=+(((aQ()|0)&3)+67|0);g[d>>2]=+g[a>>2]+ +(((aQ()|0)%6|0)-3|0);g[d+4>>2]=+g[k>>2]+ +(((aQ()|0)%6|0)-3|0);g[d+8>>2]=+g[m>>2]+ +(((aQ()|0)%6|0)-3|0);w=o+-3.0;break};case 1:{v=+(((aQ()|0)&3)+2|0);g[d+32>>2]=v;g[d+12>>2]=+(c[9976+(~~v<<2)>>2]|0);c[d+40>>2]=3;g[d>>2]=+g[a>>2]+ +(((aQ()|0)%6|0)-3|0);g[d+4>>2]=+g[k>>2]+ +(((aQ()|0)%6|0)-3|0);g[d+8>>2]=+g[m>>2]+ +(((aQ()|0)%6|0)-3|0);w=o;break};case 3:case 5:{g[u>>2]=+h[321194]+.5;c[d+40>>2]=0;x=c[665020]<<1&8;if(b){g[d+12>>2]=+(x|52|0)}else{g[d+12>>2]=+(x|230|0)}c[665020]=(c[665020]|0)+1;g[d>>2]=+g[a>>2];g[d+4>>2]=+g[k>>2];g[d+8>>2]=+g[m>>2];v=+g[l>>2];if((c[665020]&1|0)==0){g[s>>2]=v*-30.0;g[t>>2]=+g[j>>2]*30.0;w=o;break L7028}else{g[s>>2]=v*30.0;g[t>>2]=+g[j>>2]*-30.0;w=o;break L7028}break};case 2:{c[d+40>>2]=1;g[d+12>>2]=+(((aQ()|0)&3)+67|0);g[d>>2]=+g[a>>2]+ +(((aQ()|0)%6|0)-3|0);g[d+4>>2]=+g[k>>2]+ +(((aQ()|0)%6|0)-3|0);g[d+8>>2]=+g[m>>2]+ +(((aQ()|0)%6|0)-3|0);w=o;break};default:{w=o}}}while(0);g[a>>2]=+g[a>>2]+ +g[j>>2];g[k>>2]=+g[k>>2]+ +g[l>>2];g[m>>2]=+g[m>>2]+ +g[n>>2];if(w>0.0){q=w}else{r=5292;break}}if((r|0)==5292){i=e;return}else if((r|0)==5293){i=e;return}}function uL(a){a=a|0;return a|0}function uM(){var a=0.0,b=0.0,d=0.0,e=0.0,f=0.0,i=0.0,j=0.0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0;a=+h[321194];b=a- +h[321195];d=+g[644]*b*.05;e=b*15.0;f=b*10.0;i=b*5.0;j=b*4.0;k=c[664792]|0;if((k|0)==0){return}else{l=k;m=a}while(1){if(+g[l+36>>2]>=m){break}k=l+16|0;c[664792]=c[k>>2];c[k>>2]=c[350540];c[350540]=l;k=c[664792]|0;if((k|0)==0){n=5323;break}l=k;m=+h[321194]}if((n|0)==5323){return}if((l|0)==0){return}else{o=l}while(1){l=o+16|0;n=c[l>>2]|0;L7061:do{if((n|0)==0){p=0}else{k=n;while(1){if(+g[k+36>>2]>=+h[321194]){p=k;break L7061}q=k+16|0;c[l>>2]=c[q>>2];c[q>>2]=c[350540];c[350540]=k;q=c[l>>2]|0;if((q|0)==0){p=0;break}else{k=q}}}}while(0);l=o+20|0;m=+g[l>>2];a=b*m;n=o|0;g[n>>2]=+g[n>>2]+a;n=o+24|0;r=+g[n>>2];s=b*r;k=o+4|0;g[k>>2]=+g[k>>2]+s;k=o+28|0;t=+g[k>>2];u=b*t;q=o+8|0;g[q>>2]=+g[q>>2]+u;switch(c[o+40>>2]|0){case 5:{q=o+32|0;v=e+ +g[q>>2];g[q>>2]=v;if(v<8.0){g[o+12>>2]=+(c[10008+(~~v<<2)>>2]|0)}else{g[o+36>>2]=-1.0}g[l>>2]=m-a;g[n>>2]=r-s;g[k>>2]=t-u-d;break};case 6:{g[l>>2]=m+j*m;g[n>>2]=r+j*r;g[k>>2]=t+j*t-d;break};case 7:{g[l>>2]=m-j*m;g[n>>2]=r-j*r;g[k>>2]=t-d;break};case 4:{q=o+32|0;u=f+ +g[q>>2];g[q>>2]=u;if(u<8.0){g[o+12>>2]=+(c[10040+(~~u<<2)>>2]|0)}else{g[o+36>>2]=-1.0}g[l>>2]=m+j*m;g[n>>2]=r+j*r;g[k>>2]=t+j*t-d;break};case 3:{n=o+32|0;r=i+ +g[n>>2];g[n>>2]=r;if(r<6.0){g[o+12>>2]=+(c[9976+(~~r<<2)>>2]|0)}else{g[o+36>>2]=-1.0}g[k>>2]=d+t;break};case 1:case 2:{g[k>>2]=t-d;break};default:{}}if((p|0)==0){break}else{o=p}}return}function uN(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[b+44>>2]|0;e=0;while(1){f=e<<8|128;g=0;do{h=f+g|0;a[639800+h|0]=a[b+(h+d)|0]|0;g=g+1|0;}while((g|0)<128);g=e+1|0;if((g|0)<128){e=g}else{i=0;break}}do{e=i<<8;g=i*131|0;f=0;do{h=a[b+((f&127|e)+d)|0]|0;j=f+g|0;k=2605656+j|0;if(h<<24>>24==0){a[k]=0;a[2622424+j|0]=-1}else{a[k]=h;a[2622424+j|0]=0}f=f+1|0;}while((f|0)<131);i=i+1|0;}while((i|0)<128);c[157308]=639800;return}function uO(){var a=0,b=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0;a=~~(+g[888]*+g[892]);if((a|0)==(c[28072]|0)&(a|0)==(c[28070]|0)){return}c[28072]=a;c[28070]=a;b=639800;e=0;while(1){f=(e+a&127)*131|0;h=b;i=0;while(1){j=(i+a&127)+f|0;k=2605656+j|0;l=2622424+j|0;c[h>>2]=c[h+128>>2]&(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24)|(d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24);k=i+4|0;if((k|0)<128){h=h+4|0;i=k}else{break}}i=e+1|0;if((i|0)<128){b=b+256|0;e=i}else{break}}c[157310]=1;return}function uP(){var a=0,b=0;pf();q9(117312,+g[14],629528);q9(117296,+g[4],629512);g[157386]=+g[29332];g[157387]=+g[29333];g[157388]=+g[29334];a=c[664792]|0;if((a|0)==0){pe();return}else{b=a}do{ph(b);b=c[b+16>>2]|0;}while((b|0)!=0);pe();return}function uQ(){var a=0,b=0,d=0,e=0.0,f=0.0;a=c[4182]|0;g[892]=+(a|0);b=c[4180]|0;g[890]=+(b|0);d=q4(a,b)|0;e=+(ab(((c[4182]|0)/(d|0)|0)<<7,(c[4180]|0)/(d|0)|0)|0);f=+h[321194];g[888]=f-e*+(~~(f/e)|0);c[157310]=0;return}function uR(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;d=ab(c[a+4>>2]|0,c[a>>2]|0)|0;b=a+24|0;yJ(b|0,e|0,d)|0;return}function uS(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0,I=0,J=0,K=0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0.0;d=i;i=i+624|0;e=d|0;f=d+88|0;j=d+104|0;k=d+120|0;l=d+136|0;m=d+152|0;n=d+168|0;o=d+592|0;p=d+608|0;q=c[(c[b+136>>2]|0)+388>>2]|0;r=vW(b,q,+h[321194]+ +g[b+152>>2])|0;c[157292]=r;c[145618]=c[r>>2];c[145622]=c[r+4>>2];r=c[q>>2]|0;L7123:do{switch(r|0){case 1:{s=p|0;g[s>>2]=-0.0- +g[169390];t=p+4|0;g[t>>2]=-0.0- +g[169391];u=p+8|0;g[u>>2]=-0.0- +g[169392];+q1(s);v=+g[u>>2];if(v>.999848|v<-.999848){i=d;return}else{g[157293]=0.0;g[157294]=0.0;g[157295]=1.0;g[157296]=+g[t>>2];g[157297]=-0.0- +g[s>>2];g[157298]=0.0;+q1(629184);g[157299]=-0.0- +g[157297];g[157300]=+g[157296];g[157301]=0.0;break L7123}break};case 2:{g[157293]=+g[29324];g[157296]=+g[29328];g[157299]=+g[29332];g[157294]=+g[29325];g[157297]=+g[29329];g[157300]=+g[29333];g[157295]=+g[29326];g[157298]=+g[29330];g[157301]=+g[29334];break};case 0:{v=+g[29334];if(v>.999848|v<-.999848){i=d;return}else{g[157293]=0.0;g[157294]=0.0;g[157295]=1.0;g[157296]=+g[29333];g[157297]=-0.0- +g[29332];g[157298]=0.0;+q1(629184);g[157299]=-0.0- +g[157297];g[157300]=+g[157296];g[157301]=0.0;break L7123}break};case 4:{v=+g[b+132>>2]*.017453292519943295;w=+U(+v);x=+T(+v);v=-0.0-w;g[157299]=+g[29332];y=+g[29328];z=+g[29324];g[157296]=x*y+w*z;g[157293]=y*v+x*z;g[157300]=+g[29333];z=+g[29329];y=+g[29325];g[157297]=x*z+w*y;g[157294]=z*v+x*y;g[157301]=+g[29334];y=+g[29330];z=+g[29326];g[157298]=x*y+w*z;g[157295]=y*v+x*z;break};case 3:{rc(b+124|0,629196,629184,629172);break};default:{w1(92936,(A=i,i=i+16|0,c[A>>2]=110040,c[A+8>>2]=r,A)|0);i=A}}}while(0);z=+g[q+16>>2];if(z==0.0){B=+g[169390];C=+g[169391];D=+g[169392]}else{q=o|0;q9(629196,-0.0-z,q);z=+g[q>>2];g[157466]=+g[157466]+z;x=+g[o+4>>2];g[157467]=+g[157467]+x;v=+g[o+8>>2];g[157468]=+g[157468]+v;y=+g[169390]-z;g[169390]=y;z=+g[169391]-x;g[169391]=z;x=+g[169392]-v;g[169392]=x;B=y;C=z;D=x}if(+g[157299]*B+ +g[157300]*C+ +g[157301]*D>=0.0){i=d;return}q=j|0;q9(629184,+g[(c[157292]|0)+20>>2],q);r=f|0;q9(629172,+g[(c[157292]|0)+8>>2],r);b=o|0;q9(629184,+g[(c[157292]|0)+16>>2],b);p=k|0;q9(629172,+g[(c[157292]|0)+12>>2],p);D=+g[157466];C=D+ +g[r>>2];B=+g[b>>2];g[353712]=C+B;x=+g[157467];z=x+ +g[f+4>>2];y=+g[o+4>>2];g[353713]=z+y;v=+g[157468];w=v+ +g[f+8>>2];E=+g[o+8>>2];g[353714]=w+E;g[353715]=0.0;g[353716]=0.0;F=+g[q>>2];g[353717]=C+F;C=+g[j+4>>2];g[353718]=z+C;z=+g[j+8>>2];g[353719]=w+z;w=+(c[145618]|0);g[353720]=w;g[353721]=0.0;G=D+ +g[p>>2];g[353722]=F+G;F=x+ +g[k+4>>2];g[353723]=C+F;C=v+ +g[k+8>>2];g[353724]=z+C;g[353725]=w;w=+(c[145622]|0);g[353726]=w;g[353727]=B+G;g[353728]=y+F;g[353729]=E+C;g[353730]=0.0;g[353731]=w;a[21592]=0;k=e|0;p=4;j=0;q=0;while(1){w=+g[117372+(j*28|0)>>2];o=q^1;f=q?1415248:1414848;b=q?1414848:1415248;a[21592]=o;if((p|0)<=0){H=5394;break}C=+g[117360+(j*28|0)>>2];E=+g[117364+(j*28|0)>>2];F=+g[117368+(j*28|0)>>2];r=f;s=0;while(1){g[e+(s<<2)>>2]=C*+g[r>>2]+E*+g[r+4>>2]+F*+g[r+8>>2]-w;t=s+1|0;if((t|0)<(p|0)){r=r+20|0;s=t}else{break}}g[e+(p<<2)>>2]=+g[k>>2];s=f+((p*5|0)<<2)|0;r=f;c[s>>2]=c[r>>2];c[s+4>>2]=c[r+4>>2];c[s+8>>2]=c[r+8>>2];c[s+12>>2]=c[r+12>>2];c[s+16>>2]=c[r+16>>2];r=0;s=f;t=b;u=0;while(1){I=e+(u<<2)|0;w=+g[I>>2];if(w<0.0){J=t;K=r;L=w}else{M=t;N=s;c[M>>2]=c[N>>2];c[M+4>>2]=c[N+4>>2];c[M+8>>2]=c[N+8>>2];c[M+12>>2]=c[N+12>>2];c[M+16>>2]=c[N+16>>2];J=t+20|0;K=r+1|0;L=+g[I>>2]}I=u+1|0;do{if(L==0.0){O=J;P=K}else{w=+g[e+(I<<2)>>2];if(w==0.0){O=J;P=K;break}if(!(L>0.0^w>0.0)){O=J;P=K;break}F=L/(L-w);w=+g[s>>2];g[J>>2]=w+F*(+g[s+20>>2]-w);w=+g[s+4>>2];g[J+4>>2]=w+F*(+g[s+24>>2]-w);w=+g[s+8>>2];g[J+8>>2]=w+F*(+g[s+28>>2]-w);w=+g[s+12>>2];g[J+12>>2]=w+F*(+g[s+32>>2]-w);w=+g[s+16>>2];g[J+16>>2]=w+F*(+g[s+36>>2]-w);O=J+20|0;P=K+1|0}}while(0);if((I|0)>=(p|0)){break}r=P;s=s+20|0;t=O;u=I}if((P|0)<3){H=5396;break}if((P|0)>19){w1(103424,(A=i,i=i+8|0,c[A>>2]=11e4,A)|0);i=A;Q=a[21592]|0}else{Q=o}u=j+1|0;if((u|0)<4){p=P;j=u;q=Q}else{H=5383;break}}if((H|0)==5383){g[157302]=-999999.0;if((P|0)>0){q=m|0;j=m+4|0;p=m+8|0;m=l|0;A=l+8|0;O=l+4|0;l=1414848+((Q&1)*400|0)|0;Q=0;while(1){g[q>>2]=+g[l>>2]- +g[157424];g[j>>2]=+g[l+4>>2]- +g[157425];g[p>>2]=+g[l+8>>2]- +g[157426];uu(q,m);L=+g[A>>2];if(L<.01){g[A>>2]=.009999999776482582;R=.009999999776482582}else{R=L}L=1.0/R;g[n+(Q*20|0)+16>>2]=L;if(L>+g[157302]){g[157302]=L}g[n+(Q*20|0)+8>>2]=+g[l+12>>2];g[n+(Q*20|0)+12>>2]=+g[l+16>>2];g[n+(Q*20|0)>>2]=+g[20]+L*+g[18]*+g[m>>2];g[n+(Q*20|0)+4>>2]=+g[10]-L*+g[8]*+g[O>>2];K=Q+1|0;if((K|0)<(P|0)){l=l+20|0;Q=K}else{break}}}c[157290]=P;c[157291]=n;pH();i=d;return}else if((H|0)==5394){i=d;return}else if((H|0)==5396){i=d;return}}function uT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,j=0;d=i;if((c[a+140>>2]|0)==0){e=b}else{a=c[b+40>>2]|0;e=(a|0)==0?b:a}a=c[e+24>>2]|0;if((a|0)==0){f=e;i=d;return f|0}b=(~~(+h[321194]*10.0)|0)%(a|0)|0;a=1;g=e;while(1){if((c[g+28>>2]|0)<=(b|0)){if((c[g+32>>2]|0)>(b|0)){f=g;break}}e=c[g+36>>2]|0;if((e|0)==0){w1(92832,(j=i,i=i+8|0,c[j>>2]=109960,j)|0);i=j}if((a|0)>100){w1(103400,(j=i,i=i+8|0,c[j>>2]=109960,j)|0);i=j}a=a+1|0;g=e}i=d;return f|0}function uU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[157430]|0)<=0){return}b=0;e=c[158774]|0;f=c[157542]|0;while(1){g=c[157452]|0;h=c[g>>2]|0;c[274570]=h;i=c[g+4>>2]|0;c[274566]=i;j=c[157450]|0;k=g+(j<<2)|0;c[157452]=k;c[274568]=((c[k>>2]|0)-h|0)>>>4;c[274564]=((c[g+(j+1<<2)>>2]|0)-i|0)>>>4;j=0;g=e;k=f;l=h;h=i;while(1){i=l-h>>4;m=15;n=h;while(1){a[k+m|0]=a[(c[29377]|0)+(d[g+m|0]|0|n&65280)|0]|0;if((m|0)>0){m=m-1|0;n=n+i|0}else{break}}o=c[145628]|0;p=g+o|0;i=(c[274566]|0)+(c[274564]|0)|0;c[274566]=i;n=(c[274570]|0)+(c[274568]|0)|0;c[274570]=n;q=k+(c[73916]|0)|0;m=j+1|0;if((m|0)<16){j=m;g=p;k=q;l=n;h=i}else{break}}if(p>>>0<(c[157304]|0)>>>0){r=p}else{r=g+(o-(c[157284]|0))|0}h=b+1|0;if((h|0)<(c[157430]|0)){b=h;e=r;f=q}else{break}}return}function uV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[157430]|0)<=0){return}b=0;e=c[158774]|0;f=c[157542]|0;while(1){g=c[157452]|0;h=c[g>>2]|0;c[274570]=h;i=c[g+4>>2]|0;c[274566]=i;j=c[157450]|0;k=g+(j<<2)|0;c[157452]=k;c[274568]=((c[k>>2]|0)-h|0)>>>3;c[274564]=((c[g+(j+1<<2)>>2]|0)-i|0)>>>3;j=0;g=e;k=f;l=h;h=i;while(1){i=l-h>>3;a[k+7|0]=a[(c[29377]|0)+(d[g+7|0]|0|h&65280)|0]|0;m=h+i|0;a[k+6|0]=a[(c[29377]|0)+(d[g+6|0]|0|m&65280)|0]|0;n=m+i|0;a[k+5|0]=a[(c[29377]|0)+(d[g+5|0]|0|n&65280)|0]|0;m=n+i|0;a[k+4|0]=a[(c[29377]|0)+(d[g+4|0]|0|m&65280)|0]|0;n=m+i|0;a[k+3|0]=a[(c[29377]|0)+(d[g+3|0]|0|n&65280)|0]|0;m=n+i|0;a[k+2|0]=a[(c[29377]|0)+(d[g+2|0]|0|m&65280)|0]|0;n=m+i|0;a[k+1|0]=a[(c[29377]|0)+(d[g+1|0]|0|n&65280)|0]|0;a[k]=a[(c[29377]|0)+(d[g]|0|n+i&65280)|0]|0;o=c[145628]|0;p=g+o|0;i=(c[274566]|0)+(c[274564]|0)|0;c[274566]=i;n=(c[274570]|0)+(c[274568]|0)|0;c[274570]=n;q=k+(c[73916]|0)|0;m=j+1|0;if((m|0)<8){j=m;g=p;k=q;l=n;h=i}else{break}}if(p>>>0<(c[157304]|0)>>>0){r=p}else{r=g+(o-(c[157284]|0))|0}h=b+1|0;if((h|0)<(c[157430]|0)){b=h;e=r;f=q}else{break}}return}function uW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[157430]|0)<=0){return}b=0;e=c[158774]|0;f=c[157542]|0;while(1){g=c[157452]|0;h=c[g>>2]|0;c[274570]=h;i=c[g+4>>2]|0;c[274566]=i;j=c[157450]|0;k=g+(j<<2)|0;c[157452]=k;c[274568]=((c[k>>2]|0)-h|0)>>>2;c[274564]=((c[g+(j+1<<2)>>2]|0)-i|0)>>>2;j=0;g=e;k=f;l=h;h=i;while(1){i=l-h>>2;a[k+3|0]=a[(c[29377]|0)+(d[g+3|0]|0|h&65280)|0]|0;m=h+i|0;a[k+2|0]=a[(c[29377]|0)+(d[g+2|0]|0|m&65280)|0]|0;n=m+i|0;a[k+1|0]=a[(c[29377]|0)+(d[g+1|0]|0|n&65280)|0]|0;a[k]=a[(c[29377]|0)+(d[g]|0|n+i&65280)|0]|0;o=c[145628]|0;p=g+o|0;i=(c[274566]|0)+(c[274564]|0)|0;c[274566]=i;n=(c[274570]|0)+(c[274568]|0)|0;c[274570]=n;q=k+(c[73916]|0)|0;m=j+1|0;if((m|0)<4){j=m;g=p;k=q;l=n;h=i}else{break}}if(p>>>0<(c[157304]|0)>>>0){r=p}else{r=g+(o-(c[157284]|0))|0}h=b+1|0;if((h|0)<(c[157430]|0)){b=h;e=r;f=q}else{break}}return}function uX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[157430]|0)<=0){return}b=0;e=c[158774]|0;f=c[157542]|0;while(1){g=c[157452]|0;h=c[g>>2]|0;c[274570]=h;i=c[g+4>>2]|0;c[274566]=i;j=c[157450]|0;k=g+(j<<2)|0;c[157452]=k;c[274568]=((c[k>>2]|0)-h|0)>>>1;c[274564]=((c[g+(j+1<<2)>>2]|0)-i|0)>>>1;a[f+1|0]=a[(c[29377]|0)+(d[e+1|0]|0|i&65280)|0]|0;a[f]=a[(c[29377]|0)+(d[e]|0|i+((h-i|0)>>>1)&65280)|0]|0;i=c[145628]|0;h=(c[274566]|0)+(c[274564]|0)|0;c[274566]=h;j=(c[274570]|0)+(c[274568]|0)|0;c[274570]=j;g=c[73916]|0;a[f+(g+1)|0]=a[(c[29377]|0)+(d[e+(i+1)|0]|0|h&65280)|0]|0;a[f+g|0]=a[(c[29377]|0)+(d[e+i|0]|0|h+((j-h|0)>>>1)&65280)|0]|0;h=c[145628]|0;j=e+(i+h)|0;c[274566]=(c[274566]|0)+(c[274564]|0);c[274570]=(c[274570]|0)+(c[274568]|0);if(j>>>0<(c[157304]|0)>>>0){l=j}else{l=e+(i+(h-(c[157284]|0)))|0}h=b+1|0;if((h|0)<(c[157430]|0)){b=h;e=l;f=f+(g+(c[73916]|0))|0}else{break}}return}function uY(){var e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,R=0,S=0,T=0,U=0,V=0;e=c[157484]|0;f=e+68|0;h=e+70|0;i=ab((b[h>>1]>>4)+1|0,(b[f>>1]>>4)+1|0)|0;j=c[e+88>>2]|0;do{if(+g[2740]!=0.0){k=5456}else{if((c[(c[644470]|0)+380>>2]|0)==0){k=5456;break}l=(i|0)>0;do{if(l){m=c[157360]<<8;n=0;do{c[2639200+(n<<2)>>2]=m;n=n+1|0;}while((n|0)<(i|0));if((j|0)==0){break}if((a[e+84|0]|0)==-1){break}n=c[157485]|0;m=0;do{o=ab(d[j+m|0]|0,n)|0;p=2639200+(m<<2)|0;c[p>>2]=o+(c[p>>2]|0);m=m+1|0;}while((m|0)<(i|0));if((a[e+85|0]|0)==-1){break}m=c[157486]|0;n=0;do{p=ab(d[j+(n+i)|0]|0,m)|0;o=2639200+(n<<2)|0;c[o>>2]=p+(c[o>>2]|0);n=n+1|0;}while((n|0)<(i|0));n=i<<1;if((a[e+86|0]|0)==-1){break}m=c[157487]|0;o=0;do{p=ab(d[j+(o+n)|0]|0,m)|0;q=2639200+(o<<2)|0;c[q>>2]=p+(c[q>>2]|0);o=o+1|0;}while((o|0)<(i|0));o=n+i|0;if((a[e+87|0]|0)==-1){break}m=c[157488]|0;q=0;do{p=ab(d[j+(o+q)|0]|0,m)|0;r=2639200+(q<<2)|0;c[r>>2]=p+(c[r>>2]|0);q=q+1|0;}while((q|0)<(i|0))}}while(0);if((c[e+76>>2]|0)==(c[2750]|0)){q=b[f>>1]>>4;m=q+1|0;o=b[h>>1]>>4;n=o+1|0;r=c[e+72>>2]|0;p=e+80|0;s=e+32|0;t=r|0;u=r+4|0;v=r+8|0;w=r+12|0;x=r+16|0;y=r+20|0;z=r+24|0;A=r+28|0;r=e+64|0;B=e+66|0;C=(o|q|0)<0;q=0;do{do{if((c[p>>2]&1<<q|0)!=0){D=+g[2566976+(q*36|0)>>2];E=+g[2566964+(q*36|0)>>2];o=c[s>>2]|0;F=+g[o>>2];G=+g[2566968+(q*36|0)>>2];H=+g[o+4>>2];I=+g[2566972+(q*36|0)>>2];J=+g[o+8>>2];K=E*F+G*H+I*J- +g[o+12>>2];L=D- +Q(+K);D=+g[2566988+(q*36|0)>>2];if(L<D){break}M=E-F*K;F=G-H*K;H=I-J*K;K=L-D;D=+g[w>>2]+(M*+g[t>>2]+F*+g[u>>2]+H*+g[v>>2])- +(b[r>>1]|0);J=+g[A>>2]+(M*+g[x>>2]+F*+g[y>>2]+H*+g[z>>2])- +(b[B>>1]|0);if(C){break}else{N=0}do{o=~~(J- +(N<<4|0));O=(o|0)<0?-o|0:o;o=O>>1;P=ab(N,m)|0;R=0;do{S=~~(D- +(R<<4|0));T=(S|0)<0?-S|0:S;if((T|0)>(O|0)){U=T+o|0}else{U=(T>>1)+O|0}H=+(U|0);if(H<K){T=2639200+(R+P<<2)|0;c[T>>2]=~~((L-H)*256.0+ +((c[T>>2]|0)>>>0>>>0))}R=R+1|0;}while((R|0)<(m|0));N=N+1|0;}while((N|0)<(n|0))}}while(0);q=q+1|0;}while((q|0)<32)}if(l){V=0}else{break}do{q=2639200+(V<<2)|0;n=65280-(c[q>>2]|0)>>2;c[q>>2]=(n|0)<64?64:n;V=V+1|0;}while((V|0)<(i|0))}}while(0);do{if((k|0)==5456){if((i|0)<=0){break}yG(2639200,0,i<<2|0)}}while(0);c[73916]=c[157483];i=c[157489]|0;k=c[157490]|0;V=c[i+44+(k<<2)>>2]|0;c[157306]=i+V;N=i+16|0;U=(c[N>>2]|0)>>>(k>>>0);h=16>>>(k>>>0);c[659798]=h;j=4-k|0;c[660124]=j;c[660126]=(1<<j)-1;c[157450]=(b[f>>1]>>4)+1;f=c[157491]>>j;c[157434]=f;c[157430]=c[157492]>>j;j=c[2848+(k<<2)>>2]|0;l=(c[N>>2]|0)>>>(k>>>0);N=(c[i+20>>2]|0)>>>(k>>>0);c[145628]=U;c[157284]=ab(N,U)|0;c[157304]=i+(V+(ab(N,l)|0));n=ab(((b[e+66>>1]>>k)+(N<<16)|0)%(N|0)|0,U)|0;if((f|0)<=0){return}f=c[157482]|0;U=((b[e+64>>1]>>k)+(l<<16)|0)%(l|0)|0;k=0;while(1){c[157452]=2639200+(k<<2);c[157542]=f;c[158774]=i+(V+(U+n));fQ[j&1023]();e=(c[659798]|0)+U|0;N=k+1|0;if((N|0)<(c[157434]|0)){f=f+h|0;U=(e|0)<(l|0)?e:0;k=N}else{break}}return}function uZ(){c[155506]=0;c[155498]=0;return}function u_(){c[155498]=0;return}function u$(){if((c[155506]|0)!=0){return}c[155506]=1;c[155498]=0;return}function u0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[a>>2]|0;e=b|0;if((d|0)==0){f=c[e>>2]|0;g=f+4|0;c[g>>2]=1;return}else{h=a;i=d}while(1){d=i+4|0;if((c[d>>2]|0)!=0){j=5548;break}a=i|0;b=c[a>>2]|0;k=b+12|0;l=c[k>>2]|0;L7325:do{if((i|0)==(l|0)){m=c[b+8>>2]|0;do{if((m|0)!=0){n=m+4|0;if((c[n>>2]|0)!=0){break}c[n>>2]=1;c[d>>2]=1;c[b+4>>2]=0;o=b;break L7325}}while(0);m=i+8|0;if((c[m>>2]|0)==(h|0)){n=h+12|0;p=c[n>>2]|0;c[m>>2]=p;if((p|0)!=0){c[c[n>>2]>>2]=i}c[n>>2]=i;n=c[a>>2]|0;c[h>>2]=n;do{if((n|0)==0){c[e>>2]=h}else{p=c[a>>2]|0;m=p+12|0;if((c[m>>2]|0)==(i|0)){c[m>>2]=h;break}else{c[p+8>>2]=h;break}}}while(0);c[a>>2]=h;q=i;r=h}else{q=h;r=i}c[r+4>>2]=1;c[b+4>>2]=0;n=c[k>>2]|0;p=n+8|0;m=c[p>>2]|0;c[k>>2]=m;if((m|0)!=0){c[c[p>>2]>>2]=b}c[p>>2]=b;p=b|0;m=c[p>>2]|0;c[n>>2]=m;do{if((m|0)==0){c[e>>2]=n}else{s=c[p>>2]|0;t=s+8|0;if((c[t>>2]|0)==(b|0)){c[t>>2]=n;break}else{c[s+12>>2]=n;break}}}while(0);c[p>>2]=n;o=q}else{do{if((l|0)!=0){m=l+4|0;if((c[m>>2]|0)!=0){break}c[m>>2]=1;c[d>>2]=1;c[b+4>>2]=0;o=b;break L7325}}while(0);n=i+12|0;if((c[n>>2]|0)==(h|0)){p=h+8|0;m=c[p>>2]|0;c[n>>2]=m;if((m|0)!=0){c[c[p>>2]>>2]=i}c[p>>2]=i;p=c[a>>2]|0;c[h>>2]=p;do{if((p|0)==0){c[e>>2]=h}else{m=c[a>>2]|0;n=m+8|0;if((c[n>>2]|0)==(i|0)){c[n>>2]=h;break}else{c[m+12>>2]=h;break}}}while(0);c[a>>2]=h;u=i;v=h}else{u=h;v=i}c[v+4>>2]=1;c[b+4>>2]=0;p=b+8|0;m=c[p>>2]|0;n=m+12|0;s=c[n>>2]|0;c[p>>2]=s;if((s|0)!=0){c[c[n>>2]>>2]=b}c[n>>2]=b;n=b|0;s=c[n>>2]|0;c[m>>2]=s;do{if((s|0)==0){c[e>>2]=m}else{p=c[n>>2]|0;t=p+12|0;if((c[t>>2]|0)==(b|0)){c[t>>2]=m;break}else{c[p+8>>2]=m;break}}}while(0);c[n>>2]=m;o=u}}while(0);b=c[o>>2]|0;if((b|0)==0){j=5546;break}else{h=o;i=b}}if((j|0)==5546){f=c[e>>2]|0;g=f+4|0;c[g>>2]=1;return}else if((j|0)==5548){f=c[e>>2]|0;g=f+4|0;c[g>>2]=1;return}}function u1(){var a=0,b=0,d=0,e=0,f=0,g=0;a=i;b=0;do{d=oh(92752,(e=i,i=i+8|0,c[e>>2]=b,e)|0)|0;i=e;c[622048+(b<<2)>>2]=pM(d)|0;d=oh(103352,(e=i,i=i+8|0,c[e>>2]=b,e)|0)|0;i=e;c[622092+(b<<2)>>2]=pM(d)|0;b=b+1|0;}while((b|0)<10);c[155522]=pM(83744)|0;c[155533]=pM(69992)|0;c[155592]=pM(60360)|0;c[155500]=pM(54576)|0;c[155442]=pM(50296)|0;c[155443]=pM(46416)|0;c[155444]=pM(42224)|0;c[155445]=pM(38472)|0;c[155446]=pM(108544)|0;c[155447]=pM(105312)|0;c[155448]=pM(102032)|0;c[155450]=pM(99768)|0;c[155451]=pM(98184)|0;c[155452]=pM(95952)|0;c[155453]=pM(93872)|0;c[155454]=pM(92240)|0;c[155455]=pM(90504)|0;c[155456]=pM(88688)|0;b=0;while(1){d=b+1|0;f=oh(86936,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;g=b+2|0;c[621768+(g<<5)>>2]=pM(f)|0;f=oh(85024,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;c[621772+(g<<5)>>2]=pM(f)|0;f=oh(82576,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;c[621776+(g<<5)>>2]=pM(f)|0;f=oh(80592,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;c[621780+(g<<5)>>2]=pM(f)|0;f=oh(78816,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;c[621784+(g<<5)>>2]=pM(f)|0;f=oh(77552,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;c[621788+(g<<5)>>2]=pM(f)|0;f=oh(76152,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;c[621792+(g<<5)>>2]=pM(f)|0;if((d|0)<5){b=d}else{break}}c[155598]=pM(74888)|0;c[155599]=pM(73968)|0;c[155600]=pM(72904)|0;c[155601]=pM(72032)|0;c[155594]=pM(70808)|0;c[155595]=pM(69232)|0;c[155596]=pM(67960)|0;c[155536]=pM(66968)|0;c[155537]=pM(65968)|0;c[155538]=pM(65024)|0;c[155539]=pM(64280)|0;c[155540]=pM(63472)|0;c[155541]=pM(62712)|0;c[155502]=pM(62040)|0;c[155503]=pM(61048)|0;c[155504]=pM(59776)|0;c[155505]=pM(59200)|0;c[155578]=pM(58680)|0;c[155579]=pM(58112)|0;c[155576]=pM(57608)|0;c[155577]=pM(57096)|0;c[155574]=pM(56664)|0;c[155575]=pM(56184)|0;c[155572]=pM(55784)|0;c[155573]=pM(55160)|0;c[155570]=pM(54104)|0;c[155571]=pM(53512)|0;c[155590]=pM(52880)|0;c[155586]=pM(52512)|0;c[155588]=pM(52272)|0;c[155584]=pM(51992)|0;oE(51712,302);oE(51336,432);c[155510]=pM(51088)|0;c[155568]=pM(50640)|0;c[155508]=pM(49896)|0;if((c[278834]|0)!=0){c[278588]=pM(49488)|0;c[278589]=pM(49136)|0;c[278590]=pM(48792)|0;c[278591]=pM(48528)|0;c[278592]=pM(48240)|0;c[278593]=pM(47992)|0;c[278594]=pM(47576)|0;c[278595]=pM(47240)|0;c[278596]=pM(46776)|0;c[278597]=pM(45792)|0;b=0;while(1){d=b+1|0;f=oh(45352,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;g=b+2|0;c[1114352+(g*20|0)>>2]=pM(f)|0;f=oh(44912,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;c[1114356+(g*20|0)>>2]=pM(f)|0;f=oh(44608,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;c[1114360+(g*20|0)>>2]=pM(f)|0;f=oh(44304,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;c[1114364+(g*20|0)>>2]=pM(f)|0;f=oh(43992,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e;c[1114368+(g*20|0)>>2]=pM(f)|0;if((d|0)<5){b=d}else{break}}c[278624]=pM(43752)|0;c[278625]=pM(43368)|0}if((c[155622]|0)==0){i=a;return}c[155616]=pM(42960)|0;c[155617]=pM(42464)|0;c[155606]=pM(41608)|0;c[155607]=pM(41168)|0;c[155608]=pM(40768)|0;c[155609]=pM(40424)|0;c[155610]=pM(40200)|0;c[155614]=pM(39960)|0;c[155615]=pM(39728)|0;c[155612]=pM(39312)|0;c[155618]=pM(39072)|0;c[155619]=pM(38720)|0;c[155620]=pM(37976)|0;i=a;return}function u2(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;i=i+16|0;j=h|0;k=j|0;if((e|0)<0){a[k]=45;l=-e|0;m=j+1|0}else{l=e;m=k}if((l|0)<10){n=l;o=10;p=m}else{e=10;while(1){q=e*10|0;if((l|0)<(q|0)){n=l;o=q;p=m;break}else{e=q}}}while(1){e=(o|0)/10|0;m=(n|0)/(e|0)|0;r=p+1|0;a[p]=m+48&255;l=n-(ab(m,e)|0)|0;if((o-10|0)>>>0>9){n=l;o=e;p=r}else{break}}a[r]=0;p=r-j|0;if((p|0)>(f|0)){s=j+(p-f)|0}else{s=k}if((p|0)<(f|0)){t=((f-p|0)*24|0)+b|0}else{t=b}b=d-24|0;d=t;t=s;while(1){s=a[t]|0;if((s<<24>>24|0)==0){break}else if((s<<24>>24|0)==45){u=10}else{u=(s<<24>>24)-48|0}s=c[622048+(g*44|0)+(u<<2)>>2]|0;if((c[644469]|0)==1){pT(d,b+(c[29382]|0)|0,s)}else{pT(((c[29381]|0)-320>>1)+d|0,b+(c[29382]|0)|0,s)}d=d+24|0;t=t+1|0}i=h;return}function u3(){var a=0,b=0,d=0,e=0,f=0.0,g=0,j=0;a=i;i=i+80|0;b=a|0;d=c[642263]|0;cl(b|0,37328,(e=i,i=i+16|0,c[e>>2]=c[642265],c[e+8>>2]=d,e)|0)|0;i=e;if((c[644469]|0)==1){pP(8,(c[29382]|0)-20|0,b)}else{pP(((c[29381]|0)-320>>1)+8|0,(c[29382]|0)-20|0,b)}d=c[642262]|0;cl(b|0,37040,(e=i,i=i+16|0,c[e>>2]=c[642264],c[e+8>>2]=d,e)|0)|0;i=e;if((c[644469]|0)==1){pP(8,(c[29382]|0)-12|0,b)}else{pP(((c[29381]|0)-320>>1)+8|0,(c[29382]|0)-12|0,b)}f=+h[321194];d=~~(f/60.0);g=~~(f- +(d*60|0|0));j=(g|0)/10|0;cl(b|0,36880,(e=i,i=i+24|0,c[e>>2]=d,c[e+8>>2]=j,c[e+16>>2]=g+(j*-10|0),e)|0)|0;i=e;if((c[644469]|0)==1){pP(184,(c[29382]|0)-20|0,b)}else{pP(((c[29381]|0)-320>>1)+184|0,(c[29382]|0)-20|0,b)}b=232-((yF(2577828)|0)<<2)|0;if((c[644469]|0)==1){pP(b,(c[29382]|0)-12|0,2577828);i=a;return}else{pP(((c[29381]|0)-320>>1)+b|0,(c[29382]|0)-12|0,2577828);i=a;return}}function u4(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+16|0;e=b|0;c[155172]=1;c[155162]=0;f=pN(36448)|0;rg((320-(c[f>>2]|0)|0)/2|0,8,f);c[155434]=0;f=c[644468]|0;if((f|0)<=0){i=b;return}g=c[644542]|0;h=0;j=0;while(1){if((a[g+(h*16428|0)|0]|0)==0){k=j}else{c[1402176+(j<<2)>>2]=h;l=j+1|0;c[155434]=l;k=l}l=h+1|0;if((l|0)<(f|0)){h=l;j=k}else{break}}if((k|0)>0){m=0}else{i=b;return}do{j=k+~m|0;if((j|0)>0){h=0;f=c[350544]|0;while(1){l=h+1|0;n=1402176+(l<<2)|0;o=c[n>>2]|0;if((c[g+(f*16428|0)+36>>2]|0)<(c[g+(o*16428|0)+36>>2]|0)){c[1402176+(h<<2)>>2]=o;c[n>>2]=f;p=f}else{p=o}if((l|0)<(j|0)){h=l;f=p}else{break}}}m=m+1|0;}while((m|0)<(k|0));m=(c[29381]|0)-320>>1;p=m+80|0;if((k|0)<=0){i=b;return}g=e|0;f=m+88|0;h=m+96|0;j=e+1|0;l=m+104|0;o=e+2|0;e=m+72|0;n=m+144|0;m=40;q=0;while(1){r=c[1402176+(q<<2)>>2]|0;s=c[644542]|0;t=s+(r*16428|0)|0;if((a[t]|0)==0){u=m}else{v=d[s+(r*16428|0)+40|0]|0;w=v>>>0<13?v:13;if((w|0)==0){x=8}else{x=w<<4|8}w=d[s+(r*16428|0)+41|0]|0;v=w>>>0<13?w:13;if((v|0)==0){y=8}else{y=v<<4|8}pQ(p,m,40,4,x);pQ(p,m+4|0,40,4,y);v=c[s+(r*16428|0)+36>>2]|0;cl(g|0,36680,(s=i,i=i+8|0,c[s>>2]=v,s)|0)|0;i=s;pF(f,m,a[g]|0);pF(h,m,a[j]|0);pF(l,m,a[o]|0);if((r|0)==((c[644467]|0)-1|0)){pF(e,m,12)}pP(n,m,t);u=m+10|0}t=q+1|0;if((t|0)<(k|0)){m=u;q=t}else{break}}i=b;return}function u5(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0;b=i;i=i+8|0;d=b|0;do{if((c[155622]|0)==0){e=c[155568]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-48|0,e);f=0;break}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-48|0,e);f=0;break}}else{if((c[642261]|0)>4095){e=c[155616]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-48|0,e);f=0;break}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-48|0,e);f=0;break}}else{e=c[155617]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-48|0,e);f=0;break}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-48|0,e);f=0;break}}}}while(0);do{e=1<<f;do{if((c[642266]&e|0)!=0){j=~~((+h[321194]- +g[2569132+(f<<2)>>2])*10.0);k=(j|0)>0?j:0;if((k|0)>9){l=(c[642261]|0)==(e|0)|0}else{l=((k|0)%5|0)+2|0}k=f*24|0;j=c[621768+(l<<5)+(f<<2)>>2]|0;if((c[644469]|0)==1){pS(k,(c[29382]|0)-40|0,j)}else{pS(((c[29381]|0)-320>>1)+k|0,(c[29382]|0)-40|0,j)}if((l|0)<=1){break}c[155498]=0}}while(0);f=f+1|0;}while((f|0)<7);if((c[278834]|0)!=0){f=0;l=0;while(1){e=c[642266]|0;j=c[18720+(f<<2)>>2]|0;k=1<<j;do{if((k&e|0)==0){m=l}else{n=~~((+h[321194]- +g[2569132+(j<<2)>>2])*10.0);if((n|0)>9){o=(c[642261]|0)==(k|0)|0}else{o=((n|0)%5|0)+2|0}do{if((f|0)==2){if((e&65536|0)==0|(o|0)==0){p=l;break}n=c[1114360+(o*20|0)>>2]|0;if((c[644469]|0)==1){pS(96,(c[29382]|0)-40|0,n);p=1;break}else{pS(((c[29381]|0)-320>>1)+96|0,(c[29382]|0)-40|0,n);p=1;break}}else if((f|0)==3){if((e&16|0)==0){n=c[1114368+(o*20|0)>>2]|0;if((c[644469]|0)==1){pS(96,(c[29382]|0)-40|0,n);p=l;break}else{pS(((c[29381]|0)-320>>1)+96|0,(c[29382]|0)-40|0,n);p=l;break}}n=(l|0)==0;if((o|0)!=0&n){q=c[1114364+(o*20|0)>>2]|0;if((c[644469]|0)==1){pS(96,(c[29382]|0)-40|0,q);p=0;break}else{pS(((c[29381]|0)-320>>1)+96|0,(c[29382]|0)-40|0,q);p=0;break}}if(!n){p=l;break}n=c[278591]|0;if((c[644469]|0)==1){pS(96,(c[29382]|0)-40|0,n);p=0;break}else{pS(((c[29381]|0)-320>>1)+96|0,(c[29382]|0)-40|0,n);p=0;break}}else{n=(f*24|0)+176|0;q=c[1114352+(o*20|0)+(f<<2)>>2]|0;if((c[644469]|0)==1){pS(n,(c[29382]|0)-40|0,q);p=l;break}else{pS(((c[29381]|0)-320>>1)+n|0,(c[29382]|0)-40|0,q);p=l;break}}}while(0);if((o|0)<=1){m=p;break}c[155498]=0;m=p}}while(0);e=f+1|0;if((e|0)<4){f=e;l=m}else{break}}}m=c[642261]|0;L7559:do{if((c[155622]|0)!=0&(m|0)>4095){l=0;f=m;while(1){do{if((f|0)==(4096<<l|0)){p=(l*24|0)+48|0;o=c[622424+(l<<2)>>2]|0;if((c[644469]|0)==1){pS(p,(c[29382]|0)-40|0,o);break}else{pS(((c[29381]|0)-320>>1)+p|0,(c[29382]|0)-40|0,o);break}}}while(0);o=l+1|0;if((o|0)>=5){break L7559}l=o;f=c[642261]|0}}}while(0);m=d|0;f=d+1|0;l=d+2|0;d=0;while(1){cl(m|0,36680,(o=i,i=i+8|0,c[o>>2]=c[2569004+(d+6<<2)>>2],o)|0)|0;i=o;o=a[m]|0;do{if(o<<24>>24!=32){p=d*48|0;e=(o<<24>>24)-30|0;if((c[644469]|0)==1){pF(p|10,(c[29382]|0)-48|0,e);break}else{pF(((c[29381]|0)-320>>1)+(p|10)|0,(c[29382]|0)-48|0,e);break}}}while(0);o=a[f]|0;do{if(o<<24>>24!=32){e=d*48|0|14;p=(o<<24>>24)-30|0;if((c[644469]|0)==1){pF(e+4|0,(c[29382]|0)-48|0,p);break}else{pF(e+4+((c[29381]|0)-320>>1)|0,(c[29382]|0)-48|0,p);break}}}while(0);o=a[l]|0;do{if(o<<24>>24!=32){p=d*48|0;e=(o<<24>>24)-30|0;if((c[644469]|0)==1){pF(p+26|0,(c[29382]|0)-48|0,e);break}else{pF(p+26+((c[29381]|0)-320>>1)|0,(c[29382]|0)-48|0,e);break}}}while(0);o=d+1|0;if((o|0)<4){d=o}else{r=0;break}}do{d=r+17|0;do{if((c[642266]&1<<d|0)!=0){s=+g[2569132+(d<<2)>>2];l=s!=0.0;do{if((c[278834]|0)==0|(r|0)>1){f=(r<<4)+192|0;m=c[622144+(r<<2)>>2]|0;if((c[644469]|0)==1){pS(f,(c[29382]|0)-40|0,m);break}else{pS(((c[29381]|0)-320>>1)+f|0,(c[29382]|0)-40|0,m);break}}}while(0);if(!l){break}if(s<=+h[321194]+-2.0){break}c[155498]=0}}while(0);r=r+1|0;}while((r|0)<6);do{if((c[278834]|0)!=0){do{if((c[642266]&16777216|0)!=0){t=+g[642307];r=c[278624]|0;if((c[644469]|0)==1){pS(288,(c[29382]|0)-40|0,r)}else{pS(((c[29381]|0)-320>>1)+288|0,(c[29382]|0)-40|0,r)}if(t==0.0){break}if(t<=+h[321194]+-2.0){break}c[155498]=0}}while(0);if((c[642266]&33554432|0)==0){break}t=+g[642308];r=c[278625]|0;if((c[644469]|0)==1){pS(304,(c[29382]|0)-40|0,r)}else{pS(((c[29381]|0)-320>>1)+304|0,(c[29382]|0)-40|0,r)}if(t==0.0){break}if(t<=+h[321194]+-2.0){break}c[155498]=0}}while(0);if((c[155622]|0)==0){r=0;do{d=r+28|0;do{if((c[642266]&1<<d|0)!=0){t=+g[2569132+(d<<2)>>2];m=(r<<3)+288|0;f=c[622008+(r<<2)>>2]|0;if((c[644469]|0)==1){pS(m,(c[29382]|0)-40|0,f)}else{pS(((c[29381]|0)-320>>1)+m|0,(c[29382]|0)-40|0,f)}if(t==0.0){break}if(t<=+h[321194]+-2.0){break}c[155498]=0}}while(0);r=r+1|0;}while((r|0)<4);i=b;return}do{if((c[642266]&536870912|0)!=0){t=+g[642312];r=c[155614]|0;if((c[644469]|0)==1){pS(288,(c[29382]|0)-40|0,r)}else{pS(((c[29381]|0)-320>>1)+288|0,(c[29382]|0)-40|0,r)}if(t==0.0){break}if(t<=+h[321194]+-2.0){break}c[155498]=0}}while(0);if((c[642266]&1073741824|0)==0){i=b;return}t=+g[642313];r=c[155615]|0;if((c[644469]|0)==1){pS(304,(c[29382]|0)-40|0,r)}else{pS(((c[29381]|0)-320>>1)+304|0,(c[29382]|0)-40|0,r)}if(t==0.0){i=b;return}if(t<=+h[321194]+-2.0){i=b;return}c[155498]=0;i=b;return}function u6(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+16|0;e=b|0;c[155434]=0;f=c[644468]|0;do{if((f|0)>0){g=c[644542]|0;h=0;j=0;while(1){if((a[g+(h*16428|0)|0]|0)==0){k=j}else{c[1402176+(j<<2)>>2]=h;l=j+1|0;c[155434]=l;k=l}l=h+1|0;if((l|0)<(f|0)){h=l;j=k}else{break}}if((k|0)>0){m=0}else{n=k;break}while(1){j=k+~m|0;if((j|0)>0){h=0;l=c[350544]|0;while(1){o=h+1|0;p=1402176+(o<<2)|0;q=c[p>>2]|0;if((c[g+(l*16428|0)+36>>2]|0)<(c[g+(q*16428|0)+36>>2]|0)){c[1402176+(h<<2)>>2]=q;c[p>>2]=l;r=l}else{r=q}if((o|0)<(j|0)){h=o;l=r}else{break}}}l=m+1|0;if((l|0)<(k|0)){m=l}else{n=k;break}}}else{n=0}}while(0);k=(n|0)>4?4:n;if((c[644469]|0)==1){s=10}else{s=((c[29381]|0)-320>>1)+10|0}n=c[29382]|0;m=n-47|0;if((k|0)<=0){i=b;return}r=n-43|0;n=e|0;f=e+1|0;g=e+2|0;e=23;l=0;while(1){h=c[1402176+(l<<2)>>2]|0;j=c[644542]|0;if((a[j+(h*16428|0)|0]|0)==0){t=e}else{o=d[j+(h*16428|0)+40|0]|0;q=o>>>0<13?o:13;if((q|0)==0){u=8}else{u=q<<4|8}q=d[j+(h*16428|0)+41|0]|0;o=q>>>0<13?q:13;if((o|0)==0){v=8}else{v=o<<4|8}o=e<<3;q=s+o|0;pQ(q,m,28,4,u);pQ(q,r,28,3,v);q=c[j+(h*16428|0)+36>>2]|0;cl(n|0,36680,(j=i,i=i+8|0,c[j>>2]=q,j)|0)|0;i=j;j=a[n]|0;if((c[644469]|0)==1){pF(o+12|0,(c[29382]|0)-48|0,j)}else{pF(o+12+((c[29381]|0)-320>>1)|0,(c[29382]|0)-48|0,j)}j=a[f]|0;if((c[644469]|0)==1){pF(o+20|0,(c[29382]|0)-48|0,j)}else{pF(o+20+((c[29381]|0)-320>>1)|0,(c[29382]|0)-48|0,j)}j=a[g]|0;if((c[644469]|0)==1){pF(o+28|0,(c[29382]|0)-48|0,j)}else{pF(o+28+((c[29381]|0)-320>>1)|0,(c[29382]|0)-48|0,j)}do{if((h|0)==((c[644467]|0)-1|0)){if((c[644469]|0)==1){pF(o|6,(c[29382]|0)-48|0,16)}else{pF(((c[29381]|0)-320>>1)+(o|6)|0,(c[29382]|0)-48|0,16)}if((c[644469]|0)==1){pF(o+32|0,(c[29382]|0)-48|0,17);break}else{pF(o+32+((c[29381]|0)-320>>1)|0,(c[29382]|0)-48|0,17);break}}}while(0);t=e+4|0}o=l+1|0;if((o|0)<(k|0)){e=t;l=o}else{break}}i=b;return}function u7(){var b=0,e=0,f=0.0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+16|0;e=b|0;f=+g[478];if(!((c[155622]|0)!=0&(c[644468]|0)!=1&f>3.0&f<7.0)){j=c[642266]|0;if((j&1572864|0)==1572864){k=c[155588]|0;if((c[644469]|0)==1){pS(112,(c[29382]|0)-24|0,k);i=b;return}else{pS(((c[29381]|0)-320>>1)+112|0,(c[29382]|0)-24|0,k);i=b;return}}if((j&4194304|0)!=0){k=c[155584]|0;if((c[644469]|0)==1){pS(112,(c[29382]|0)-24|0,k);i=b;return}else{pS(((c[29381]|0)-320>>1)+112|0,(c[29382]|0)-24|0,k);i=b;return}}if((j&524288|0)!=0){k=c[155590]|0;if((c[644469]|0)==1){pS(112,(c[29382]|0)-24|0,k);i=b;return}else{pS(((c[29381]|0)-320>>1)+112|0,(c[29382]|0)-24|0,k);i=b;return}}if((j&1048576|0)!=0){j=c[155586]|0;if((c[644469]|0)==1){pS(112,(c[29382]|0)-24|0,j);i=b;return}else{pS(((c[29381]|0)-320>>1)+112|0,(c[29382]|0)-24|0,j);i=b;return}}j=c[642251]|0;if((j|0)>99){l=4}else{l=(j|0)/20|0}if(+h[321194]>+g[642315]){m=0}else{c[155498]=0;m=1}j=c[622280+(l<<3)+(m<<2)>>2]|0;if((c[644469]|0)==1){pS(112,(c[29382]|0)-24|0,j);i=b;return}else{pS(((c[29381]|0)-320>>1)+112|0,(c[29382]|0)-24|0,j);i=b;return}}j=(c[644467]|0)-1|0;m=c[644542]|0;l=d[m+(j*16428|0)+40|0]|0;k=l>>>0<13?l:13;if((k|0)==0){n=8}else{n=k<<4|8}k=d[m+(j*16428|0)+41|0]|0;l=k>>>0<13?k:13;if((l|0)==0){o=8}else{o=l<<4|8}if((c[644469]|0)==1){pS(112,(c[29382]|0)-24|0,c[155612]|0);p=113}else{l=(c[29381]|0)-320>>1;pS(l+112|0,(c[29382]|0)-24|0,c[155612]|0);p=l+113|0}pQ(p,(c[29382]|0)-21|0,22,9,n);pQ(p,(c[29382]|0)-12|0,22,9,o);o=e|0;cl(o|0,36680,(p=i,i=i+8|0,c[p>>2]=c[m+(j*16428|0)+36>>2],p)|0)|0;i=p;p=a[o]|0;o=p<<24>>24;if((n|0)!=8){if((c[644469]|0)==1){pF(113,(c[29382]|0)-21|0,o)}else{pF(((c[29381]|0)-320>>1)+113|0,(c[29382]|0)-21|0,o)}n=a[e+1|0]|0;if((c[644469]|0)==1){pF(120,(c[29382]|0)-21|0,n)}else{pF(((c[29381]|0)-320>>1)+120|0,(c[29382]|0)-21|0,n)}n=a[e+2|0]|0;if((c[644469]|0)==1){pF(127,(c[29382]|0)-21|0,n);i=b;return}else{pF(((c[29381]|0)-320>>1)+127|0,(c[29382]|0)-21|0,n);i=b;return}}do{if(p<<24>>24!=32){n=o-30|0;if((c[644469]|0)==1){pF(113,(c[29382]|0)-21|0,n);break}else{pF(((c[29381]|0)-320>>1)+113|0,(c[29382]|0)-21|0,n);break}}}while(0);o=a[e+1|0]|0;do{if(o<<24>>24!=32){p=(o<<24>>24)-30|0;if((c[644469]|0)==1){pF(120,(c[29382]|0)-21|0,p);break}else{pF(((c[29381]|0)-320>>1)+120|0,(c[29382]|0)-21|0,p);break}}}while(0);o=a[e+2|0]|0;if(o<<24>>24==32){i=b;return}e=(o<<24>>24)-30|0;if((c[644469]|0)==1){pF(127,(c[29382]|0)-21|0,e);i=b;return}else{pF(((c[29381]|0)-320>>1)+127|0,(c[29382]|0)-21|0,e);i=b;return}}function u8(){var a=0,b=0,d=0,e=0;a=c[29382]|0;if(+g[1180]==+(a|0)){return}b=c[155498]|0;if((b|0)>=(c[29384]|0)){return}c[155172]=1;c[155498]=b+1;b=c[155534]|0;d=c[29381]|0;if((b|0)!=0&(d|0)>320){pW(0,a-b|0,d,b);e=c[155534]|0}else{e=b}do{if((e|0)>24){u5();if((c[644468]|0)==1){break}u6()}}while(0);do{if((c[155506]|0)!=0|(c[642251]|0)<1){e=c[155508]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-24|0,e)}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-24|0,e)}u3();if((c[644469]|0)==1){u4()}c[155498]=0}else{if((c[155534]|0)==0){break}e=c[155510]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-24|0,e)}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-24|0,e)}do{if((c[278834]|0)!=0){do{if((c[642266]&131072|0)!=0){e=c[155536]|0;if((c[644469]|0)==1){pS(209,(c[29382]|0)-21|0,e);break}else{pS(((c[29381]|0)-320>>1)+209|0,(c[29382]|0)-21|0,e);break}}}while(0);if((c[642266]&262144|0)==0){break}e=c[155537]|0;if((c[644469]|0)==1){pS(209,(c[29382]|0)-12|0,e);break}else{pS(((c[29381]|0)-320>>1)+209|0,(c[29382]|0)-12|0,e);break}}}while(0);do{if((c[642266]&1048576|0)==0){e=(c[155622]|0)==0;b=c[642255]|0;u2(24,0,b,3,(b|0)<26|0);b=c[642266]|0;if(e){if((b&32768|0)!=0){e=c[155596]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-24|0,e);break}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-24|0,e);break}}if((b&16384|0)!=0){e=c[155595]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-24|0,e);break}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-24|0,e);break}}if((b&8192|0)==0){break}e=c[155594]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-24|0,e);break}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-24|0,e);break}}else{if((b&33554432|0)!=0){e=c[155596]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-24|0,e);break}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-24|0,e);break}}if((b&16777216|0)!=0){e=c[155595]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-24|0,e);break}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-24|0,e);break}}if((b&8388608|0)==0){break}b=c[155594]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-24|0,b);break}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-24|0,b);break}}}else{u2(24,0,666,3,1);b=c[350710]|0;if((c[644469]|0)==1){pS(0,(c[29382]|0)-24|0,b);break}else{pS((c[29381]|0)-320>>1,(c[29382]|0)-24|0,b);break}}}while(0);u7();b=c[642251]|0;u2(136,0,b,3,(b|0)<26|0);b=c[642266]|0;do{if((c[155622]|0)==0){if((b&256|0)!=0){e=c[155598]|0;if((c[644469]|0)==1){pS(224,(c[29382]|0)-24|0,e);break}else{pS(((c[29381]|0)-320>>1)+224|0,(c[29382]|0)-24|0,e);break}}if((b&512|0)!=0){e=c[155599]|0;if((c[644469]|0)==1){pS(224,(c[29382]|0)-24|0,e);break}else{pS(((c[29381]|0)-320>>1)+224|0,(c[29382]|0)-24|0,e);break}}if((b&1024|0)!=0){e=c[155600]|0;if((c[644469]|0)==1){pS(224,(c[29382]|0)-24|0,e);break}else{pS(((c[29381]|0)-320>>1)+224|0,(c[29382]|0)-24|0,e);break}}if((b&2048|0)==0){break}e=c[155601]|0;if((c[644469]|0)==1){pS(224,(c[29382]|0)-24|0,e);break}else{pS(((c[29381]|0)-320>>1)+224|0,(c[29382]|0)-24|0,e);break}}else{if((b&128|0)!=0){e=c[155598]|0;if((c[644469]|0)==1){pS(224,(c[29382]|0)-24|0,e);break}else{pS(((c[29381]|0)-320>>1)+224|0,(c[29382]|0)-24|0,e);break}}if((b&256|0)!=0){e=c[155599]|0;if((c[644469]|0)==1){pS(224,(c[29382]|0)-24|0,e);break}else{pS(((c[29381]|0)-320>>1)+224|0,(c[29382]|0)-24|0,e);break}}if((b&512|0)!=0){e=c[155600]|0;if((c[644469]|0)==1){pS(224,(c[29382]|0)-24|0,e);break}else{pS(((c[29381]|0)-320>>1)+224|0,(c[29382]|0)-24|0,e);break}}if((b&1024|0)!=0){e=c[155601]|0;if((c[644469]|0)==1){pS(224,(c[29382]|0)-24|0,e);break}else{pS(((c[29381]|0)-320>>1)+224|0,(c[29382]|0)-24|0,e);break}}if((b&67108864|0)!=0){e=c[155618]|0;if((c[644469]|0)==1){pS(224,(c[29382]|0)-24|0,e);break}else{pS(((c[29381]|0)-320>>1)+224|0,(c[29382]|0)-24|0,e);break}}if((b&134217728|0)!=0){e=c[155619]|0;if((c[644469]|0)==1){pS(224,(c[29382]|0)-24|0,e);break}else{pS(((c[29381]|0)-320>>1)+224|0,(c[29382]|0)-24|0,e);break}}if((b&268435456|0)==0){break}e=c[155620]|0;if((c[644469]|0)==1){pS(224,(c[29382]|0)-24|0,e);break}else{pS(((c[29381]|0)-320>>1)+224|0,(c[29382]|0)-24|0,e);break}}}while(0);b=c[642254]|0;u2(248,0,b,3,(b|0)<11|0)}}while(0);if(!((c[29381]|0)>320&(c[644469]|0)==1)){return}u9();return}function u9(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+16|0;e=b|0;f=c[155534]|0;if(!((c[29381]|0)>511&(f|0)!=0)){i=b;return}c[155172]=1;c[155162]=0;c[155434]=0;g=c[644468]|0;do{if((g|0)>0){h=c[644542]|0;j=0;k=0;while(1){if((a[h+(j*16428|0)|0]|0)==0){l=k}else{c[1402176+(k<<2)>>2]=j;m=k+1|0;c[155434]=m;l=m}m=j+1|0;if((m|0)<(g|0)){j=m;k=l}else{break}}if((l|0)>0){n=0}else{o=l;break}while(1){k=l+~n|0;if((k|0)>0){j=0;m=c[350544]|0;while(1){p=j+1|0;q=1402176+(p<<2)|0;r=c[q>>2]|0;if((c[h+(m*16428|0)+36>>2]|0)<(c[h+(r*16428|0)+36>>2]|0)){c[1402176+(j<<2)>>2]=r;c[q>>2]=m;s=m}else{s=r}if((p|0)<(k|0)){j=p;m=s}else{break}}}m=n+1|0;if((m|0)<(l|0)){n=m}else{o=l;break}}}else{o=0}}while(0);l=c[29382]|0;n=l-f|0;s=(f|0)/8|0;if((f|0)<24){i=b;return}g=(c[644467]|0)-1|0;h=0;while(1){if((h|0)>=(o|0)){break}if((c[1402176+(h<<2)>>2]|0)==(g|0)){break}else{h=h+1|0}}if((h|0)==(o|0)){t=0}else{t=h-((f|0)/16|0)|0}f=o-s|0;s=(t|0)>(f|0)?f:t;t=(s|0)<0?0:s;if((t|0)>=(o|0)){i=b;return}s=e|0;f=e+1|0;h=e+2|0;e=n;n=t;t=o;o=l;while(1){if((e|0)>=(o-8|0)){u=6001;break}l=c[1402176+(n<<2)>>2]|0;g=c[644542]|0;m=g+(l*16428|0)|0;if((a[m]|0)==0){v=e;w=t}else{j=d[g+(l*16428|0)+40|0]|0;k=j>>>0<13?j:13;if((k|0)==0){x=8}else{x=k<<4|8}k=d[g+(l*16428|0)+41|0]|0;j=k>>>0<13?k:13;if((j|0)==0){y=8}else{y=j<<4|8}pQ(324,e+1|0,40,3,x);pQ(324,e+4|0,40,4,y);j=c[g+(l*16428|0)+36>>2]|0;cl(s|0,36680,(g=i,i=i+8|0,c[g>>2]=j,g)|0)|0;i=g;pF(332,e,a[s]|0);pF(340,e,a[f]|0);pF(348,e,a[h]|0);if((l|0)==((c[644467]|0)-1|0)){pF(324,e,16);pF(356,e,17)}pP(372,e,m);v=e+8|0;w=c[155434]|0}m=n+1|0;if((m|0)>=(w|0)){u=6002;break}e=v;n=m;t=w;o=c[29382]|0}if((u|0)==6002){i=b;return}else if((u|0)==6001){i=b;return}}function va(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0;b=i;i=i+16|0;d=b|0;c[155172]=1;c[155162]=0;if((c[644469]|0)==1){u4();i=b;return}pS(64,24,pN(36176)|0);pT(0,56,pN(109080)|0);e=c[642382]|0;f=(e|0)/60|0;g=d|0;if((e|0)<-59){a[g]=45;h=-f|0;j=d+1|0}else{h=f;j=g}if((h|0)<10){k=h;l=10;m=j}else{e=10;while(1){n=e*10|0;if((h|0)<(n|0)){k=h;l=n;m=j;break}else{e=n}}}while(1){e=(l|0)/10|0;j=(k|0)/(e|0)|0;o=m+1|0;a[m]=j+48&255;h=k-(ab(j,e)|0)|0;if((l-10|0)>>>0>9){k=h;l=e;m=o}else{break}}a[o]=0;m=d;l=o-m|0;if((l|0)>3){p=d+(l-3)|0}else{p=g}if((l|0)<3){q=((3-l|0)*24|0)+160|0;r=p}else{q=160;r=p}while(1){p=a[r]|0;if((p<<24>>24|0)==45){s=10}else if((p<<24>>24|0)==0){break}else{s=(p<<24>>24)-48|0}pT(q,64,c[622048+(s<<2)>>2]|0);q=q+24|0;r=r+1|0}r=(c[642382]|0)+(f*-60|0)|0;pT(234,64,c[155592]|0);pT(246,64,c[622048+(((r|0)/10|0)<<2)>>2]|0);pT(266,64,c[622048+(((r|0)%10|0)<<2)>>2]|0);r=c[642264]|0;if((r|0)<0){a[g]=45;t=-r|0;u=d+1|0}else{t=r;u=g}if((t|0)<10){v=t;w=10;x=u}else{r=10;while(1){f=r*10|0;if((t|0)<(f|0)){v=t;w=f;x=u;break}else{r=f}}}while(1){r=(w|0)/10|0;u=(v|0)/(r|0)|0;y=x+1|0;a[x]=u+48&255;t=v-(ab(u,r)|0)|0;if((w-10|0)>>>0>9){v=t;w=r;x=y}else{break}}a[y]=0;x=y-m|0;if((x|0)>3){z=d+(x-3)|0}else{z=g}if((x|0)<3){A=((3-x|0)*24|0)+160|0;B=z}else{A=160;B=z}while(1){z=a[B]|0;if((z<<24>>24|0)==0){break}else if((z<<24>>24|0)==45){C=10}else{C=(z<<24>>24)-48|0}pT(A,104,c[622048+(C<<2)>>2]|0);A=A+24|0;B=B+1|0}pT(232,104,c[155500]|0);B=c[642262]|0;if((B|0)<0){a[g]=45;D=-B|0;E=d+1|0}else{D=B;E=g}if((D|0)<10){F=D;G=10;H=E}else{B=10;while(1){A=B*10|0;if((D|0)<(A|0)){F=D;G=A;H=E;break}else{B=A}}}while(1){B=(G|0)/10|0;E=(F|0)/(B|0)|0;I=H+1|0;a[H]=E+48&255;D=F-(ab(E,B)|0)|0;if((G-10|0)>>>0>9){F=D;G=B;H=I}else{break}}a[I]=0;H=I-m|0;if((H|0)>3){J=d+(H-3)|0}else{J=g}if((H|0)<3){K=((3-H|0)*24|0)+240|0;L=J}else{K=240;L=J}while(1){J=a[L]|0;if((J<<24>>24|0)==45){M=10}else if((J<<24>>24|0)==0){break}else{M=(J<<24>>24)-48|0}pT(K,104,c[622048+(M<<2)>>2]|0);K=K+24|0;L=L+1|0}L=c[642265]|0;if((L|0)<0){a[g]=45;N=-L|0;O=d+1|0}else{N=L;O=g}if((N|0)<10){P=N;Q=10;R=O}else{L=10;while(1){K=L*10|0;if((N|0)<(K|0)){P=N;Q=K;R=O;break}else{L=K}}}while(1){L=(Q|0)/10|0;O=(P|0)/(L|0)|0;S=R+1|0;a[R]=O+48&255;N=P-(ab(O,L)|0)|0;if((Q-10|0)>>>0>9){P=N;Q=L;R=S}else{break}}a[S]=0;R=S-m|0;if((R|0)>3){T=d+(R-3)|0}else{T=g}if((R|0)<3){U=((3-R|0)*24|0)+160|0;V=T}else{U=160;V=T}while(1){T=a[V]|0;if((T<<24>>24|0)==45){W=10}else if((T<<24>>24|0)==0){break}else{W=(T<<24>>24)-48|0}pT(U,144,c[622048+(W<<2)>>2]|0);U=U+24|0;V=V+1|0}pT(232,144,c[155500]|0);V=c[642263]|0;if((V|0)<0){a[g]=45;X=-V|0;Y=d+1|0}else{X=V;Y=g}if((X|0)<10){Z=X;_=10;$=Y}else{V=10;while(1){U=V*10|0;if((X|0)<(U|0)){Z=X;_=U;$=Y;break}else{V=U}}}while(1){V=(_|0)/10|0;Y=(Z|0)/(V|0)|0;aa=$+1|0;a[$]=Y+48&255;X=Z-(ab(Y,V)|0)|0;if((_-10|0)>>>0>9){Z=X;_=V;$=aa}else{break}}a[aa]=0;$=aa-m|0;if(($|0)>3){ac=d+($-3)|0}else{ac=g}if(($|0)<3){ad=((3-$|0)*24|0)+240|0;ae=ac}else{ad=240;ae=ac}while(1){ac=a[ae]|0;if((ac<<24>>24|0)==0){break}else if((ac<<24>>24|0)==45){af=10}else{af=(ac<<24>>24)-48|0}pT(ad,144,c[622048+(af<<2)>>2]|0);ad=ad+24|0;ae=ae+1|0}i=b;return}function vb(){var a=0;c[155172]=1;a=pN(108728)|0;pT(((c[29381]|0)-(c[a>>2]|0)|0)/2|0,16,a);return}function vc(b){b=b|0;var d=0,e=0,f=0,i=0;yP(620696|0,b|0,1024)|0;a[621719|0]=0;g[1184]=+g[1190];g[1182]=+h[321194];c[155430]=1;d=b;b=1;while(1){e=a[d]|0;if((e<<24>>24|0)==10){f=b+1|0;c[155430]=f;i=f}else if((e<<24>>24|0)==0){break}else{i=b}d=d+1|0;b=i}return}function vd(){var b=0,d=0,e=0,f=0.0,j=0,k=0.0,l=0.0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+24|0;d=b|0;if((c[155432]|0)!=0){i=b;return}do{if((c[155168]|0)!=0){if(+h[1153]- +g[1162]>5.0){c[155168]=0;oW(60144,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e;break}else{i=b;return}}}while(0);if((c[353150]|0)==0){i=b;return}if(!(a[4568]&(c[352654]|0)!=0)){i=b;return}c[155170]=0;c[155172]=0;f=+g[1148];if(+g[28068]!=f){g[28068]=f;c[29385]=1}f=+g[1034];if(+g[28066]!=f){g[28066]=f;c[29385]=1;j=6085}else{if((c[29385]|0)!=0){j=6085}}if((j|0)==6085){c[155162]=0;c[29385]=0;u_();f=+g[1034];if(f<30.0){o9(91104,74856);k=+g[1034]}else{k=f}if(k>120.0){o9(91104,73944)}k=+g[1148];if(k<10.0){o9(83384,72896);l=+g[1148]}else{l=k}if(l>170.0){o9(83384,72016)}l=(c[642381]|0)==0?+g[1034]:120.0;do{if(l<120.0){if(l<110.0){c[155534]=48;m=48;break}else{c[155534]=24;m=24;break}}else{c[155534]=0;m=0}}while(0);c[d>>2]=0;c[d+4>>2]=0;c[d+8>>2]=c[29381];c[d+12>>2]=c[29382];uj(d,620592,m);l=+g[1148];g[157358]=l;k=+(c[157326]|0);f=+(c[157327]|0);if(l<1.0|l>179.0){w1(70712,(e=i,i=i+8|0,h[e>>3]=l,e)|0);i=e}g[157359]=+Y(+(f/(k/+V(+(l/360.0*3.141592653589793)))))*360.0/3.141592653589793;l=+(c[29382]|0);if(+g[1180]>l){g[1180]=l}us(d,c[155534]|0,+g[29383])}d=c[155162]|0;c[155162]=d+1;if((d|0)<(c[29384]|0)){c[155172]=1;pW(0,0,c[29381]|0,c[29382]|0);u_()}oU();do{if(!(a[4632]|0)){do{if((c[644470]|0)==0){c[352656]=1;j=6109}else{d=(c[353150]|0)!=4;c[352656]=d&1;if(d){j=6109;break}if((c[278172]|0)==1){l=+((c[29382]|0)/2|0|0);g[1178]=l;n=l;break}else{g[1178]=0.0;n=0.0;break}}}while(0);if((j|0)==6109){l=+(c[29382]|0);g[1178]=l;g[1180]=l;n=l}l=+g[1180];do{if(n<l){k=l- +g[1168]*+h[2332];g[1180]=k;if(n<=k){break}g[1180]=n}else{if(n<=l){break}k=l+ +g[1168]*+h[2332];g[1180]=k;if(n>=k){break}g[1180]=n}}while(0);d=c[353914]|0;c[353914]=d+1;e=c[29384]|0;if((d|0)<(e|0)){u_();break}d=c[353912]|0;c[353912]=d+1;if((d|0)<(e|0)){c[155170]=1;pW(0,0,c[29381]|0,c[352646]|0);break}else{c[352646]=0;break}}}while(0);e=c[155166]|0;c[155166]=e+1;if((e|0)>(c[29384]|0)){c[155164]=0}else{e=c[29382]|0;if((c[155430]|0)<5){o=~~(+(e|0)*.35)}else{o=48}d=c[155164]<<3;m=e-o-1|0;c[155170]=1;pW(0,o,c[29381]|0,(d|0)<(m|0)?d:m)}xU();do{if(a[4640]|0){u8();pZ();m=~~(+(c[29382]|0)*.35);d=c[155158]|0;while(1){o=0;while(1){e=a[d+o|0]|0;if((e<<24>>24|0)==10|(e<<24>>24|0)==0){j=6134;break}e=o+1|0;if((e|0)<40){o=e}else{p=e;j=6135;break}}if((j|0)==6134){j=0;if((o|0)>0){p=o;j=6135}else{q=d}}if((j|0)==6135){j=0;e=0;r=((c[29381]|0)-(p<<3)|0)/2|0;while(1){pF(r,m,a[d+e|0]|0);s=e+1|0;if((s|0)<(p|0)){e=s;r=r+8|0}else{q=d;break}}}do{r=a[q]|0;t=r<<24>>24==0;q=q+1|0}while(r<<24>>24!=10&(t^1));if(t){break}else{m=m+8|0;d=q}}c[155172]=1}else{if(a[4632]|0){d=pN(76104)|0;pS(((c[29381]|0)-(c[d>>2]|0)|0)/2|0,((c[29382]|0)-48-(c[d+4>>2]|0)|0)/2|0,d);u8();break}d=c[642381]|0;m=(c[278172]|0)==0;if((d|0)==1&m){va();break}if((d|0)==2&m){vb();vg();break}if((d|0)==3&m){vg();break}if(!(+h[1153]- +g[642392]<.3|(c[353697]|0)!=0)){pS((c[155148]|0)+64|0,c[155149]|0,c[155160]|0)}vg();u8();n=+g[1180];do{if(n!=0.0){c[155172]=1;o_(~~n);c[353914]=0}else{m=c[278172]|0;if(!((m|0)==2|(m|0)==0)){break}oZ()}}while(0);rt()}}while(0);xP();i=b;return}function ve(){vF(1);if((c[353150]|0)!=4){return}oS();g[1184]=0.0;g[1180]=0.0;a[4632]=1;c[155162]=0;u_();vd();a[4632]=0;c[155168]=1;g[1162]=+h[1153];c[155162]=0;return}function vf(){c[155168]=0;c[155162]=0;oS();return}function vg(){var b=0,d=0.0,e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[155170]=1;b=c[155430]|0;if((b|0)>(c[155164]|0)){c[155164]=b}d=+g[1184]- +h[2332];g[1184]=d;e=(c[642381]|0)!=0;if((c[278172]|0)!=0|(d>0.0|e)^1){return}if(e){f=~~(+g[1090]*(+h[321194]- +g[1182]))}else{f=9999}c[155166]=0;if((b|0)<5){i=f;j=~~(+(c[29382]|0)*.35);k=620696}else{i=f;j=48;k=620696}L8280:while(1){f=0;while(1){b=a[k+f|0]|0;if((b<<24>>24|0)==10|(b<<24>>24|0)==0){l=6178;break}b=f+1|0;if((b|0)<40){f=b}else{m=b;l=6179;break}}if((l|0)==6178){l=0;if((f|0)>0){m=f;l=6179}else{n=i}}if((l|0)==6179){l=0;b=0;e=((c[29381]|0)-(m<<3)|0)/2|0;o=i;while(1){pF(e,j,a[k+b|0]|0);if((o|0)==0){l=6187;break L8280}p=o-1|0;q=b+1|0;if((q|0)<(m|0)){b=q;e=e+8|0;o=p}else{n=p;break}}}o=k;do{e=a[o]|0;r=e<<24>>24==0;o=o+1|0}while(e<<24>>24!=10&(r^1));if(r){l=6186;break}else{i=n;j=j+8|0;k=o}}if((l|0)==6186){return}else if((l|0)==6187){return}}function vh(){pb(4576);pb(4120);pb(4656);pb(4232);pb(4176);pb(4288);pb(4744);pb(4344);pb(3656);oE(54432,288);oE(50144,134);oE(46256,168);c[155156]=pM(41952)|0;c[155160]=pM(38280)|0;c[155154]=pM(108232)|0;a[4568]=1;return}function vi(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+208|0;e=d|0;f=d+80|0;g=e|0;yJ(g|0,104976,12)|0;h=e+5|0;j=e+6|0;e=f|0;f=0;while(1){if((f|0)>=100){break}a[h]=((f|0)/10|0)+48&255;a[j]=((f|0)%10|0)+48&255;cl(e|0,101968,(k=i,i=i+16|0,c[k>>2]=1411672,c[k+8>>2]=g,k)|0)|0;i=k;if((wX(e)|0)==-1){break}else{f=f+1|0}}if((f|0)==100){oW(99672,(k=i,i=i+8|0,c[k>>2]=109936,k)|0);i=k;i=d;return}pl();f=c[29376]|0;e=c[29381]|0;j=c[29382]|0;h=c[29380]|0;l=c[278818]|0;m=x7((ab(e<<1,j)|0)+1e3|0)|0;if((m|0)==0){oW(95832,(k=i,i=i+1|0,i=i+7>>3<<3,c[k>>2]=0,k)|0);i=k}else{a[m]=10;a[m+1|0]=5;a[m+2|0]=1;a[m+3|0]=8;b[m+4>>1]=0;b[m+6>>1]=0;b[m+8>>1]=e+65535&65535;b[m+10>>1]=j+65535&65535;n=e&65535;b[m+12>>1]=n;b[m+14>>1]=j&65535;yG(m+16|0,0,48);a[m+65|0]=1;b[m+66>>1]=n;b[m+68>>1]=1;yG(m+70|0,0,58);n=m+128|0;if((j|0)>0&(e|0)>0){o=0;p=f;f=n;while(1){q=0;r=p;s=f;while(1){t=a[r]|0;u=s+1|0;if((t&-64)<<24>>24==-64){a[s]=-63;a[u]=a[r]|0;v=s+2|0}else{a[s]=t;v=u}u=q+1|0;if((u|0)<(e|0)){q=u;r=r+1|0;s=v}else{break}}s=o+1|0;if((s|0)<(j|0)){o=s;p=p+h|0;f=v}else{w=v;break}}}else{w=n}a[w]=12;n=0;v=l;l=w;while(1){f=l+1|0;a[f]=a[v]|0;h=n+1|0;if((h|0)<768){n=h;v=v+1|0;l=f}else{break}}oi(g,m,w+769-m|0)}pm();oW(98064,(k=i,i=i+8|0,c[k>>2]=g,k)|0);i=k;i=d;return}function vj(){pa(91104,+g[1034]+10.0);c[29385]=1;return}function vk(){pa(91104,+g[1034]+-10.0);c[29385]=1;return}function vl(){c[145616]=x7(2048)|0;c[145614]=2048;c[145610]=0;return}function vm(a){a=a|0;var b=0,d=0;b=c[(c[a>>2]|0)+12>>2]|0;if((b|0)==0){d=0}else{d=b-16+12|0}c[a>>2]=d;return}function vn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a+12|0;e=d|0;f=c[e>>2]|0;g=b|0;L8336:do{if((f|0)==0){h=0;i=e}else{j=c[g>>2]|0;k=f;while(1){l=yM(j|0,c[k-16+12>>2]|0)|0;if((l|0)<0){m=k+12|0}else{if((l|0)<=0){n=0;break}m=k+8|0}l=c[m>>2]|0;if((l|0)==0){h=k;i=m;break L8336}else{k=l}}return n|0}}while(0);m=a|0;c[m>>2]=(c[m>>2]|0)+1;m=yF(c[g>>2]|0)|0;g=a+4|0;if(m>>>0>(c[g>>2]|0)>>>0){c[g>>2]=m}g=a+8|0;if(m>>>0<(c[g>>2]|0)>>>0){c[g>>2]=m}m=b+4|0;c[m>>2]=h;c[b+8>>2]=0;c[b+12>>2]=0;c[b+16>>2]=0;c[i>>2]=m;u0(m,d);n=1;return n|0}function vo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[145614]|0;do{if(e>>>0<20){f=x8(2048)|0;g=f;c[145616]=g;h=(f|0)!=0;f=h?2048:0;c[145614]=f;if(h){i=f;j=g;break}else{k=0}return k|0}else{i=e;j=c[145616]|0}}while(0);c[145616]=j+20;c[145614]=i-20;if((j|0)==0){k=0;return k|0}do{if((d|0)==0){c[j>>2]=b}else{i=(yF(b|0)|0)+1|0;e=c[145610]|0;if(e>>>0<i>>>0){g=x8(4096)|0;c[145612]=g;f=(g|0)!=0?4096:0;c[145610]=f;l=f}else{l=e}if(l>>>0<i>>>0){break}e=c[145612]|0;c[145612]=e+i;c[145610]=l-i;if((e|0)==0){break}yQ(e|0,b|0)|0;c[j>>2]=e}}while(0);k=vn(a,j)|0;return k|0}function vp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[b+8>>2]|0;f=yF(d|0)|0;d=c[b+12>>2]|0;g=d-16+12|0;h=c[b>>2]|0;if((h|0)==1){b=yF(c[g>>2]|0)|0;i=xZ(b+2|0)|0;if((i|0)==0){j=0;return j|0}k=c[g>>2]|0;yP(i|0,k|0,b|0)|0;a[i+b|0]=32;a[i+(b+1)|0]=0;j=i;return j|0}if(h>>>0<=1){j=0;return j|0}h=vq(d,c[g>>2]|0,f,e)|0;e=xZ(h+1|0)|0;if((e|0)==0){j=0;return j|0}yP(e|0,c[g>>2]|0,h|0)|0;a[e+h|0]=0;j=e;return j|0}function vq(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((a|0)==0){f=e;return f|0}else{g=a;h=e}while(1){e=g-16+12|0;a=vq(c[g+12>>2]|0,b,d,h)|0;while(1){if((a|0)<=(d|0)){break}if((yL(b|0,c[e>>2]|0,a|0)|0)==0){break}else{a=a-1|0}}e=c[g+8>>2]|0;if((e|0)==0){f=a;break}else{g=e;h=a}}return f|0}function vr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=c[a+12>>2]|0;if((d|0)==0){e=0;return e|0}else{f=d}while(1){g=f-16+12|0;d=yM(b|0,c[g>>2]|0)|0;if((d|0)<0){h=f+12|0}else{if((d|0)<=0){break}h=f+8|0}d=c[h>>2]|0;if((d|0)==0){e=0;i=6276;break}else{f=d}}if((i|0)==6276){return e|0}e=g;return e|0}function vs(a,b){a=a|0;b=b|0;var d=0,e=0;vt(a);d=c[a+12>>2]|0;if((d|0)==0){e=0}else{e=d-16+12|0}c[b>>2]=e;return}function vt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=xZ(12)|0;e=d;f=a+16|0;c[f>>2]=e;do{if((d|0)==0){g=e;h=6286}else{c[d+4>>2]=0;j=a|0;k=q3((c[j>>2]|0)+1|0)|0;c[d+8>>2]=k<<1;l=xZ(k<<3)|0;c[d>>2]=l;if((l|0)==0){xY(d);c[f>>2]=0;m=j;break}else{g=c[f>>2]|0;h=6286;break}}}while(0);do{if((h|0)==6286){if((g|0)==0){m=a|0;break}else{i=b;return}}}while(0);a=(q3((c[m>>2]|0)+1|0)|0)<<1;w1(89592,(m=i,i=i+16|0,c[m>>2]=109920,c[m+8>>2]=a,m)|0);i=m;i=b;return}function vu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[b>>2]|0;if((d|0)!=0){e=d+4|0;f=d+16|0;if((c[f>>2]|0)==0){g=e}else{d=a+16|0;h=e;e=f;while(1){f=c[d>>2]|0;i=f+4|0;j=c[i>>2]|0;c[i>>2]=j+1;c[(c[f>>2]|0)+(j<<2)>>2]=h;j=c[e>>2]|0;f=j+12|0;if((c[f>>2]|0)==0){g=j;break}else{h=j;e=f}}}e=g-16+12|0;c[b>>2]=e;k=e;l=(k|0)!=0;m=l&1;return m|0}e=a+16|0;a=c[e>>2]|0;g=a+4|0;h=c[g>>2]|0;if((h|0)>0){d=h-1|0;c[g>>2]=d;g=(c[(c[a>>2]|0)+(d<<2)>>2]|0)-16+12|0;c[b>>2]=g;k=g;l=(k|0)!=0;m=l&1;return m|0}if((a|0)==0){k=0;l=(k|0)!=0;m=l&1;return m|0}xY(c[a>>2]|0);xY(c[e>>2]|0);c[e>>2]=0;k=c[b>>2]|0;l=(k|0)!=0;m=l&1;return m|0}function vv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=yF(d|0)|0;f=b+12|0;while(1){g=c[f>>2]|0;if((g|0)==0){h=6308;break}i=yL(d|0,c[g-16+12>>2]|0,e|0)|0;if((i|0)<0){h=6310;break}if((i|0)>0){f=g+8|0}else{j=g;h=6312;break}}if((h|0)==6310){j=c[g+12>>2]|0;h=6312}else if((h|0)==6308){vt(b);h=6313}L8455:do{if((h|0)==6312){vt(b);if((j|0)==0){h=6313;break}g=b+16|0;f=j;L8458:while(1){i=c[f-16+12>>2]|0;k=yL(d|0,i|0,e|0)|0;do{if((k|0)==0){l=c[145614]|0;if(l>>>0<20){m=x8(2048)|0;n=m;c[145616]=n;o=(m|0)!=0;m=o?2048:0;c[145614]=m;if(o){p=m;q=n;h=6319}}else{p=l;q=c[145616]|0;h=6319}do{if((h|0)==6319){h=0;c[145616]=q+20;c[145614]=p-20;if((q|0)==0){break}c[q>>2]=i;vn(a,q)|0}}while(0);l=f+12|0;n=c[l>>2]|0;m=c[f+8>>2]|0;if((n|0)==0){r=m;break}if((m|0)==0){f=n;continue L8458}n=c[g>>2]|0;o=n+4|0;s=c[o>>2]|0;c[o>>2]=s+1;c[(c[n>>2]|0)+(s<<2)>>2]=m;r=c[l>>2]|0}else{if((k|0)<0){r=c[f+12>>2]|0;break}else{r=c[f+8>>2]|0;break}}}while(0);if((r|0)!=0){f=r;continue}k=c[g>>2]|0;i=k+4|0;l=c[i>>2]|0;if((l|0)<=0){t=g;break L8455}m=l-1|0;c[i>>2]=m;i=c[(c[k>>2]|0)+(m<<2)>>2]|0;if((i|0)==0){t=g;break}else{f=i}}}}while(0);if((h|0)==6313){t=b+16|0}b=c[t>>2]|0;if((b|0)==0){return}xY(c[b>>2]|0);xY(c[t>>2]|0);c[t>>2]=0;return}function vw(){var b=0,d=0;b=i;if(!(a[3472]|0)){i=b;return}do{if(!(a[19504]|0)){if((xB()|0)!=0){break}oW(59968,(d=i,i=i+8|0,c[d>>2]=109584,d)|0);i=d;a[3352]=0;i=b;return}}while(0);a[3352]=1;i=b;return}function vx(){var b=0,d=0,e=0,f=0,h=0;b=i;oW(54280,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d;if((ob(50112)|0)!=0){i=b;return}if((ob(46224)|0)!=0){a[19504]=1}oE(41936,20);oE(38216,460);oE(108200,456);oE(104936,336);oE(101936,112);pb(14896);pb(168);pb(13656);pb(15632);pb(26960);pb(27656);pb(27712);pb(3416);pb(3360);pb(109416);if((c[278806]|0)<8388608){o9(83280,99632);oW(98024,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d}a[3472]=1;do{if(a[19504]|0){e=1}else{if((xB()|0)!=0){e=1;break}oW(59968,(d=i,i=i+8|0,c[d>>2]=109584,d)|0);i=d;e=0}}while(0);a[3352]=e;vS();c[274644]=x1(36864,95784)|0;c[159944]=0;if(a[19504]|0){e=x1(28,93776)|0;c[155108]=e;c[e+16>>2]=16;c[(c[155108]|0)+20>>2]=22050;c[c[155108]>>2]=2;c[(c[155108]|0)+4>>2]=32768;c[(c[155108]|0)+12>>2]=0;c[(c[155108]|0)+8>>2]=1;e=x1(65536,92144)|0;c[(c[155108]|0)+24>>2]=e}do{if(a[3352]|0){oW(90376,(d=i,i=i+8|0,c[d>>2]=c[(c[155108]|0)+20>>2],d)|0);i=d;if(+g[3728]!=0.0|a[3352]^1){f=0;break}e=vI(88568)|0;if(+g[3418]==0.0){f=e;break}vQ(e)|0;f=e}else{f=0}}while(0);c[664764]=f;do{if(+g[3728]!=0.0|a[3352]^1){h=0}else{f=vI(86816)|0;if(+g[3418]==0.0){h=f;break}vQ(f)|0;h=f}}while(0);c[664765]=h;vF(1);i=b;return}function vy(){var b=0,d=0,e=0,f=0,h=0,j=0;b=i;i=i+256|0;d=b|0;if((oq()|0)<=1){i=b;return}e=d|0;f=1;do{h=(cn(os(f)|0,46)|0)==0;yQ(e|0,os(f)|0)|0;if(h){h=d+(yF(e|0)|0)|0;a[h]=a[73928]|0;a[h+1|0]=a[73929|0]|0;a[h+2|0]=a[73930|0]|0;a[h+3|0]=a[73931|0]|0;a[h+4|0]=a[73932|0]|0}do{if(+g[3728]!=0.0|a[3352]^1){j=0}else{h=vI(e)|0;if(+g[3418]==0.0){j=h;break}vQ(h)|0;j=h}}while(0);h=c[28058]|0;c[28058]=h+1;vJ(h,0,j,1098240,1.0,1.0);f=f+1|0;}while((f|0)<(oq()|0));i=b;return}function vz(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0.0;b=i;i=i+256|0;d=b|0;if((oq()|0)<=1){i=b;return}e=d|0;f=1;do{h=(cn(os(f)|0,46)|0)==0;yQ(e|0,os(f)|0)|0;if(h){h=d+(yF(e|0)|0)|0;a[h]=a[73928]|0;a[h+1|0]=a[73929|0]|0;a[h+2|0]=a[73930|0]|0;a[h+3|0]=a[73931|0]|0;a[h+4|0]=a[73932|0]|0}do{if(+g[3728]!=0.0|a[3352]^1){j=0}else{h=vI(e)|0;if(+g[3418]==0.0){j=h;break}vQ(h)|0;j=h}}while(0);k=+nF(os(f+1|0)|0);h=c[28060]|0;c[28060]=h+1;vJ(h,0,j,1098240,k,1.0);f=f+2|0;}while((f|0)<(oq()|0));i=b;return}function vA(){vF(1);return}function vB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=0;while(1){if((c[2578680+(d*52|0)>>2]|0)==(a|0)){if((c[2578684+(d*52|0)>>2]|0)==(b|0)){break}}e=d+1|0;if((e|0)<128){d=e}else{f=6395;break}}if((f|0)==6395){return}c[2578668+(d*52|0)>>2]=0;c[2578656+(d*52|0)>>2]=0;return}function vC(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;a=i;if((c[159944]|0)<=0){b=0;oW(74824,(d=i,i=i+8|0,c[d>>2]=b,d)|0);i=d;i=a;return}e=c[274644]|0;f=0;g=0;while(1){h=yc(e+64|0)|0;if((h|0)==0){j=g}else{k=h+12|0;l=ab(c[k>>2]|0,c[h>>2]|0)|0;m=ab(l,(c[h+16>>2]|0)+1|0)|0;if((c[h+4>>2]|0)>-1){oW(78744,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d}else{oW(77488,(d=i,i=i+1|0,i=i+7>>3<<3,c[d>>2]=0,d)|0);i=d}oW(76072,(d=i,i=i+24|0,c[d>>2]=c[k>>2]<<3,c[d+8>>2]=m,c[d+16>>2]=e,d)|0);i=d;j=m+g|0}m=f+1|0;if((m|0)<(c[159944]|0)){e=e+72|0;f=m;g=j}else{b=j;break}}oW(74824,(d=i,i=i+8|0,c[d>>2]=b,d)|0);i=d;i=a;return}function vD(){var b=0,d=0,e=0,f=0;b=i;d=c[155108]|0;if(a[3352]&(d|0)!=0){e=d|0;d=(c[e>>2]|0)==1?57544:57048;oW(58064,(f=i,i=i+16|0,c[f>>2]=c[e>>2],c[f+8>>2]=d,f)|0);i=f;oW(56640,(f=i,i=i+8|0,c[f>>2]=c[(c[155108]|0)+4>>2],f)|0);i=f;oW(56160,(f=i,i=i+8|0,c[f>>2]=c[(c[155108]|0)+12>>2],f)|0);i=f;oW(55584,(f=i,i=i+8|0,c[f>>2]=c[(c[155108]|0)+16>>2],f)|0);i=f;oW(54936,(f=i,i=i+8|0,c[f>>2]=c[(c[155108]|0)+8>>2],f)|0);i=f;oW(53848,(f=i,i=i+8|0,c[f>>2]=c[(c[155108]|0)+20>>2],f)|0);i=f;oW(53280,(f=i,i=i+8|0,c[f>>2]=c[(c[155108]|0)+24>>2],f)|0);i=f;oW(52840,(f=i,i=i+8|0,c[f>>2]=c[45866],f)|0);i=f;i=b;return}else{oW(58624,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;i=b;return}}function vE(b){b=b|0;var c=0,d=0;if(+g[3728]!=0.0|a[3352]^1){c=0;return c|0}d=vI(b)|0;if(+g[3418]==0.0){c=d;return c|0}vQ(d)|0;c=d;return c|0}function vF(b){b=b|0;var d=0,e=0,f=0;if(!(a[3352]|0)){return}c[45866]=132;d=0;do{e=2578656+(d*52|0)|0;if((c[e>>2]|0)!=0){c[e>>2]=0}d=d+1|0;}while((d|0)<512);yG(2578656,0,26624);if((b|0)==0|(c[155108]|0)==0){return}if((xf()|0)==0){b=c[155108]|0;d=b+16|0;e=c[b+24>>2]|0;f=(c[d>>2]|0)==8?-128:0;yG(e|0,f|0,(ab(c[d>>2]|0,c[b+4>>2]|0)|0)/8|0|0);xg();return}if(!(a[3352]|0)){return}c[155108]=0;a[3352]=0;if(a[19504]|0){return}xh();return}function vG(){if(!(a[3352]|0)){return}c[155108]=0;a[3352]=0;if(a[19504]|0){return}xh();return}function vH(b){b=b|0;if(!(a[3352]|0)){return}yc((vI(b)|0)+64|0)|0;return}function vI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;if((a|0)==0){w1(72872,(d=i,i=i+8|0,c[d>>2]=109616,d)|0);i=d}if((yF(a|0)|0)>>>0>63){w1(71976,(d=i,i=i+16|0,c[d>>2]=109616,c[d+8>>2]=a,d)|0);i=d}e=c[159944]|0;f=c[274644]|0;g=0;while(1){if((g|0)>=(e|0)){break}if((cS(f+(g*72|0)|0,a|0)|0)==0){h=6457;break}else{g=g+1|0}}if((h|0)==6457){j=f+(g*72|0)|0;i=b;return j|0}if((e|0)==512){w1(70672,(d=i,i=i+8|0,c[d>>2]=109616,d)|0);i=d;k=c[274644]|0}else{k=f}f=k+(g*72|0)|0;yQ(f|0,a|0)|0;c[159944]=(c[159944]|0)+1;j=f;i=b;return j|0}function vJ(b,d,e,f,h,i){b=b|0;d=d|0;e=e|0;f=f|0;h=+h;i=+i;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((e|0)==0|a[3352]^1|+g[3728]!=0.0){return}j=c[644467]|0;k=(j|0)==(b|0);l=c[158906]|0;L8648:do{if((d|0)==(-1|0)){m=2147483647;n=4;o=0;while(1){p=2578656+(n*52|0)|0;q=c[2578680+(n*52|0)>>2]|0;if((q|0)==(b|0)){r=p;break L8648}if((q|0)!=(j|0)|k){s=6473}else{if((c[p>>2]|0)==0){s=6473}else{t=o;u=m}}if((s|0)==6473){s=0;q=(c[2578668+(n*52|0)>>2]|0)-l|0;v=(q|0)<(m|0);t=v?p:o;u=v?q:m}q=n+1|0;if((q|0)<132){m=u;n=q;o=t}else{w=t;s=6481;break}}}else if((d|0)==0){o=2147483647;n=4;m=0;while(1){q=2578656+(n*52|0)|0;if((c[2578680+(n*52|0)>>2]|0)!=(j|0)|k){s=6468}else{if((c[q>>2]|0)==0){s=6468}else{x=m;y=o}}if((s|0)==6468){s=0;v=(c[2578668+(n*52|0)>>2]|0)-l|0;p=(v|0)<(o|0);x=p?q:m;y=p?v:o}v=n+1|0;if((v|0)<132){o=y;n=v;m=x}else{w=x;s=6481;break}}}else{m=2147483647;n=4;o=0;while(1){v=2578656+(n*52|0)|0;p=c[2578680+(n*52|0)>>2]|0;if((p|0)==(b|0)){if((c[2578684+(n*52|0)>>2]|0)==(d|0)){r=v;break L8648}else{z=b}}else{z=p}if((z|0)!=(j|0)|k){s=6479}else{if((c[v>>2]|0)==0){s=6479}else{A=o;B=m}}if((s|0)==6479){s=0;p=(c[2578668+(n*52|0)>>2]|0)-l|0;q=(p|0)<(m|0);A=q?v:o;B=q?p:m}p=n+1|0;if((p|0)<132){m=B;n=p;o=A}else{w=A;s=6481;break}}}}while(0);do{if((s|0)==6481){if((w|0)!=0){r=w;break}return}}while(0);w=r|0;do{if((c[w>>2]|0)==0){if((r|0)!=0){break}return}else{c[w>>2]=0}}while(0);yG(r|0,0,52);g[r+32>>2]=+g[f>>2];g[r+36>>2]=+g[f+4>>2];g[r+40>>2]=+g[f+8>>2];g[r+44>>2]=i/1.0e3;c[r+48>>2]=~~(h*255.0);c[r+24>>2]=b;c[r+28>>2]=d;vK(r);do{if((c[r+4>>2]|0)==0){if((c[r+8>>2]|0)!=0){break}return}}while(0);d=vQ(e)|0;if((d|0)==0){c[w>>2]=0;return}c[w>>2]=e;w=r+16|0;c[w>>2]=0;b=r+12|0;c[b>>2]=(c[d>>2]|0)+(c[158906]|0);d=2578864;f=4;L8691:while(1){do{if((d|0)!=(r|0)){if((c[d>>2]|0)!=(e|0)){break}if((c[d+16>>2]|0)==0){break L8691}}}while(0);A=f+1|0;if((A|0)<132){d=d+52|0;f=A}else{s=6497;break}}if((s|0)==6497){return}s=aQ()|0;f=(s|0)%(~~(+(c[(c[155108]|0)+20>>2]|0)*.1)|0)|0;s=c[b>>2]|0;d=(f|0)<(s|0)?f:s-1|0;c[w>>2]=d+(c[w>>2]|0);c[b>>2]=s-d;return}function vK(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0.0,k=0.0,l=0.0,m=0.0;b=i;i=i+16|0;d=b|0;if((c[a+24>>2]|0)==(c[644467]|0)){e=c[a+48>>2]|0;c[a+4>>2]=e;c[a+8>>2]=e;i=b;return}e=d|0;g[e>>2]=+g[a+32>>2]- +g[274560];f=d+4|0;g[f>>2]=+g[a+36>>2]- +g[274561];h=d+8|0;g[h>>2]=+g[a+40>>2]- +g[274562];j=+q1(e);if((c[c[155108]>>2]|0)==1){k=1.0;l=1.0}else{m=+g[3932]*+g[e>>2]+ +g[3930]*+g[f>>2]+ +g[3928]*+g[h>>2];k=m+1.0;l=1.0-m}m=1.0-j*+g[a+44>>2];j=+(c[a+48>>2]|0);h=~~(j*m*k);c[a+8>>2]=(h|0)<0?0:h;h=~~(m*l*j);f=a+4|0;c[f>>2]=h;if((h|0)>=0){i=b;return}c[f>>2]=0;i=b;return}function vL(a,b,d,e){a=a|0;b=b|0;d=+d;e=+e;var f=0,h=0,j=0,k=0,l=0;f=i;if((a|0)==0){i=f;return}h=c[45866]|0;if((h|0)==512){oW(84896,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0);i=j;i=f;return}k=2578656+(h*52|0)|0;c[45866]=h+1;l=vQ(a)|0;if((l|0)==0){i=f;return}if((c[l+4>>2]|0)==-1){oW(82480,(j=i,i=i+8|0,c[j>>2]=a,j)|0);i=j;i=f;return}else{c[k>>2]=a;g[2578688+(h*52|0)>>2]=+g[b>>2];g[2578692+(h*52|0)>>2]=+g[b+4>>2];g[2578696+(h*52|0)>>2]=+g[b+8>>2];c[2578704+(h*52|0)>>2]=~~d;g[2578700+(h*52|0)>>2]=e*.015625/1.0e3;c[2578668+(h*52|0)>>2]=(c[l>>2]|0)+(c[158906]|0);vK(k);i=f;return}}function vM(){return}function vN(){return}function vO(b,e,f,i){b=b|0;e=e|0;f=f|0;i=i|0;var j=0.0,k=0,l=0.0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((c[153832]|0)>0|a[3352]^1){return}g[274560]=+g[b>>2];g[274561]=+g[b+4>>2];g[274562]=+g[b+8>>2];g[3932]=+g[f>>2];g[3930]=+g[f+4>>2];g[3928]=+g[f+8>>2];f=c[644470]|0;do{if((f|0)!=0){b=rB(f,1098240)|0;j=+g[6918];if((b|0)!=0&j!=0.0){k=0}else{c[644664]=0;c[644677]=0;c[644690]=0;c[644703]=0;break}do{c[2578656+(k*52|0)>>2]=c[2659056+(k<<2)>>2];l=j*+(d[b+60+k|0]|0|0);m=l<8.0?0.0:l;i=2578704+(k*52|0)|0;e=c[i>>2]|0;l=+(e|0);do{if(l<m){n=~~(+(e|0)+ +h[2332]*+g[6932]);c[i>>2]=n;if(+(n|0)<=m){o=n;break}n=~~m;c[i>>2]=n;o=n}else{if(l<=m){o=e;break}n=~~(+(e|0)- +h[2332]*+g[6932]);c[i>>2]=n;if(+(n|0)>=m){o=n;break}n=~~m;c[i>>2]=n;o=n}}while(0);c[2578664+(k*52|0)>>2]=o;c[2578660+(k*52|0)>>2]=o;k=k+1|0;}while((k|0)<4)}}while(0);if((c[45866]|0)>4){k=4;o=2578864;f=0;while(1){b=o|0;L8752:do{if((c[b>>2]|0)==0){p=f}else{vK(o);i=o+4|0;e=c[i>>2]|0;if((e|0)==0){if(!((c[o+8>>2]|0)!=0&(k|0)>131)){p=f;break}}else{if((k|0)<=131){p=f;break}}do{if((f|0)!=0){if((c[f>>2]|0)!=(c[b>>2]|0)){break}n=f+4|0;c[n>>2]=(c[n>>2]|0)+e;n=o+8|0;q=f+8|0;c[q>>2]=(c[q>>2]|0)+(c[n>>2]|0);c[n>>2]=0;c[i>>2]=0;p=f;break L8752}}while(0);L8762:do{if((k|0)>132){n=c[b>>2]|0;q=132;r=2585520;while(1){if((c[r>>2]|0)==(n|0)){s=q;t=r;break L8762}u=q+1|0;v=r+52|0;if((u|0)<(k|0)){q=u;r=v}else{s=u;t=v;break}}}else{s=132;t=2585520}}while(0);if((s|0)==(c[45866]|0)){p=0;break}if((t|0)==(o|0)){p=o;break}r=t+4|0;c[r>>2]=(c[r>>2]|0)+e;r=o+8|0;q=t+8|0;c[q>>2]=(c[q>>2]|0)+(c[r>>2]|0);c[r>>2]=0;c[i>>2]=0;p=t}}while(0);b=k+1|0;if((b|0)<(c[45866]|0)){k=b;o=o+52|0;f=p}else{break}}}if((c[153832]|0)>0|a[3352]^1){return}p=c[155108]|0;f=(c[p+4>>2]|0)/(c[p>>2]|0)|0;p=xC()|0;do{if((p|0)<(c[667366]|0)){c[667368]=(c[667368]|0)+1;if((c[158906]|0)<=1073741824){break}c[667368]=0;c[158906]=f;vF(1)}}while(0);c[667366]=p;o=ab(c[667368]|0,f)|0;f=((p|0)/(c[c[155108]>>2]|0)|0)+o|0;c[145630]=f;if((c[158906]|0)<(f|0)){c[158906]=f}o=c[155108]|0;p=~~(+(f|0)+ +g[27358]*+(c[o+20>>2]|0));k=c[o+4>>2]>>(c[o>>2]|0)-1;vU((p-f|0)>>>0>k>>>0?k+f|0:p);xi();return}function vP(b){b=b|0;var d=0,e=0.0,f=0;d=i;e=+g[3728];if(!(e==0.0&a[3352])){i=d;return}do{if(e==0.0){f=vI(b)|0;if(+g[3418]!=0.0){vQ(f)|0}if((f|0)==0){break}vJ(c[644467]|0,-1,f,117584,1.0,1.0);i=d;return}}while(0);oW(80496,(f=i,i=i+16|0,c[f>>2]=109600,c[f+8>>2]=b,f)|0);i=f;i=d;return}function vQ(e){e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0;f=i;i=i+1280|0;h=e+64|0;j=yc(h)|0;if((j|0)!=0){k=j;i=f;return k|0}j=f|0;a[j]=a[87888]|0;a[j+1|0]=a[87889|0]|0;a[j+2|0]=a[87890|0]|0;a[j+3|0]=a[87891|0]|0;a[j+4|0]=a[87892|0]|0;a[j+5|0]=a[87893|0]|0;a[j+6|0]=a[87894|0]|0;l=e|0;yR(j|0,l|0)|0;e=on(j,f+256|0,1024,0)|0;if((e|0)==0){oW(102696,(m=i,i=i+8|0,c[m>>2]=j,m)|0);i=m;k=0;i=f;return k|0}j=c[352950]|0;yG(2669440,0,24);c[278510]=e;n=e+j|0;c[278508]=n;c[274574]=e;j=n;o=e;while(1){p=o+8|0;if(p>>>0>=n>>>0){q=6583;break}r=o+4|0;c[350720]=r;s=(d[o+5|0]|0)<<8|(d[r]|0)|(d[o+6|0]|0)<<16|(d[o+7|0]|0)<<24;c[350720]=p;c[278512]=s;if((s|0)<0){q=6586;break}if((s|0)>(j-p|0)){q=6586;break}r=o+(s+9&-2)|0;c[274574]=r;c[350720]=o;if((bN(o|0,69584,4)|0)==0){q=6588;break}else{o=r}}L8810:do{if((q|0)==6586){oX(95736,(m=i,i=i+24|0,c[m>>2]=69584,c[m+8>>2]=s,c[m+16>>2]=l,m)|0);i=m;c[350720]=0;q=6590}else if((q|0)==6588){if((o|0)==0){q=6590;break}if((bN(p|0,59952,4)|0)!=0){q=6590;break}r=o+12|0;c[278510]=r;c[274574]=r;t=r;while(1){u=t+8|0;if(u>>>0>=n>>>0){q=6593;break}v=t+4|0;c[350720]=v;w=(d[t+5|0]|0)<<8|(d[v]|0)|(d[t+6|0]|0)<<16|(d[t+7|0]|0)<<24;c[350720]=u;c[278512]=w;if((w|0)<0){q=6596;break}if((w|0)>(j-u|0)){q=6596;break}v=t+(w+9&-2)|0;c[274574]=v;c[350720]=t;if((bN(t|0,50080,4)|0)==0){q=6598;break}else{t=v}}do{if((q|0)==6598){if((t|0)==0){break}c[350720]=u;v=(d[t+9|0]|0)<<8|(d[u]|0);x=t+10|0;c[350720]=x;if(v<<16>>16!=1){oW(41872,(m=i,i=i+1|0,i=i+7>>3<<3,c[m>>2]=0,m)|0);i=m;break L8810}v=(d[t+11|0]|0)<<8|(d[x]|0);x=t+12|0;c[350720]=x;c[667362]=v<<16>>16;c[667360]=(d[t+13|0]|0)<<8|(d[x]|0)|(d[t+14|0]|0)<<16|(d[t+15|0]|0)<<24;x=t+22|0;c[350720]=x;v=(d[t+23|0]|0)<<8|(d[x]|0);c[350720]=t+24;c[667361]=(v<<16>>16|0)/8|0;c[274574]=r;v=r;while(1){x=v+8|0;if(x>>>0>=n>>>0){q=6604;break}y=v+4|0;c[350720]=y;z=(d[v+5|0]|0)<<8|(d[y]|0)|(d[v+6|0]|0)<<16|(d[v+7|0]|0)<<24;c[350720]=x;c[278512]=z;if((z|0)<0){q=6607;break}if((z|0)>(j-x|0)){q=6607;break}A=v+(z+9&-2)|0;c[274574]=A;c[350720]=v;if((bN(v|0,38184,4)|0)==0){q=6609;break}else{v=A}}do{if((q|0)==6609){if((v|0)==0){q=6620;break}x=v+32|0;c[350720]=x;y=(d[v+33|0]|0)<<8|(d[x]|0)|(d[v+34|0]|0)<<16|(d[v+35|0]|0)<<24;c[350720]=v+36;c[667363]=y;x=A;while(1){B=x+8|0;if(B>>>0>=n>>>0){q=6612;break}C=x+4|0;c[350720]=C;D=(d[x+5|0]|0)<<8|(d[C]|0)|(d[x+6|0]|0)<<16|(d[x+7|0]|0)<<24;c[350720]=B;c[278512]=D;if((D|0)<0){q=6615;break}if((D|0)>(j-B|0)){q=6615;break}B=x+(D+9&-2)|0;c[274574]=B;c[350720]=x;if((bN(x|0,108176,4)|0)==0){q=6617;break}else{x=B}}if((q|0)==6615){oX(95736,(m=i,i=i+24|0,c[m>>2]=108176,c[m+8>>2]=D,c[m+16>>2]=l,m)|0);i=m;c[350720]=0;break}else if((q|0)==6612){c[350720]=0;break}else if((q|0)==6617){if((x|0)==0){break}B=x+28|0;if((bN(B|0,104904,4)|0)!=0){break}C=x+24|0;c[350720]=C;E=(d[x+25|0]|0)<<8|(d[C]|0)|(d[x+26|0]|0)<<16|(d[x+27|0]|0)<<24;c[350720]=B;c[667364]=E+y;break}}else if((q|0)==6607){oX(95736,(m=i,i=i+24|0,c[m>>2]=38184,c[m+8>>2]=z,c[m+16>>2]=l,m)|0);i=m;c[350720]=0;q=6620}else if((q|0)==6604){c[350720]=0;q=6620}}while(0);if((q|0)==6620){c[667363]=-1}v=c[278510]|0;c[274574]=v;E=c[278508]|0;B=E;C=v;while(1){F=C+8|0;if(F>>>0>=E>>>0){q=6623;break}G=C+4|0;c[350720]=G;H=C+5|0;I=C+6|0;J=C+7|0;K=(d[H]|0)<<8|(d[G]|0)|(d[I]|0)<<16|(d[J]|0)<<24;c[350720]=F;c[278512]=K;if((K|0)<0){q=6626;break}if((K|0)>(B-F|0)){q=6626;break}v=C+(K+9&-2)|0;c[274574]=v;c[350720]=C;if((bN(C|0,101920,4)|0)==0){q=6628;break}else{C=v}}do{if((q|0)==6628){if((C|0)==0){break}c[350720]=G;B=(d[H]|0)<<8|(d[G]|0)|(d[I]|0)<<16|(d[J]|0)<<24;c[350720]=F;E=(B|0)/(c[667361]|0)|0;B=c[667364]|0;do{if((B|0)==0){c[667364]=E;L=F}else{if((E|0)>=(B|0)){L=F;break}w1(97992,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;L=c[350720]|0}}while(0);c[667365]=L-e;break L8810}else if((q|0)==6626){oX(95736,(m=i,i=i+24|0,c[m>>2]=101920,c[m+8>>2]=K,c[m+16>>2]=l,m)|0);i=m;c[350720]=0}else if((q|0)==6623){c[350720]=0}}while(0);oW(99600,(m=i,i=i+1|0,i=i+7>>3<<3,c[m>>2]=0,m)|0);i=m;break L8810}else if((q|0)==6596){oX(95736,(m=i,i=i+24|0,c[m>>2]=50080,c[m+8>>2]=w,c[m+16>>2]=l,m)|0);i=m;c[350720]=0}else if((q|0)==6593){c[350720]=0}}while(0);oW(46176,(m=i,i=i+1|0,i=i+7>>3<<3,c[m>>2]=0,m)|0);i=m}else if((q|0)==6583){c[350720]=0;q=6590}}while(0);if((q|0)==6590){oW(54240,(m=i,i=i+1|0,i=i+7>>3<<3,c[m>>2]=0,m)|0);i=m}if((c[667362]|0)!=1){oW(83144,(m=i,i=i+8|0,c[m>>2]=l,m)|0);i=m;k=0;i=f;return k|0}m=yd(h,(ab(c[667361]|0,~~(+(c[667364]|0)/(+(c[667360]|0)/+(c[(c[155108]|0)+20>>2]|0))))|0)+24|0,l)|0;if((m|0)==0){k=0;i=f;return k|0}l=m;c[m>>2]=c[667364];c[m+4>>2]=c[667363];q=c[667360]|0;c[m+8>>2]=q;w=c[667361]|0;c[m+12>>2]=w;c[m+16>>2]=c[667362];m=c[667365]|0;K=e+m|0;L=yc(h)|0;if((L|0)==0){k=l;i=f;return k|0}M=+(q|0)/+(c[(c[155108]|0)+20>>2]|0);q=L;h=~~(+(c[q>>2]|0)/M);c[q>>2]=h;q=L+4|0;F=c[q>>2]|0;if((F|0)!=-1){c[q>>2]=~~(+(F|0)/M)}c[L+8>>2]=c[(c[155108]|0)+20>>2];F=L+12|0;q=+g[3912]!=0.0?1:w;c[F>>2]=q;c[L+16>>2]=0;if(M==1.0&(w|0)==1&(q|0)==1){if((h|0)>0){N=0}else{k=l;i=f;return k|0}while(1){a[L+(N+20)|0]=a[e+(N+m)|0]^-128;J=N+1|0;if((J|0)<(h|0)){N=J}else{k=l;break}}i=f;return k|0}N=~~(M*256.0);if((h|0)<=0){k=l;i=f;return k|0}J=K;K=L+20|0;if((w|0)==2){w=0;I=0;G=q;while(1){H=b[J+(w>>8<<1)>>1]|0;if((G|0)==2){b[K+(I<<1)>>1]=H}else{a[L+(I+20)|0]=(H&65535)>>>8&255}H=I+1|0;if((H|0)>=(h|0)){k=l;break}w=w+N|0;I=H;G=c[F>>2]|0}i=f;return k|0}else{G=0;I=0;w=q;while(1){q=((d[e+((G>>8)+m)|0]|0)<<8)-32768|0;if((w|0)==2){b[K+(I<<1)>>1]=q&65535}else{a[L+(I+20)|0]=q>>>8&255}q=I+1|0;if((q|0)>=(h|0)){k=l;break}G=G+N|0;I=q;w=c[F>>2]|0}i=f;return k|0}return 0}function vR(a){a=a|0;var d=0,e=0,f=0,h=0,i=0,j=0;c[145632]=~~(+g[46]*256.0);c[153826]=635632;d=c[158906]|0;if((xf()|0)!=0){vG();vw();return}if((d|0)<(a|0)){e=d;do{d=c[155108]|0;f=(c[d+4>>2]>>1)-1&e;c[153828]=(c[d+24>>2]|0)+(f<<1<<1);d=(c[(c[155108]|0)+4>>2]>>1)-f|0;f=((d+e|0)>(a|0)?a-e|0:d)<<1;c[153830]=f;if((f|0)>0){d=0;while(1){h=(ab(c[145632]|0,c[(c[153826]|0)+(d<<2)>>2]|0)|0)>>8;do{if((h|0)>32767){b[(c[153828]|0)+(d<<1)>>1]=32767}else{if((h|0)<-32768){b[(c[153828]|0)+(d<<1)>>1]=-32768;break}else{b[(c[153828]|0)+(d<<1)>>1]=h&65535;break}}}while(0);h=d|1;i=(ab(c[145632]|0,c[(c[153826]|0)+(h<<2)>>2]|0)|0)>>8;do{if((i|0)>32767){b[(c[153828]|0)+(h<<1)>>1]=32767}else{if((i|0)<-32768){b[(c[153828]|0)+(h<<1)>>1]=-32768;break}else{b[(c[153828]|0)+(h<<1)>>1]=i&65535;break}}}while(0);i=d+2|0;h=c[153830]|0;if((i|0)<(h|0)){d=i}else{j=h;break}}}else{j=f}c[153826]=(c[153826]|0)+(j<<2);e=(j>>1)+e|0;}while((e|0)<(a|0))}xg();return}function vS(){var a=0,b=0,d=0;a=0;do{b=a<<3;d=0;do{c[582536+(a<<10)+(d<<2)>>2]=ab(b,(d|0)<128?d:d-256|0)|0;d=d+1|0;}while((d|0)<256);a=a+1|0;}while((a|0)<32);return}function vT(d){d=d|0;var e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=c[155108]|0;do{if((c[e+16>>2]|0)==16){if((c[e>>2]|0)!=2){break}vR(d);return}}while(0);e=c[158906]|0;f=c[155108]|0;h=f|0;i=ab(c[h>>2]|0,d-e|0)|0;d=(c[f+4>>2]|0)-1|0;f=(ab(c[h>>2]|0,e)|0)&d;e=3-(c[h>>2]|0)|0;h=~~(+g[46]*256.0);if((xf()|0)!=0){vG();vw();return}j=c[155108]|0;k=j+16|0;do{if((c[k>>2]|0)==16){l=c[j+24>>2]|0;if((i|0)==0){break}else{m=635632;n=f;o=i}while(1){p=o-1|0;q=(ab(c[m>>2]|0,h)|0)>>8;if((q|0)>32767){r=32767}else{r=(q|0)<-32768?-32768:q&65535}b[l+(n<<1)>>1]=r;if((p|0)==0){break}else{m=m+(e<<2)|0;n=n+1&d;o=p}}}else{if((c[k>>2]|0)!=8){break}l=c[j+24>>2]|0;if((i|0)==0){break}else{s=635632;t=f;u=i}while(1){p=u-1|0;q=(ab(c[s>>2]|0,h)|0)>>8;if((q|0)>32767){v=-1}else{v=(q|0)<-32768?0:(q>>>8)+128&255}a[l+t|0]=v;if((p|0)==0){break}else{s=s+(e<<2)|0;t=t+1&d;u=p}}}}while(0);xg();return}function vU(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=c[158906]|0;if((e|0)<(a|0)){f=e}else{return}while(1){e=(a-f|0)>512?f+512|0:a;yG(635632,0,e-f<<3|0);if((c[45866]|0)>0){g=2578656;h=0;while(1){i=g|0;j=c[i>>2]|0;L8983:do{if((j|0)!=0){k=g+4|0;if((c[k>>2]|0)==0){if((c[g+8>>2]|0)==0){break}}l=vQ(j)|0;if((l|0)==0){break}m=c[158906]|0;if((m|0)>=(e|0)){break}n=g+12|0;o=l+12|0;p=g+8|0;q=g+16|0;r=l+20|0;s=l+4|0;t=l|0;u=m;m=c[n>>2]|0;while(1){v=(m|0)<(e|0)?m:e;w=v-u|0;do{if((w|0)>0){x=c[k>>2]|0;if((c[o>>2]|0)!=1){y=c[p>>2]|0;z=c[q>>2]|0;A=0;do{B=b[r+(A+z<<1)>>1]|0;C=(ab(B,x)|0)>>8;D=(ab(B,y)|0)>>8;B=635632+(A<<3)|0;c[B>>2]=C+(c[B>>2]|0);B=635636+(A<<3)|0;c[B>>2]=D+(c[B>>2]|0);A=A+1|0;}while((A|0)<(w|0));c[q>>2]=(c[q>>2]|0)+w;E=v;break}if((x|0)>255){c[k>>2]=255;F=31}else{F=x>>3}A=c[p>>2]|0;if((A|0)>255){c[p>>2]=255;G=31}else{G=A>>3}A=c[q>>2]|0;y=0;do{z=d[y+A+(l+20)|0]|0;B=635632+(y<<3)|0;c[B>>2]=(c[B>>2]|0)+(c[582536+(F<<10)+(z<<2)>>2]|0);B=635636+(y<<3)|0;c[B>>2]=(c[B>>2]|0)+(c[582536+(G<<10)+(z<<2)>>2]|0);y=y+1|0;}while((y|0)<(w|0));c[q>>2]=(c[q>>2]|0)+w;E=v}else{E=u}}while(0);v=c[n>>2]|0;if((E|0)<(v|0)){H=v}else{v=c[s>>2]|0;if((v|0)<=-1){break}c[q>>2]=v;w=E-v+(c[t>>2]|0)|0;c[n>>2]=w;H=w}if((E|0)<(e|0)){u=E;m=H}else{break L8983}}c[i>>2]=0}}while(0);i=h+1|0;if((i|0)<(c[45866]|0)){g=g+52|0;h=i}else{break}}}vT(e);c[158906]=e;if((e|0)<(a|0)){f=e}else{break}}return}function vV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;f=c[b+4>>2]|0;if((f|0)!=1){w1(87584,(h=i,i=i+32|0,c[h>>2]=110528,c[h+8>>2]=a,c[h+16>>2]=f,c[h+24>>2]=1,h)|0);i=h}f=c[b+24>>2]|0;j=x1((f<<3)+28|0,d)|0;c[a+388>>2]=j;c[j>>2]=c[b+8>>2];k=j+4|0;c[k>>2]=c[b+16>>2];l=j+8|0;c[l>>2]=c[b+20>>2];g[j+16>>2]=+g[b+28>>2];c[a+76>>2]=c[b+32>>2];c[j+12>>2]=f;m=+((c[k>>2]|0)/-2|0|0);g[a+88>>2]=m;g[a+84>>2]=m;m=+((c[k>>2]|0)/2|0|0);g[a+100>>2]=m;g[a+96>>2]=m;g[a+92>>2]=+((c[l>>2]|0)/-2|0|0);g[a+104>>2]=+((c[l>>2]|0)/2|0|0);if((f|0)<1){w1(102664,(h=i,i=i+16|0,c[h>>2]=110528,c[h+8>>2]=f,h)|0);i=h;c[a+72>>2]=f;c[a+80>>2]=0;n=a+68|0;c[n>>2]=1;i=e;return}c[a+72>>2]=f;c[a+80>>2]=0;l=j+20|0;j=b+36|0;b=0;while(1){k=c[j>>2]|0;c[l+(b<<3)>>2]=k;o=j+4|0;p=l+(b<<3)+4|0;do{if((k|0)==0){q=c[j+12>>2]|0;r=c[j+16>>2]|0;s=ab(r,q)|0;t=(uL(s)|0)+28|0;u=x1(t,d)|0;v=u;yG(u|0,0,t|0);c[p>>2]=v;c[u>>2]=q;c[u+4>>2]=r;t=c[o>>2]|0;w=c[j+8>>2]|0;g[u+8>>2]=+(w|0);g[u+12>>2]=+(w-r|0);g[u+16>>2]=+(t|0);g[u+20>>2]=+(t+q|0);uR(v,d,b,j+20|0);x=j+(s+20)|0}else{s=c[o>>2]|0;v=s<<2;q=x1(v+12|0,d)|0;c[q>>2]=s;c[p>>2]=q;t=j+8|0;u=x1(v,d)|0;c[q+4>>2]=u;if((s|0)<=0){x=t;break}r=v+8|0;v=0;w=t;t=u;while(1){m=+g[w>>2];g[t>>2]=m;if(m<=0.0){w1(69560,(h=i,i=i+8|0,c[h>>2]=110552,h)|0);i=h}u=v+1|0;if((u|0)<(s|0)){v=u;w=w+4|0;t=t+4|0}else{break}}t=q+8|0;w=b*100|0;v=0;u=j+r|0;while(1){y=c[u+8>>2]|0;z=c[u+12>>2]|0;A=ab(z,y)|0;B=(uL(A)|0)+28|0;C=x1(B,d)|0;D=C;yG(C|0,0,B|0);c[t+(v<<2)>>2]=D;c[C>>2]=y;c[C+4>>2]=z;B=c[u>>2]|0;E=c[u+4>>2]|0;g[C+8>>2]=+(E|0);g[C+12>>2]=+(E-z|0);g[C+16>>2]=+(B|0);g[C+20>>2]=+(B+y|0);uR(D,d,v+w|0,u+16|0);D=u+(A+16)|0;A=v+1|0;if((A|0)<(s|0)){v=A;u=D}else{x=D;break}}}}while(0);p=b+1|0;if((p|0)<(f|0)){j=x;b=p}else{break}}n=a+68|0;c[n>>2]=1;i=e;return}function vW(a,b,d){a=a|0;b=b|0;d=+d;var e=0,f=0,h=0,j=0,k=0.0,l=0.0;e=i;f=c[a+140>>2]|0;if((f|0)>=(c[b+12>>2]|0)|(f|0)<0){oW(83112,(a=i,i=i+8|0,c[a>>2]=f,a)|0);i=a;h=0}else{h=f}f=c[b+20+(h<<3)+4>>2]|0;if((c[b+20+(h<<3)>>2]|0)==0){j=f;i=e;return j|0}h=c[f+4>>2]|0;b=(c[f>>2]|0)-1|0;k=+g[h+(b<<2)>>2];l=d-k*+(~~(d/k)|0);a=0;while(1){if((a|0)>=(b|0)){break}if(+g[h+(a<<2)>>2]>l){break}else{a=a+1|0}}j=c[f+8+(a<<2)>>2]|0;i=e;return j|0}function vX(){var a=0,b=0,d=0;a=i;pb(2392);pb(2560);pb(2616);pb(2672);pb(2208);pb(2448);pb(2784);pb(2504);pb(2728);pb(2336);oE(87536,400);oK(87536,46);b=0;do{cl(1091928+(b*6|0)|0,102648,(d=i,i=i+8|0,c[d>>2]=b,d)|0)|0;i=d;b=b+1|0;}while((b|0)<1024);i=a;return}function vY(){var a=0,b=0,d=0,e=0,f=0,g=0;a=i;if((oq()|0)==1){b=c[582]|0;d=0;while(1){if(d>>>0>=5){e=64160;break}if((c[2264+(d*12|0)>>2]|0)==(b|0)){f=6779;break}else{d=d+1|0}}if((f|0)==6779){e=c[2268+(d*12|0)>>2]|0}oW(63232,(g=i,i=i+16|0,c[g>>2]=b,c[g+8>>2]=e,g)|0);i=g;i=a;return}if((oq()|0)!=2){oW(58568,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=a;return}if((yM(os(1)|0,62656)|0)==0){oW(61896,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;oW(60928,(g=i,i=i+24|0,c[g>>2]=15,c[g+8>>2]=74768,c[g+16>>2]=73840,g)|0);i=g;oW(60928,(g=i,i=i+24|0,c[g>>2]=666,c[g+8>>2]=72792,c[g+16>>2]=71896,g)|0);i=g;oW(60928,(g=i,i=i+24|0,c[g>>2]=1e4,c[g+8>>2]=70584,c[g+16>>2]=69040,g)|0);i=g;oW(60928,(g=i,i=i+24|0,c[g>>2]=10001,c[g+8>>2]=67808,c[g+16>>2]=66824,g)|0);i=g;oW(60928,(g=i,i=i+24|0,c[g>>2]=10002,c[g+8>>2]=65848,c[g+16>>2]=64952,g)|0);i=g;i=a;return}e=nE(os(1)|0)|0;b=0;while(1){if(b>>>0>=5){break}if((c[2264+(b*12|0)>>2]|0)==(e|0)){break}d=c[2268+(b*12|0)>>2]|0;if((yM(d|0,os(1)|0)|0)==0){break}else{b=b+1|0}}if((b|0)==5){oW(59656,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=a;return}e=c[2264+(b*12|0)>>2]|0;if((c[582]|0)==(e|0)){i=a;return}c[582]=e;if((c[46140]|0)==0){i=a;return}oW(59096,(g=i,i=i+1|0,i=i+7>>3<<3,c[g>>2]=0,g)|0);i=g;i=a;return}function vZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+16|0;d=b|0;e=xZ(20)|0;f=e;if((e|0)==0){i=b;return f|0}c[e>>2]=0;c[e+4>>2]=0;c[e+8>>2]=-1;c[e+16>>2]=0;vl();if((a|0)==0){e=d|0;vo(f,74768,0)|0;bR(e|0,10,75968,(g=i,i=i+8|0,c[g>>2]=15,g)|0)|0;i=g;vo(f,72792,0)|0;bR(e|0,10,75968,(g=i,i=i+8|0,c[g>>2]=666,g)|0)|0;i=g;vo(f,70584,0)|0;bR(e|0,10,75968,(g=i,i=i+8|0,c[g>>2]=1e4,g)|0)|0;i=g;vo(f,67808,0)|0;bR(e|0,10,75968,(g=i,i=i+8|0,c[g>>2]=10001,g)|0)|0;i=g;vo(f,65848,0)|0;bR(e|0,10,75968,(g=i,i=i+8|0,c[g>>2]=10002,g)|0)|0;i=g;i=b;return f|0}e=yF(a|0)|0;h=d|0;d=(e|0)==0;j=0;do{k=c[2268+(j*12|0)>>2]|0;if((yL(k|0,a|0,e|0)|0)==0){vo(f,k,0)|0}bR(h|0,10,75968,(g=i,i=i+8|0,c[g>>2]=c[2264+(j*12|0)>>2],g)|0)|0;i=g;do{if(!d){if((bN(h|0,a|0,e|0)|0)!=0){break}vo(f,h,1)|0}}while(0);j=j+1|0;}while(j>>>0<5);i=b;return f|0}function v_(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0;if((c[49328]|0)>32756){return}nV(197296,18);n1(197296,+g[a>>2]);n1(197296,+g[a+4>>2]);n1(197296,+g[a+8>>2]);a=~~(+g[b>>2]*16.0);if((a|0)>127){f=127}else{f=(a|0)<-128?-128:a}nU(197296,f);f=~~(+g[b+4>>2]*16.0);if((f|0)>127){h=127}else{h=(f|0)<-128?-128:f}nU(197296,h);h=~~(+g[b+8>>2]*16.0);if((h|0)>127){i=127}else{i=(h|0)<-128?-128:h}nU(197296,i);nV(197296,e);nV(197296,d);return}function v$(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=+f;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=i;if(e>>>0>255){w1(83024,(k=i,i=i+16|0,c[k>>2]=109712,c[k+8>>2]=e,k)|0);i=k}if(f<0.0|f>4.0){w1(69480,(k=i,i=i+16|0,c[k>>2]=109712,h[k+8>>3]=f,k)|0);i=k}if(b>>>0>7){w1(59896,(k=i,i=i+16|0,c[k>>2]=109712,c[k+8>>2]=b,k)|0);i=k}if((c[49328]|0)>32754){i=j;return}else{l=1}while(1){if((l|0)>=1024){break}m=c[192928+(l<<2)>>2]|0;if((m|0)==0){break}if((cS(d|0,m|0)|0)==0){break}else{l=l+1|0}}do{if((l|0)!=1024){if((c[192928+(l<<2)>>2]|0)==0){break}m=tx(a)|0;n=(e|0)!=255|0;o=f!=1.0?n|2:n;do{if((m|0)>8191){if((c[73915]|0)==666){p=o|8;break}else{i=j;return}}else{p=o}}while(0);do{if((l|0)>255|(b|0)>7){if((c[73915]|0)==666){q=p|16;break}else{i=j;return}}else{q=p}}while(0);nV(197296,6);nV(197296,q);if((q&1|0)!=0){nV(197296,e)}if((q&2|0)!=0){nV(197296,~~(f*64.0))}if((q&8|0)==0){nW(197296,m<<3|b)}else{nW(197296,m);nV(197296,b)}o=c[73915]|0;do{if((o|0)==15|(o|0)==1e4){nV(197296,l)}else if((o|0)==666){if((q&16|0)==0){nV(197296,l);break}else{nW(197296,l);break}}else if((o|0)==10001|(o|0)==10002){nW(197296,l)}else{qa(104784,(k=i,i=i+16|0,c[k>>2]=109648,c[k+8>>2]=o,k)|0);i=k}}while(0);n1(197296,+g[a+136>>2]+(+g[a+228>>2]+ +g[a+240>>2])*.5);n1(197296,+g[a+140>>2]+(+g[a+232>>2]+ +g[a+244>>2])*.5);n1(197296,+g[a+144>>2]+(+g[a+236>>2]+ +g[a+248>>2])*.5);i=j;return}}while(0);oW(54208,(k=i,i=i+16|0,c[k>>2]=109712,c[k+8>>2]=d,k)|0);i=k;i=j;return}function v0(a){a=a|0;var b=0,d=0,f=0,h=0,j=0;b=i;d=a+64|0;nV(d,8);f=e[315444]|0;n0(d,50008,(h=i,i=i+24|0,c[h>>2]=2,c[h+8>>2]=46144,c[h+16>>2]=f,h)|0);i=h;nV(d,11);nX(d,c[73915]|0);nV(d,c[45874]|0);if(+g[5344]==0.0&+g[5066]!=0.0){nV(d,1)}else{nV(d,0)}n_(d,ti(c[(c[49322]|0)+492>>2]|0)|0);h=c[46185]|0;if((h|0)!=0){f=184740;j=h;do{n_(d,j);f=f+4|0;j=c[f>>2]|0;}while((j|0)!=0)}nV(d,0);j=c[48233]|0;if((j|0)!=0){f=192932;h=j;do{n_(d,h);f=f+4|0;h=c[f>>2]|0;}while((h|0)!=0)}nV(d,0);nV(d,32);nV(d,~~+g[(c[49322]|0)+496>>2]);nV(d,~~+g[(c[49322]|0)+496>>2]);nV(d,5);nW(d,tx(c[a+32852>>2]|0)|0);nV(d,25);nV(d,1);c[a+12>>2]=1;c[a+4>>2]=0;i=b;return}function v1(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+64|0;d=b|0;e=c[45876]|0;f=e+(a*33032|0)|0;h=e+(a*33032|0)+24|0;oX(41792,(j=i,i=i+8|0,c[j>>2]=(c[h>>2]|0)+65636,j)|0);i=j;j=tq(a+1|0)|0;k=c[h>>2]|0;if((c[46142]|0)!=0){l=d;m=e+(a*33032|0)+32960|0;yJ(l|0,m|0,64)|0}yG(f|0,0,33032);c[h>>2]=k;k=e+(a*33032|0)+32856|0;yJ(k|0,38128,12)|0;c[f>>2]=1;c[e+(a*33032|0)+4>>2]=0;c[e+(a*33032|0)+32852>>2]=j;c[e+(a*33032|0)+72>>2]=e+(a*33032|0)+84;c[e+(a*33032|0)+76>>2]=32768;c[e+(a*33032|0)+64>>2]=1;if((c[46142]|0)==0){tm(c[(c[157712]|0)+360>>2]|0);g[e+(a*33032|0)+32960>>2]=+g[(c[157712]|0)+172>>2];g[e+(a*33032|0)+32964>>2]=+g[(c[157712]|0)+176>>2];g[e+(a*33032|0)+32968>>2]=+g[(c[157712]|0)+180>>2];g[e+(a*33032|0)+32972>>2]=+g[(c[157712]|0)+184>>2];g[e+(a*33032|0)+32976>>2]=+g[(c[157712]|0)+188>>2];g[e+(a*33032|0)+32980>>2]=+g[(c[157712]|0)+192>>2];g[e+(a*33032|0)+32984>>2]=+g[(c[157712]|0)+196>>2];g[e+(a*33032|0)+32988>>2]=+g[(c[157712]|0)+200>>2];g[e+(a*33032|0)+32992>>2]=+g[(c[157712]|0)+204>>2];g[e+(a*33032|0)+32996>>2]=+g[(c[157712]|0)+208>>2];g[e+(a*33032|0)+33e3>>2]=+g[(c[157712]|0)+212>>2];g[e+(a*33032|0)+33004>>2]=+g[(c[157712]|0)+216>>2];g[e+(a*33032|0)+33008>>2]=+g[(c[157712]|0)+220>>2];g[e+(a*33032|0)+33012>>2]=+g[(c[157712]|0)+224>>2];g[e+(a*33032|0)+33016>>2]=+g[(c[157712]|0)+228>>2];g[e+(a*33032|0)+33020>>2]=+g[(c[157712]|0)+232>>2];v0(f);i=b;return}else{j=e+(a*33032|0)+32960|0;a=d;yJ(j|0,a|0,64)|0;v0(f);i=b;return}}function v2(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=i;b=r2()|0;if((b|0)==0){i=a;return}else{d=b}do{b=c[45874]|0;e=c[45876]|0;f=0;while(1){if((f|0)>=(b|0)){break}if((c[e+(f*33032|0)>>2]|0)==0){break}else{f=f+1|0}}if((f|0)==(b|0)){w1(108104,(g=i,i=i+8|0,c[g>>2]=109896,g)|0);i=g;h=c[45876]|0}else{h=e}c[h+(f*33032|0)+24>>2]=d;v1(f);c[169356]=(c[169356]|0)+1;d=r2()|0;}while((d|0)!=0);i=a;return}function v3(){nT(197296);return}function v4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=c[73915]|0;do{if((f|0)==15){nV(a,b)}else if((f|0)==1e4|(f|0)==10001|(f|0)==10002){nW(a,b)}else if((f|0)==666){if((d&1|0)==0){nV(a,b);break}else{nW(a,b);break}}else{qa(104784,(g=i,i=i+16|0,c[g>>2]=109672,c[g+8>>2]=f,g)|0);i=g}}while(0);i=e;return}function v5(d,e){d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0;f=i;i=i+16|0;h=f|0;j=h|0;g[j>>2]=+g[d+136>>2]+ +g[d+344>>2];g[h+4>>2]=+g[d+140>>2]+ +g[d+348>>2];g[h+8>>2]=+g[d+144>>2]+ +g[d+352>>2];h=rD(c[46183]|0,j)|0;if((c[49320]|0)<=1){i=f;return}j=e+12|0;k=e+16|0;l=1;m=(c[49322]|0)+(c[157718]|0)|0;L9231:while(1){do{if((m|0)==(d|0)){n=6911}else{if(+g[m+96>>2]==0.0){break}if((a[ti(c[m+212>>2]|0)|0]|0)==0){break}o=m+16|0;p=c[m+12>>2]|0;q=0;while(1){if((q|0)>=(p|0)){break}r=b[o+(q<<1)>>1]|0;if((1<<(r&31)&c[h+4+(r>>5<<2)>>2]|0)==0){q=q+1|0}else{break}}if((q|0)!=(p|0)){n=6911}}}while(0);do{if((n|0)==6911){n=0;if(((c[j>>2]|0)-(c[k>>2]|0)|0)<16){break L9231}o=m+136|0;s=+g[o>>2]- +g[m+48>>2];r=s<-.1|s>.1?2:0;s=+g[m+140>>2]- +g[m+52>>2];t=s<-.1|s>.1?r|4:r;s=+g[m+144>>2]- +g[m+56>>2];r=s<-.1|s>.1?t|8:t;t=m+172|0;u=+g[t>>2]!=+g[m+60>>2]?r|256:r;r=m+176|0;v=+g[r>>2]!=+g[m+64>>2]?u|16:u;u=m+180|0;w=+g[u>>2]!=+g[m+68>>2]?v|512:v;v=+g[m+128>>2]==4.0?w|32:w;w=m+404|0;x=+(c[m+80>>2]|0)!=+g[w>>2]?v|2048:v;v=m+220|0;y=+(c[m+84>>2]|0)!=+g[v>>2]?x|4096:x;x=m+216|0;s=+g[x>>2];z=+(c[m+76>>2]|0)!=s?y|64:y;y=m+224|0;A=+(c[m+88>>2]|0)!=+g[y>>2]?z|8192:z;z=m+96|0;B=+g[z>>2];C=+(c[m+72>>2]|0)!=B?A|1024:A;do{if((c[73915]|0)==666){if((C&64|0)==0){D=C}else{D=(~~s&65280|0)==0?C:C|131072}if((D&1024|0)==0){E=D}else{E=(~~B&65280|0)==0?D:D|262144}A=(E&16711680|0)==0?E:E|32768;if(A>>>0<=16777215){F=A;break}F=A|8388608}else{F=C}}while(0);C=(l|0)>255?F|16384:F;p=(C|0)>255|C;nV(e,p|128);if((p&1|0)!=0){nV(e,C>>8)}if((C&32768|0)!=0){nV(e,C>>16)}if((C&8388608|0)!=0){nV(e,C>>24)}if((C&16384|0)==0){nV(e,l)}else{nW(e,l)}do{if((C&1024|0)!=0){p=~~+g[z>>2];q=c[73915]|0;if((q|0)==666){nV(e,p);break}else if((q|0)==15){nV(e,p);break}else if((q|0)==1e4|(q|0)==10001|(q|0)==10002){nW(e,p);break}else{qa(104784,(G=i,i=i+16|0,c[G>>2]=109672,c[G+8>>2]=q,G)|0);i=G;break}}}while(0);if((C&64|0)!=0){nV(e,~~+g[x>>2])}if((C&2048|0)!=0){nV(e,~~+g[w>>2])}if((C&4096|0)!=0){nV(e,~~+g[v>>2])}if((C&8192|0)!=0){nV(e,~~+g[y>>2])}if((C&2|0)!=0){n1(e,+g[o>>2])}if((C&256|0)!=0){n2(e,+g[t>>2])}if((C&4|0)!=0){n1(e,+g[m+140>>2])}if((C&16|0)!=0){n2(e,+g[r>>2])}if((C&8|0)!=0){n1(e,+g[m+144>>2])}if((C&512|0)!=0){n2(e,+g[u>>2])}if((C&131072|0)!=0){nV(e,~~+g[x>>2]>>8)}if((C&262144|0)==0){break}nV(e,~~+g[z>>2]>>8)}}while(0);q=l+1|0;if((q|0)<(c[49320]|0)){l=q;m=m+(c[157718]|0)|0}else{n=6962;break}}if((n|0)==6962){i=f;return}oW(101872,(G=i,i=i+1|0,i=i+7>>3<<3,c[G>>2]=0,G)|0);i=G;i=f;return}function v6(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=i;f=b+464|0;h=b+468|0;if(+g[f>>2]!=0.0){j=6966}else{if(+g[h>>2]!=0.0){j=6966}}if((j|0)==6966){k=c[49322]|0;l=c[b+472>>2]|0;nV(d,19);nV(d,~~+g[h>>2]);nV(d,~~+g[f>>2]);n1(d,+g[k+(l+136)>>2]+(+g[k+(l+228)>>2]+ +g[k+(l+240)>>2])*.5);n1(d,+g[k+(l+140)>>2]+(+g[k+(l+232)>>2]+ +g[k+(l+244)>>2])*.5);n1(d,+g[k+(l+144)>>2]+(+g[k+(l+236)>>2]+ +g[k+(l+248)>>2])*.5);g[f>>2]=0.0;g[h>>2]=0.0}wy();h=b+372|0;if(+g[h>>2]!=0.0){nV(d,10);n2(d,+g[b+172>>2]);n2(d,+g[b+176>>2]);n2(d,+g[b+180>>2]);g[h>>2]=0.0}h=b+352|0;f=+g[h>>2]!=22.0|0;l=b+388|0;k=+g[l>>2]!=0.0?f|2:f;f=~~+g[b+328>>2];m=ts(b,99576)|0;if((m|0)==0){n=~~+g[(c[157712]|0)+152>>2]<<28}else{n=~~+g[m>>2]<<23}m=k|~~+g[b+400>>2]<<1&1024|(+g[b+428>>2]<2.0?512:2560);k=b+196|0;o=+g[k>>2]!=0.0?m|4:m;m=b+160|0;p=+g[m>>2]!=0.0?o|32:o;o=b+200|0;q=+g[o>>2]!=0.0?p|8:p;p=b+164|0;r=+g[p>>2]!=0.0?q|64:q;q=b+204|0;s=+g[q>>2]!=0.0?r|16:r;r=b+168|0;t=+g[r>>2]!=0.0?s|128:s;s=n|f;f=b+304|0;n=+g[f>>2]!=0.0?t|4096:t;t=b+424|0;u=+g[t>>2];v=u!=0.0?n|8192:n;n=v|16384;do{if((c[73915]|0)==666){w=(c[157608]|0)+(c[b+300>>2]|0)|0;L9329:do{if((w|0)==0){x=0;y=u}else{if((a[w]|0)==0){x=0;y=u;break}else{z=0}while(1){if((z|0)>=1024){j=6978;break}A=c[184736+(z<<2)>>2]|0;if((A|0)==0){B=z;break}if((cS(A|0,w|0)|0)==0){x=z;y=u;break L9329}else{z=z+1|0}}do{if((j|0)==6978){if((z|0)==1024){B=1024;break}if((c[184736+(z<<2)>>2]|0)==0){B=z}else{x=z;y=u;break L9329}}}while(0);w1(97944,(C=i,i=i+16|0,c[C>>2]=109816,c[C+8>>2]=w,C)|0);i=C;x=B;y=+g[t>>2]}}while(0);w=(x&65280|0)==0?n:v|81920;A=(~~y&65280|0)==0?w:w|131072;w=(~~+g[b+308>>2]&65280|0)==0?A:A|262144;A=(~~+g[b+312>>2]&65280|0)==0?w:w|524288;w=(~~+g[b+316>>2]&65280|0)==0?A:A|1048576;A=(~~+g[b+320>>2]&65280|0)==0?w:w|2097152;w=(~~+g[b+324>>2]&65280|0)==0?A:A|4194304;if((w&4096|0)==0){D=w}else{D=(~~+g[f>>2]&65280|0)==0?w:w|16777216}w=(D&16711680|0)==0?D:D|32768;if(w>>>0<=16777215){E=w;break}E=w|8388608}else{E=n}}while(0);nV(d,15);nW(d,E);if((E&32768|0)!=0){nV(d,E>>16)}if((E&8388608|0)!=0){nV(d,E>>24)}if((E&1|0)!=0){nU(d,~~+g[h>>2])}if((E&2|0)!=0){nU(d,~~+g[l>>2])}if((E&4|0)!=0){nU(d,~~+g[k>>2])}if((E&32|0)!=0){nU(d,~~(+g[m>>2]*.0625))}if((E&8|0)!=0){nU(d,~~+g[o>>2])}if((E&64|0)!=0){nU(d,~~(+g[p>>2]*.0625))}if((E&16|0)!=0){nU(d,~~+g[q>>2])}if((E&128|0)!=0){nU(d,~~(+g[r>>2]*.0625))}nX(d,s);if((E&4096|0)!=0){nV(d,~~+g[f>>2])}if((E&8192|0)!=0){nV(d,~~+g[t>>2])}do{if((E&16384|0)!=0){s=ti(c[b+300>>2]|0)|0;L9383:do{if((s|0)==0){F=0}else{if((a[s]|0)==0){F=0;break}else{G=0}while(1){if((G|0)>=1024){j=7007;break}r=c[184736+(G<<2)>>2]|0;if((r|0)==0){H=G;break}if((cS(r|0,s|0)|0)==0){F=G;break L9383}else{G=G+1|0}}do{if((j|0)==7007){if((G|0)==1024){H=1024;break}if((c[184736+(G<<2)>>2]|0)==0){H=G}else{F=G;break L9383}}}while(0);w1(97944,(C=i,i=i+16|0,c[C>>2]=109816,c[C+8>>2]=s,C)|0);i=C;F=H}}while(0);s=c[73915]|0;if((s|0)==15){nV(d,F);break}else if((s|0)==1e4|(s|0)==10001|(s|0)==10002){nW(d,F);break}else if((s|0)==666){nV(d,F);break}else{qa(104784,(C=i,i=i+16|0,c[C>>2]=109672,c[C+8>>2]=s,C)|0);i=C;break}}}while(0);nW(d,~~+g[b+288>>2]);F=b+308|0;nV(d,~~+g[F>>2]);H=b+312|0;nV(d,~~+g[H>>2]);G=b+316|0;nV(d,~~+g[G>>2]);s=b+320|0;nV(d,~~+g[s>>2]);r=b+324|0;nV(d,~~+g[r>>2]);q=b+296|0;L9400:do{if((c[836]|0)==0){p=0;while(1){if((p|0)>=32){break L9400}if((~~+g[q>>2]&1<<p|0)==0){p=p+1|0}else{break}}nV(d,p)}else{nV(d,~~+g[q>>2])}}while(0);if((E&65536|0)!=0){q=(c[157608]|0)+(c[b+300>>2]|0)|0;L9409:do{if((q|0)==0){I=0}else{if((a[q]|0)==0){I=0;break}else{J=0}while(1){if((J|0)>=1024){j=7026;break}b=c[184736+(J<<2)>>2]|0;if((b|0)==0){K=J;break}if((cS(b|0,q|0)|0)==0){I=J;break L9409}else{J=J+1|0}}do{if((j|0)==7026){if((J|0)==1024){K=1024;break}if((c[184736+(J<<2)>>2]|0)==0){K=J}else{I=J;break L9409}}}while(0);w1(97944,(C=i,i=i+16|0,c[C>>2]=109816,c[C+8>>2]=q,C)|0);i=C;I=K}}while(0);nV(d,I>>8)}if((E&131072|0)!=0){nV(d,~~+g[t>>2]>>8)}if((E&262144|0)!=0){nV(d,~~+g[F>>2]>>8)}if((E&524288|0)!=0){nV(d,~~+g[H>>2]>>8)}if((E&1048576|0)!=0){nV(d,~~+g[G>>2]>>8)}if((E&2097152|0)!=0){nV(d,~~+g[s>>2]>>8)}if((E&4194304|0)!=0){nV(d,~~+g[r>>2]>>8)}if((E&16777216|0)==0){i=e;return}nV(d,~~+g[f>>2]>>8);i=e;return}function v7(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;L9444:do{if((b|0)==0){e=0}else{if((a[b]|0)==0){e=0;break}else{f=0}while(1){if((f|0)>=1024){g=7060;break}h=c[184736+(f<<2)>>2]|0;if((h|0)==0){j=f;break}if((cS(h|0,b|0)|0)==0){e=f;break L9444}else{f=f+1|0}}do{if((g|0)==7060){if((f|0)==1024){j=1024;break}if((c[184736+(f<<2)>>2]|0)==0){j=f}else{e=f;break L9444}}}while(0);w1(97944,(h=i,i=i+16|0,c[h>>2]=109816,c[h+8>>2]=b,h)|0);i=h;e=j}}while(0);i=d;return e|0}function v8(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,j=0,k=0;b=i;i=i+32792|0;d=b+32768|0;c[d+8>>2]=b;e=a+24|0;f=c[(c[e>>2]|0)+56>>2]|0;g=d+12|0;c[g>>2]=(f|0)>32768?32768:f;f=d+16|0;c[f>>2]=0;nV(d,7);nY(d,+h[23072]);j=a+32852|0;v6(c[j>>2]|0,d);v5(c[j>>2]|0,d);j=c[49328]|0;if((j+(c[f>>2]|0)|0)<(c[g>>2]|0)){nZ(d,c[49326]|0,j)}if((r6(c[e>>2]|0,d)|0)!=-1){k=1;i=b;return k|0}p5(1);k=0;i=b;return k|0}function v9(){var a=0,b=0,d=0,e=0,f=0,h=0.0,i=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0;a=c[45876]|0;c[278816]=a;b=c[45874]|0;if((b|0)>0){d=a;e=0;f=b}else{nT(230084);return}while(1){h=+g[(c[d+32852>>2]|0)+292>>2];if(+(c[d+33024>>2]|0)!=h){if((f|0)>0){b=0;a=c[45876]|0;i=f;while(1){if((c[a>>2]|0)==0){j=i}else{k=a+64|0;nV(k,14);nV(k,e);nW(k,~~+g[(c[(c[278816]|0)+32852>>2]|0)+292>>2]);j=c[45874]|0}k=b+1|0;if((k|0)<(j|0)){b=k;a=a+33032|0;i=j}else{break}}i=c[278816]|0;l=i;m=+g[(c[i+32852>>2]|0)+292>>2]}else{l=d;m=h}c[l+33024>>2]=~~m;n=c[278816]|0;o=c[45874]|0}else{n=d;o=f}i=e+1|0;a=n+33032|0;c[278816]=a;if((i|0)<(o|0)){d=a;e=i;f=o}else{break}}if((o|0)<=0){nT(230084);return}f=0;e=c[45876]|0;d=o;while(1){if((c[e>>2]|0)==0){p=d}else{nZ(e+64|0,c[57523]|0,c[57525]|0);p=c[45874]|0}o=f+1|0;if((o|0)<(p|0)){f=o;e=e+33032|0;d=p}else{break}}nT(230084);return}function wa(){var a=0,b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0;a=i;i=i+32|0;b=a|0;v9();d=c[45876]|0;c[278816]=d;if((c[45874]|0)>0){e=a+24|0;f=b+8|0;j=b+12|0;k=b+16|0;l=d;d=0;do{L9495:do{if((c[l>>2]|0)!=0){do{if((c[l+4>>2]|0)==0){if((c[l+12>>2]|0)!=0){m=l;break}n=l+16|0;if(+h[1153]- +h[n>>3]<=5.0){break L9495}c[f>>2]=e;c[j>>2]=4;c[k>>2]=0;nU(b,1);if((r6(c[l+24>>2]|0,b)|0)==-1){p5(1)}h[n>>3]=+h[1153];break L9495}else{if((v8(l)|0)==0){break L9495}m=c[278816]|0}}while(0);if((c[m+68>>2]|0)!=0){p5(1);c[(c[278816]|0)+68>>2]=0;break}if((c[m+80>>2]|0)==0){if((c[m+8>>2]|0)==0){break}}if((r7(c[m+24>>2]|0)|0)==0){break}n=c[278816]|0;if((c[n+8>>2]|0)!=0){p5(0);break}if((r5(c[n+24>>2]|0,n+64|0)|0)==-1){p5(1)}nT((c[278816]|0)+64|0);h[(c[278816]|0)+16>>3]=+h[1153];c[(c[278816]|0)+12>>2]=0}}while(0);d=d+1|0;l=(c[278816]|0)+33032|0;c[278816]=l;}while((d|0)<(c[45874]|0))}if((c[49320]|0)<=1){i=a;return}d=1;l=(c[49322]|0)+(c[157718]|0)|0;while(1){m=l+224|0;g[m>>2]=+(~~+g[m>>2]&-3|0);m=d+1|0;if((m|0)<(c[49320]|0)){d=m;l=l+(c[157718]|0)|0}else{break}}i=a;return}function wb(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=i;if((c[49320]|0)>0){d=0}else{i=b;return}do{e=tq(d)|0;do{if((c[e>>2]|0)==0){if((d|0)>(c[45874]|0)){if(+g[e+96>>2]==0.0){break}}f=e+48|0;g[f>>2]=+g[e+136>>2];h=e+52|0;g[h>>2]=+g[e+140>>2];j=e+56|0;g[j>>2]=+g[e+144>>2];k=e+60|0;g[k>>2]=+g[e+172>>2];l=e+64|0;g[l>>2]=+g[e+176>>2];m=e+68|0;g[m>>2]=+g[e+180>>2];n=e+76|0;c[n>>2]=~~+g[e+216>>2];o=e+84|0;c[o>>2]=~~+g[e+220>>2];p=e+80|0;if((d|0)<1|(d|0)>(c[45874]|0)){c[p>>2]=0;q=ti(c[e+212>>2]|0)|0;L9540:do{if((q|0)==0){r=0}else{if((a[q]|0)==0){r=0;break}else{s=0}while(1){if((s|0)>=1024){t=7136;break}u=c[184736+(s<<2)>>2]|0;if((u|0)==0){v=s;break}if((cS(u|0,q|0)|0)==0){r=s;break L9540}else{s=s+1|0}}do{if((t|0)==7136){t=0;if((s|0)==1024){v=1024;break}if((c[184736+(s<<2)>>2]|0)==0){v=s}else{r=s;break L9540}}}while(0);w1(97944,(w=i,i=i+16|0,c[w>>2]=109816,c[w+8>>2]=q,w)|0);i=w;r=v}}while(0);c[e+72>>2]=r;x=r}else{c[p>>2]=d;q=0;while(1){if((q|0)>=1024){t=7127;break}u=c[184736+(q<<2)>>2]|0;if((u|0)==0){y=q;t=7129;break}if((cS(u|0,95688)|0)==0){z=q;break}else{q=q+1|0}}do{if((t|0)==7127){t=0;if((q|0)==1024){y=1024;t=7129;break}if((c[184736+(q<<2)>>2]|0)==0){y=q;t=7129}else{z=q}}}while(0);if((t|0)==7129){t=0;w1(97944,(w=i,i=i+16|0,c[w>>2]=109816,c[w+8>>2]=95688,w)|0);i=w;z=y}c[e+72>>2]=z;x=z}q=e+72|0;do{if((c[73915]|0)==666){u=(x&65280|0)!=0;A=u&1;if((c[n>>2]&65280|0)==0){if(u){B=A}else{t=7145;break}}else{B=A|2}nV(262872,42);nW(262872,d);nV(262872,B);C=B}else{t=7145}}while(0);if((t|0)==7145){t=0;nV(262872,22);nW(262872,d);C=0}A=c[q>>2]|0;u=c[73915]|0;do{if((u|0)==666){if((C&1|0)==0){nV(262872,A);break}else{nW(262872,A);break}}else if((u|0)==15){nV(262872,A)}else if((u|0)==1e4|(u|0)==10001|(u|0)==10002){nW(262872,A)}else{qa(104784,(w=i,i=i+16|0,c[w>>2]=109672,c[w+8>>2]=u,w)|0);i=w}}while(0);u=c[n>>2]|0;if((C&2|0)==0){nV(262872,u)}else{nW(262872,u)}nV(262872,c[p>>2]|0);nV(262872,c[o>>2]|0);n1(262872,+g[f>>2]);n2(262872,+g[k>>2]);n1(262872,+g[h>>2]);n2(262872,+g[l>>2]);n1(262872,+g[j>>2]);n2(262872,+g[m>>2])}}while(0);d=d+1|0;}while((d|0)<(c[49320]|0));i=b;return}function wc(){var a=0,b=0,d=0,e=0,f=0,h=0,i=0;c[45877]=~~+g[(c[157712]|0)+152>>2];a=c[45876]|0;c[278816]=a;b=c[45874]|0;if((b|0)>0){d=a;e=0;f=b}else{return}while(1){if((c[d>>2]|0)==0){h=d;i=f}else{c[(c[157712]|0)+112>>2]=(c[d+32852>>2]|0)-(c[49322]|0);tm(c[(c[157712]|0)+364>>2]|0);g[(c[278816]|0)+32960>>2]=+g[(c[157712]|0)+172>>2];g[(c[278816]|0)+32964>>2]=+g[(c[157712]|0)+176>>2];g[(c[278816]|0)+32968>>2]=+g[(c[157712]|0)+180>>2];g[(c[278816]|0)+32972>>2]=+g[(c[157712]|0)+184>>2];g[(c[278816]|0)+32976>>2]=+g[(c[157712]|0)+188>>2];g[(c[278816]|0)+32980>>2]=+g[(c[157712]|0)+192>>2];g[(c[278816]|0)+32984>>2]=+g[(c[157712]|0)+196>>2];g[(c[278816]|0)+32988>>2]=+g[(c[157712]|0)+200>>2];g[(c[278816]|0)+32992>>2]=+g[(c[157712]|0)+204>>2];g[(c[278816]|0)+32996>>2]=+g[(c[157712]|0)+208>>2];g[(c[278816]|0)+33e3>>2]=+g[(c[157712]|0)+212>>2];g[(c[278816]|0)+33004>>2]=+g[(c[157712]|0)+216>>2];g[(c[278816]|0)+33008>>2]=+g[(c[157712]|0)+220>>2];g[(c[278816]|0)+33012>>2]=+g[(c[157712]|0)+224>>2];g[(c[278816]|0)+33016>>2]=+g[(c[157712]|0)+228>>2];g[(c[278816]|0)+33020>>2]=+g[(c[157712]|0)+232>>2];h=c[278816]|0;i=c[45874]|0}b=e+1|0;a=h+33032|0;c[278816]=a;if((b|0)<(i|0)){d=a;e=b;f=i}else{break}}return}function wd(b){b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0.0,m=0,n=0,o=0;d=i;i=i+152|0;e=d+128|0;if((a[c[4635]|0]|0)==0){o9(92120,90360)}g[1184]=0.0;oX(88528,(f=i,i=i+8|0,c[f>>2]=b,f)|0);i=f;c[45878]=0;do{if((c[46140]|0)!=0){c[e+8>>2]=d;c[e+16>>2]=0;c[e+12>>2]=128;nU(e,9);n_(e,93752);r8(e,5.0)|0;if((c[353150]|0)==0){break}oy(93752,1)}}while(0);if(+g[5344]!=0.0){pa(86792,0.0)}e=~~(+g[898]+.5);j=(e|0)<0?0:e;e=(j|0)>3?3:j;c[352264]=e;pa(84800,+(e|0));p6();yG(184560,0,111104);yQ(184604,b|0)|0;c[73915]=c[582];tK();c[49321]=2048;c[49322]=x1(c[157718]<<11,82384)|0;c[49327]=32768;c[49328]=0;c[49326]=197316;c[57524]=32768;c[57525]=0;c[57523]=230104;c[65721]=32768;c[65722]=0;c[65720]=262892;e=c[45874]|0;c[49320]=e+1;if((e|0)>0){e=0;while(1){j=e+1|0;k=tq(j)|0;c[(c[45876]|0)+(e*33032|0)+32852>>2]=k;if((j|0)<(c[45874]|0)){e=j}else{break}}}c[49323]=0;c[46141]=0;h[23072]=1.0;yQ(184604,b|0)|0;cl(184668,80408,(f=i,i=i+8|0,c[f>>2]=b,f)|0)|0;i=f;b=rG(184668,0)|0;c[46183]=b;if((b|0)==0){oW(78600,(f=i,i=i+8|0,c[f>>2]=184668,f)|0);i=f;c[46140]=0;i=d;return}c[47209]=b;yk();b=c[157608]|0;c[48232]=b;c[46184]=b;c[46185]=184668;if((c[(c[46183]|0)+120>>2]|0)>1){b=1;do{e=1091928+(b*6|0)|0;b=b+1|0;c[184736+(b<<2)>>2]=e;c[188832+(b<<2)>>2]=rG(e,0)|0;}while((b|0)<(c[(c[46183]|0)+120>>2]|0))}b=tq(0)|0;e=b+96|0;yG(e|0,0,c[(c[157544]|0)+56>>2]<<2|0);c[b>>2]=0;c[b+212>>2]=to(c[46183]|0)|0;g[e>>2]=1.0;g[b+132>>2]=4.0;g[b+128>>2]=7.0;l=+g[5344];if(l!=0.0){g[(c[157712]|0)+144>>2]=l}else{g[(c[157712]|0)+140>>2]=+g[5066]}b=to(184604)|0;c[(c[157712]|0)+136>>2]=b;g[(c[157712]|0)+152>>2]=+(c[45877]|0);tG(c[(c[46183]|0)+384>>2]|0);c[46140]=1;c[49323]=1;h[2332]=.1;wx();wx();wb();b=c[45876]|0;c[278816]=b;e=c[45874]|0;if((e|0)>0){j=b;b=0;k=e;while(1){if((c[j>>2]|0)==0){m=j;n=k}else{v0(j);m=c[278816]|0;n=c[45874]|0}e=b+1|0;o=m+33032|0;c[278816]=o;if((e|0)<(n|0)){j=o;b=e;k=n}else{break}}}oX(77400,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;i=d;return}function we(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+144|0;d=b|0;e=b+16|0;f=b+32|0;h=b+88|0;j=+g[a+136>>2];k=j+ +g[a+228>>2];l=+g[a+140>>2];m=l+ +g[a+232>>2];n=+g[a+144>>2]+ +g[a+236>>2];o=j+ +g[a+240>>2];j=l+ +g[a+244>>2];p=d+8|0;g[p>>2]=n+-1.0;q=d|0;r=d+4|0;d=0;while(1){if((d|0)>=2){s=0;t=7205;break}g[q>>2]=k;g[r>>2]=(d|0)==0?m:j;if((yr(q)|0)==-2){d=d+1|0}else{break}}L9635:do{if((t|0)==7205){while(1){t=0;if((s|0)>=2){break}g[q>>2]=o;g[r>>2]=(s|0)==0?m:j;if((yr(q)|0)==-2){s=s+1|0;t=7205}else{break L9635}}c[651340]=(c[651340]|0)+1;u=1;i=b;return u|0}}while(0);c[651346]=(c[651346]|0)+1;g[p>>2]=n;l=(k+o)*.5;p=e|0;g[p>>2]=l;g[q>>2]=l;l=(m+j)*.5;s=e+4|0;g[s>>2]=l;g[r>>2]=l;g[e+8>>2]=n+-36.0;yt(f,q,117584,117584,p,1,a);n=+g[f+28>>2];if(+g[f+16>>2]==1.0){u=0;i=b;return u|0}f=h+16|0;e=h+28|0;d=0;while(1){if((d|0)>=2){v=0;t=7201;break}g[p>>2]=k;g[q>>2]=k;l=(d|0)==0?m:j;g[s>>2]=l;g[r>>2]=l;yt(h,q,117584,117584,p,1,a);if(+g[f>>2]==1.0){u=0;t=7212;break}if(n- +g[e>>2]>18.0){u=0;t=7213;break}else{d=d+1|0}}if((t|0)==7213){i=b;return u|0}else if((t|0)==7201){while(1){t=0;if((v|0)>=2){t=7202;break}g[p>>2]=o;g[q>>2]=o;k=(v|0)==0?m:j;g[s>>2]=k;g[r>>2]=k;yt(h,q,117584,117584,p,1,a);if(+g[f>>2]==1.0){u=0;t=7208;break}if(n- +g[e>>2]>18.0){u=0;t=7214;break}else{v=v+1|0;t=7201}}if((t|0)==7214){i=b;return u|0}else if((t|0)==7202){c[651340]=(c[651340]|0)+1;u=1;i=b;return u|0}else if((t|0)==7208){i=b;return u|0}}else if((t|0)==7212){i=b;return u|0}return 0}function wf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0.0,q=0,r=0.0,s=0.0,t=0,u=0,v=0.0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0.0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0.0,Q=0.0;e=i;i=i+200|0;f=e|0;h=e+16|0;j=e+32|0;k=e+88|0;l=e+144|0;m=a+136|0;n=+g[m>>2];o=a+140|0;p=+g[o>>2];q=a+144|0;r=+g[q>>2];s=n+ +g[b>>2];t=f|0;g[t>>2]=s;u=b+4|0;v=p+ +g[u>>2];w=f+4|0;g[w>>2]=v;x=b+8|0;y=r+ +g[x>>2];z=f+8|0;g[z>>2]=y;f=a+400|0;if((~~+g[f>>2]&3|0)!=0){A=a+396|0;B=a+228|0;C=a+240|0;D=j+16|0;E=0;while(1){if((E|0)>=2){F=0;G=7250;break}g[t>>2]=+g[m>>2]+ +g[b>>2];g[w>>2]=+g[o>>2]+ +g[u>>2];H=+g[q>>2];I=H+ +g[x>>2];g[z>>2]=I;J=c[49322]|0;K=J;L=c[A>>2]|0;M=K+L|0;do{if(!((E|0)!=0|(M|0)==(J|0))){N=H- +g[K+(L+144)>>2];if(N>40.0){O=I+-8.0;g[z>>2]=O;P=O}else{P=I}if(N>=30.0){break}g[z>>2]=P+8.0}}while(0);yt(j,m,B,C,t,0,a);if(+g[D>>2]==1.0){G=7224;break}if((M|0)==(c[49322]|0)){F=0;G=7255;break}else{E=E+1|0}}if((G|0)==7255){i=e;return F|0}else if((G|0)==7250){i=e;return F|0}else if((G|0)==7224){G=j+20|0;do{if((~~+g[f>>2]&2|0)!=0){if((yr(G)|0)==-1){F=0}else{break}i=e;return F|0}}while(0);g[m>>2]=+g[G>>2];g[o>>2]=+g[j+24>>2];g[q>>2]=+g[j+28>>2];if((d|0)==0){F=1;i=e;return F|0}yn(a,1);F=1;i=e;return F|0}}P=y+18.0;g[z>>2]=P;G=h|0;g[G>>2]=s;g[h+4>>2]=v;g[h+8>>2]=P+-36.0;h=a+228|0;E=a+240|0;yt(k,t,h,E,G,0,a);D=j;C=k;yJ(D|0,C|0,52)|0;C=j|0;if((c[C>>2]|0)!=0){F=0;i=e;return F|0}k=j+4|0;do{if((c[k>>2]|0)!=0){g[z>>2]=+g[z>>2]+-18.0;yt(l,t,h,E,G,0,a);B=l;yJ(D|0,B|0,52)|0;if((c[C>>2]|0)!=0){F=0;i=e;return F|0}if((c[k>>2]|0)==0){break}else{F=0}i=e;return F|0}}while(0);if(+g[j+16>>2]==1.0){P=+g[f>>2];if((~~P&1024|0)==0){F=0;i=e;return F|0}g[m>>2]=+g[m>>2]+ +g[b>>2];g[o>>2]=+g[o>>2]+ +g[u>>2];g[q>>2]=+g[q>>2]+ +g[x>>2];if((d|0)==0){Q=P}else{yn(a,1);Q=+g[f>>2]}g[f>>2]=+(~~Q&-513|0);F=1;i=e;return F|0}g[m>>2]=+g[j+20>>2];g[o>>2]=+g[j+24>>2];g[q>>2]=+g[j+28>>2];x=(we(a)|0)==0;u=~~+g[f>>2];b=(u&1024|0)!=0;if(!x){if(b){g[f>>2]=+(u&-1025|0)}c[a+284>>2]=(c[j+48>>2]|0)-(c[49322]|0);if((d|0)==0){F=1;i=e;return F|0}yn(a,1);F=1;i=e;return F|0}if(!b){g[m>>2]=n;g[o>>2]=p;g[q>>2]=r;F=0;i=e;return F|0}if((d|0)==0){F=1;i=e;return F|0}yn(a,1);F=1;i=e;return F|0}function wg(a,b,c){a=a|0;b=+b;c=+c;var d=0,e=0,f=0,h=0.0,j=0,k=0,l=0,m=0,n=0.0;d=i;i=i+16|0;e=d|0;f=a+436|0;g[f>>2]=b;sh();h=b*3.141592653589793*2.0/360.0;b=c;j=e|0;g[j>>2]=b*+T(+h);g[e+4>>2]=b*+U(+h);g[e+8>>2]=0.0;e=a+136|0;h=+g[e>>2];k=a+140|0;b=+g[k>>2];l=a+144|0;c=+g[l>>2];if((wf(a,j,0)|0)==0){yn(a,1);m=0;i=d;return m|0}n=+g[a+176>>2]- +g[f>>2];if(n>45.0&n<315.0){g[e>>2]=h;g[k>>2]=b;g[l>>2]=c}yn(a,1);m=1;i=d;return m|0}
function wh(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0.0,f=0.0,h=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0.0,p=0.0;d=a+436|0;e=+qS(+(~~(+g[d>>2]/45.0)*45|0|0));f=+qS(e+-180.0);h=+g[b+136>>2]- +g[a+136>>2];i=+g[b+140>>2]- +g[a+140>>2];if(h>10.0){j=0.0}else{j=h<-10.0?180.0:-1.0}if(i<-10.0){k=270.0}else{k=i>10.0?90.0:-1.0}do{if(j!=-1.0&k!=-1.0){b=k==90.0;if(j==0.0){l=b?45.0:315.0}else{l=b?135.0:215.0}if(l==f){break}if((wg(a,l,c)|0)==0){break}return}}while(0);if(((aQ()|0)&1|0)==0){b=~~i;m=~~h;if((((b|0)>-1?b:-b|0)|0)>(((m|0)>-1?m:-m|0)|0)){n=7283}else{o=k;p=j}}else{n=7283}if((n|0)==7283){o=j;p=k}do{if(p!=-1.0&p!=f){if((wg(a,p,c)|0)==0){break}return}}while(0);do{if(o!=-1.0&o!=f){if((wg(a,o,c)|0)==0){break}return}}while(0);do{if(e!=-1.0){if((wg(a,e,c)|0)==0){break}return}}while(0);do{if(((aQ()|0)&1|0)==0){do{if(f!=315.0){if((wg(a,315.0,c)|0)==0){break}return}}while(0);do{if(f!=270.0){if((wg(a,270.0,c)|0)==0){break}return}}while(0);do{if(f!=225.0){if((wg(a,225.0,c)|0)==0){break}return}}while(0);do{if(f!=180.0){if((wg(a,180.0,c)|0)==0){break}return}}while(0);do{if(f!=135.0){if((wg(a,135.0,c)|0)==0){break}return}}while(0);do{if(f!=90.0){if((wg(a,90.0,c)|0)==0){break}return}}while(0);do{if(f!=45.0){if((wg(a,45.0,c)|0)==0){break}return}}while(0);if(f==0.0){break}if((wg(a,0.0,c)|0)==0){break}return}else{do{if(f!=0.0){if((wg(a,0.0,c)|0)==0){break}return}}while(0);do{if(f!=45.0){if((wg(a,45.0,c)|0)==0){break}return}}while(0);do{if(f!=90.0){if((wg(a,90.0,c)|0)==0){break}return}}while(0);do{if(f!=135.0){if((wg(a,135.0,c)|0)==0){break}return}}while(0);do{if(f!=180.0){if((wg(a,180.0,c)|0)==0){break}return}}while(0);do{if(f!=225.0){if((wg(a,225.0,c)|0)==0){break}return}}while(0);do{if(f!=270.0){if((wg(a,270.0,c)|0)==0){break}return}}while(0);if(f==315.0){break}if((wg(a,315.0,c)|0)==0){break}return}}while(0);do{if(f!=-1.0){if((wg(a,f,c)|0)==0){break}return}}while(0);g[d>>2]=e;if((we(a)|0)!=0){return}d=a+400|0;g[d>>2]=+(~~+g[d>>2]|1024|0);return}function wi(){var a=0,b=0,d=0,e=0,f=0,h=0,i=0.0;a=c[49322]|0;b=a;d=c[(c[157712]|0)+112>>2]|0;e=b+d|0;f=b+(c[b+(d+448)>>2]|0)|0;h=c[157708]|0;i=+g[h+16>>2];if((~~+g[b+(d+400)>>2]&515|0)==0){g[h+4>>2]=0.0;return}L9845:do{if((b+(c[b+(d+396)>>2]|0)|0)!=(a|0)){h=0;while(1){if((h|0)>=3){break}if(+g[f+100+(h<<2)>>2]>i+ +g[e+112+(h<<2)>>2]){break L9845}if(+g[f+112+(h<<2)>>2]<+g[e+100+(h<<2)>>2]-i){break L9845}else{h=h+1|0}}return}}while(0);do{if(((aQ()|0)&3|0)!=1){if((wg(e,+g[b+(d+436)>>2],i)|0)==0){break}return}}while(0);wh(e,f,i);return}function wj(a){a=a|0;var b=0,d=0,e=0,f=0,h=0,j=0.0,l=0,m=0,n=0.0,o=0.0,p=0,q=0.0,r=0.0,s=0,t=0.0,u=0.0;b=i;d=a+208|0;e=a+160|0;f=c[e>>2]|0;h=c[3802]|0;j=(c[k>>2]=f,+g[k>>2]);if((h&f|0)==(h|0)){f=ti(c[d>>2]|0)|0;oW(104752,(l=i,i=i+8|0,c[l>>2]=f,l)|0);i=l;g[e>>2]=0.0;m=c[3802]|0;n=0.0}else{m=h;n=j}h=a+136|0;if((m&c[h>>2]|0)==(m|0)){m=ti(c[d>>2]|0)|0;oW(101848,(l=i,i=i+8|0,c[l>>2]=m,l)|0);i=l;g[h>>2]=0.0;o=+g[e>>2]}else{o=n}n=+g[602];do{if(o>n){g[e>>2]=n}else{j=-0.0-n;if(o>=j){break}g[e>>2]=j}}while(0);e=a+164|0;h=c[e>>2]|0;m=c[3802]|0;o=(c[k>>2]=h,+g[k>>2]);if((m&h|0)==(m|0)){h=ti(c[d>>2]|0)|0;oW(104752,(l=i,i=i+8|0,c[l>>2]=h,l)|0);i=l;g[e>>2]=0.0;p=c[3802]|0;q=0.0}else{p=m;q=o}m=a+140|0;if((p&c[m>>2]|0)==(p|0)){p=ti(c[d>>2]|0)|0;oW(101848,(l=i,i=i+8|0,c[l>>2]=p,l)|0);i=l;g[m>>2]=0.0;r=+g[e>>2]}else{r=q}q=+g[602];do{if(r>q){g[e>>2]=q}else{o=-0.0-q;if(r>=o){break}g[e>>2]=o}}while(0);e=a+168|0;m=c[e>>2]|0;p=c[3802]|0;r=(c[k>>2]=m,+g[k>>2]);if((p&m|0)==(p|0)){m=ti(c[d>>2]|0)|0;oW(104752,(l=i,i=i+8|0,c[l>>2]=m,l)|0);i=l;g[e>>2]=0.0;s=c[3802]|0;t=0.0}else{s=p;t=r}p=a+144|0;if((s&c[p>>2]|0)==(s|0)){s=ti(c[d>>2]|0)|0;oW(101848,(l=i,i=i+8|0,c[l>>2]=s,l)|0);i=l;g[p>>2]=0.0;u=+g[e>>2]}else{u=t}t=+g[602];if(u>t){g[e>>2]=t;i=b;return}r=-0.0-t;if(u>=r){i=b;return}g[e>>2]=r;i=b;return}function wk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[157712]|0;e=c[d+112>>2]|0;f=c[d+116>>2]|0;g[d+124>>2]=+h[23072];d=a+264|0;do{if((c[d>>2]|0)!=0){if(+g[a+132>>2]==0.0){break}c[(c[157712]|0)+112>>2]=a-(c[49322]|0);c[(c[157712]|0)+116>>2]=b-(c[49322]|0);tm(c[d>>2]|0)}}while(0);d=b+264|0;do{if((c[d>>2]|0)!=0){if(+g[b+132>>2]==0.0){break}c[(c[157712]|0)+112>>2]=b-(c[49322]|0);c[(c[157712]|0)+116>>2]=a-(c[49322]|0);tm(c[d>>2]|0)}}while(0);c[(c[157712]|0)+112>>2]=e;c[(c[157712]|0)+116>>2]=f;return}function wl(a,b,d){a=a|0;b=+b;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0.0,n=0,o=0.0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ab=0,ac=0,ad=0.0,ae=0.0,af=0.0,ag=0.0,ah=0.0,ai=0.0,aj=0.0,ak=0.0,al=0,am=0,an=0,ao=0.0,ap=0.0,aq=0.0,ar=0.0,as=0.0,at=0.0,au=0.0,av=0.0,aw=0,ax=0,ay=0.0,az=0.0,aA=0.0,aB=0,aC=0,aD=0,aE=0.0,aF=0.0,aG=0.0,aH=0,aI=0.0,aJ=0.0,aK=0.0,aL=0.0,aM=0.0,aN=0.0,aO=0,aP=0,aQ=0,aR=0.0,aS=0.0,aT=0.0,aU=0.0,aV=0.0,aW=0.0;e=i;i=i+168|0;f=e|0;h=e+16|0;j=e+96|0;k=e+112|0;l=a+160|0;m=+g[l>>2];n=a+164|0;o=+g[n>>2];p=a+168|0;q=+g[p>>2];r=a+136|0;s=a+228|0;t=a+240|0;u=j|0;v=k|0;w=k+4|0;x=e+80|0;y=k+16|0;z=k+20|0;A=k+24|0;B=k+28|0;C=k+32|0;D=k+36|0;E=k+40|0;F=k+44|0;G=k+48|0;H=a+140|0;I=a+144|0;J=a+400|0;K=a+284|0;L=a|0;M=h|0;N=h+12|0;O=f|0;P=f+4|0;Q=f+8|0;f=(d|0)==0;R=d|0;S=d+4|0;T=d+16|0;U=d+20|0;V=d+24|0;W=d+28|0;X=d+32|0;Y=d+36|0;Z=d+40|0;_=d+44|0;$=d+48|0;d=0;aa=b;ab=0;ac=0;b=0.0;ad=0.0;ae=0.0;af=m;ag=o;ah=q;ai=m;aj=o;ak=q;while(1){if((ab|0)>=4){al=d;am=7438;break}if(!(ai!=0.0|aj!=0.0|ak!=0.0)){al=d;am=7437;break}g[u>>2]=+g[r>>2]+aa*ai;g[j+4>>2]=+g[H>>2]+aa*aj;g[j+8>>2]=+g[I>>2]+aa*ak;yt(k,r,s,t,u,0,a);an=c[v>>2]|0;c[x>>2]=c[w>>2];c[x+4>>2]=c[w+4>>2];c[x+8>>2]=c[w+8>>2];ao=+g[y>>2];ap=+g[z>>2];aq=+g[A>>2];ar=+g[B>>2];as=+g[C>>2];at=+g[D>>2];au=+g[E>>2];av=+g[F>>2];aw=c[G>>2]|0;if((an|0)!=0){am=7404;break}if(ao>0.0){g[r>>2]=ap;g[H>>2]=aq;g[I>>2]=ar;ax=0;ay=+g[l>>2];az=+g[n>>2];aA=+g[p>>2]}else{ax=ac;ay=af;az=ag;aA=ah}if(ao==1.0){al=d;am=7440;break}if((aw|0)==0){w1(99560,(an=i,i=i+8|0,c[an>>2]=109856,an)|0);i=an}do{if(au>.7){an=d|1;if(+g[aw+132>>2]!=4.0){aB=an;break}g[J>>2]=+(~~+g[J>>2]|512|0);c[K>>2]=aw-(c[49322]|0);aB=an}else{aB=d}}while(0);do{if(au!=0.0){aC=aB}else{an=aB|2;if(f){aC=an;break}c[R>>2]=0;c[S>>2]=c[x>>2];c[S+4>>2]=c[x+4>>2];c[S+8>>2]=c[x+8>>2];g[T>>2]=ao;g[U>>2]=ap;g[V>>2]=aq;g[W>>2]=ar;g[X>>2]=as;g[Y>>2]=at;g[Z>>2]=au;g[_>>2]=av;c[$>>2]=aw;aC=an}}while(0);wk(a,aw);if((c[L>>2]|0)!=0){al=aC;am=7443;break}av=aa-aa*ao;if((ax|0)>4){am=7418;break}g[h+(ax*12|0)>>2]=as;g[h+(ax*12|0)+4>>2]=at;g[h+(ax*12|0)+8>>2]=au;an=ax+1|0;L9926:do{if((an|0)>0){aD=0;ar=b;aq=ad;ap=ae;while(1){if((aD|0)>=(an|0)){aE=ar;aF=aq;aG=ap;aH=aD;break L9926}aI=+g[h+(aD*12|0)+8>>2];aJ=+g[h+(aD*12|0)>>2];aK=+g[h+(aD*12|0)+4>>2];aL=aA*aI+(ay*aJ+az*aK);aM=ay-aJ*aL;aJ=aM;aN=aJ>-.1&aJ<.1?0.0:aM;aM=az-aK*aL;aK=aM;aJ=aK>-.1&aK<.1?0.0:aM;aM=aA-aI*aL;aL=aM;aI=aL>-.1&aL<.1?0.0:aM;aO=0;while(1){if((aO|0)!=(aD|0)){if(aN*+g[h+(aO*12|0)>>2]+aJ*+g[h+(aO*12|0)+4>>2]+aI*+g[h+(aO*12|0)+8>>2]<0.0){aP=aO;break}}aQ=aO+1|0;if((aQ|0)<(an|0)){aO=aQ}else{aP=aQ;break}}if((aP|0)==(an|0)){aE=aN;aF=aJ;aG=aI;aH=aD;break}else{aD=aD+1|0;ar=aN;aq=aJ;ap=aI}}}else{aD=0;ap=b;aq=ad;ar=ae;while(1){if((aD|0)>=(an|0)){aE=ap;aF=aq;aG=ar;aH=aD;break L9926}aM=+g[h+(aD*12|0)+8>>2];aL=+g[h+(aD*12|0)>>2];aK=+g[h+(aD*12|0)+4>>2];aR=aA*aM+(ay*aL+az*aK);aS=ay-aL*aR;aL=aS;aT=aL>-.1&aL<.1?0.0:aS;aS=az-aK*aR;aK=aS;aL=aK>-.1&aK<.1?0.0:aS;aS=aA-aM*aR;aR=aS;aM=aR>-.1&aR<.1?0.0:aS;if((an|0)==0){aE=aT;aF=aL;aG=aM;aH=aD;break}else{aD=aD+1|0;ap=aT;aq=aL;ar=aM}}}}while(0);if((aH|0)==(an|0)){if((an|0)!=2){am=7431;break}qU(M,N,O);q9(O,+g[O>>2]*+g[l>>2]+ +g[P>>2]*+g[n>>2]+ +g[Q>>2]*+g[p>>2],l);aU=+g[l>>2];aV=+g[n>>2];aW=+g[p>>2]}else{g[l>>2]=aE;g[n>>2]=aF;g[p>>2]=aG;aU=aE;aV=aF;aW=aG}if(m*aU+o*aV+q*aW>0.0){d=aC;aa=av;ab=ab+1|0;ac=an;b=aE;ad=aF;ae=aG;af=ay;ag=az;ah=aA;ai=aU;aj=aV;ak=aW}else{am=7434;break}}if((am|0)==7418){g[l>>2]=+g[29396];g[n>>2]=+g[29397];g[p>>2]=+g[29398];al=3;i=e;return al|0}else if((am|0)==7404){g[l>>2]=+g[29396];g[n>>2]=+g[29397];g[p>>2]=+g[29398];al=3;i=e;return al|0}else if((am|0)==7443){i=e;return al|0}else if((am|0)==7431){g[l>>2]=+g[29396];g[n>>2]=+g[29397];g[p>>2]=+g[29398];al=7;i=e;return al|0}else if((am|0)==7434){g[l>>2]=+g[29396];g[n>>2]=+g[29397];g[p>>2]=+g[29398];al=aC;i=e;return al|0}else if((am|0)==7438){i=e;return al|0}else if((am|0)==7437){i=e;return al|0}else if((am|0)==7440){i=e;return al|0}return 0}function wm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0,y=0,z=0;e=i;i=i+224|0;f=e|0;h=e+24|0;j=e+40|0;k=e+56|0;l=e+112|0;m=e+168|0;n=b+136|0;o=j|0;g[o>>2]=+g[n>>2]+ +g[d>>2];p=b+140|0;g[j+4>>2]=+g[p>>2]+ +g[d+4>>2];q=b+144|0;g[j+8>>2]=+g[q>>2]+ +g[d+8>>2];do{if(+g[b+128>>2]==9.0){yt(k,n,b+228|0,b+240|0,o,2,b);d=k;j=f;c[j>>2]=c[d>>2];c[j+4>>2]=c[d+4>>2];c[j+8>>2]=c[d+8>>2];c[j+12>>2]=c[d+12>>2];c[j+16>>2]=c[d+16>>2];r=+g[k+20>>2];s=+g[k+24>>2];t=+g[k+28>>2];d=k+32|0;j=h;c[j>>2]=c[d>>2];c[j+4>>2]=c[d+4>>2];c[j+8>>2]=c[d+8>>2];c[j+12>>2]=c[d+12>>2];u=r;v=s;w=t;x=c[k+48>>2]|0}else{t=+g[b+132>>2];d=b+228|0;j=b+240|0;if(t==1.0|t==0.0){yt(l,n,d,j,o,1,b);y=l;z=f;c[z>>2]=c[y>>2];c[z+4>>2]=c[y+4>>2];c[z+8>>2]=c[y+8>>2];c[z+12>>2]=c[y+12>>2];c[z+16>>2]=c[y+16>>2];t=+g[l+20>>2];s=+g[l+24>>2];r=+g[l+28>>2];y=l+32|0;z=h;c[z>>2]=c[y>>2];c[z+4>>2]=c[y+4>>2];c[z+8>>2]=c[y+8>>2];c[z+12>>2]=c[y+12>>2];u=t;v=s;w=r;x=c[l+48>>2]|0;break}else{yt(m,n,d,j,o,0,b);j=m;d=f;c[d>>2]=c[j>>2];c[d+4>>2]=c[j+4>>2];c[d+8>>2]=c[j+8>>2];c[d+12>>2]=c[j+12>>2];c[d+16>>2]=c[j+16>>2];r=+g[m+20>>2];s=+g[m+24>>2];t=+g[m+28>>2];j=m+32|0;d=h;c[d>>2]=c[j>>2];c[d+4>>2]=c[j+4>>2];c[d+8>>2]=c[j+8>>2];c[d+12>>2]=c[j+12>>2];u=r;v=s;w=t;x=c[m+48>>2]|0;break}}}while(0);g[n>>2]=u;g[p>>2]=v;g[q>>2]=w;yn(b,1);if((x|0)!=0){wk(b,x)}b=a;q=f;c[b>>2]=c[q>>2];c[b+4>>2]=c[q+4>>2];c[b+8>>2]=c[q+8>>2];c[b+12>>2]=c[q+12>>2];c[b+16>>2]=c[q+16>>2];g[a+20>>2]=u;g[a+24>>2]=v;g[a+28>>2]=w;q=a+32|0;b=h;c[q>>2]=c[b>>2];c[q+4>>2]=c[b+4>>2];c[q+8>>2]=c[b+8>>2];c[q+12>>2]=c[b+12>>2];c[a+48>>2]=x;i=e;return}function wn(a,b){a=a|0;b=+b;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0.0,v=0,w=0.0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0,L=0.0,M=0,N=0.0,O=0,P=0.0,Q=0,R=0;d=i;i=i+32872|0;e=d|0;f=d+16|0;h=d+32|0;j=d+48|0;k=d+8240|0;l=d+32816|0;m=+g[a+160>>2];n=+g[a+164>>2];do{if(!(m!=0.0|n!=0.0)){if(+g[a+168>>2]!=0.0){break}o=a+124|0;g[o>>2]=+g[o>>2]+b;i=d;return}}while(0);p=m*b;o=h|0;g[o>>2]=p;q=e|0;g[q>>2]=+g[a+100>>2]+p;r=f|0;g[r>>2]=+g[a+112>>2]+p;m=n*b;g[h+4>>2]=m;s=e+4|0;g[s>>2]=+g[a+104>>2]+m;t=f+4|0;g[t>>2]=+g[a+116>>2]+m;n=+g[a+168>>2]*b;g[h+8>>2]=n;h=e+8|0;g[h>>2]=+g[a+108>>2]+n;e=f+8|0;g[e>>2]=+g[a+120>>2]+n;f=a+136|0;u=+g[f>>2];v=a+140|0;w=+g[v>>2];x=a+144|0;y=+g[x>>2];g[f>>2]=u+p;g[v>>2]=w+m;g[x>>2]=y+n;z=a+124|0;g[z>>2]=+g[z>>2]+b;yn(a,0);if((c[49320]|0)<=1){i=d;return}A=a+132|0;B=1;C=0;D=(c[49322]|0)+(c[157718]|0)|0;L9978:while(1){E=D;do{if((c[D>>2]|0)==0){F=D+128|0;n=+g[F>>2];if(n==7.0|n==0.0|n==8.0){G=C;break}H=D+400|0;if((~~+g[H>>2]&512|0)==0){I=7461}else{if(((c[49322]|0)+(c[D+284>>2]|0)|0)==(a|0)){J=n}else{I=7461}}if((I|0)==7461){I=0;if(+g[D+100>>2]>=+g[r>>2]){G=C;break}if(+g[D+104>>2]>=+g[t>>2]){G=C;break}if(+g[D+108>>2]>=+g[e>>2]){G=C;break}if(+g[D+112>>2]<=+g[q>>2]){G=C;break}if(+g[D+116>>2]<=+g[s>>2]){G=C;break}if(+g[D+120>>2]<=+g[h>>2]){G=C;break}if((ys(E)|0)==0){G=C;break}J=+g[F>>2]}if(J!=3.0){g[H>>2]=+(~~+g[H>>2]&-513|0)}K=D+136|0;L=+g[K>>2];M=D+140|0;N=+g[M>>2];O=D+144|0;P=+g[O>>2];g[k+(C*12|0)>>2]=L;g[k+(C*12|0)+4>>2]=+g[M>>2];g[k+(C*12|0)+8>>2]=+g[O>>2];c[j+(C<<2)>>2]=E;Q=C+1|0;g[A>>2]=0.0;wm(l,E,o);g[A>>2]=4.0;if((ys(E)|0)==0){G=Q;break}H=D+228|0;F=D+240|0;if(+g[H>>2]==+g[F>>2]){G=Q;break}n=+g[D+132>>2];if(!(n==0.0|n==1.0)){break L9978}g[D+232>>2]=0.0;g[H>>2]=0.0;g[F>>2]=0.0;g[D+244>>2]=0.0;g[D+248>>2]=+g[D+236>>2];G=Q}else{G=C}}while(0);F=B+1|0;if((F|0)<(c[49320]|0)){B=F;C=G;D=D+(c[157718]|0)|0}else{I=7484;break}}if((I|0)==7484){i=d;return}g[K>>2]=L;g[M>>2]=N;g[O>>2]=P;yn(E,1);g[f>>2]=u;g[v>>2]=w;g[x>>2]=y;yn(a,0);g[z>>2]=+g[z>>2]-b;z=a+276|0;if((c[z>>2]|0)!=0){c[(c[157712]|0)+112>>2]=a-(c[49322]|0);c[(c[157712]|0)+116>>2]=D-(c[49322]|0);tm(c[z>>2]|0)}if((Q|0)>0){R=0}else{i=d;return}do{z=c[j+(R<<2)>>2]|0;g[z+136>>2]=+g[k+(R*12|0)>>2];g[z+140>>2]=+g[k+(R*12|0)+4>>2];g[z+144>>2]=+g[k+(R*12|0)+8>>2];yn(z,0);R=R+1|0;}while((R|0)<(Q|0));i=d;return}function wo(a){a=a|0;var b=0,d=0,e=0,f=0.0,h=0.0,j=0,k=0.0,l=0,m=0,n=0.0,o=0.0,p=0,q=0;b=i;d=(ys(a)|0)==0;e=a+136|0;f=+g[e>>2];if(d){g[a+148>>2]=f;g[a+152>>2]=+g[a+140>>2];g[a+156>>2]=+g[a+144>>2];i=b;return}d=a+140|0;h=+g[d>>2];j=a+144|0;k=+g[j>>2];g[e>>2]=+g[a+148>>2];g[d>>2]=+g[a+152>>2];g[j>>2]=+g[a+156>>2];if((ys(a)|0)==0){oX(95672,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l;yn(a,1);i=b;return}else{m=0}L10021:while(1){n=k+ +(m|0);o=f+-1.0;p=-1;while(1){if((p|0)>=2){break}g[e>>2]=o;g[d>>2]=h+ +(p|0);g[j>>2]=n;if((ys(a)|0)==0){q=7493;break L10021}else{p=p+1|0}}o=f+0.0;p=-1;while(1){if((p|0)>=2){break}g[e>>2]=o;g[d>>2]=h+ +(p|0);g[j>>2]=n;if((ys(a)|0)==0){q=7493;break L10021}else{p=p+1|0}}o=f+1.0;p=-1;while(1){if((p|0)>=2){break}g[e>>2]=o;g[d>>2]=h+ +(p|0);g[j>>2]=n;if((ys(a)|0)==0){q=7493;break L10021}else{p=p+1|0}}p=m+1|0;if((p|0)<18){m=p}else{q=7495;break}}if((q|0)==7495){g[e>>2]=f;g[d>>2]=h;g[j>>2]=k;oX(93720,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l;i=b;return}else if((q|0)==7493){oX(95672,(l=i,i=i+1|0,i=i+7>>3<<3,c[l>>2]=0,l)|0);i=l;yn(a,1);i=b;return}}function wp(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,h=0,j=0,k=0;b=i;i=i+16|0;c=b|0;d=c|0;g[d>>2]=+g[a+136>>2];g[c+4>>2]=+g[a+140>>2];e=a+144|0;f=a+236|0;h=c+8|0;g[h>>2]=+g[e>>2]+ +g[f>>2]+1.0;c=a+428|0;g[c>>2]=0.0;j=a+432|0;g[j>>2]=-1.0;k=yr(d)|0;do{if((k|0)<-2){g[j>>2]=+(k|0);g[c>>2]=1.0;g[h>>2]=+g[e>>2]+(+g[f>>2]+ +g[a+248>>2])*.5;if((yr(d)|0)>=-2){break}g[c>>2]=2.0;g[h>>2]=+g[e>>2]+ +g[a+352>>2];if((yr(d)|0)>=-2){break}g[c>>2]=3.0}}while(0);i=b;return+g[c>>2]>1.0|0}function wq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,j=0.0,k=0.0,l=0.0,m=0.0;c=i;i=i+64|0;d=c|0;e=c+48|0;f=d|0;rc(a+376|0,f,c+16|0,c+32|0);h=b+32|0;j=+g[h>>2];k=+g[b+36>>2];l=+g[b+40>>2];m=j*+g[f>>2]+k*+g[d+4>>2]+l*+g[d+8>>2]+.5;if(m>=0.0){i=c;return}d=a+160|0;f=a+164|0;b=e|0;q9(h,j*+g[d>>2]+k*+g[f>>2]+l*+g[a+168>>2],b);l=+g[f>>2]- +g[e+4>>2];k=m+1.0;g[d>>2]=k*(+g[d>>2]- +g[b>>2]);g[f>>2]=k*l;i=c;return}function wr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,h=0,j=0.0,k=0,l=0.0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c=i;i=i+128|0;d=c|0;e=c+16|0;f=c+72|0;h=a+136|0;j=+g[h>>2];k=a+140|0;l=+g[k>>2];m=a+144|0;n=+g[m>>2];o=d|0;g[o>>2]=+g[29396];p=d+4|0;g[p>>2]=+g[29397];g[d+8>>2]=+g[29398];d=a+160|0;q=b+4|0;r=a+164|0;s=a+168|0;t=0;while(1){switch(t|0){case 5:{g[o>>2]=-2.0;g[p>>2]=2.0;break};case 7:{g[o>>2]=-2.0;g[p>>2]=-2.0;break};case 2:{g[o>>2]=-2.0;g[p>>2]=0.0;break};case 1:{g[o>>2]=0.0;g[p>>2]=2.0;break};case 4:{g[o>>2]=2.0;g[p>>2]=2.0;break};case 0:{g[o>>2]=2.0;g[p>>2]=0.0;break};case 3:{g[o>>2]=0.0;g[p>>2]=-2.0;break};case 6:{g[o>>2]=2.0;g[p>>2]=-2.0;break};default:{}}wm(f,a,o);g[d>>2]=+g[b>>2];g[r>>2]=+g[q>>2];g[s>>2]=0.0;u=wl(a,.10000000149011612,e)|0;if(+Q(+(l- +g[k>>2]))>4.0){v=u;w=7534;break}if(+Q(+(j- +g[h>>2]))>4.0){v=u;w=7532;break}g[h>>2]=j;g[k>>2]=l;g[m>>2]=n;u=t+1|0;if((u|0)<8){t=u}else{w=7530;break}}if((w|0)==7530){g[d>>2]=+g[29396];g[r>>2]=+g[29397];g[s>>2]=+g[29398];v=7;i=c;return v|0}else if((w|0)==7532){i=c;return v|0}else if((w|0)==7534){i=c;return v|0}return 0}function ws(a){a=a|0;var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0.0,s=0,t=0.0,u=0,v=0.0,w=0,x=0,y=0.0,z=0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0;b=i;i=i+216|0;d=b|0;e=b+16|0;f=b+32|0;j=b+48|0;k=b+104|0;l=b+160|0;m=a+400|0;n=~~+g[m>>2];g[m>>2]=+(n&-513|0);o=a+136|0;p=+g[o>>2];q=a+140|0;r=+g[q>>2];s=a+144|0;t=+g[s>>2];u=a+160|0;v=+g[u>>2];w=f|0;g[w>>2]=v;x=a+164|0;y=+g[x>>2];g[f+4>>2]=y;z=a+168|0;A=+g[z>>2];g[f+8>>2]=A;if(((wl(a,+h[2332],j)|0)&2|0)==0){i=b;return}do{if((n&512|0)==0){if(+g[a+428>>2]!=0.0){break}i=b;return}}while(0);if(+g[a+128>>2]!=3.0|+g[588]!=0.0){i=b;return}if((~~+g[(c[45880]|0)+400>>2]&2048|0)!=0){i=b;return}B=+g[o>>2];C=+g[q>>2];D=+g[s>>2];E=+g[u>>2];F=+g[x>>2];G=+g[z>>2];g[o>>2]=p;g[q>>2]=r;g[s>>2]=t;t=+g[29396];n=d|0;g[n>>2]=t;H=+g[29397];g[d+4>>2]=H;f=e|0;g[f>>2]=t;g[e+4>>2]=H;g[d+8>>2]=18.0;g[e+8>>2]=A*+h[2332]+-18.0;wm(k,a,n);g[u>>2]=v;g[x>>2]=y;g[z>>2]=0.0;n=wl(a,+h[2332],j)|0;do{if((n|0)!=0){do{if(+Q(+(r- +g[q>>2]))<.03125){if(+Q(+(p- +g[o>>2]))>=.03125){I=n;break}I=wr(a,w)|0}else{I=n}}while(0);if((I&2|0)==0){break}wq(a,j)}}while(0);wm(l,a,f);f=c[l+48>>2]|0;if(+g[l+40>>2]<=.7){g[o>>2]=B;g[q>>2]=C;g[s>>2]=D;g[u>>2]=E;g[x>>2]=F;g[z>>2]=G;i=b;return}if(+g[a+132>>2]!=4.0){i=b;return}g[m>>2]=+(~~+g[m>>2]|512|0);c[a+284>>2]=f-(c[49322]|0);i=b;return}function wt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0,r=0.0;d=i;if((c[(c[45876]|0)+((b-1|0)*33032|0)>>2]|0)==0){i=d;return}g[(c[157712]|0)+124>>2]=+h[23072];b=a;c[(c[157712]|0)+112>>2]=b-(c[49322]|0);tm(c[(c[157712]|0)+336>>2]|0);wj(a);e=~~+g[a+128>>2];L10105:do{switch(e|0){case 5:{f=a+280|0;j=+g[f>>2];do{if(j>0.0){k=j;l=+h[23072];if(k>l+ +h[2332]){break}if(k<l){m=l}else{m=j}g[f>>2]=0.0;g[(c[157712]|0)+124>>2]=m;c[(c[157712]|0)+112>>2]=b-(c[49322]|0);c[(c[157712]|0)+116>>2]=0;tm(c[a+272>>2]|0);if((c[a>>2]|0)==0){break}i=d;return}}while(0);wl(a,+h[2332],0)|0;break};case 6:case 10:{wu(a);break};case 8:{f=a+280|0;j=+g[f>>2];do{if(j>0.0){l=j;k=+h[23072];if(l>k+ +h[2332]){break}if(l<k){n=k}else{n=j}g[f>>2]=0.0;g[(c[157712]|0)+124>>2]=n;c[(c[157712]|0)+112>>2]=b-(c[49322]|0);c[(c[157712]|0)+116>>2]=0;tm(c[a+272>>2]|0);if((c[a>>2]|0)==0){break}i=d;return}}while(0);f=a+136|0;q7(f,+h[2332],a+160|0,f);break};case 0:{f=a+280|0;j=+g[f>>2];if(j<=0.0){break L10105}k=j;l=+h[23072];if(k>l+ +h[2332]){break L10105}if(k<l){o=l}else{o=j}g[f>>2]=0.0;g[(c[157712]|0)+124>>2]=o;c[(c[157712]|0)+112>>2]=b-(c[49322]|0);c[(c[157712]|0)+116>>2]=0;tm(c[a+272>>2]|0);if((c[a>>2]|0)==0){break L10105}i=d;return};case 3:{f=a+280|0;j=+g[f>>2];do{if(j>0.0){l=j;k=+h[23072];if(l>k+ +h[2332]){break}if(l<k){p=k}else{p=j}g[f>>2]=0.0;g[(c[157712]|0)+124>>2]=p;c[(c[157712]|0)+112>>2]=b-(c[49322]|0);c[(c[157712]|0)+116>>2]=0;tm(c[a+272>>2]|0);if((c[a>>2]|0)==0){break}i=d;return}}while(0);do{if((wp(a)|0)==0){if((~~+g[a+400>>2]&2048|0)!=0){break}f=ts(a,97936)|0;if((f|0)==0){q=7574}else{j=+g[f>>2];if(j!=0.0){r=j}else{q=7574}}if((q|0)==7574){r=1.0}f=a+168|0;g[f>>2]=+g[f>>2]- +h[2332]*r*+g[644]}}while(0);wo(a);ws(a);break};default:{w1(92088,(f=i,i=i+16|0,c[f>>2]=109776,c[f+8>>2]=e,f)|0);i=f}}}while(0);yn(a,1);g[(c[157712]|0)+124>>2]=+h[23072];c[(c[157712]|0)+112>>2]=b-(c[49322]|0);tm(c[(c[157712]|0)+340>>2]|0);i=d;return}function wu(a){a=a|0;var b=0,d=0,e=0,f=0,j=0.0,k=0.0,l=0.0,m=0.0,n=0,o=0,p=0,q=0.0,r=0,s=0.0,t=0.0,u=0.0,v=0.0;b=i;i=i+72|0;d=b|0;e=b+16|0;f=a+280|0;j=+g[f>>2];do{if(j>0.0){k=j;l=+h[23072];if(k>l+ +h[2332]){break}if(k<l){m=l}else{m=j}g[f>>2]=0.0;g[(c[157712]|0)+124>>2]=m;c[(c[157712]|0)+112>>2]=a-(c[49322]|0);c[(c[157712]|0)+116>>2]=0;tm(c[a+272>>2]|0);if((c[a>>2]|0)==0){break}i=b;return}}while(0);f=a+400|0;if((~~+g[f>>2]&512|0)!=0){i=b;return}wj(a);n=a+128|0;m=+g[n>>2];if(m!=5.0&m!=9.0){o=ts(a,97936)|0;if((o|0)==0){p=7608}else{m=+g[o>>2];if(m!=0.0){q=m}else{p=7608}}if((p|0)==7608){q=1.0}p=a+168|0;g[p>>2]=+g[p>>2]- +h[2332]*q*+g[644]}p=a+172|0;o=a+184|0;q7(p,+h[2332],o,p);p=a+160|0;r=d|0;q9(p,+h[2332],r);wm(e,a,r);q=+g[e+32>>2];m=+g[e+36>>2];j=+g[e+40>>2];r=c[e+48>>2]|0;if(+g[e+16>>2]==1.0){i=b;return}if((c[a>>2]|0)!=0){i=b;return}l=+g[n>>2];k=+g[p>>2];n=a+164|0;s=+g[n>>2];e=a+168|0;t=+g[e>>2];u=(l==10.0?1.5:1.0)*(q*k+m*s+j*t);v=k-q*u;q=v;g[p>>2]=q>-.1&q<.1?0.0:v;v=s-m*u;m=v;g[n>>2]=m>-.1&m<.1?0.0:v;v=t-j*u;u=v;t=u>-.1&u<.1?0.0:v;g[e>>2]=t;do{if(j>.7){if(!(t<60.0|l!=10.0)){break}g[f>>2]=+(~~+g[f>>2]|512|0);c[a+284>>2]=r-(c[49322]|0);g[p>>2]=+g[29396];g[n>>2]=+g[29397];g[e>>2]=+g[29398];g[o>>2]=+g[29396];g[a+188>>2]=+g[29397];g[a+192>>2]=+g[29398]}}while(0);o=yr(a+136|0)|0;e=a+432|0;l=+g[e>>2];if(l==0.0){g[e>>2]=+(o|0);g[a+428>>2]=1.0;i=b;return}if((o|0)<-2){if(l==-1.0){v$(a,0,90328,255,1.0)}g[e>>2]=+(o|0);g[a+428>>2]=1.0;i=b;return}else{if(l!=-1.0){v$(a,0,90328,255,1.0)}g[e>>2]=-1.0;g[a+428>>2]=+(o|0);i=b;return}}function wv(a){a=a|0;var b=0,d=0.0,e=0.0,f=0.0,i=0.0;b=a+280|0;d=+g[b>>2];do{if(d>0.0){e=d;f=+h[23072];if(e>f+ +h[2332]){break}if(e<f){i=f}else{i=d}g[b>>2]=0.0;g[(c[157712]|0)+124>>2]=i;c[(c[157712]|0)+112>>2]=a-(c[49322]|0);c[(c[157712]|0)+116>>2]=0;tm(c[a+272>>2]|0);if((c[a>>2]|0)==0){break}return}}while(0);b=a+172|0;q7(b,+h[2332],a+184|0,b);b=a+136|0;q7(b,+h[2332],a+160|0,b);yn(a,0);return}function ww(a){a=a|0;var b=0,d=0,e=0.0,f=0.0,i=0,j=0,k=0.0,l=0.0,m=0.0;b=a+400|0;do{if((~~+g[b>>2]&515|0)==0){d=a+168|0;e=+g[d>>2];f=+g[644]*-.1;i=ts(a,97936)|0;if((i|0)==0){j=7644}else{k=+g[i>>2];if(k!=0.0){l=k}else{j=7644}}if((j|0)==7644){l=1.0}g[d>>2]=+g[d>>2]- +h[2332]*l*+g[644];wj(a);k=+h[2332];wl(a,k,0)|0;yn(a,1);if((~~+g[b>>2]&512|0)==0|e>=f){break}v$(a,0,88488,255,1.0)}}while(0);b=a+280|0;l=+g[b>>2];do{if(l>0.0){f=l;e=+h[23072];if(f>e+ +h[2332]){break}if(f<e){m=e}else{m=l}g[b>>2]=0.0;g[(c[157712]|0)+124>>2]=m;c[(c[157712]|0)+112>>2]=a-(c[49322]|0);c[(c[157712]|0)+116>>2]=0;tm(c[a+272>>2]|0)}}while(0);b=yr(a+136|0)|0;j=a+432|0;m=+g[j>>2];if(m==0.0){g[j>>2]=+(b|0);g[a+428>>2]=1.0;return}if((b|0)<-2){if(m==-1.0){v$(a,0,90328,255,1.0)}g[j>>2]=+(b|0);g[a+428>>2]=1.0;return}else{if(m!=-1.0){v$(a,0,90328,255,1.0)}g[j>>2]=-1.0;g[a+428>>2]=+(b|0);return}}function wx(){var a=0,b=0,d=0,e=0.0,f=0,j=0.0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0,q=0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0;a=i;c[(c[157712]|0)+112>>2]=0;c[(c[157712]|0)+116>>2]=0;g[(c[157712]|0)+124>>2]=+h[23072];tm(c[(c[157712]|0)+332>>2]|0);if((c[49320]|0)>0){b=0;d=c[49322]|0;while(1){do{if((c[d>>2]|0)==0){if(+g[(c[157712]|0)+132>>2]!=0.0){yn(d,1)}if(!((b|0)<1|(b|0)>(c[45874]|0))){wt(d,b);break}e=+g[d+128>>2];if(e==7.0){f=d+124|0;j=+g[f>>2];k=d+280|0;l=+g[k>>2];m=+h[2332];if(l<j+m){n=l-j;if(n>=0.0){o=n;p=7676}}else{o=m;p=7676}do{if((p|0)==7676){p=0;if(o==0.0){break}wn(d,o)}}while(0);if(l<=j){break}if(l>+g[f>>2]){break}g[k>>2]=0.0;g[(c[157712]|0)+124>>2]=+h[23072];c[(c[157712]|0)+112>>2]=d-(c[49322]|0);c[(c[157712]|0)+116>>2]=0;tm(c[d+272>>2]|0);break}if(e==0.0){q=d+280|0;m=+g[q>>2];if(m<=0.0){break}n=m;r=+h[23072];if(n>r+ +h[2332]){break}if(n<r){s=r}else{s=m}g[q>>2]=0.0;g[(c[157712]|0)+124>>2]=s;c[(c[157712]|0)+112>>2]=d-(c[49322]|0);c[(c[157712]|0)+116>>2]=0;tm(c[d+272>>2]|0);break}if(e==8.0){wv(d);break}if(e==4.0){ww(d);break}if(e==6.0|e==10.0|e==5.0|e==9.0){wu(d);break}else{w1(92088,(q=i,i=i+16|0,c[q>>2]=109800,c[q+8>>2]=~~e,q)|0);i=q;break}}}while(0);q=b+1|0;if((q|0)<(c[49320]|0)){b=q;d=d+(c[157718]|0)|0}else{break}}}d=(c[157712]|0)+132|0;s=+g[d>>2];if(s==0.0){t=+h[2332];u=+h[23072];v=t+u;h[23072]=v;i=a;return}g[d>>2]=s+-1.0;t=+h[2332];u=+h[23072];v=t+u;h[23072]=v;i=a;return}function wy(){var a=0,b=0,d=0,e=0,f=0,h=0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0,x=0,y=0,z=0;a=i;i=i+112|0;b=a|0;d=a+16|0;e=a+32|0;f=a+56|0;h=c[45880]|0;if((~~+g[h+400>>2]&512|0)==0){i=a;return}j=+g[h+176>>2]*3.141592653589793*2.0/360.0;k=+U(+j);l=+T(+j);m=b|0;n=b+4|0;o=b+8|0;b=d|0;p=d+4|0;q=d+8|0;d=f|0;r=f+16|0;s=0;t=h;while(1){j=+(s+3|0);u=l*j*12.0+ +g[t+136>>2];g[m>>2]=u;v=k*j*12.0+ +g[t+140>>2];g[n>>2]=v;j=+g[t+144>>2]+ +g[t+352>>2];g[o>>2]=j;g[b>>2]=u;g[p>>2]=v;g[q>>2]=j+-160.0;yt(f,m,117584,117584,b,1,t);j=+g[r>>2];if((c[d>>2]|0)!=0|j==1.0){w=7717;break}v=+g[o>>2];g[e+(s<<2)>>2]=v+j*(+g[q>>2]-v);x=s+1|0;if((x|0)>=6){break}s=x;t=c[45880]|0}if((w|0)==7717){i=a;return}do{if((s|0)>0){t=1;q=0;o=0;k=+g[e>>2];while(1){l=+g[e+(t<<2)>>2];d=~~(l-k);if((d|0)==0){y=o;z=q}else{if(!((q|0)==0|(d|0)==(q|0))){w=7720;break}y=o+1|0;z=d}d=t+1|0;if((d|0)<(x|0)){t=d;q=z;o=y;k=l}else{break}}if((w|0)==7720){i=a;return}if((z|0)==0){break}if((y|0)<2){i=a;return}g[(c[45880]|0)+388>>2]=+(-z|0)*+g[630];i=a;return}}while(0);g[(c[45880]|0)+388>>2]=0.0;i=a;return}function wz(){var a=0,b=0,d=0,e=0,f=0,j=0.0,k=0,l=0.0,m=0.0,n=0,o=0,p=0,q=0,r=0.0;a=i;i=i+88|0;b=a|0;d=a+16|0;e=a+32|0;f=c[29394]|0;j=+g[f>>2];k=f+4|0;l=+g[k>>2];m=+R(+(j*j+l*l));if(m==0.0){i=a;return}n=c[159932]|0;l=+g[n>>2]+j/m*16.0;o=d|0;g[o>>2]=l;p=b|0;g[p>>2]=l;l=+g[n+4>>2]+ +g[k>>2]/m*16.0;g[d+4>>2]=l;g[b+4>>2]=l;q=c[45880]|0;l=+g[n+8>>2]+ +g[q+236>>2];g[b+8>>2]=l;g[d+8>>2]=l+-34.0;yt(e,p,117584,117584,o,1,q);l=+g[658];if(+g[e+16>>2]==1.0){r=l*+g[672]}else{r=l}l=+g[556];j=m-r*+h[2332]*(m<l?l:m);l=(j<0.0?0.0:j)/m;g[f>>2]=l*+g[f>>2];g[k>>2]=l*+g[k>>2];k=f+8|0;g[k>>2]=l*+g[k>>2];i=a;return}function wA(){var a=0,b=0,d=0.0,e=0.0,f=0,j=0,k=0.0,l=0,m=0.0,n=0.0,o=0.0,p=0.0;a=i;i=i+16|0;b=a|0;rc((c[45880]|0)+376|0,1402248,622496,117600);d=+g[353147];e=+g[353148];f=b|0;g[f>>2]=+g[350562]*d+ +g[155624]*e;j=b+4|0;g[j>>2]=+g[350563]*d+ +g[155625]*e;k=+g[350564]*d+ +g[155626]*e;l=b+8|0;g[l>>2]=k;m=+g[353149];if(d!=0.0|e!=0.0|m!=0.0){n=m+k}else{n=k+-60.0}g[l>>2]=n;n=+rd(f);k=+g[616];if(n>k){q9(f,k/n,f);o=+g[616]}else{o=n}n=o*.7;o=+rd(c[29394]|0);if(o!=0.0){k=o;m=k-k*+h[2332]*+g[658];k=m<0.0?0.0:m;b=c[29394]|0;q9(b,k/o,b);p=k}else{p=0.0}if(n==0.0){i=a;return}k=n-p;if(k<=0.0){i=a;return}+q1(f);p=+h[2332]*n*+g[700];n=p>k?k:p;b=c[29394]|0;g[b>>2]=n*+g[f>>2]+ +g[b>>2];b=(c[29394]|0)+4|0;g[b>>2]=n*+g[j>>2]+ +g[b>>2];b=(c[29394]|0)+8|0;g[b>>2]=n*+g[l>>2]+ +g[b>>2];i=a;return}function wB(){var a=0,b=0,d=0.0,e=0.0,f=0,j=0.0,k=0,l=0.0,m=0,n=0,o=0.0;a=i;i=i+16|0;b=a|0;rc((c[45880]|0)+172|0,1402248,622496,117600);d=+g[353147];e=+g[353148];f=c[45880]|0;j=+h[23072]<+g[f+416>>2]&d<0.0?0.0:d;d=j*+g[350562]+e*+g[155624];k=b|0;g[k>>2]=d;l=j*+g[350563]+e*+g[155625];m=b+4|0;g[m>>2]=l;n=b+8|0;g[n>>2]=j*+g[350564]+e*+g[155626];e=(~~+g[f+128>>2]|0)==3?0.0:+g[353149];g[n>>2]=e;g[29308]=d;g[29309]=l;g[29310]=e;e=+q1(117232);g[24]=e;l=+g[616];if(e>l){q9(k,l/e,k);g[24]=+g[616]}if(+g[(c[45880]|0)+128>>2]==8.0){g[c[29394]>>2]=+g[k>>2];g[(c[29394]|0)+4>>2]=+g[m>>2];g[(c[29394]|0)+8>>2]=+g[n>>2];i=a;return}if((c[159938]|0)==0){e=+q1(k);f=c[29394]|0;l=+g[f>>2];d=+g[k>>2];j=(e>30.0?30.0:e)-(l*d+ +g[f+4>>2]*+g[m>>2]+ +g[f+8>>2]*+g[n>>2]);if(j<=0.0){i=a;return}e=+h[2332]*+g[700]*+g[24];o=e>j?j:e;g[f>>2]=l+d*o;f=(c[29394]|0)+4|0;g[f>>2]=+g[f>>2]+ +g[m>>2]*o;m=(c[29394]|0)+8|0;g[m>>2]=+g[n>>2]*o+ +g[m>>2];i=a;return}else{wz();m=c[29394]|0;o=+g[m>>2];d=+g[29308];l=+g[24];e=l-(o*d+ +g[m+4>>2]*+g[29309]+ +g[m+8>>2]*+g[29310]);if(e<=0.0){i=a;return}j=l*+g[700]*+h[2332];l=j>e?e:j;g[m>>2]=o+d*l;m=(c[29394]|0)+4|0;g[m>>2]=+g[m>>2]+ +g[29309]*l;m=(c[29394]|0)+8|0;g[m>>2]=+g[29310]*l+ +g[m>>2];i=a;return}}function wC(){var a=0,b=0.0,d=0.0,e=0,f=0.0,i=0.0,j=0.0,k=0,l=0,m=0;a=c[45880]|0;if(+g[a+128>>2]==0.0){return}c[159938]=~~+g[a+400>>2]&512;c[159932]=a+136;c[29394]=a+160;b=+q1(a+196|0);d=b- +h[2332]*10.0;a=(c[45880]|0)+196|0;q9(a,d<0.0?0.0:d,a);a=c[45880]|0;if(+g[a+288>>2]<=0.0){return}e=(c[278816]|0)+28|0;c[353144]=c[e>>2];c[353145]=c[e+4>>2];c[353146]=c[e+8>>2];c[353147]=c[e+12>>2];c[353148]=c[e+16>>2];c[353149]=c[e+20>>2];e=a+172|0;c[664762]=e;d=+g[a+376>>2];b=+g[a+196>>2];f=+g[a+380>>2];i=+g[a+200>>2];j=+xK(e,a+160|0)*4.0;g[(c[664762]|0)+8>>2]=j;a=c[45880]|0;if(+g[a+372>>2]!=0.0){k=a}else{g[c[664762]>>2]=(-0.0-(d+b))/3.0;g[(c[664762]|0)+4>>2]=f+i;k=c[45880]|0}a=k+400|0;e=~~+g[a>>2];if((e&2048|0)!=0){if(+h[23072]>+g[k+416>>2]){l=7765}else{if(+g[k+428>>2]!=0.0){m=k}else{l=7765}}if((l|0)==7765){g[a>>2]=+(e&-2049|0);g[(c[45880]|0)+416>>2]=0.0;m=c[45880]|0}g[m+160>>2]=+g[m+480>>2];m=c[45880]|0;g[m+164>>2]=+g[m+484>>2];return}do{if(+g[k+428>>2]>=2.0){if(+g[k+128>>2]==8.0){break}wA();return}}while(0);wB();return}function wD(a,b){a=a|0;b=b|0;return}function wE(a,b,c){a=a|0;b=b|0;c=c|0;return}function wF(){return 0}function wG(){return}function wH(){return}function wI(){a[18496]=1;return}function wJ(){return}function wK(){return 1}function wL(a,b){a=a|0;b=b|0;return}function wM(a){a=a|0;c[660660]=a;return}function wN(a){a=a|0;c[664760]=a;return}function wO(a){a=a|0;c[158752]=a;return}function wP(a){a=a|0;c[278436]=a;return}function wQ(a){a=a|0;c[29368]=a;return}function wR(){return}function wS(a){a=a|0;h[a+24>>3]=+g[4848];h[a+32>>3]=44100.0;c[a>>2]=c[29312];c[a+4>>2]=c[278838];c[a+8>>2]=1024;c[a+12>>2]=768;g[a+16>>2]=1.3333333730697632;return}function wT(a){a=a|0;var b=0.0,d=0.0,e=0,f=0.0,i=0.0,j=0.0;b=+h[23072];d=b- +nO();e=c[278816]|0;g[e+32892+(((c[e+32956>>2]|0)%16|0)<<2)>>2]=d;e=(c[278816]|0)+32956|0;c[e>>2]=(c[e>>2]|0)+1;if((c[73915]|0)==666){f=+nS()}else{f=+nR()}if((c[73915]|0)==666){i=+nS()}else{i=+nR()}if((c[73915]|0)==666){j=+nS()}else{j=+nR()}g[(c[(c[278816]|0)+32852>>2]|0)+376>>2]=f;g[(c[(c[278816]|0)+32852>>2]|0)+380>>2]=i;g[(c[(c[278816]|0)+32852>>2]|0)+384>>2]=j;g[a+12>>2]=+(nM()|0);g[a+16>>2]=+(nM()|0);g[a+20>>2]=+(nM()|0);a=nL()|0;g[(c[(c[278816]|0)+32852>>2]|0)+356>>2]=+(a&1|0);g[(c[(c[278816]|0)+32852>>2]|0)+364>>2]=+(a>>>1&1|0);a=nL()|0;if((a|0)==0){return}g[(c[(c[278816]|0)+32852>>2]|0)+368>>2]=+(a|0);return}function wU(){var a=0,b=0,d=0,e=0,f=0;a=i;L10421:while(1){b=r4(c[(c[278816]|0)+24>>2]|0)|0;if((b|0)==(-1|0)){d=7809;break}else if((b|0)==0){e=1;d=7843;break}nJ();if((c[c[278816]>>2]|0)==0){e=0;d=7842;break}while(1){if((c[169380]|0)!=0){d=7812;break L10421}L10427:do{switch(nK()|0){case 4:{b=nP()|0;do{if((yL(b|0,104744,6)|0)!=0){if((yL(b|0,101824,3)|0)==0){break}if((yL(b|0,99520,8)|0)==0){break}if((yL(b|0,97928,3)|0)==0){break}if((yL(b|0,95640,4)|0)==0){break}if((yL(b|0,93712,6)|0)==0){break}if((yL(b|0,92080,3)|0)==0){break}if((yL(b|0,90312,8)|0)==0){break}if((yL(b|0,88480,4)|0)==0){break}if((yL(b|0,86784,5)|0)==0){break}if((yL(b|0,84792,4)|0)==0){break}if((yL(b|0,82376,5)|0)==0){break}if((yL(b|0,80400,5)|0)==0){break}if((yL(b|0,78592,5)|0)==0){break}if((yL(b|0,77384,8)|0)==0){break}if((yL(b|0,75960,4)|0)==0){break}if((yL(b|0,74760,4)|0)==0){break}if((yL(b|0,73832,4)|0)==0){break}if((yL(b|0,72784,3)|0)==0){break}oX(71880,(f=i,i=i+16|0,c[f>>2]=(c[278816]|0)+32856,c[f+8>>2]=b,f)|0);i=f;break L10427}}while(0);oy(b,0);break};case 2:{e=0;d=7840;break L10421;break};case 1:{break};case-1:{continue L10421;break};case 3:{wT((c[278816]|0)+28|0);break};default:{d=7814;break L10421}}}while(0);if((c[c[278816]>>2]|0)==0){e=0;d=7841;break L10421}}}if((d|0)==7809){wD(41728,(f=i,i=i+8|0,c[f>>2]=109752,f)|0);i=f;e=0;i=a;return e|0}else if((d|0)==7840){i=a;return e|0}else if((d|0)==7841){i=a;return e|0}else if((d|0)==7842){i=a;return e|0}else if((d|0)==7843){i=a;return e|0}else if((d|0)==7812){wD(38104,(f=i,i=i+8|0,c[f>>2]=109752,f)|0);i=f;e=0;i=a;return e|0}else if((d|0)==7814){wD(108072,(f=i,i=i+8|0,c[f>>2]=109752,f)|0);i=f;e=0;i=a;return e|0}return 0}function wV(){var a=0,b=0,d=0;a=c[45876]|0;c[278816]=a;if((c[45874]|0)>0){b=a;d=0}else{return}do{do{if((c[b>>2]|0)!=0){c[45880]=c[b+32852>>2];if((wU()|0)==0){p5(0);break}a=c[278816]|0;if((c[a+4>>2]|0)==0){yG(a+28|0,0,24);break}if((c[46141]|0)!=0){break}if(!((c[45874]|0)>1|(c[278172]|0)==0)){break}wC()}}while(0);d=d+1|0;b=(c[278816]|0)+33032|0;c[278816]=b;}while((d|0)<(c[45874]|0));return}function wW(){qc();return}function wX(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+72|0;d=b|0;if((eP(a|0,d|0)|0)==-1){e=-1}else{e=c[d+40>>2]|0}i=b;return e|0}function wY(a){a=a|0;bG(a|0,511)|0;return}function wZ(){var a=0,b=0,d=0,e=0,f=0.0;a=i;i=i+16|0;b=a|0;dO(b|0,a+8|0)|0;d=c[665018]|0;e=c[b>>2]|0;if((d|0)==0){c[665018]=e;f=+(c[b+4>>2]|0)/1.0e6;i=a;return+f}else{f=+(e-d|0)+ +(c[b+4>>2]|0)/1.0e6;i=a;return+f}return 0.0}function w_(b){b=b|0;yG(b|0,0,16);c[b>>2]=69320;c[b+4>>2]=59808;a[b+12|0]=0;c[b+8>>2]=54112;return}function w$(a){a=a|0;var b=0,d=0;b=i;i=i+24|0;c[350582]=a;d=b|0;c[d>>2]=c[1476];c[d+4>>2]=c[1477];c[d+8>>2]=c[1478];c[d+12>>2]=c[1479];c[d+16>>2]=c[1480];c[d+20>>2]=c[1481];fL[a&63](16,d)|0;i=b;return}function w0(){var a=0,b=0,d=0,e=0;fQ[c[158752]&1023]();do{if((fO[c[278436]&15](0,3,0,119)|0)<<16>>16==0){if((fO[c[278436]&15](0,3,0,273)|0)<<16>>16==0){q0(273,0);break}else{q0(273,1);break}}else{q0(273,1)}}while(0);do{if((fO[c[278436]&15](0,3,0,115)|0)<<16>>16==0){if((fO[c[278436]&15](0,3,0,274)|0)<<16>>16==0){q0(274,0);break}else{q0(274,1);break}}else{q0(274,1)}}while(0);if((fO[c[278436]&15](0,3,0,97)|0)<<16>>16==0){q0(44,0)}else{q0(44,1)}if((fO[c[278436]&15](0,3,0,100)|0)<<16>>16==0){q0(46,0)}else{q0(46,1)}do{if((fO[c[278436]&15](0,3,0,32)|0)<<16>>16==0){if((fO[c[278436]&15](0,3,0,13)|0)<<16>>16!=0){a=7891;break}if((fO[c[278436]&15](0,2,0,3)|0)<<16>>16!=0){a=7891;break}q0(13,0)}else{a=7891}}while(0);if((a|0)==7891){q0(13,1)}if((fO[c[278436]&15](0,3,0,49)|0)<<16>>16==0){q0(49,0)}else{q0(49,1)}if((fO[c[278436]&15](0,3,0,50)|0)<<16>>16==0){q0(50,0)}else{q0(50,1)}if((fO[c[278436]&15](0,3,0,51)|0)<<16>>16==0){q0(51,0)}else{q0(51,1)}if((fO[c[278436]&15](0,3,0,52)|0)<<16>>16==0){q0(52,0)}else{q0(52,1)}if((fO[c[278436]&15](0,3,0,53)|0)<<16>>16==0){q0(53,0)}else{q0(53,1)}if((fO[c[278436]&15](0,3,0,54)|0)<<16>>16==0){q0(54,0)}else{q0(54,1)}if((fO[c[278436]&15](0,3,0,55)|0)<<16>>16==0){q0(55,0)}else{q0(55,1)}if((fO[c[278436]&15](0,3,0,56)|0)<<16>>16==0){q0(56,0)}else{q0(56,1)}if((fO[c[278436]&15](0,3,0,9)|0)<<16>>16==0){q0(9,0)}else{q0(9,1)}if((fO[c[278436]&15](0,3,0,99)|0)<<16>>16==0){q0(47,0)}else{q0(47,1)}do{if((fO[c[278436]&15](0,2,0,2)|0)<<16>>16==0){if((fO[c[278436]&15](0,3,0,306)|0)<<16>>16!=0){a=7925;break}q0(323,0)}else{a=7925}}while(0);if((a|0)==7925){q0(323,1)}if((fO[c[278436]&15](0,3,0,276)|0)<<16>>16==0){q0(275,0)}else{q0(275,1)}if((fO[c[278436]&15](0,3,0,275)|0)<<16>>16==0){q0(276,0)}else{q0(276,1)}pa(108032,400.0);pa(104680,400.0);if((c[350716]|0)!=1){return}a=fO[c[278436]&15](0,5,0,0)|0;b=fO[c[278436]&15](0,5,0,1)|0;d=fO[c[278436]&15](0,5,1,0)|0;e=fO[c[278436]&15](0,5,1,1)|0;do{if(a<<16>>16>4096){q0(46,1)}else{if(a<<16>>16>=-4096){break}q0(44,1)}}while(0);if(b<<16>>16>4096){q0(274,1)}if(b<<16>>16<-4096){q0(273,1)}if(d<<16>>16>4096){q0(276,1)}if(d<<16>>16<-4096){q0(275,1)}q0(127,e<<16>>16>4096|0);q0(281,e<<16>>16<-4096|0);return}function w1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+4112|0;e=d|0;f=e;c[f>>2]=b;c[f+4>>2]=0;f=d+16|0;bV(f|0,4096,a|0,e|0)|0;en(c[p>>2]|0,82632,(e=i,i=i+8|0,c[e>>2]=f,e)|0)|0;i=e;qc();ck(1)}function w2(){return 0}function w3(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function w4(){return 0}function w5(a,b){a=a|0;b=b|0;return 0}function w6(a,b){a=a|0;b=b|0;return 0}function w7(a){a=a|0;return 0}function w8(a){a=a|0;return 0}function w9(){return}function xa(a,b,c){a=a|0;b=b|0;c=c|0;return}function xb(a){a=a|0;return}function xc(a){a=a|0;return}function xd(){return}function xe(){return}function xf(){return 0}function xg(){return}function xh(){return}function xi(){return}function xj(a){a=a|0;return 0}function xk(a){a=a|0;return 1}function xl(a){a=a|0;return 0}function xm(){return-1|0}function xn(){return}function xo(){return}function xp(){return}function xq(){return}function xr(){return}function xs(a){a=a|0;return}function xt(a){a=a|0;return 0}function xu(a){a=a|0;return-1|0}function xv(){return}function xw(){return}function xx(){return}function xy(){c[642324]=215;c[642325]=186;c[642326]=69;c[642327]=50;return}function xz(){h[321187]=+h[321194];c[642371]=1;g[642370]=0.0;return}function xA(){if(+h[321187]==+h[321194]){return}if((c[642371]|0)==0&+g[642370]!=0.0){return}g[642370]=+g[254];c[642371]=0;g[642372]=0.0;return}function xB(){c[155108]=615336;c[153839]=44100;c[c[155108]>>2]=2;c[(c[155108]|0)+12>>2]=0;c[(c[155108]|0)+16>>2]=16;c[(c[155108]|0)+4>>2]=8192;c[(c[155108]|0)+24>>2]=2642656;return 1}function xC(){var a=0;a=c[660662]|0;c[(c[155108]|0)+12>>2]=a;return a|0}function xD(){var e=0,f=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0,v=0,w=0;e=i;i=i+24|0;f=e|0;j=e+8|0;k=e+16|0;l=c[29376]|0;m=c[350570]|0;a[k]=0;do{if(fL[c[350582]&63](17,k)|0){if((a[k]&1)==0){break}xE()}}while(0);dO(f|0,j|0)|0;j=c[665018]|0;k=c[f>>2]|0;if((j|0)==0){c[665018]=k;n=+(c[f+4>>2]|0)/1.0e6}else{n=+(k-j|0)+ +(c[f+4>>2]|0)/1.0e6}h[1883]=n;o=+h[1860];p=n-o;h[4511]=p;q=+g[492];do{if((c[353150]|0)==0){r=q;if(p<r){i=e;return}else{h[4511]=r;s=r;break}}else{s=p}}while(0);if(s>q*2.0){t=n}else{t=s+o}h[1860]=t;p8(s);f=c[29312]|0;j=c[278838]|0;if((ab(j,f)|0)==0){u=f;v=j}else{j=0;f=m;m=l;while(1){b[f>>1]=b[635112+((d[m]|0)<<1)>>1]|0;l=j+1|0;k=c[29312]|0;w=c[278838]|0;if(l>>>0<(ab(w,k)|0)>>>0){j=l;f=f+2|0;m=m+1|0}else{u=k;v=w;break}}}fR[c[29368]&63](c[350570]|0,u,v,u<<1);s=88200.0/+g[4848];u=c[660662]|0;v=~~(s+ +(u>>>0>>>0));m=(v>>>0>8192?8192:v)-u|0;fL[c[664760]&63](2642656+(u<<1)|0,m>>>1)|0;u=m+(c[660662]|0)&8191;c[660662]=u;fL[c[664760]&63](2642656+(u<<1)|0,~~(s- +(m>>>0>>>0))>>>1)|0;i=e;return}function xE(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+112|0;d=b|0;e=b+8|0;f=d|0;c[f>>2]=49912;g=d+4|0;c[g>>2]=0;h=d;do{if(fL[c[350582]&63](15,h)|0){if(!(a[18496]|0)){break}d=e|0;j=c[g>>2]|0;bR(d|0,100,101744,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;j=a4(d|0,71872)|0;if((j|0)!=0){c[29312]=aX(j|0,0,0)|0}j=a4(d|0,71872)|0;if((j|0)==0){l=c[278838]|0}else{d=aX(j|0,0,0)|0;c[278838]=d;l=d}d=c[p>>2]|0;j=c[29312]|0;en(d|0,70552,(k=i,i=i+16|0,c[k>>2]=j,c[k+8>>2]=l,k)|0)|0;i=k;a[18496]=0}}while(0);c[f>>2]=41616;c[g>>2]=0;if(!(fL[c[350582]&63](15,h)|0)){i=b;return}h=c[g>>2]|0;if((cS(h|0,41616)|0)==0){c[350716]=0;i=b;return}if((cS(h|0,69024)|0)!=0){i=b;return}c[350716]=1;i=b;return}function xF(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0.0;d=i;i=i+48|0;e=d|0;f=d+8|0;g=d+16|0;j=d+40|0;xE();k=b|0;yP(1242960,c[k>>2]|0,255)|0;a[1243215]=0;b=cn(1242960,47)|0;do{if((b|0)==0){l=cn(1242960,92)|0;if((l|0)!=0){m=l;n=8031;break}a[1242960]=0}else{m=b;n=8031}}while(0);if((n|0)==8031){a[m]=0}bR(1243216,256,101744,(m=i,i=i+8|0,c[m>>2]=c[k>>2],m)|0)|0;i=m;c[667350]=32;b=c[k>>2]|0;do{if((bw(b|0,99496)|0)==0){if((bw(b|0,97904)|0)!=0){n=8037;break}if((bw(b|0,95600)|0)!=0){n=8037;break}if((bw(b|0,93704)|0)!=0){n=8037}}else{n=8037}}while(0);L10701:do{if((n|0)==8037){yP(1242960,1242960,255)|0;a[1243215]=0;b=cn(1242960,47)|0;do{if((b|0)==0){k=cn(1242960,92)|0;if((k|0)!=0){o=k;break}a[1242960]=0;break L10701}else{o=b}}while(0);a[o]=0}}while(0);yG(g|0,0,12);oe(0,0);c[g+4>>2]=c[353050];c[g+8>>2]=c[353048];c[g>>2]=1242960;o=c[667350]<<20;c[g+16>>2]=o;n=yx(o)|0;c[278840]=n;c[g+12>>2]=n;en(c[p>>2]|0,92040,(m=i,i=i+8|0,c[m>>2]=90304,m)|0)|0;i=m;qb(g);o9(88472,86776);o9(84776,82368);o9(80384,78584);o9(77376,82368);o9(75944,74752);pb(19376);o9(84072,102080);c[j>>2]=2;if(!(fL[c[350582]&63](10,j)|0)){j=c[p>>2]|0;a5(73800,25,1,j|0)|0;q=0;i=d;return q|0}dO(e|0,f|0)|0;f=c[665018]|0;j=c[e>>2]|0;if((f|0)==0){c[665018]=j;r=+(c[e+4>>2]|0)/1.0e6}else{r=+(j-f|0)+ +(c[e+4>>2]|0)/1.0e6}h[1860]=r+-.1;q=1;i=d;return q|0}function xG(){qc();yz(c[278840]|0);return}function xH(a){a=a|0;var b=0,d=0,e=0,f=0;a=c[29312]|0;b=c[278838]|0;d=yx(ab(b,a)|0)|0;c[29374]=d;e=ab(a<<1,b)|0;f=yx(e)|0;c[29304]=f;c[350570]=yx(e)|0;c[29381]=a;c[29382]=b;c[29390]=320;c[29391]=200;c[29388]=a;c[29389]=b;c[29384]=1;e=c[278814]|0;c[29377]=e;c[29379]=256-(c[e+8192>>2]|0);c[29386]=d;c[29376]=d;c[29380]=a;c[29387]=a;g[29383]=+(b|0)/+(a|0)*1.3333333333333333;c[351966]=f;pJ(295672,262144);return}function xI(){var a=0;a=c[29374]|0;if((a|0)!=0){yz(a)}a=c[29304]|0;if((a|0)!=0){yz(a)}a=c[350570]|0;if((a|0)==0){return}yz(a);return}function xJ(a){a=a|0;var b=0,d=0.0,e=0,f=0.0;a=fO[c[278436]&15](0,2,0,0)|0;b=fO[c[278436]&15](0,2,0,1)|0;do{if((a<<16>>16|0)==(c[667356]|0)){if((b<<16>>16|0)!=(c[667354]|0)){break}return}}while(0);d=+g[960];e=~~(+(a<<16>>16|0)*d);a=~~(+(b<<16>>16|0)*d);g[642355]=+g[642355]- +g[3820]*+(e|0);xz();d=+g[642354]+ +(a|0)*+g[3854];f=d>80.0?80.0:d;g[642354]=f<-70.0?-70.0:f;c[667356]=e;c[667354]=a;return}function xK(a,b){a=a|0;b=b|0;var c=0.0,d=0.0,e=0.0,f=0.0,h=0.0,i=0.0;rc(a,1402264,622512,117616);c=+g[b>>2]*+g[155628]+ +g[b+4>>2]*+g[155629]+ +g[b+8>>2]*+g[155630];d=c<0.0?-1.0:1.0;e=+Q(+c);c=+g[5488];f=+g[5474];if(e>=f){h=c;i=d*h;return+i}h=e*c/f;i=d*h;return+i}function xL(){var a=0.0,b=0.0,d=0.0,e=0.0,f=0.0,i=0.0,j=0.0;if((c[642379]|0)==0|(c[159948]|0)!=0|(c[353697]|0)!=0){g[642372]=0.0;g[642370]=0.0;return}if((c[642371]|0)!=0){a=+Q(+(+g[642248]));if(a<+g[5558]){b=0.0}else{b=+h[2332]+ +g[642372]}g[642372]=b;if(b<=+g[268]){return}if(+h[321187]==+h[321194]){return}g[642370]=+g[254];c[642371]=0;g[642372]=0.0;return}b=+g[642354];a=+g[642369]-b;if(a==0.0){g[642370]=0.0;return}d=+h[2332];e=+g[642370];f=d*e;g[642370]=e+d*+g[254];if(a>0.0){if(f>a){g[642370]=0.0;i=a}else{i=f}g[642354]=i+b;return}if(a>=0.0){return}i=-0.0-a;if(f>i){g[642370]=0.0;j=i}else{j=f}g[642354]=b-j;return}function xM(){var a=0,b=0,d=0,e=0,f=0,j=0,k=0,l=0.0,m=0,n=0.0,o=0,p=0.0,q=0,r=0.0,s=0.0,t=0;a=i;i=i+64|0;b=a|0;d=a+16|0;e=a+32|0;f=a+48|0;j=nL()|0;k=nL()|0;l=+nQ();m=b|0;g[m>>2]=l;n=+nQ();o=b+4|0;g[o>>2]=n;p=+nQ();q=b+8|0;g[q>>2]=p;r=+(j|0)*.5+ +(k|0)*.5;s=r<10.0?10.0:r;g[642315]=+h[321194]+.2;b=~~(s*3.0+ +(c[642323]|0));t=(b|0)<0?0:b;c[642323]=(t|0)>150?150:t;do{if((j|0)>(k|0)){c[642320]=200;c[642321]=100;c[642322]=100}else{if((j|0)==0){c[642320]=255;c[642321]=0;c[642322]=0;break}else{c[642320]=220;c[642321]=50;c[642322]=50;break}}}while(0);j=c[644467]|0;g[m>>2]=l- +g[1960864+(j*264|0)>>2];g[o>>2]=n- +g[1960868+(j*264|0)>>2];g[q>>2]=p- +g[1960872+(j*264|0)>>2];+q1(m);k=d|0;t=e|0;rc(1960876+(j*264|0)|0,k,t,f|0);p=+g[m>>2];n=+g[o>>2];l=+g[q>>2];g[246]=+g[108]*s*(p*+g[t>>2]+n*+g[e+4>>2]+l*+g[e+8>>2]);g[248]=+g[122]*s*(p*+g[k>>2]+n*+g[d+4>>2]+l*+g[d+8>>2]);g[244]=+g[94];i=a;return}function xN(){c[5154]=fi(os(1)|0)|0;c[5155]=fi(os(2)|0)|0;c[5156]=fi(os(3)|0)|0;c[5157]=fi(os(4)|0)|0;return}function xO(a){a=a|0;if((a|0)==(-1|0)|(a|0)==(-2|0)){c[642316]=c[5154];c[2569268>>2]=c[5155];c[2569272>>2]=c[5156];c[2569276>>2]=c[5157];return}else if((a|0)==(-4|0)){c[642316]=c[5146];c[2569268>>2]=c[5147];c[2569272>>2]=c[5148];c[2569276>>2]=c[5149];return}else if((a|0)==(-5|0)){c[642316]=c[5150];c[2569268>>2]=c[5151];c[2569272>>2]=c[5152];c[2569276>>2]=c[5153];return}else{c[642316]=c[5142];c[2569268>>2]=c[5143];c[2569272>>2]=c[5144];c[2569276>>2]=c[5145];return}}function xP(){var e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0,D=0;e=c[642266]|0;do{if((e&4194304|0)==0){if((e&2097152|0)!=0){c[642328]=0;c[642329]=255;c[642330]=0;c[642331]=20;f=20;break}if((e&524288|0)!=0){c[642328]=100;c[642329]=100;c[642330]=100;c[642331]=100;f=100;break}if((e&1048576|0)==0){c[642331]=0;f=0;break}else{c[642328]=255;c[642329]=255;c[642330]=0;c[642331]=30;f=30;break}}else{c[642328]=0;c[642329]=0;c[642330]=255;c[642331]=30;f=30}}while(0);e=c[642319]|0;if((e|0)==(c[642335]|0)){i=0}else{c[642335]=e;i=1}j=c[642316]|0;if((j|0)==(c[642332]|0)){k=i}else{c[642332]=j;k=1}i=c[642317]|0;if((i|0)==(c[642333]|0)){l=k}else{c[642333]=i;l=1}k=c[642318]|0;if((k|0)==(c[642334]|0)){m=l}else{c[642334]=k;m=1}l=c[642323]|0;if((l|0)==(c[642339]|0)){n=m}else{c[642339]=l;n=1}m=c[642320]|0;if((m|0)==(c[642336]|0)){o=n}else{c[642336]=m;o=1}n=c[642321]|0;if((n|0)==(c[642337]|0)){p=o}else{c[642337]=n;p=1}o=c[642322]|0;if((o|0)==(c[642338]|0)){q=p}else{c[642338]=o;q=1}p=c[642327]|0;if((p|0)==(c[642343]|0)){r=q}else{c[642343]=p;r=1}q=c[642324]|0;if((q|0)==(c[642340]|0)){s=r}else{c[642340]=q;s=1}r=c[642325]|0;if((r|0)==(c[642341]|0)){t=s}else{c[642341]=r;t=1}s=c[642326]|0;if((s|0)==(c[642342]|0)){u=t}else{c[642342]=s;u=1}if((f|0)==(c[642347]|0)){v=u}else{c[642347]=f;v=1}u=c[642328]|0;if((u|0)==(c[642344]|0)){w=v}else{c[642344]=u;w=1}v=c[642329]|0;if((v|0)==(c[642345]|0)){x=w}else{c[642345]=v;x=1}w=c[642330]|0;if((w|0)==(c[642346]|0)){y=x}else{c[642346]=w;y=1}z=+h[2332];x=~~(+(l|0)-z*150.0);l=(x|0)>0?x:0;c[642323]=l;x=~~(+(p|0)-z*100.0);p=(x|0)>0?x:0;c[642327]=p;z=+g[234];do{if(z==+g[27982]){if((y|0)!=0){break}return}else{g[27982]=z;if(z==1.0){x=0;do{a[1140304+x|0]=x&255;x=x+1|0;}while((x|0)<256)}else{x=0;do{t=~~(+S(+((+(x|0)+.5)/255.5),+z)*255.0+.5);A=(t|0)<0?0:t;a[1140304+x|0]=(A|0)>255?-1:A&255;x=x+1|0;}while((x|0)<256)}c[29385]=1}}while(0);y=c[278818]|0;x=635112;A=1;t=e;e=j;j=i;i=k;k=l;l=m;m=n;n=o;o=p;p=q;q=r;r=s;s=f;f=u;u=v;v=w;while(1){w=d[y]|0;B=d[y+1|0]|0;C=d[y+2|0]|0;D=((ab(e-w|0,t)|0)>>8)+w|0;w=((ab(j-B|0,t)|0)>>8)+B|0;B=((ab(i-C|0,t)|0)>>8)+C|0;C=((ab(l-D|0,k)|0)>>8)+D|0;D=((ab(m-w|0,k)|0)>>8)+w|0;w=((ab(n-B|0,k)|0)>>8)+B|0;B=((ab(p-C|0,o)|0)>>8)+C|0;C=((ab(q-D|0,o)|0)>>8)+D|0;D=((ab(r-w|0,o)|0)>>8)+w|0;w=((ab(f-B|0,s)|0)>>8)+B|0;B=((ab(u-C|0,s)|0)>>8)+C|0;C=((ab(v-D|0,s)|0)>>8)+D|0;b[x>>1]=(d[1140304+B|0]|0)<<3&2016|(d[1140304+w|0]|0)<<8&-2048|(a[1140304+C|0]&255)>>>3;if((A|0)>=256){break}y=y+3|0;x=x+2|0;A=A+1|0;t=c[642319]|0;e=c[642316]|0;j=c[642317]|0;i=c[642318]|0;k=c[642323]|0;l=c[642320]|0;m=c[642321]|0;n=c[642322]|0;o=c[642327]|0;p=c[642324]|0;q=c[642325]|0;r=c[642326]|0;s=c[642331]|0;f=c[642328]|0;u=c[642329]|0;v=c[642330]|0}return}function xQ(){var a=0.0,b=0.0,c=0.0,d=0.0,e=0.0,f=0.0,i=0.0;a=+g[157356];b=+g[157355];c=+qS(a-a);if(c>180.0){d=c+-360.0}else{d=c}c=d*.4;d=c>10.0?10.0:c;c=d<-10.0?-10.0:d;d=+qS(b- +g[157355]);if(d>180.0){e=d+-360.0}else{e=d}d=e*.4;e=d>10.0?10.0:d;d=e<-10.0?-10.0:e;e=+h[2332]*20.0;b=+g[28098];do{if(c>b){a=b+e;if(a>=c){f=c;break}f=a}else{a=b-e;if(a<=c){f=c;break}f=a}}while(0);c=+g[28100];do{if(d>c){b=e+c;if(b>=d){i=d;break}i=b}else{b=c-e;if(b<=d){i=d;break}i=b}}while(0);g[28098]=f;g[28100]=i;d=f+ +g[157356];f=-0.0-(i+ +g[157355]);i=+g[220];e=+h[321194];c=i*+U(+(e*+g[178]));g[644507]=+g[644507]-c*+g[164];c=i*+U(+(e*+g[206]));g[644505]=f-c*+g[192];c=i*+U(+(e*+g[150]));g[644506]=d-c*+g[136];return}function xR(){var a=0.0,b=0.0,d=0.0,e=0.0,f=0.0;rc(1960876+((c[644467]|0)*264|0)|0,1402264,622512,117616);a=+g[642363]*+g[155628]+ +g[642364]*+g[155629]+ +g[642365]*+g[155630];b=+Q(+a);d=+g[5488];e=+g[5474];if(b<e){f=b*d/e}else{f=d}d=+g[157357]+(a<0.0?-1.0:1.0)*f;g[157357]=d;f=+g[244];if(f>0.0){a=f/+g[94];g[157357]=d+a*+g[246];g[157355]=+g[157355]+a*+g[248];g[244]=f- +h[2332]}if((c[642251]|0)>=1){return}g[157357]=80.0;return}function xS(a){a=a|0;return}function xT(){var a=0,b=0,d=0,e=0,f=0,j=0,k=0.0,l=0,m=0.0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0.0;a=i;i=i+64|0;b=a|0;d=a+16|0;e=a+32|0;f=a+48|0;xL();j=c[644467]|0;k=+g[642355];l=1960880+(j*264|0)|0;g[l>>2]=k;m=+g[642354];n=1960876+(j*264|0)|0;g[n>>2]=-0.0-m;o=+g[5628];do{if(o!=0.0){p=+h[321194];q=(p-o*+(~~(p/o)|0))/o;p=+g[5614];if(q<p){r=q*3.141592653589793/p}else{r=(q-p)*3.141592653589793/(1.0-p)+3.141592653589793}p=+g[642363];q=+g[642364];s=+R(+(p*p+q*q));q=s*+g[5642];s=q*.3+ +U(+r)*q*.7;if(s>4.0){t=4.0;break}if(s>=-7.0){t=s;break}t=-7.0}else{t=0.0}}while(0);u=1960864+(j*264|0)|0;v=1960868+(j*264|0)|0;r=+g[v>>2];w=1960872+(j*264|0)|0;o=+g[w>>2]+(t+ +g[642376]);g[157352]=+g[u>>2]+.03125;g[157353]=r+.03125;g[157354]=o+.03125;g[157355]=m;g[157356]=k;g[157357]=+g[642356];xR();k=+g[220];m=+h[321194];o=k*+U(+(m*+g[178]));g[157357]=+g[157357]+o*+g[164];o=k*+U(+(m*+g[206]));g[157355]=+g[157355]+o*+g[192];o=k*+U(+(m*+g[150]));g[157356]=+g[157356]+o*+g[136];x=f|0;g[x>>2]=-0.0- +g[n>>2];g[f+4>>2]=+g[l>>2];g[f+8>>2]=+g[1960884+(j*264|0)>>2];j=b|0;f=d|0;l=e|0;rc(x,j,f,l);o=+g[1132];m=+g[1118];k=+g[1104];r=+g[157352]+(o*+g[j>>2]+m*+g[f>>2]+k*+g[l>>2]);g[157352]=r;l=b+4|0;s=+g[157353]+(o*+g[l>>2]+m*+g[d+4>>2]+k*+g[e+4>>2]);g[157353]=s;f=b+8|0;q=+g[157354]+(o*+g[f>>2]+m*+g[d+8>>2]+k*+g[e+8>>2]);g[157354]=q;e=c[644467]|0;k=+g[1960864+(e*264|0)>>2];m=k+-14.0;do{if(r<m){g[157352]=m}else{o=k+14.0;if(r<=o){break}g[157352]=o}}while(0);r=+g[1960868+(e*264|0)>>2];k=r+-14.0;do{if(s<k){g[157353]=k}else{m=r+14.0;if(s<=m){break}g[157353]=m}}while(0);s=+g[1960872+(e*264|0)>>2];r=s+-22.0;do{if(q<r){g[157354]=r}else{k=s+30.0;if(q<=k){break}g[157354]=k}}while(0);g[644505]=+g[642354];g[644506]=+g[642355];g[644507]=+g[642356];xQ();q=+g[v>>2];s=+g[w>>2];r=s+ +g[642376];g[644502]=+g[u>>2]+t*+g[j>>2]*.4;g[644503]=q+t*+g[l>>2]*.4;q=t+(r+t*+g[f>>2]*.4);g[644504]=q;t=+g[1034];do{if(t==110.0){r=q+1.0;g[644504]=r;y=r}else{if(t==100.0){r=q+2.0;g[644504]=r;y=r;break}if(t==90.0){r=q+1.0;g[644504]=r;y=r;break}if(t!=80.0){y=q;break}r=q+.5;g[644504]=r;y=r}}while(0);c[644508]=c[2569572+(c[642253]<<2)>>2];c[644509]=c[642256];c[644510]=c[29377];g[157355]=+g[157355]+ +g[642366];g[157356]=+g[157356]+ +g[642367];g[157357]=+g[157357]+ +g[642368];do{if((c[642379]|0)==0){z=8226}else{q=+g[27984];if(s-q<=0.0){z=8226;break}t=+h[321194]- +h[321195];r=q+(t<0.0?0.0:t*80.0);t=r>s?s:r;if(s-t>12.0){A=s+-12.0}else{A=t}g[27984]=A;t=A-s;g[157354]=+g[157354]+t;g[644504]=y+t}}while(0);if((z|0)==8226){g[27984]=s}if(+g[5762]==0.0){i=a;return}m5();i=a;return}function xU(){var a=0,b=0.0,d=0.0,e=0.0,f=0.0,i=0.0;if((c[352656]|0)!=0){return}if((c[644468]|0)>1){o9(81336,101544);o9(82248,101544);o9(68952,101544)}do{if((c[642381]|0)==0){if((c[642378]|0)!=0){break}xT()}else{a=c[644467]|0;g[157352]=+g[1960864+(a*264|0)>>2];g[157353]=+g[1960868+(a*264|0)>>2];g[157354]=+g[1960872+(a*264|0)>>2];b=+g[1960876+(a*264|0)>>2];d=+g[1960880+(a*264|0)>>2];e=+g[1960884+(a*264|0)>>2];c[644508]=0;f=+h[321194];i=+U(+(f*+g[178]));g[157357]=e+i*+g[164];i=+U(+(f*+g[206]));g[157355]=b+i*+g[192];i=+U(+(f*+g[150]));g[157356]=d+i*+g[136]}}while(0);um();ut();if(+g[5176]==0.0){return}pR();return}function xV(){var b=0;oE(63184,498);oE(62640,14);oE(61864,50);pb(1056);pb(1e3);pb(584);pb(696);pb(808);pb(528);pb(640);pb(752);pb(864);pb(20688);pb(20632);pb(22328);pb(22272);pb(4512);pb(4456);pb(4400);pb(21880);pb(21936);pb(22552);pb(22496);pb(22440);pb(360);pb(416);pb(472);b=0;do{a[1140304+b|0]=b&255;b=b+1|0;}while((b|0)<256);pb(920);return}function xW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=ok(b)|0;c[29322]=e;if((e|0)==0){w1(79848,(f=i,i=i+16|0,c[f>>2]=109552,c[f+8>>2]=b,f)|0);i=f;g=c[29322]|0}else{g=e}do{if((a[g]|0)==87){if((a[g+1|0]|0)!=65){h=8254;break}if((a[g+2|0]|0)!=68){h=8254;break}if((a[g+3|0]|0)==50){j=g}else{h=8254}}else{h=8254}}while(0);if((h|0)==8254){w1(101216,(f=i,i=i+8|0,c[f>>2]=b,f)|0);i=f;j=c[29322]|0}f=c[g+4>>2]|0;c[29318]=f;b=j+(c[g+8>>2]|0)|0;c[29320]=b;if((f|0)==0){i=d;return}else{k=0;l=b}while(1){b=0;while(1){m=l+16+b|0;f=a[m]|0;if(f<<24>>24==0){h=8258;break}a[m]=(f-65&255)<26?f+32&255:f;f=b+1|0;if((f|0)<16){b=f}else{break}}if((h|0)==8258){h=0;yG(m|0,0,16-b|0)}f=k+1|0;if(f>>>0<(c[29318]|0)>>>0){k=f;l=l+32|0}else{break}}i=d;return}function xX(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+16|0;e=d|0;f=e|0;g=0;while(1){h=a[b+g|0]|0;if(h<<24>>24==0){j=8266;break}a[e+g|0]=(h-65&255)<26?h+32&255:h;h=g+1|0;if((h|0)<16){g=h}else{break}}if((j|0)==8266){yG(e+g|0,0,16-g|0)}g=c[29320]|0;e=c[29318]|0;L11002:do{if((e|0)>0){j=0;h=g;while(1){if((cS(f|0,h+16|0)|0)==0){k=h;break}l=j+1|0;m=h+32|0;if((l|0)<(e|0)){j=l;h=m}else{n=m;break L11002}}o=c[29322]|0;p=k|0;q=c[p>>2]|0;r=o+q|0;i=d;return r|0}else{n=g}}while(0);w1(82064,(g=i,i=i+16|0,c[g>>2]=109568,c[g+8>>2]=b,g)|0);i=g;k=n;o=c[29322]|0;p=k|0;q=c[p>>2]|0;r=o+q|0;i=d;return r|0}function xY(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;if((a|0)==0){w1(79720,(d=i,i=i+8|0,c[d>>2]=109512,d)|0);i=d}e=a-24|0;f=e;if((c[a-16>>2]|0)!=1919505){w1(101152,(d=i,i=i+8|0,c[d>>2]=109512,d)|0);i=d}g=a-20|0;if((c[g>>2]|0)==0){w1(82032,(d=i,i=i+8|0,c[d>>2]=109512,d)|0);i=d}c[g>>2]=0;g=c[a-8>>2]|0;do{if((c[g+4>>2]|0)==0){d=g|0;c[d>>2]=(c[d>>2]|0)+(c[e>>2]|0);d=c[a-12>>2]|0;c[g+12>>2]=d;c[d+16>>2]=g;d=(c[270780]|0)+28|0;if((f|0)!=(c[d>>2]|0)){h=g;break}c[d>>2]=g;h=g}else{h=f}}while(0);f=h+12|0;g=c[f>>2]|0;if((c[g+4>>2]|0)!=0){i=b;return}a=h|0;c[a>>2]=(c[a>>2]|0)+(c[g>>2]|0);a=c[g+12>>2]|0;c[f>>2]=a;c[a+16>>2]=h;a=(c[270780]|0)+28|0;if((g|0)!=(c[a>>2]|0)){i=b;return}c[a>>2]=h;i=b;return}function xZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;d=c[270780]|0;e=c[d+16>>2]|0;f=e+12|0;g=c[f>>2]|0;if((g|0)==(d+4|0)){h=d}else{d=e;e=f;f=g;while(1){if((d+(c[d>>2]|0)|0)==(f|0)){j=f}else{w1(58e3,(k=i,i=i+8|0,c[k>>2]=109520,k)|0);i=k;j=c[e>>2]|0}if((c[j+16>>2]|0)!=(d|0)){w1(57464,(k=i,i=i+8|0,c[k>>2]=109520,k)|0);i=k}do{if((c[d+4>>2]|0)==0){if((c[(c[e>>2]|0)+4>>2]|0)!=0){break}w1(57e3,(k=i,i=i+8|0,c[k>>2]=109520,k)|0);i=k}}while(0);g=c[e>>2]|0;l=g+12|0;m=c[l>>2]|0;n=c[270780]|0;if((m|0)==(n+4|0)){h=n;break}else{d=g;e=l;f=m}}}f=a+35&-8;e=c[h+28>>2]|0;h=c[e+16>>2]|0;L11045:do{if((e|0)!=(h|0)){d=e;j=e;while(1){m=c[d+12>>2]|0;o=(c[d+4>>2]|0)==0?j:m;p=o+4|0;if((c[p>>2]|0)==0){q=o|0;r=c[q>>2]|0;if((r|0)>=(f|0)){break}}if((m|0)==(h|0)){break L11045}else{d=m;j=o}}j=r-f|0;if((j|0)>64){d=o;m=d+f|0;l=m;c[m>>2]=j;c[d+(f|4)>>2]=0;c[d+(f+16)>>2]=o;c[d+(f+8)>>2]=1919505;j=o+12|0;m=c[j>>2]|0;c[d+(f+12)>>2]=m;c[m+16>>2]=l;c[j>>2]=l;c[q>>2]=f;s=l;t=d}else{s=c[o+12>>2]|0;t=o}c[p>>2]=1;c[(c[270780]|0)+28>>2]=s;c[o+8>>2]=1919505;c[t+((c[q>>2]|0)-4)>>2]=1919505;d=o+24|0;if((d|0)==0){break}else{u=d}yG(u|0,0,a|0);i=b;return u|0}}while(0);w1(68792,(k=i,i=i+16|0,c[k>>2]=109496,c[k+8>>2]=a,k)|0);i=k;u=0;yG(u|0,0,a|0);i=b;return u|0}function x_(){return c[278582]|0}function x$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;if((a|0)==0){e=xZ(b)|0;i=d;return e|0}if((c[a-16>>2]|0)!=1919505){w1(59528,(f=i,i=i+8|0,c[f>>2]=109480,f)|0);i=f}if((c[a-20>>2]|0)==0){w1(53768,(f=i,i=i+8|0,c[f>>2]=109480,f)|0);i=f}g=(c[a-24>>2]|0)-28|0;xY(a);h=b+35&-8;j=c[(c[270780]|0)+28>>2]|0;k=c[j+16>>2]|0;L11071:do{if((j|0)==(k|0)){l=8327}else{m=j;n=j;while(1){o=c[m+12>>2]|0;p=(c[m+4>>2]|0)==0?n:o;q=p+4|0;if((c[q>>2]|0)==0){r=p|0;s=c[r>>2]|0;if((s|0)>=(h|0)){break}}if((o|0)==(k|0)){l=8327;break L11071}else{m=o;n=p}}n=s-h|0;if((n|0)>64){m=p;o=m+h|0;t=o;c[o>>2]=n;c[m+(h|4)>>2]=0;c[m+(h+16)>>2]=p;c[m+(h+8)>>2]=1919505;n=p+12|0;o=c[n>>2]|0;c[m+(h+12)>>2]=o;c[o+16>>2]=t;c[n>>2]=t;c[r>>2]=h;u=t;v=m}else{u=c[p+12>>2]|0;v=p}c[q>>2]=1;c[(c[270780]|0)+28>>2]=u;c[p+8>>2]=1919505;c[v+((c[r>>2]|0)-4)>>2]=1919505;m=p+24|0;if((m|0)==0){l=8327}else{w=m}}}while(0);if((l|0)==8327){w1(68792,(f=i,i=i+16|0,c[f>>2]=109480,c[f+8>>2]=b,f)|0);i=f;w=0}if((w|0)==(a|0)){e=a;i=d;return e|0}yN(w|0,a|0,((g|0)<(b|0)?g:b)|0);e=w;i=d;return e|0}function x0(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;a=i;if((c[278582]|0)==0){i=a;return}b=c[278586]|0;do{if((c[b>>2]|0)!=502268397){w1(49816,(d=i,i=i+8|0,c[d>>2]=111232,d)|0);i=d}e=b+4|0;f=c[e>>2]|0;if(f>>>0<16){g=8340}else{h=c[278586]|0;if((b+f-h|0)>(c[278580]|0)){g=8340}else{j=f;k=h}}if((g|0)==8340){g=0;w1(45736,(d=i,i=i+8|0,c[d>>2]=111232,d)|0);i=d;j=c[e>>2]|0;k=c[278586]|0}b=b+j|0;}while((b|0)!=(k+(c[278582]|0)|0));i=a;return}function x1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;if((b|0)<0){w1(41552,(f=i,i=i+16|0,c[f>>2]=111248,c[f+8>>2]=b,f)|0);i=f}g=b+31&-16;b=c[278582]|0;if(((c[278580]|0)-b-(c[278584]|0)|0)<(g|0)){w1(37856,(f=i,i=i+1|0,i=i+7>>3<<3,c[f>>2]=0,f)|0);i=f;h=c[278582]|0}else{h=b}b=c[278586]|0;f=b+h|0;j=h+g|0;c[278582]=j;k=c[651337]|0;L11111:do{if((k|0)!=2605304){l=k;m=b;while(1){if(l>>>0>=(m+j|0)>>>0){break L11111}n=l|0;o=yf(c[n>>2]|0,1)|0;if((o|0)==0){ya(c[l+4>>2]|0)}else{p=o+56|0;q=l+56|0;r=(c[n>>2]|0)-56|0;yJ(p|0,q|0,r)|0;r=l+4|0;q=o+4|0;c[q>>2]=c[r>>2];n=o+8|0;o=l+8|0;yJ(n|0,o|0,32)|0;o=c[r>>2]|0;r=c[o+4>>2]|0;ya(o);c[(c[q>>2]|0)+4>>2]=r;r=c[q>>2]|0;c[r>>2]=p+(c[r+4>>2]|0)}r=c[651337]|0;if((r|0)==2605304){break L11111}l=r;m=c[278586]|0}}}while(0);yG(f|0,0,g|0);c[b+(h+4)>>2]=g;c[f>>2]=502268397;f=b+(h+8)|0;g=f;j=g|0;x=0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=g+4|0;x=0;a[j]=x&255;x=x>>8;a[j+1|0]=x&255;x=x>>8;a[j+2|0]=x&255;x=x>>8;a[j+3|0]=x&255;j=yF(d|0)|0;g=(j|0)<8?j:8;yJ(f|0,d|0,g)|0;i=e;return b+(h+16)|0}function x2(a){a=a|0;return x1(a,107984)|0}function x3(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=c[278582]|0;if((a|0)<0|(d|0)<(a|0)){w1(104632,(e=i,i=i+16|0,c[e>>2]=111184,c[e+8>>2]=a,e)|0);i=e;f=c[278582]|0}else{f=d}yG((c[278586]|0)+a|0,0,f-a|0);c[278582]=a;i=b;return}function x4(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;if(a[18528]|0){a[18528]=0;x4(c[278578]|0)}e=c[278584]|0;if((b|0)<0|(e|0)<(b|0)){w1(104632,(f=i,i=i+16|0,c[f>>2]=111208,c[f+8>>2]=b,f)|0);i=f;g=c[278584]|0}else{g=e}yG((c[278586]|0)+((c[278580]|0)-g)|0,0,g-b|0);c[278584]=b;i=d;return}function x5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;if((b|0)<0){w1(41552,(f=i,i=i+16|0,c[f>>2]=111160,c[f+8>>2]=b,f)|0);i=f}if(a[18528]|0){x4(c[278578]|0);a[18528]=0}g=b+31&-16;b=c[278584]|0;if(((c[278580]|0)-(c[278582]|0)-b|0)<(g|0)){oW(101656,(f=i,i=i+8|0,c[f>>2]=g,f)|0);i=f;h=0;i=e;return h|0}else{f=b+g|0;c[278584]=f;x6(f);f=c[278586]|0;b=(c[278580]|0)-(c[278584]|0)|0;j=f+b|0;yG(j|0,0,g|0);c[f+(b+4)>>2]=g;c[j>>2]=502268397;j=f+(b+8)|0;yP(j|0,d|0,7)|0;a[f+(b+15)|0]=0;h=f+(b+16)|0;i=e;return h|0}return 0}function x6(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[651336]|0;if((b|0)==2605304){return}else{d=0;e=b}L11148:while(1){b=e;while(1){f=b|0;g=c[f>>2]|0;if((b+g|0)>>>0<=((c[278586]|0)+((c[278580]|0)-a)|0)>>>0){h=8388;break L11148}if((b|0)!=(d|0)){break}ya(c[d+4>>2]|0);i=c[651336]|0;if((i|0)==2605304){h=8389;break L11148}else{b=i}}i=yf(g,1)|0;if((i|0)==0){ya(c[b+4>>2]|0)}else{j=i+56|0;k=b+56|0;l=(c[f>>2]|0)-56|0;yJ(j|0,k|0,l)|0;l=b+4|0;k=i+4|0;c[k>>2]=c[l>>2];m=i+8|0;i=b+8|0;yJ(m|0,i|0,32)|0;i=c[l>>2]|0;l=c[i+4>>2]|0;ya(i);c[(c[k>>2]|0)+4>>2]=l;l=c[k>>2]|0;c[l>>2]=j+(c[l+4>>2]|0)}l=c[651336]|0;if((l|0)==2605304){h=8387;break}else{d=b;e=l}}if((h|0)==8389){return}else if((h|0)==8387){return}else if((h|0)==8388){return}}function x7(b){b=b|0;var d=0;if(a[18528]|0){x4(c[278578]|0);a[18528]=0}c[278578]=c[278584];d=x5(b+15&-16,99464)|0;a[18528]=1;return d|0}function x8(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;if(!(a[18528]|0)){w1(97840,(e=i,i=i+8|0,c[e>>2]=111120,e)|0);i=e}f=c[278586]|0;g=(c[278580]|0)-(c[278584]|0)|0;h=f+g|0;if((c[h>>2]|0)!=502268397){w1(95544,(e=i,i=i+8|0,c[e>>2]=111120,e)|0);i=e}if((bN(f+(g+8)|0,99464,8)|0)!=0){w1(93640,(e=i,i=i+8|0,c[e>>2]=111120,e)|0);i=e}g=b+15&-16;b=c[278584]|0;if(((c[278580]|0)-(c[278582]|0)-b|0)<(g|0)){oW(91960,(e=i,i=i+16|0,c[e>>2]=111120,c[e+8>>2]=g,e)|0);i=e;j=0;i=d;return j|0}else{e=b+g|0;c[278584]=e;x6(e);e=c[278586]|0;b=(c[278580]|0)-(c[278584]|0)|0;yN(e+b|0,h|0,16);h=e+(b+4)|0;c[h>>2]=(c[h>>2]|0)+g;j=e+(b+16)|0;i=d;return j|0}return 0}function x9(){var a=0,b=0;a=c[651337]|0;if((a|0)==2605304){return}else{b=a}do{ya(c[b+4>>2]|0);b=c[651337]|0;}while((b|0)!=2605304);return}function ya(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=a|0;e=c[d>>2]|0;if((e|0)==0){w1(88416,(f=i,i=i+8|0,c[f>>2]=111680,f)|0);i=f;g=c[d>>2]|0}else{g=e}e=a+4|0;a=-56-(c[e>>2]|0)|0;h=g+(a+44)|0;j=g+(a+40)|0;c[(c[j>>2]|0)+44>>2]=c[h>>2];c[(c[h>>2]|0)+40>>2]=c[j>>2];c[j>>2]=0;c[h>>2]=0;c[e>>2]=0;c[d>>2]=0;d=g+(a+52)|0;e=c[d>>2]|0;h=g+(a+48)|0;do{if((e|0)!=0){a=c[h>>2]|0;if((a|0)==0){break}else{k=a;l=e}m=l+48|0;c[m>>2]=k;n=c[d>>2]|0;o=c[h>>2]|0;p=o+52|0;c[p>>2]=n;c[d>>2]=0;c[h>>2]=0;i=b;return}}while(0);w1(59064,(f=i,i=i+8|0,c[f>>2]=111632,f)|0);i=f;k=c[h>>2]|0;l=c[d>>2]|0;m=l+48|0;c[m>>2]=k;n=c[d>>2]|0;o=c[h>>2]|0;p=o+52|0;c[p>>2]=n;c[d>>2]=0;c[h>>2]=0;i=b;return}function yb(){var a=0,b=0;a=i;oX(90248,(b=i,i=i+8|0,h[b>>3]=+((c[278580]|0)-(c[278584]|0)-(c[278582]|0)|0)*9.5367431640625e-7,b)|0);i=b;i=a;return}function yc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=a|0;e=c[d>>2]|0;if((e|0)==0){f=0;i=b;return f|0}g=-56-(c[a+4>>2]|0)|0;a=e+g|0;h=e+(g+52)|0;j=c[h>>2]|0;k=e+(g+48)|0;if((j|0)==0){l=8422}else{g=c[k>>2]|0;if((g|0)==0){l=8422}else{m=g;n=j}}if((l|0)==8422){w1(59064,(l=i,i=i+8|0,c[l>>2]=111632,l)|0);i=l;m=c[k>>2]|0;n=c[h>>2]|0}c[n+48>>2]=m;c[(c[k>>2]|0)+52>>2]=c[h>>2];c[h>>2]=0;c[k>>2]=0;c[(c[651339]|0)+48>>2]=a;c[h>>2]=c[651339];c[k>>2]=2605304;c[651339]=a;f=c[d>>2]|0;i=b;return f|0}function yd(a,b,c){a=a|0;b=b|0;c=c|0;return ye(a,0,b,c)|0}function ye(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;g=a|0;if((c[g>>2]|0)!=0){w1(86728,(h=i,i=i+8|0,c[h>>2]=111696,h)|0);i=h}if((d|0)<1){w1(84744,(h=i,i=i+16|0,c[h>>2]=111696,c[h+8>>2]=d,h)|0);i=h}j=b+71+d&-16;d=yf(j,0)|0;if((d|0)==0){while(1){k=c[651338]|0;if((k|0)==2605304){w1(82312,(h=i,i=i+8|0,c[h>>2]=111696,h)|0);i=h;l=c[651338]|0}else{l=k}ya(c[l+4>>2]|0);k=yf(j,0)|0;if((k|0)!=0){m=k;break}}}else{m=d}yP(m+8|0,e|0,31)|0;e=m+4|0;c[e>>2]=a;c[a+4>>2]=b;a=m+56|0;m=c[(c[e>>2]|0)+4>>2]|0;e=a+m|0;c[g>>2]=e;if((e|0)==0){n=0;i=f;return n|0}e=-56-b|0;b=a+(e+m)|0;d=a+(m+52+e)|0;j=c[d>>2]|0;l=a+(m+48+e)|0;if((j|0)==0){o=8436}else{e=c[l>>2]|0;if((e|0)==0){o=8436}else{p=e;q=j}}if((o|0)==8436){w1(59064,(h=i,i=i+8|0,c[h>>2]=111632,h)|0);i=h;p=c[l>>2]|0;q=c[d>>2]|0}c[q+48>>2]=p;c[(c[l>>2]|0)+52>>2]=c[d>>2];c[d>>2]=0;c[l>>2]=0;c[(c[651339]|0)+48>>2]=b;c[d>>2]=c[651339];c[l>>2]=2605304;c[651339]=b;n=c[g>>2]|0;i=f;return n|0}function yf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;e=(b|0)==0;if(e&(c[651336]|0)==2605304){b=c[278582]|0;if(((c[278580]|0)-(c[278584]|0)-b|0)<(a|0)){w1(60856,(f=i,i=i+16|0,c[f>>2]=111648,c[f+8>>2]=a,f)|0);i=f;g=c[278582]|0}else{g=b}b=c[278586]|0;h=b+g|0;j=h;yG(h|0,0,56);c[h>>2]=a;c[651337]=j;c[651336]=j;c[b+(g+44)>>2]=2605304;c[b+(g+40)>>2]=2605304;h=b+(g+52)|0;k=b+(g+48)|0;if((c[h>>2]|0)==0){if((c[k>>2]|0)!=0){l=8449}}else{l=8449}if((l|0)==8449){w1(59624,(f=i,i=i+8|0,c[f>>2]=111664,f)|0);i=f}c[(c[651339]|0)+48>>2]=j;c[h>>2]=c[651339];c[k>>2]=2605304;c[651339]=j;m=j;i=d;return m|0}j=c[278586]|0;k=j+(c[278582]|0)|0;h=c[651337]|0;L11245:do{if(e){g=k;b=h;while(1){if((b-g|0)>=(a|0)){n=b;o=g;l=8456;break L11245}p=b;q=c[b>>2]|0;r=p+q|0;s=r;t=c[b+44>>2]|0;if((t|0)==2605304){u=p;v=q;w=r;x=s;break}else{g=s;b=t}}}else{b=k;g=h;while(1){if((g|0)!=(h|0)){if((g-b|0)>=(a|0)){n=g;o=b;l=8456;break L11245}}t=g;s=c[g>>2]|0;r=t+s|0;q=r;p=c[g+44>>2]|0;if((p|0)==2605304){u=t;v=s;w=r;x=q;break}else{b=q;g=p}}}}while(0);if((l|0)==8456){yG(o|0,0,56);c[o>>2]=a;c[o+44>>2]=n;h=n+40|0;c[o+40>>2]=c[h>>2];c[(c[h>>2]|0)+44>>2]=o;c[h>>2]=o;h=o+52|0;n=o+48|0;if((c[h>>2]|0)==0){if((c[n>>2]|0)!=0){l=8458}}else{l=8458}if((l|0)==8458){w1(59624,(f=i,i=i+8|0,c[f>>2]=111664,f)|0);i=f}c[(c[651339]|0)+48>>2]=o;c[h>>2]=c[651339];c[n>>2]=2605304;c[651339]=o;m=o;i=d;return m|0}if((j+((c[278580]|0)-(c[278584]|0))-w|0)<(a|0)){m=0;i=d;return m|0}yG(w|0,0,56);c[w>>2]=a;c[u+(v+44)>>2]=2605304;c[u+(v+40)>>2]=c[651336];c[(c[651336]|0)+44>>2]=x;c[651336]=x;a=u+(v+52)|0;w=u+(v+48)|0;if((c[a>>2]|0)==0){if((c[w>>2]|0)!=0){l=8464}}else{l=8464}if((l|0)==8464){w1(59624,(f=i,i=i+8|0,c[f>>2]=111664,f)|0);i=f}c[(c[651339]|0)+48>>2]=x;c[a>>2]=c[651339];c[w>>2]=2605304;c[651339]=x;m=x;i=d;return m|0}function yg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;c[278586]=a;c[278580]=b;c[278582]=0;c[278584]=0;c[651336]=2605304;c[651337]=2605304;c[651338]=2605304;c[651339]=2605304;b=ob(80352)|0;do{if((b|0)==0){e=262144}else{if(b>>>0<((c[353050]|0)-1|0)>>>0){e=(nE(c[(c[353048]|0)+(b+1<<2)>>2]|0)|0)<<10;break}else{w1(78512,(a=i,i=i+8|0,c[a>>2]=111080,a)|0);i=a;e=262144;break}}}while(0);b=x1(e,77344)|0;c[270780]=b;a=b+32|0;f=a;g=b+4|0;c[b+20>>2]=f;c[b+16>>2]=f;c[b+8>>2]=1;c[b+12>>2]=0;c[g>>2]=0;c[b+28>>2]=f;c[b+44>>2]=g;c[b+48>>2]=g;c[b+36>>2]=0;c[b+40>>2]=1919505;c[a>>2]=e-32;oE(75904,466);oE(74728,58);oE(73776,146);i=d;return}function yh(){var a=0,b=0;a=i;do{if((oq()|0)==2){if((cS(os(1)|0,72760)|0)==0){yj(0);i=a;return}if((cS(os(1)|0,68992)|0)!=0){break}yj(1);i=a;return}}while(0);oW(67760,(b=i,i=i+1|0,i=i+7>>3<<3,c[b>>2]=0,b)|0);i=b;i=a;return}function yi(){var a=0,b=0,d=0,e=0,f=0;a=i;do{if((oq()|0)==2){if((cS(os(1)|0,72760)|0)==0){b=c[651337]|0;if((b|0)==2605304){i=a;return}else{d=b}do{oW(70520,(e=i,i=i+16|0,c[e>>2]=c[d>>2],c[e+8>>2]=d+8,e)|0);i=e;d=c[d+44>>2]|0;}while((d|0)!=2605304);i=a;return}if((cS(os(1)|0,75904)|0)!=0){break}b=c[651337]|0;if((b|0)==2605304){i=a;return}else{f=b}do{ya(c[f+4>>2]|0);f=c[651337]|0;}while((f|0)!=2605304);i=a;return}}while(0);oW(71832,(e=i,i=i+1|0,i=i+7>>3<<3,c[e>>2]=0,e)|0);i=e;i=a;return}function yj(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=i;i=i+16|0;e=b|0;f=e|0;yG(f|0,0,9);g=(a|0)!=0;a=g?10:8;h=c[278586]|0;j=h+(c[278582]|0)|0;k=c[278580]|0;l=h+k|0;m=h+(k-(c[278584]|0))|0;oW(66784,(n=i,i=i+24|0,c[n>>2]=a,c[n+8>>2]=2659256,c[n+16>>2]=k,n)|0);i=n;oW(64880,(n=i,i=i+1|0,i=i+7>>3<<3,c[n>>2]=0,n)|0);i=n;k=e;if(g){g=0;e=h;while(1){if((e|0)==(j|0)){oW(64880,(n=i,i=i+1|0,i=i+7>>3<<3,c[n>>2]=0,n)|0);i=n;o=(c[278580]|0)-(c[278582]|0)-(c[278584]|0)|0;oW(64088,(n=i,i=i+24|0,c[n>>2]=a,c[n+8>>2]=2659256,c[n+16>>2]=o,n)|0);i=n;oW(64880,(n=i,i=i+1|0,i=i+7>>3<<3,c[n>>2]=0,n)|0);i=n;p=m}else{p=e}if((p|0)==(l|0)){q=g;break}if((c[p>>2]|0)!=502268397){w1(49816,(n=i,i=i+8|0,c[n>>2]=111144,n)|0);i=n}o=p+4|0;r=c[o>>2]|0;if((r|0)<16){s=8508}else{if((p+r-(c[278586]|0)|0)>(c[278580]|0)){s=8508}else{t=r}}if((s|0)==8508){s=0;w1(45736,(n=i,i=i+8|0,c[n>>2]=111144,n)|0);i=n;t=c[o>>2]|0}r=p+8|0;u=r|0;v=r+4|0;r=d[v]|d[v+1|0]<<8|d[v+2|0]<<16|d[v+3|0]<<24|0;c[k>>2]=d[u]|d[u+1|0]<<8|d[u+2|0]<<16|d[u+3|0]<<24;c[k+4>>2]=r;r=c[o>>2]|0;oW(63168,(n=i,i=i+40|0,c[n>>2]=a,c[n+8>>2]=p,c[n+16>>2]=r,c[n+24>>2]=8,c[n+32>>2]=f,n)|0);i=n;g=g+1|0;e=p+t|0}oW(64880,(n=i,i=i+1|0,i=i+7>>3<<3,c[n>>2]=0,n)|0);i=n;oW(61840,(n=i,i=i+8|0,c[n>>2]=q,n)|0);i=n;i=b;return}else{w=0;x=h;y=0}while(1){if((x|0)==(j|0)){oW(64880,(n=i,i=i+1|0,i=i+7>>3<<3,c[n>>2]=0,n)|0);i=n;h=(c[278580]|0)-(c[278582]|0)-(c[278584]|0)|0;oW(64088,(n=i,i=i+24|0,c[n>>2]=a,c[n+8>>2]=2659256,c[n+16>>2]=h,n)|0);i=n;oW(64880,(n=i,i=i+1|0,i=i+7>>3<<3,c[n>>2]=0,n)|0);i=n;z=m}else{z=x}if((z|0)==(l|0)){q=w;break}if((c[z>>2]|0)!=502268397){w1(49816,(n=i,i=i+8|0,c[n>>2]=111144,n)|0);i=n}h=z+4|0;t=c[h>>2]|0;if((t|0)<16){s=8517}else{if((z+t-(c[278586]|0)|0)>(c[278580]|0)){s=8517}else{A=t}}if((s|0)==8517){s=0;w1(45736,(n=i,i=i+8|0,c[n>>2]=111144,n)|0);i=n;A=c[h>>2]|0}h=z+A|0;t=w+1|0;p=A+y|0;e=z+8|0;g=e;r=g|0;o=g+4|0;g=d[o]|d[o+1|0]<<8|d[o+2|0]<<16|d[o+3|0]<<24|0;c[k>>2]=d[r]|d[r+1|0]<<8|d[r+2|0]<<16|d[r+3|0]<<24;c[k+4>>2]=g;if(!((h|0)==(j|0)|(h|0)==(l|0))){g=(bN(e|0,z+(A+8)|0,8)|0)==0;if(g){w=t;x=h;y=g?p:0;continue}}oW(62616,(n=i,i=i+40|0,c[n>>2]=a,c[n+8>>2]=2659256,c[n+16>>2]=p,c[n+24>>2]=8,c[n+32>>2]=f,n)|0);i=n;w=t;x=h;y=0}oW(64880,(n=i,i=i+1|0,i=i+7>>3<<3,c[n>>2]=0,n)|0);i=n;oW(61840,(n=i,i=i+8|0,c[n>>2]=q,n)|0);i=n;i=b;return}function yk(){var b=0;c[651386]=2605584;c[651387]=2605424;c[651388]=0;c[651389]=5;c[651396]=0;c[651397]=-1;c[651398]=1;a[2605440|0]=0;g[651356]=1.0;c[651399]=1;c[651401]=-1;c[651400]=2;a[2605460|0]=0;g[651361]=1.0;c[651402]=2;c[651403]=-1;c[651404]=3;a[2605480|0]=1;g[651367]=1.0;c[651405]=3;c[651407]=-1;c[651406]=4;a[2605500|0]=1;g[651372]=1.0;c[651408]=4;c[651409]=-1;c[651410]=5;a[2605520|0]=2;g[651378]=1.0;c[651411]=5;c[651413]=-1;c[651412]=-2;a[2605540|0]=2;g[651383]=1.0;yG(183536|0,0|0,1024|0);c[45882]=0;b=c[46183]|0;yl(0,b+84|0,b+96|0)|0;return}function yl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0.0,u=0.0;e=i;i=i+64|0;f=e|0;h=e+16|0;j=e+32|0;k=e+48|0;l=c[45882]|0;if((l|0)==32){w1(41512,(m=i,i=i+8|0,c[m>>2]=109872,m)|0);i=m;n=c[45882]|0}else{n=l}l=183536+(n<<5)|0;c[45882]=n+1;nB(183552+(n<<5)|0);nB(183560+(n<<5)|0);if((a|0)==4){c[l>>2]=-1;c[183548+(n<<5)>>2]=0;c[183544+(n<<5)>>2]=0;i=e;return l|0}else{m=d+4|0;o=b+4|0;p=+g[d>>2]- +g[b>>2]<=+g[m>>2]- +g[o>>2]|0;c[l>>2]=p;q=(+g[d+(p<<2)>>2]+ +g[b+(p<<2)>>2])*.5;g[183540+(n<<5)>>2]=q;r=+g[b>>2];s=f|0;g[s>>2]=r;t=+g[o>>2];g[f+4>>2]=t;u=+g[b+8>>2];g[f+8>>2]=u;f=j|0;g[f>>2]=r;g[j+4>>2]=t;g[j+8>>2]=u;u=+g[d>>2];b=h|0;g[b>>2]=u;t=+g[m>>2];g[h+4>>2]=t;r=+g[d+8>>2];g[h+8>>2]=r;d=k|0;g[d>>2]=u;g[k+4>>2]=t;g[k+8>>2]=r;g[j+(p<<2)>>2]=q;g[h+(p<<2)>>2]=q;p=a+1|0;c[183544+(n<<5)>>2]=yl(p,f,d)|0;c[183548+(n<<5)>>2]=yl(p,s,b)|0;i=e;return l|0}return 0}function ym(a){a=a|0;var b=0,d=0;b=a+4|0;d=b|0;if((c[d>>2]|0)==0){return}nC(b);c[a+8>>2]=0;c[d>>2]=0;return}function yn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0.0,h=0.0,i=0.0,j=0.0,k=0,l=0.0,m=0.0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0;d=a+4|0;e=d|0;if((c[e>>2]|0)!=0){nC(d);c[a+8>>2]=0;c[e>>2]=0}if((c[49322]|0)==(a|0)){return}if((c[a>>2]|0)!=0){return}f=+g[a+136>>2];h=f+ +g[a+228>>2];e=a+100|0;g[e>>2]=h;i=+g[a+140>>2];j=i+ +g[a+232>>2];k=a+104|0;g[k>>2]=j;l=+g[a+144>>2];m=l+ +g[a+236>>2];n=a+108|0;g[n>>2]=m;o=f+ +g[a+240>>2];p=a+112|0;g[p>>2]=o;f=i+ +g[a+244>>2];q=a+116|0;g[q>>2]=f;i=l+ +g[a+248>>2];r=a+120|0;g[r>>2]=i;if((~~+g[a+400>>2]&256|0)==0){g[e>>2]=h+-1.0;g[k>>2]=j+-1.0;g[n>>2]=m+-1.0;g[p>>2]=o+1.0;g[q>>2]=f+1.0;g[r>>2]=i+1.0}else{g[e>>2]=h+-15.0;g[k>>2]=j+-15.0;g[p>>2]=o+15.0;g[q>>2]=f+15.0}c[a+12>>2]=0;if(+g[a+96>>2]!=0.0){yo(a,c[(c[46183]|0)+164>>2]|0)}f=+g[a+132>>2];if(f==0.0){return}q=c[45884]|0;L11379:do{if((q|0)==-1){s=183536}else{p=183536;k=q;while(1){o=+g[p+4>>2];if(+g[a+100+(k<<2)>>2]>o){t=p+8|0}else{if(+g[a+112+(k<<2)>>2]>=o){s=p;break L11379}t=p+12|0}e=c[t>>2]|0;r=c[e>>2]|0;if((r|0)==-1){s=e;break}else{p=e;k=r}}}}while(0);if(f==1.0){nD(d,s+16|0)}else{nD(d,s+24|0)}if((b|0)==0){return}yp(a,183536);return}function yo(d,e){d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0;f=c[e>>2]|0;if((f|0)==-2){return}h=d+100|0;i=d+112|0;j=e;e=f;while(1){if((e|0)<0){k=8568;break}f=c[j+40>>2]|0;l=a[f+16|0]|0;m=l&255;do{if((l&255)<3){n=+g[f+12>>2];if(n<=+g[d+100+(m<<2)>>2]){o=1;k=8575;break}p=n>=+g[d+112+(m<<2)>>2]?2:3;k=8574}else{p=rb(h,i,f)|0;k=8574}}while(0);if((k|0)==8574){k=0;if((p&1|0)==0){q=p}else{o=p;k=8575}}if((k|0)==8575){k=0;yo(d,c[j+44>>2]|0);q=o}if((q&2|0)==0){k=8583;break}f=c[j+48>>2]|0;m=c[f>>2]|0;if((m|0)==-2){k=8580;break}else{j=f;e=m}}if((k|0)==8568){e=d+12|0;q=c[e>>2]|0;if((q|0)==16){return}b[d+16+(q<<1)>>1]=((j-(c[(c[46183]|0)+140>>2]|0)|0)>>>6)+65535&65535;c[e>>2]=(c[e>>2]|0)+1;return}else if((k|0)==8580){return}else if((k|0)==8583){return}}function yp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0,E=0.0;d=i;e=a+100|0;f=a+104|0;j=a+108|0;k=a+112|0;l=a+116|0;m=a+120|0;n=a;o=b;while(1){b=o+16|0;p=c[o+20>>2]|0;if((p|0)!=(b|0)){q=p;while(1){p=q+4|0;if((q|0)==0){r=8588}else{s=c[p>>2]|0;if((s|0)==0){r=8588}else{t=s}}if((r|0)==8588){r=0;qa(49784,(u=i,i=i+8|0,c[u>>2]=109696,u)|0);i=u;t=c[p>>2]|0}p=q+4|0;s=q-8+4|0;do{if((s|0)==(a|0)){v=t}else{w=s+264|0;if((c[w>>2]|0)==0){v=t;break}if(+g[s+132>>2]!=1.0){v=t;break}if(+g[e>>2]>+g[s+112>>2]){v=t;break}if(+g[f>>2]>+g[s+116>>2]){v=t;break}if(+g[j>>2]>+g[s+120>>2]){v=t;break}if(+g[k>>2]<+g[s+100>>2]){v=t;break}if(+g[l>>2]<+g[s+104>>2]){v=t;break}if(+g[m>>2]<+g[s+108>>2]){v=t;break}x=c[157712]|0;y=x+112|0;z=c[y>>2]|0;A=c[x+116>>2]|0;c[y>>2]=s-(c[49322]|0);c[(c[157712]|0)+116>>2]=n-(c[49322]|0);g[(c[157712]|0)+124>>2]=+h[23072];tm(c[w>>2]|0);w=c[p>>2]|0;if((t|0)==(w|0)|(w|0)==0){B=t}else{oX(45704,(u=i,i=i+8|0,c[u>>2]=109696,u)|0);i=u;B=c[p>>2]|0}c[(c[157712]|0)+112>>2]=z;c[(c[157712]|0)+116>>2]=A;v=B}}while(0);if((v|0)==(b|0)){break}else{q=v}}}q=o|0;b=c[q>>2]|0;if((b|0)==-1){r=8608;break}p=o+4|0;C=+g[p>>2];if(+g[a+112+(b<<2)>>2]>C){yp(a,c[o+8>>2]|0);D=c[q>>2]|0;E=+g[p>>2]}else{D=b;E=C}if(+g[a+100+(D<<2)>>2]>=E){r=8609;break}o=c[o+12>>2]|0}if((r|0)==8608){i=d;return}else if((r|0)==8609){i=d;return}}function yq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0;f=i;if((d|0)<=-1){h=d;i=f;return h|0}j=b+8|0;k=b|0;l=b+4|0;m=e+4|0;n=e+8|0;o=b+12|0;b=d;while(1){if((b|0)<(c[j>>2]|0)){p=8614}else{if((b|0)>(c[o>>2]|0)){p=8614}}if((p|0)==8614){p=0;w1(78384,(d=i,i=i+16|0,c[d>>2]=109832,c[d+8>>2]=b,d)|0);i=d}d=c[k>>2]|0;q=c[l>>2]|0;r=c[d+(b*12|0)>>2]|0;s=a[q+(r*20|0)+16|0]|0;if((s&255)<3){t=+g[e+((s&255)<<2)>>2]- +g[q+(r*20|0)+12>>2]}else{t=+g[q+(r*20|0)>>2]*+g[e>>2]+ +g[q+(r*20|0)+4>>2]*+g[m>>2]+ +g[q+(r*20|0)+8>>2]*+g[n>>2]- +g[q+(r*20|0)+12>>2]}if(t<0.0){u=d+(b*12|0)+8|0}else{u=d+(b*12|0)+4|0}d=c[u>>2]|0;if((d|0)>-1){b=d}else{h=d;break}}i=f;return h|0}function yr(a){a=a|0;var b=0;b=yq((c[46183]|0)+208|0,0,a)|0;return((b+14|0)>>>0<6?-3:b)|0}function ys(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+56|0;d=b|0;e=a+136|0;yt(d,e,a+228|0,a+240|0,e,0,a);i=b;return((c[d+4>>2]|0)==0?0:c[49322]|0)|0}function yt(a,b,d,e,f,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0;k=i;i=i+184|0;l=k|0;m=k+128|0;yG(l|0,0,124);yv(m,c[49322]|0,b,d,e,f);n=l+64|0;o=m;yJ(n|0,o|0,52)|0;c[l+56>>2]=b;c[l+60>>2]=f;c[l+24>>2]=d;c[l+28>>2]=e;c[l+116>>2]=h;c[l+120>>2]=j;if((h|0)==2){g[l+32>>2]=-15.0;g[l+44>>2]=15.0;g[l+36>>2]=-15.0;g[l+48>>2]=15.0;g[l+40>>2]=-15.0;g[l+52>>2]=15.0;p=-15.0;q=15.0;r=-15.0;s=15.0;t=-15.0;u=15.0}else{v=+g[d>>2];g[l+32>>2]=v;w=+g[d+4>>2];g[l+36>>2]=w;x=+g[d+8>>2];g[l+40>>2]=x;y=+g[e>>2];g[l+44>>2]=y;z=+g[e+4>>2];g[l+48>>2]=z;A=+g[e+8>>2];g[l+52>>2]=A;p=v;q=y;r=w;s=z;t=x;u=A}A=+g[f>>2];x=+g[b>>2];e=A>x;g[l>>2]=(e?x:A)+p+-1.0;g[l+12>>2]=(e?A:x)+q+1.0;q=+g[f+4>>2];x=+g[b+4>>2];if(q>x){g[l+4>>2]=x+r+-1.0;g[l+16>>2]=q+s+1.0}else{g[l+4>>2]=q+r+-1.0;g[l+16>>2]=x+s+1.0}s=+g[f+8>>2];x=+g[b+8>>2];if(s>x){g[l+8>>2]=x+t+-1.0;g[l+20>>2]=s+u+1.0;yw(183536,l);B=a;yJ(B|0,n|0,52)|0;i=k;return}else{g[l+8>>2]=s+t+-1.0;g[l+20>>2]=x+u+1.0;yw(183536,l);B=a;yJ(B|0,n|0,52)|0;i=k;return}}function yu(b,d,e,f,h,j,k){b=b|0;d=d|0;e=+e;f=+f;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0.0;l=i;i=i+16|0;m=l|0;if((d|0)<0){if((d|0)==-2){c[k+4>>2]=1;n=1;i=l;return n|0}c[k>>2]=0;if((d|0)==-1){c[k+8>>2]=1;n=1;i=l;return n|0}else{c[k+12>>2]=1;n=1;i=l;return n|0}}o=b+8|0;if((c[o>>2]|0)>(d|0)){p=8647}else{if((c[b+12>>2]|0)<(d|0)){p=8647}}if((p|0)==8647){w1(100936,(q=i,i=i+8|0,c[q>>2]=109728,q)|0);i=q}p=c[b>>2]|0;r=c[b+4>>2]|0;s=c[p+(d*12|0)>>2]|0;t=r+(s*20|0)|0;u=a[r+(s*20|0)+16|0]|0;v=u&255;if((u&255)<3){w=+g[r+(s*20|0)+12>>2];x=+g[j+(v<<2)>>2]-w;y=+g[h+(v<<2)>>2]-w}else{w=+g[t>>2];z=+g[r+(s*20|0)+4>>2];A=+g[r+(s*20|0)+8>>2];B=+g[r+(s*20|0)+12>>2];x=w*+g[j>>2]+z*+g[j+4>>2]+A*+g[j+8>>2]-B;y=w*+g[h>>2]+z*+g[h+4>>2]+A*+g[h+8>>2]-B}if(!(y<0.0|x<0.0)){n=yu(b,c[p+(d*12|0)+4>>2]|0,e,f,h,j,k)|0;i=l;return n|0}v=y<0.0;if(v&x<0.0){n=yu(b,c[p+(d*12|0)+8>>2]|0,e,f,h,j,k)|0;i=l;return n|0}B=y;if(v){C=(B+.03125)/(y-x)}else{C=(B+-.03125)/(y-x)}x=C;C=x<0.0?0.0:x;x=C>1.0?1.0:C;C=f-e;y=+g[h>>2];u=m|0;g[u>>2]=y+x*(+g[j>>2]-y);D=h+4|0;y=+g[D>>2];E=j+4|0;F=m+4|0;g[F>>2]=y+x*(+g[E>>2]-y);G=h+8|0;y=+g[G>>2];H=j+8|0;I=m+8|0;g[I>>2]=y+x*(+g[H>>2]-y);y=C*x+e;m=v&1;if((yu(b,c[p+(d*12|0)+4+(m<<2)>>2]|0,e,y,h,u,k)|0)==0){n=0;i=l;return n|0}J=c[p+(d*12|0)+4+((m^1)<<2)>>2]|0;if((yq(b,J,u)|0)!=-2){n=yu(b,J,y,f,u,j,k)|0;i=l;return n|0}if((c[k>>2]|0)!=0){n=0;i=l;return n|0}if(v){g[k+32>>2]=+g[29396]- +g[t>>2];g[k+36>>2]=+g[29397]- +g[r+(s*20|0)+4>>2];g[k+40>>2]=+g[29398]- +g[r+(s*20|0)+8>>2];g[k+44>>2]=-0.0- +g[r+(s*20|0)+12>>2]}else{g[k+32>>2]=+g[t>>2];g[k+36>>2]=+g[r+(s*20|0)+4>>2];g[k+40>>2]=+g[r+(s*20|0)+8>>2];g[k+44>>2]=+g[r+(s*20|0)+12>>2]}L11539:do{if((yq(b,c[o>>2]|0,u)|0)==-2){f=x;B=y;while(1){A=f+-.1;if(A<0.0){break}z=+g[h>>2];g[u>>2]=z+A*(+g[j>>2]-z);z=+g[D>>2];g[F>>2]=z+A*(+g[E>>2]-z);z=+g[G>>2];g[I>>2]=z+A*(+g[H>>2]-z);z=C*A+e;if((yq(b,c[o>>2]|0,u)|0)==-2){f=A;B=z}else{K=z;break L11539}}g[k+16>>2]=B;g[k+20>>2]=+g[u>>2];g[k+24>>2]=+g[F>>2];g[k+28>>2]=+g[I>>2];oX(81768,(q=i,i=i+1|0,i=i+7>>3<<3,c[q>>2]=0,q)|0);i=q;n=0;i=l;return n|0}else{K=y}}while(0);g[k+16>>2]=K;g[k+20>>2]=+g[u>>2];g[k+24>>2]=+g[F>>2];g[k+28>>2]=+g[I>>2];n=0;i=l;return n|0}function yv(a,b,d,e,f,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0.0,z=0,A=0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0;j=i;i=i+88|0;k=j|0;l=j+56|0;m=j+72|0;n=k;yG(n|0,0,52);o=k+16|0;g[o>>2]=1.0;c[k>>2]=1;p=k+20|0;g[p>>2]=+g[h>>2];q=h+4|0;r=k+24|0;g[r>>2]=+g[q>>2];s=h+8|0;t=k+28|0;g[t>>2]=+g[s>>2];if(+g[b+132>>2]==4.0){if(+g[b+128>>2]!=7.0){w1(59496,(u=i,i=i+1|0,i=i+7>>3<<3,c[u>>2]=0,u)|0);i=u}v=c[188832+(~~+g[b+96>>2]<<2)>>2]|0;if((v|0)==0){w=8686}else{if((c[v+68>>2]|0)!=0){w=8686}}if((w|0)==8686){w1(53728,(u=i,i=i+1|0,i=i+7>>3<<3,c[u>>2]=0,u)|0);i=u}x=+g[e>>2];y=+g[f>>2]-x;u=e+4|0;w=e+8|0;do{if(y<3.0){z=v+208|0}else{if(y>32.0){z=v+288|0;break}else{z=v+248|0;break}}}while(0);A=z;B=+g[z+16>>2]-x+ +g[b+136>>2];C=+g[z+20>>2]- +g[u>>2]+ +g[b+140>>2];D=+g[z+24>>2]- +g[w>>2]+ +g[b+144>>2]}else{x=+g[b+228>>2]- +g[f>>2];y=+g[b+232>>2]- +g[f+4>>2];E=+g[b+236>>2]- +g[f+8>>2];F=+g[b+244>>2]- +g[e+4>>2];G=+g[b+248>>2]- +g[e+8>>2];g[651359]=+g[b+240>>2]- +g[e>>2];g[651364]=x;g[651369]=F;g[651374]=y;g[651379]=G;g[651384]=E;A=2605544;B=+g[b+136>>2];C=+g[b+140>>2];D=+g[b+144>>2]}e=l|0;g[e>>2]=+g[d>>2]-B;g[l+4>>2]=+g[d+4>>2]-C;g[l+8>>2]=+g[d+8>>2]-D;d=m|0;g[d>>2]=+g[h>>2]-B;g[m+4>>2]=+g[q>>2]-C;g[m+8>>2]=+g[s>>2]-D;yu(A,c[A+8>>2]|0,0.0,1.0,e,d,k)|0;E=+g[o>>2];if(E!=1.0){g[p>>2]=B+ +g[p>>2];g[r>>2]=C+ +g[r>>2];g[t>>2]=D+ +g[t>>2]}do{if(E>=1.0){if((c[k+4>>2]|0)!=0){break}H=a;yJ(H|0,n|0,52)|0;i=j;return}}while(0);c[k+48>>2]=b;H=a;yJ(H|0,n|0,52)|0;i=j;return}function yw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0.0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ab=0,ac=0,ad=0.0,ae=0,af=0,ag=0,ah=0.0;d=i;i=i+144|0;e=d+32|0;f=d+88|0;h=a+24|0;j=c[a+28>>2]|0;L11576:do{if((j|0)!=(h|0)){k=b+120|0;l=b+116|0;m=b|0;n=b+4|0;o=b+8|0;p=b+12|0;q=b+16|0;r=b+20|0;s=b+64|0;t=b+56|0;u=b+24|0;v=b+28|0;w=b+60|0;x=f|0;y=f+4|0;z=f+8|0;A=f+16|0;B=f+20|0;C=d|0;D=b+80|0;E=b+68|0;F=b+72|0;G=b+84|0;H=b+112|0;I=b+32|0;J=b+44|0;K=e|0;L=e+4|0;M=e+8|0;N=e+16|0;O=e+20|0;P=j;L11578:while(1){Q=c[P+4>>2]|0;R=P-8+4|0;S=R;T=R+132|0;U=+g[T>>2];L11580:do{if(U!=0.0){if((S|0)==(c[k>>2]|0)){break}if(U==1.0){w1(68720,(V=i,i=i+1|0,i=i+7>>3<<3,c[V>>2]=0,V)|0);i=V}if((c[l>>2]|0)==1){if(+g[T>>2]!=4.0){break}}if(+g[m>>2]>+g[R+112>>2]){break}if(+g[n>>2]>+g[R+116>>2]){break}if(+g[o>>2]>+g[R+120>>2]){break}if(+g[p>>2]<+g[R+100>>2]){break}if(+g[q>>2]<+g[R+104>>2]){break}if(+g[r>>2]<+g[R+108>>2]){break}V=c[k>>2]|0;W=(V|0)==0;do{if(!W){if(+g[V+252>>2]==0.0){break}if(+g[R+252>>2]==0.0){break L11580}}}while(0);if((c[s>>2]|0)!=0){break L11578}if(!W){X=c[49322]|0;if((X+(c[R+476>>2]|0)|0)==(V|0)){break}if((X+(c[V+476>>2]|0)|0)==(R|0)){break}}X=c[t>>2]|0;if((~~+g[R+400>>2]&32|0)==0){yv(f,S,X,c[u>>2]|0,c[v>>2]|0,c[w>>2]|0);Y=c[x>>2]|0;Z=c[y>>2]|0;_=c[z>>2]|0;$=c[z+4>>2]|0;aa=+g[A>>2];c[C>>2]=c[B>>2];c[C+4>>2]=c[B+4>>2];c[C+8>>2]=c[B+8>>2];c[C+12>>2]=c[B+12>>2];c[C+16>>2]=c[B+16>>2];c[C+20>>2]=c[B+20>>2];c[C+24>>2]=c[B+24>>2];ab=Y;ac=Z;ad=aa;ae=$;af=_}else{yv(e,S,X,I,J,c[w>>2]|0);X=c[K>>2]|0;_=c[L>>2]|0;$=c[M>>2]|0;Z=c[M+4>>2]|0;aa=+g[N>>2];c[C>>2]=c[O>>2];c[C+4>>2]=c[O+4>>2];c[C+8>>2]=c[O+8>>2];c[C+12>>2]=c[O+12>>2];c[C+16>>2]=c[O+16>>2];c[C+20>>2]=c[O+20>>2];c[C+24>>2]=c[O+24>>2];ab=X;ac=_;ad=aa;ae=Z;af=$}if((ab|ac|0)==0){if(ad>=+g[D>>2]){break}}$=(c[E>>2]|0)==0;c[s>>2]=ab;c[E>>2]=ac;c[F>>2]=af;c[F+4>>2]=ae;g[D>>2]=ad;c[G>>2]=c[C>>2];c[G+4>>2]=c[C+4>>2];c[G+8>>2]=c[C+8>>2];c[G+12>>2]=c[C+12>>2];c[G+16>>2]=c[C+16>>2];c[G+20>>2]=c[C+20>>2];c[G+24>>2]=c[C+24>>2];c[H>>2]=S;if($){break}c[E>>2]=1}}while(0);if((Q|0)==(h|0)){break L11576}else{P=Q}}i=d;return}}while(0);h=a|0;ae=c[h>>2]|0;if((ae|0)==-1){i=d;return}af=a+4|0;ad=+g[af>>2];if(+g[b+12+(ae<<2)>>2]>ad){yw(c[a+8>>2]|0,b);ag=c[h>>2]|0;ah=+g[af>>2]}else{ag=ae;ah=ad}if(+g[b+(ag<<2)>>2]>=ah){i=d;return}yw(c[a+12>>2]|0,b);i=d;return}function yx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;do{if(a>>>0<245){if(a>>>0<11){b=16}else{b=a+11&-8}d=b>>>3;e=c[664844]|0;f=e>>>(d>>>0);if((f&3|0)!=0){g=(f&1^1)+d|0;h=g<<1;i=2659416+(h<<2)|0;j=2659416+(h+2<<2)|0;h=c[j>>2]|0;k=h+8|0;l=c[k>>2]|0;do{if((i|0)==(l|0)){c[664844]=e&~(1<<g)}else{if(l>>>0<(c[664848]|0)>>>0){ca();return 0}m=l+12|0;if((c[m>>2]|0)==(h|0)){c[m>>2]=i;c[j>>2]=l;break}else{ca();return 0}}}while(0);l=g<<3;c[h+4>>2]=l|3;j=h+(l|4)|0;c[j>>2]=c[j>>2]|1;n=k;return n|0}if(b>>>0<=(c[664846]|0)>>>0){o=b;break}if((f|0)!=0){j=2<<d;l=f<<d&(j|-j);j=(l&-l)-1|0;l=j>>>12&16;i=j>>>(l>>>0);j=i>>>5&8;m=i>>>(j>>>0);i=m>>>2&4;p=m>>>(i>>>0);m=p>>>1&2;q=p>>>(m>>>0);p=q>>>1&1;r=(j|l|i|m|p)+(q>>>(p>>>0))|0;p=r<<1;q=2659416+(p<<2)|0;m=2659416+(p+2<<2)|0;p=c[m>>2]|0;i=p+8|0;l=c[i>>2]|0;do{if((q|0)==(l|0)){c[664844]=e&~(1<<r)}else{if(l>>>0<(c[664848]|0)>>>0){ca();return 0}j=l+12|0;if((c[j>>2]|0)==(p|0)){c[j>>2]=q;c[m>>2]=l;break}else{ca();return 0}}}while(0);l=r<<3;m=l-b|0;c[p+4>>2]=b|3;q=p;e=q+b|0;c[q+(b|4)>>2]=m|1;c[q+l>>2]=m;l=c[664846]|0;if((l|0)!=0){q=c[664849]|0;d=l>>>3;l=d<<1;f=2659416+(l<<2)|0;k=c[664844]|0;h=1<<d;do{if((k&h|0)==0){c[664844]=k|h;s=f;t=2659416+(l+2<<2)|0}else{d=2659416+(l+2<<2)|0;g=c[d>>2]|0;if(g>>>0>=(c[664848]|0)>>>0){s=g;t=d;break}ca();return 0}}while(0);c[t>>2]=q;c[s+12>>2]=q;c[q+8>>2]=s;c[q+12>>2]=f}c[664846]=m;c[664849]=e;n=i;return n|0}l=c[664845]|0;if((l|0)==0){o=b;break}h=(l&-l)-1|0;l=h>>>12&16;k=h>>>(l>>>0);h=k>>>5&8;p=k>>>(h>>>0);k=p>>>2&4;r=p>>>(k>>>0);p=r>>>1&2;d=r>>>(p>>>0);r=d>>>1&1;g=c[2659680+((h|l|k|p|r)+(d>>>(r>>>0))<<2)>>2]|0;r=g;d=g;p=(c[g+4>>2]&-8)-b|0;while(1){g=c[r+16>>2]|0;if((g|0)==0){k=c[r+20>>2]|0;if((k|0)==0){break}else{u=k}}else{u=g}g=(c[u+4>>2]&-8)-b|0;k=g>>>0<p>>>0;r=u;d=k?u:d;p=k?g:p}r=d;i=c[664848]|0;if(r>>>0<i>>>0){ca();return 0}e=r+b|0;m=e;if(r>>>0>=e>>>0){ca();return 0}e=c[d+24>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==(d|0)){q=d+20|0;g=c[q>>2]|0;if((g|0)==0){k=d+16|0;l=c[k>>2]|0;if((l|0)==0){v=0;break}else{w=l;x=k}}else{w=g;x=q}while(1){q=w+20|0;g=c[q>>2]|0;if((g|0)!=0){w=g;x=q;continue}q=w+16|0;g=c[q>>2]|0;if((g|0)==0){break}else{w=g;x=q}}if(x>>>0<i>>>0){ca();return 0}else{c[x>>2]=0;v=w;break}}else{q=c[d+8>>2]|0;if(q>>>0<i>>>0){ca();return 0}g=q+12|0;if((c[g>>2]|0)!=(d|0)){ca();return 0}k=f+8|0;if((c[k>>2]|0)==(d|0)){c[g>>2]=f;c[k>>2]=q;v=f;break}else{ca();return 0}}}while(0);L11703:do{if((e|0)!=0){f=d+28|0;i=2659680+(c[f>>2]<<2)|0;do{if((d|0)==(c[i>>2]|0)){c[i>>2]=v;if((v|0)!=0){break}c[664845]=c[664845]&~(1<<c[f>>2]);break L11703}else{if(e>>>0<(c[664848]|0)>>>0){ca();return 0}q=e+16|0;if((c[q>>2]|0)==(d|0)){c[q>>2]=v}else{c[e+20>>2]=v}if((v|0)==0){break L11703}}}while(0);if(v>>>0<(c[664848]|0)>>>0){ca();return 0}c[v+24>>2]=e;f=c[d+16>>2]|0;do{if((f|0)!=0){if(f>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[v+16>>2]=f;c[f+24>>2]=v;break}}}while(0);f=c[d+20>>2]|0;if((f|0)==0){break}if(f>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[v+20>>2]=f;c[f+24>>2]=v;break}}}while(0);if(p>>>0<16){e=p+b|0;c[d+4>>2]=e|3;f=r+(e+4)|0;c[f>>2]=c[f>>2]|1}else{c[d+4>>2]=b|3;c[r+(b|4)>>2]=p|1;c[r+(p+b)>>2]=p;f=c[664846]|0;if((f|0)!=0){e=c[664849]|0;i=f>>>3;f=i<<1;q=2659416+(f<<2)|0;k=c[664844]|0;g=1<<i;do{if((k&g|0)==0){c[664844]=k|g;y=q;z=2659416+(f+2<<2)|0}else{i=2659416+(f+2<<2)|0;l=c[i>>2]|0;if(l>>>0>=(c[664848]|0)>>>0){y=l;z=i;break}ca();return 0}}while(0);c[z>>2]=e;c[y+12>>2]=e;c[e+8>>2]=y;c[e+12>>2]=q}c[664846]=p;c[664849]=m}f=d+8|0;if((f|0)==0){o=b;break}else{n=f}return n|0}else{if(a>>>0>4294967231){o=-1;break}f=a+11|0;g=f&-8;k=c[664845]|0;if((k|0)==0){o=g;break}r=-g|0;i=f>>>8;do{if((i|0)==0){A=0}else{if(g>>>0>16777215){A=31;break}f=(i+1048320|0)>>>16&8;l=i<<f;h=(l+520192|0)>>>16&4;j=l<<h;l=(j+245760|0)>>>16&2;B=14-(h|f|l)+(j<<l>>>15)|0;A=g>>>((B+7|0)>>>0)&1|B<<1}}while(0);i=c[2659680+(A<<2)>>2]|0;L11751:do{if((i|0)==0){C=0;D=r;E=0}else{if((A|0)==31){F=0}else{F=25-(A>>>1)|0}d=0;m=r;p=i;q=g<<F;e=0;while(1){B=c[p+4>>2]&-8;l=B-g|0;if(l>>>0<m>>>0){if((B|0)==(g|0)){C=p;D=l;E=p;break L11751}else{G=p;H=l}}else{G=d;H=m}l=c[p+20>>2]|0;B=c[p+16+(q>>>31<<2)>>2]|0;j=(l|0)==0|(l|0)==(B|0)?e:l;if((B|0)==0){C=G;D=H;E=j;break}else{d=G;m=H;p=B;q=q<<1;e=j}}}}while(0);if((E|0)==0&(C|0)==0){i=2<<A;r=k&(i|-i);if((r|0)==0){o=g;break}i=(r&-r)-1|0;r=i>>>12&16;e=i>>>(r>>>0);i=e>>>5&8;q=e>>>(i>>>0);e=q>>>2&4;p=q>>>(e>>>0);q=p>>>1&2;m=p>>>(q>>>0);p=m>>>1&1;I=c[2659680+((i|r|e|q|p)+(m>>>(p>>>0))<<2)>>2]|0}else{I=E}if((I|0)==0){J=D;K=C}else{p=I;m=D;q=C;while(1){e=(c[p+4>>2]&-8)-g|0;r=e>>>0<m>>>0;i=r?e:m;e=r?p:q;r=c[p+16>>2]|0;if((r|0)!=0){p=r;m=i;q=e;continue}r=c[p+20>>2]|0;if((r|0)==0){J=i;K=e;break}else{p=r;m=i;q=e}}}if((K|0)==0){o=g;break}if(J>>>0>=((c[664846]|0)-g|0)>>>0){o=g;break}q=K;m=c[664848]|0;if(q>>>0<m>>>0){ca();return 0}p=q+g|0;k=p;if(q>>>0>=p>>>0){ca();return 0}e=c[K+24>>2]|0;i=c[K+12>>2]|0;do{if((i|0)==(K|0)){r=K+20|0;d=c[r>>2]|0;if((d|0)==0){j=K+16|0;B=c[j>>2]|0;if((B|0)==0){L=0;break}else{M=B;N=j}}else{M=d;N=r}while(1){r=M+20|0;d=c[r>>2]|0;if((d|0)!=0){M=d;N=r;continue}r=M+16|0;d=c[r>>2]|0;if((d|0)==0){break}else{M=d;N=r}}if(N>>>0<m>>>0){ca();return 0}else{c[N>>2]=0;L=M;break}}else{r=c[K+8>>2]|0;if(r>>>0<m>>>0){ca();return 0}d=r+12|0;if((c[d>>2]|0)!=(K|0)){ca();return 0}j=i+8|0;if((c[j>>2]|0)==(K|0)){c[d>>2]=i;c[j>>2]=r;L=i;break}else{ca();return 0}}}while(0);L11801:do{if((e|0)!=0){i=K+28|0;m=2659680+(c[i>>2]<<2)|0;do{if((K|0)==(c[m>>2]|0)){c[m>>2]=L;if((L|0)!=0){break}c[664845]=c[664845]&~(1<<c[i>>2]);break L11801}else{if(e>>>0<(c[664848]|0)>>>0){ca();return 0}r=e+16|0;if((c[r>>2]|0)==(K|0)){c[r>>2]=L}else{c[e+20>>2]=L}if((L|0)==0){break L11801}}}while(0);if(L>>>0<(c[664848]|0)>>>0){ca();return 0}c[L+24>>2]=e;i=c[K+16>>2]|0;do{if((i|0)!=0){if(i>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[L+16>>2]=i;c[i+24>>2]=L;break}}}while(0);i=c[K+20>>2]|0;if((i|0)==0){break}if(i>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[L+20>>2]=i;c[i+24>>2]=L;break}}}while(0);do{if(J>>>0<16){e=J+g|0;c[K+4>>2]=e|3;i=q+(e+4)|0;c[i>>2]=c[i>>2]|1}else{c[K+4>>2]=g|3;c[q+(g|4)>>2]=J|1;c[q+(J+g)>>2]=J;i=J>>>3;if(J>>>0<256){e=i<<1;m=2659416+(e<<2)|0;r=c[664844]|0;j=1<<i;do{if((r&j|0)==0){c[664844]=r|j;O=m;P=2659416+(e+2<<2)|0}else{i=2659416+(e+2<<2)|0;d=c[i>>2]|0;if(d>>>0>=(c[664848]|0)>>>0){O=d;P=i;break}ca();return 0}}while(0);c[P>>2]=k;c[O+12>>2]=k;c[q+(g+8)>>2]=O;c[q+(g+12)>>2]=m;break}e=p;j=J>>>8;do{if((j|0)==0){Q=0}else{if(J>>>0>16777215){Q=31;break}r=(j+1048320|0)>>>16&8;i=j<<r;d=(i+520192|0)>>>16&4;B=i<<d;i=(B+245760|0)>>>16&2;l=14-(d|r|i)+(B<<i>>>15)|0;Q=J>>>((l+7|0)>>>0)&1|l<<1}}while(0);j=2659680+(Q<<2)|0;c[q+(g+28)>>2]=Q;c[q+(g+20)>>2]=0;c[q+(g+16)>>2]=0;m=c[664845]|0;l=1<<Q;if((m&l|0)==0){c[664845]=m|l;c[j>>2]=e;c[q+(g+24)>>2]=j;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}if((Q|0)==31){R=0}else{R=25-(Q>>>1)|0}l=J<<R;m=c[j>>2]|0;while(1){if((c[m+4>>2]&-8|0)==(J|0)){break}S=m+16+(l>>>31<<2)|0;j=c[S>>2]|0;if((j|0)==0){T=8891;break}else{l=l<<1;m=j}}if((T|0)==8891){if(S>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[S>>2]=e;c[q+(g+24)>>2]=m;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}}l=m+8|0;j=c[l>>2]|0;i=c[664848]|0;if(m>>>0<i>>>0){ca();return 0}if(j>>>0<i>>>0){ca();return 0}else{c[j+12>>2]=e;c[l>>2]=e;c[q+(g+8)>>2]=j;c[q+(g+12)>>2]=m;c[q+(g+24)>>2]=0;break}}}while(0);q=K+8|0;if((q|0)==0){o=g;break}else{n=q}return n|0}}while(0);K=c[664846]|0;if(o>>>0<=K>>>0){S=K-o|0;J=c[664849]|0;if(S>>>0>15){R=J;c[664849]=R+o;c[664846]=S;c[R+(o+4)>>2]=S|1;c[R+K>>2]=S;c[J+4>>2]=o|3}else{c[664846]=0;c[664849]=0;c[J+4>>2]=K|3;S=J+(K+4)|0;c[S>>2]=c[S>>2]|1}n=J+8|0;return n|0}J=c[664847]|0;if(o>>>0<J>>>0){S=J-o|0;c[664847]=S;J=c[664850]|0;K=J;c[664850]=K+o;c[K+(o+4)>>2]=S|1;c[J+4>>2]=o|3;n=J+8|0;return n|0}do{if((c[169384]|0)==0){J=aP(8)|0;if((J-1&J|0)==0){c[169386]=J;c[169385]=J;c[169387]=-1;c[169388]=-1;c[169389]=0;c[664955]=0;c[169384]=(eU(0)|0)&-16^1431655768;break}else{ca();return 0}}}while(0);J=o+48|0;S=c[169386]|0;K=o+47|0;R=S+K|0;Q=-S|0;S=R&Q;if(S>>>0<=o>>>0){n=0;return n|0}O=c[664954]|0;do{if((O|0)!=0){P=c[664952]|0;L=P+S|0;if(L>>>0<=P>>>0|L>>>0>O>>>0){n=0}else{break}return n|0}}while(0);L11893:do{if((c[664955]&4|0)==0){O=c[664850]|0;L11895:do{if((O|0)==0){T=8921}else{L=O;P=2659824;while(1){U=P|0;M=c[U>>2]|0;if(M>>>0<=L>>>0){V=P+4|0;if((M+(c[V>>2]|0)|0)>>>0>L>>>0){break}}M=c[P+8>>2]|0;if((M|0)==0){T=8921;break L11895}else{P=M}}if((P|0)==0){T=8921;break}L=R-(c[664847]|0)&Q;if(L>>>0>=2147483647){W=0;break}m=d6(L|0)|0;e=(m|0)==((c[U>>2]|0)+(c[V>>2]|0)|0);X=e?m:-1;Y=e?L:0;Z=m;_=L;T=8930}}while(0);do{if((T|0)==8921){O=d6(0)|0;if((O|0)==-1){W=0;break}g=O;L=c[169385]|0;m=L-1|0;if((m&g|0)==0){$=S}else{$=S-g+(m+g&-L)|0}L=c[664952]|0;g=L+$|0;if(!($>>>0>o>>>0&$>>>0<2147483647)){W=0;break}m=c[664954]|0;if((m|0)!=0){if(g>>>0<=L>>>0|g>>>0>m>>>0){W=0;break}}m=d6($|0)|0;g=(m|0)==(O|0);X=g?O:-1;Y=g?$:0;Z=m;_=$;T=8930}}while(0);L11915:do{if((T|0)==8930){m=-_|0;if((X|0)!=-1){aa=Y;ab=X;T=8941;break L11893}do{if((Z|0)!=-1&_>>>0<2147483647&_>>>0<J>>>0){g=c[169386]|0;O=K-_+g&-g;if(O>>>0>=2147483647){ac=_;break}if((d6(O|0)|0)==-1){d6(m|0)|0;W=Y;break L11915}else{ac=O+_|0;break}}else{ac=_}}while(0);if((Z|0)==-1){W=Y}else{aa=ac;ab=Z;T=8941;break L11893}}}while(0);c[664955]=c[664955]|4;ad=W;T=8938}else{ad=0;T=8938}}while(0);do{if((T|0)==8938){if(S>>>0>=2147483647){break}W=d6(S|0)|0;Z=d6(0)|0;if(!((Z|0)!=-1&(W|0)!=-1&W>>>0<Z>>>0)){break}ac=Z-W|0;Z=ac>>>0>(o+40|0)>>>0;Y=Z?W:-1;if((Y|0)!=-1){aa=Z?ac:ad;ab=Y;T=8941}}}while(0);do{if((T|0)==8941){ad=(c[664952]|0)+aa|0;c[664952]=ad;if(ad>>>0>(c[664953]|0)>>>0){c[664953]=ad}ad=c[664850]|0;L11935:do{if((ad|0)==0){S=c[664848]|0;if((S|0)==0|ab>>>0<S>>>0){c[664848]=ab}c[664956]=ab;c[664957]=aa;c[664959]=0;c[664853]=c[169384];c[664852]=-1;S=0;do{Y=S<<1;ac=2659416+(Y<<2)|0;c[2659416+(Y+3<<2)>>2]=ac;c[2659416+(Y+2<<2)>>2]=ac;S=S+1|0;}while(S>>>0<32);S=ab+8|0;if((S&7|0)==0){ae=0}else{ae=-S&7}S=aa-40-ae|0;c[664850]=ab+ae;c[664847]=S;c[ab+(ae+4)>>2]=S|1;c[ab+(aa-36)>>2]=40;c[664851]=c[169388]}else{S=2659824;while(1){af=c[S>>2]|0;ag=S+4|0;ah=c[ag>>2]|0;if((ab|0)==(af+ah|0)){T=8953;break}ac=c[S+8>>2]|0;if((ac|0)==0){break}else{S=ac}}do{if((T|0)==8953){if((c[S+12>>2]&8|0)!=0){break}ac=ad;if(!(ac>>>0>=af>>>0&ac>>>0<ab>>>0)){break}c[ag>>2]=ah+aa;ac=c[664850]|0;Y=(c[664847]|0)+aa|0;Z=ac;W=ac+8|0;if((W&7|0)==0){ai=0}else{ai=-W&7}W=Y-ai|0;c[664850]=Z+ai;c[664847]=W;c[Z+(ai+4)>>2]=W|1;c[Z+(Y+4)>>2]=40;c[664851]=c[169388];break L11935}}while(0);if(ab>>>0<(c[664848]|0)>>>0){c[664848]=ab}S=ab+aa|0;Y=2659824;while(1){aj=Y|0;if((c[aj>>2]|0)==(S|0)){T=8963;break}Z=c[Y+8>>2]|0;if((Z|0)==0){break}else{Y=Z}}do{if((T|0)==8963){if((c[Y+12>>2]&8|0)!=0){break}c[aj>>2]=ab;S=Y+4|0;c[S>>2]=(c[S>>2]|0)+aa;S=ab+8|0;if((S&7|0)==0){ak=0}else{ak=-S&7}S=ab+(aa+8)|0;if((S&7|0)==0){al=0}else{al=-S&7}S=ab+(al+aa)|0;Z=S;W=ak+o|0;ac=ab+W|0;_=ac;K=S-(ab+ak)-o|0;c[ab+(ak+4)>>2]=o|3;do{if((Z|0)==(c[664850]|0)){J=(c[664847]|0)+K|0;c[664847]=J;c[664850]=_;c[ab+(W+4)>>2]=J|1}else{if((Z|0)==(c[664849]|0)){J=(c[664846]|0)+K|0;c[664846]=J;c[664849]=_;c[ab+(W+4)>>2]=J|1;c[ab+(J+W)>>2]=J;break}J=aa+4|0;X=c[ab+(J+al)>>2]|0;if((X&3|0)==1){$=X&-8;V=X>>>3;L11980:do{if(X>>>0<256){U=c[ab+((al|8)+aa)>>2]|0;Q=c[ab+(aa+12+al)>>2]|0;R=2659416+(V<<1<<2)|0;do{if((U|0)!=(R|0)){if(U>>>0<(c[664848]|0)>>>0){ca();return 0}if((c[U+12>>2]|0)==(Z|0)){break}ca();return 0}}while(0);if((Q|0)==(U|0)){c[664844]=c[664844]&~(1<<V);break}do{if((Q|0)==(R|0)){am=Q+8|0}else{if(Q>>>0<(c[664848]|0)>>>0){ca();return 0}m=Q+8|0;if((c[m>>2]|0)==(Z|0)){am=m;break}ca();return 0}}while(0);c[U+12>>2]=Q;c[am>>2]=U}else{R=S;m=c[ab+((al|24)+aa)>>2]|0;P=c[ab+(aa+12+al)>>2]|0;do{if((P|0)==(R|0)){O=al|16;g=ab+(J+O)|0;L=c[g>>2]|0;if((L|0)==0){e=ab+(O+aa)|0;O=c[e>>2]|0;if((O|0)==0){an=0;break}else{ao=O;ap=e}}else{ao=L;ap=g}while(1){g=ao+20|0;L=c[g>>2]|0;if((L|0)!=0){ao=L;ap=g;continue}g=ao+16|0;L=c[g>>2]|0;if((L|0)==0){break}else{ao=L;ap=g}}if(ap>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[ap>>2]=0;an=ao;break}}else{g=c[ab+((al|8)+aa)>>2]|0;if(g>>>0<(c[664848]|0)>>>0){ca();return 0}L=g+12|0;if((c[L>>2]|0)!=(R|0)){ca();return 0}e=P+8|0;if((c[e>>2]|0)==(R|0)){c[L>>2]=P;c[e>>2]=g;an=P;break}else{ca();return 0}}}while(0);if((m|0)==0){break}P=ab+(aa+28+al)|0;U=2659680+(c[P>>2]<<2)|0;do{if((R|0)==(c[U>>2]|0)){c[U>>2]=an;if((an|0)!=0){break}c[664845]=c[664845]&~(1<<c[P>>2]);break L11980}else{if(m>>>0<(c[664848]|0)>>>0){ca();return 0}Q=m+16|0;if((c[Q>>2]|0)==(R|0)){c[Q>>2]=an}else{c[m+20>>2]=an}if((an|0)==0){break L11980}}}while(0);if(an>>>0<(c[664848]|0)>>>0){ca();return 0}c[an+24>>2]=m;R=al|16;P=c[ab+(R+aa)>>2]|0;do{if((P|0)!=0){if(P>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[an+16>>2]=P;c[P+24>>2]=an;break}}}while(0);P=c[ab+(J+R)>>2]|0;if((P|0)==0){break}if(P>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[an+20>>2]=P;c[P+24>>2]=an;break}}}while(0);aq=ab+(($|al)+aa)|0;ar=$+K|0}else{aq=Z;ar=K}J=aq+4|0;c[J>>2]=c[J>>2]&-2;c[ab+(W+4)>>2]=ar|1;c[ab+(ar+W)>>2]=ar;J=ar>>>3;if(ar>>>0<256){V=J<<1;X=2659416+(V<<2)|0;P=c[664844]|0;m=1<<J;do{if((P&m|0)==0){c[664844]=P|m;as=X;at=2659416+(V+2<<2)|0}else{J=2659416+(V+2<<2)|0;U=c[J>>2]|0;if(U>>>0>=(c[664848]|0)>>>0){as=U;at=J;break}ca();return 0}}while(0);c[at>>2]=_;c[as+12>>2]=_;c[ab+(W+8)>>2]=as;c[ab+(W+12)>>2]=X;break}V=ac;m=ar>>>8;do{if((m|0)==0){au=0}else{if(ar>>>0>16777215){au=31;break}P=(m+1048320|0)>>>16&8;$=m<<P;J=($+520192|0)>>>16&4;U=$<<J;$=(U+245760|0)>>>16&2;Q=14-(J|P|$)+(U<<$>>>15)|0;au=ar>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=2659680+(au<<2)|0;c[ab+(W+28)>>2]=au;c[ab+(W+20)>>2]=0;c[ab+(W+16)>>2]=0;X=c[664845]|0;Q=1<<au;if((X&Q|0)==0){c[664845]=X|Q;c[m>>2]=V;c[ab+(W+24)>>2]=m;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}if((au|0)==31){av=0}else{av=25-(au>>>1)|0}Q=ar<<av;X=c[m>>2]|0;while(1){if((c[X+4>>2]&-8|0)==(ar|0)){break}aw=X+16+(Q>>>31<<2)|0;m=c[aw>>2]|0;if((m|0)==0){T=9036;break}else{Q=Q<<1;X=m}}if((T|0)==9036){if(aw>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[aw>>2]=V;c[ab+(W+24)>>2]=X;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}}Q=X+8|0;m=c[Q>>2]|0;$=c[664848]|0;if(X>>>0<$>>>0){ca();return 0}if(m>>>0<$>>>0){ca();return 0}else{c[m+12>>2]=V;c[Q>>2]=V;c[ab+(W+8)>>2]=m;c[ab+(W+12)>>2]=X;c[ab+(W+24)>>2]=0;break}}}while(0);n=ab+(ak|8)|0;return n|0}}while(0);Y=ad;W=2659824;while(1){ax=c[W>>2]|0;if(ax>>>0<=Y>>>0){ay=c[W+4>>2]|0;az=ax+ay|0;if(az>>>0>Y>>>0){break}}W=c[W+8>>2]|0}W=ax+(ay-39)|0;if((W&7|0)==0){aA=0}else{aA=-W&7}W=ax+(ay-47+aA)|0;ac=W>>>0<(ad+16|0)>>>0?Y:W;W=ac+8|0;_=ab+8|0;if((_&7|0)==0){aB=0}else{aB=-_&7}_=aa-40-aB|0;c[664850]=ab+aB;c[664847]=_;c[ab+(aB+4)>>2]=_|1;c[ab+(aa-36)>>2]=40;c[664851]=c[169388];c[ac+4>>2]=27;c[W>>2]=c[664956];c[W+4>>2]=c[2659828>>2];c[W+8>>2]=c[2659832>>2];c[W+12>>2]=c[2659836>>2];c[664956]=ab;c[664957]=aa;c[664959]=0;c[664958]=W;W=ac+28|0;c[W>>2]=7;if((ac+32|0)>>>0<az>>>0){_=W;while(1){W=_+4|0;c[W>>2]=7;if((_+8|0)>>>0<az>>>0){_=W}else{break}}}if((ac|0)==(Y|0)){break}_=ac-ad|0;W=Y+(_+4)|0;c[W>>2]=c[W>>2]&-2;c[ad+4>>2]=_|1;c[Y+_>>2]=_;W=_>>>3;if(_>>>0<256){K=W<<1;Z=2659416+(K<<2)|0;S=c[664844]|0;m=1<<W;do{if((S&m|0)==0){c[664844]=S|m;aC=Z;aD=2659416+(K+2<<2)|0}else{W=2659416+(K+2<<2)|0;Q=c[W>>2]|0;if(Q>>>0>=(c[664848]|0)>>>0){aC=Q;aD=W;break}ca();return 0}}while(0);c[aD>>2]=ad;c[aC+12>>2]=ad;c[ad+8>>2]=aC;c[ad+12>>2]=Z;break}K=ad;m=_>>>8;do{if((m|0)==0){aE=0}else{if(_>>>0>16777215){aE=31;break}S=(m+1048320|0)>>>16&8;Y=m<<S;ac=(Y+520192|0)>>>16&4;W=Y<<ac;Y=(W+245760|0)>>>16&2;Q=14-(ac|S|Y)+(W<<Y>>>15)|0;aE=_>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=2659680+(aE<<2)|0;c[ad+28>>2]=aE;c[ad+20>>2]=0;c[ad+16>>2]=0;Z=c[664845]|0;Q=1<<aE;if((Z&Q|0)==0){c[664845]=Z|Q;c[m>>2]=K;c[ad+24>>2]=m;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}if((aE|0)==31){aF=0}else{aF=25-(aE>>>1)|0}Q=_<<aF;Z=c[m>>2]|0;while(1){if((c[Z+4>>2]&-8|0)==(_|0)){break}aG=Z+16+(Q>>>31<<2)|0;m=c[aG>>2]|0;if((m|0)==0){T=9071;break}else{Q=Q<<1;Z=m}}if((T|0)==9071){if(aG>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[aG>>2]=K;c[ad+24>>2]=Z;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}}Q=Z+8|0;_=c[Q>>2]|0;m=c[664848]|0;if(Z>>>0<m>>>0){ca();return 0}if(_>>>0<m>>>0){ca();return 0}else{c[_+12>>2]=K;c[Q>>2]=K;c[ad+8>>2]=_;c[ad+12>>2]=Z;c[ad+24>>2]=0;break}}}while(0);ad=c[664847]|0;if(ad>>>0<=o>>>0){break}_=ad-o|0;c[664847]=_;ad=c[664850]|0;Q=ad;c[664850]=Q+o;c[Q+(o+4)>>2]=_|1;c[ad+4>>2]=o|3;n=ad+8|0;return n|0}}while(0);c[(d0()|0)>>2]=12;n=0;return n|0}function yy(a,b){a=a|0;b=b|0;var d=0,e=0;do{if((a|0)==0){d=0}else{e=ab(b,a)|0;if((b|a)>>>0<=65535){d=e;break}d=((e>>>0)/(a>>>0)|0|0)==(b|0)?e:-1}}while(0);b=yx(d)|0;if((b|0)==0){return b|0}if((c[b-4>>2]&3|0)==0){return b|0}yG(b|0,0,d|0);return b|0}function yz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a|0)==0){return}b=a-8|0;d=b;e=c[664848]|0;if(b>>>0<e>>>0){ca()}f=c[a-4>>2]|0;g=f&3;if((g|0)==1){ca()}h=f&-8;i=a+(h-8)|0;j=i;L22:do{if((f&1|0)==0){k=c[b>>2]|0;if((g|0)==0){return}l=-8-k|0;m=a+l|0;n=m;o=k+h|0;if(m>>>0<e>>>0){ca()}if((n|0)==(c[664849]|0)){p=a+(h-4)|0;if((c[p>>2]&3|0)!=3){q=n;r=o;break}c[664846]=o;c[p>>2]=c[p>>2]&-2;c[a+(l+4)>>2]=o|1;c[i>>2]=o;return}p=k>>>3;if(k>>>0<256){k=c[a+(l+8)>>2]|0;s=c[a+(l+12)>>2]|0;t=2659416+(p<<1<<2)|0;do{if((k|0)!=(t|0)){if(k>>>0<e>>>0){ca()}if((c[k+12>>2]|0)==(n|0)){break}ca()}}while(0);if((s|0)==(k|0)){c[664844]=c[664844]&~(1<<p);q=n;r=o;break}do{if((s|0)==(t|0)){u=s+8|0}else{if(s>>>0<e>>>0){ca()}v=s+8|0;if((c[v>>2]|0)==(n|0)){u=v;break}ca()}}while(0);c[k+12>>2]=s;c[u>>2]=k;q=n;r=o;break}t=m;p=c[a+(l+24)>>2]|0;v=c[a+(l+12)>>2]|0;do{if((v|0)==(t|0)){w=a+(l+20)|0;x=c[w>>2]|0;if((x|0)==0){y=a+(l+16)|0;z=c[y>>2]|0;if((z|0)==0){A=0;break}else{B=z;C=y}}else{B=x;C=w}while(1){w=B+20|0;x=c[w>>2]|0;if((x|0)!=0){B=x;C=w;continue}w=B+16|0;x=c[w>>2]|0;if((x|0)==0){break}else{B=x;C=w}}if(C>>>0<e>>>0){ca()}else{c[C>>2]=0;A=B;break}}else{w=c[a+(l+8)>>2]|0;if(w>>>0<e>>>0){ca()}x=w+12|0;if((c[x>>2]|0)!=(t|0)){ca()}y=v+8|0;if((c[y>>2]|0)==(t|0)){c[x>>2]=v;c[y>>2]=w;A=v;break}else{ca()}}}while(0);if((p|0)==0){q=n;r=o;break}v=a+(l+28)|0;m=2659680+(c[v>>2]<<2)|0;do{if((t|0)==(c[m>>2]|0)){c[m>>2]=A;if((A|0)!=0){break}c[664845]=c[664845]&~(1<<c[v>>2]);q=n;r=o;break L22}else{if(p>>>0<(c[664848]|0)>>>0){ca()}k=p+16|0;if((c[k>>2]|0)==(t|0)){c[k>>2]=A}else{c[p+20>>2]=A}if((A|0)==0){q=n;r=o;break L22}}}while(0);if(A>>>0<(c[664848]|0)>>>0){ca()}c[A+24>>2]=p;t=c[a+(l+16)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[664848]|0)>>>0){ca()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(l+20)>>2]|0;if((t|0)==0){q=n;r=o;break}if(t>>>0<(c[664848]|0)>>>0){ca()}else{c[A+20>>2]=t;c[t+24>>2]=A;q=n;r=o;break}}else{q=d;r=h}}while(0);d=q;if(d>>>0>=i>>>0){ca()}A=a+(h-4)|0;e=c[A>>2]|0;if((e&1|0)==0){ca()}do{if((e&2|0)==0){if((j|0)==(c[664850]|0)){B=(c[664847]|0)+r|0;c[664847]=B;c[664850]=q;c[q+4>>2]=B|1;if((q|0)!=(c[664849]|0)){return}c[664849]=0;c[664846]=0;return}if((j|0)==(c[664849]|0)){B=(c[664846]|0)+r|0;c[664846]=B;c[664849]=q;c[q+4>>2]=B|1;c[d+B>>2]=B;return}B=(e&-8)+r|0;C=e>>>3;L124:do{if(e>>>0<256){u=c[a+h>>2]|0;g=c[a+(h|4)>>2]|0;b=2659416+(C<<1<<2)|0;do{if((u|0)!=(b|0)){if(u>>>0<(c[664848]|0)>>>0){ca()}if((c[u+12>>2]|0)==(j|0)){break}ca()}}while(0);if((g|0)==(u|0)){c[664844]=c[664844]&~(1<<C);break}do{if((g|0)==(b|0)){D=g+8|0}else{if(g>>>0<(c[664848]|0)>>>0){ca()}f=g+8|0;if((c[f>>2]|0)==(j|0)){D=f;break}ca()}}while(0);c[u+12>>2]=g;c[D>>2]=u}else{b=i;f=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(b|0)){p=a+(h+12)|0;v=c[p>>2]|0;if((v|0)==0){m=a+(h+8)|0;k=c[m>>2]|0;if((k|0)==0){E=0;break}else{F=k;G=m}}else{F=v;G=p}while(1){p=F+20|0;v=c[p>>2]|0;if((v|0)!=0){F=v;G=p;continue}p=F+16|0;v=c[p>>2]|0;if((v|0)==0){break}else{F=v;G=p}}if(G>>>0<(c[664848]|0)>>>0){ca()}else{c[G>>2]=0;E=F;break}}else{p=c[a+h>>2]|0;if(p>>>0<(c[664848]|0)>>>0){ca()}v=p+12|0;if((c[v>>2]|0)!=(b|0)){ca()}m=t+8|0;if((c[m>>2]|0)==(b|0)){c[v>>2]=t;c[m>>2]=p;E=t;break}else{ca()}}}while(0);if((f|0)==0){break}t=a+(h+20)|0;u=2659680+(c[t>>2]<<2)|0;do{if((b|0)==(c[u>>2]|0)){c[u>>2]=E;if((E|0)!=0){break}c[664845]=c[664845]&~(1<<c[t>>2]);break L124}else{if(f>>>0<(c[664848]|0)>>>0){ca()}g=f+16|0;if((c[g>>2]|0)==(b|0)){c[g>>2]=E}else{c[f+20>>2]=E}if((E|0)==0){break L124}}}while(0);if(E>>>0<(c[664848]|0)>>>0){ca()}c[E+24>>2]=f;b=c[a+(h+8)>>2]|0;do{if((b|0)!=0){if(b>>>0<(c[664848]|0)>>>0){ca()}else{c[E+16>>2]=b;c[b+24>>2]=E;break}}}while(0);b=c[a+(h+12)>>2]|0;if((b|0)==0){break}if(b>>>0<(c[664848]|0)>>>0){ca()}else{c[E+20>>2]=b;c[b+24>>2]=E;break}}}while(0);c[q+4>>2]=B|1;c[d+B>>2]=B;if((q|0)!=(c[664849]|0)){H=B;break}c[664846]=B;return}else{c[A>>2]=e&-2;c[q+4>>2]=r|1;c[d+r>>2]=r;H=r}}while(0);r=H>>>3;if(H>>>0<256){d=r<<1;e=2659416+(d<<2)|0;A=c[664844]|0;E=1<<r;do{if((A&E|0)==0){c[664844]=A|E;I=e;J=2659416+(d+2<<2)|0}else{r=2659416+(d+2<<2)|0;h=c[r>>2]|0;if(h>>>0>=(c[664848]|0)>>>0){I=h;J=r;break}ca()}}while(0);c[J>>2]=q;c[I+12>>2]=q;c[q+8>>2]=I;c[q+12>>2]=e;return}e=q;I=H>>>8;do{if((I|0)==0){K=0}else{if(H>>>0>16777215){K=31;break}J=(I+1048320|0)>>>16&8;d=I<<J;E=(d+520192|0)>>>16&4;A=d<<E;d=(A+245760|0)>>>16&2;r=14-(E|J|d)+(A<<d>>>15)|0;K=H>>>((r+7|0)>>>0)&1|r<<1}}while(0);I=2659680+(K<<2)|0;c[q+28>>2]=K;c[q+20>>2]=0;c[q+16>>2]=0;r=c[664845]|0;d=1<<K;do{if((r&d|0)==0){c[664845]=r|d;c[I>>2]=e;c[q+24>>2]=I;c[q+12>>2]=q;c[q+8>>2]=q}else{if((K|0)==31){L=0}else{L=25-(K>>>1)|0}A=H<<L;J=c[I>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(H|0)){break}M=J+16+(A>>>31<<2)|0;E=c[M>>2]|0;if((E|0)==0){N=139;break}else{A=A<<1;J=E}}if((N|0)==139){if(M>>>0<(c[664848]|0)>>>0){ca()}else{c[M>>2]=e;c[q+24>>2]=J;c[q+12>>2]=q;c[q+8>>2]=q;break}}A=J+8|0;B=c[A>>2]|0;E=c[664848]|0;if(J>>>0<E>>>0){ca()}if(B>>>0<E>>>0){ca()}else{c[B+12>>2]=e;c[A>>2]=e;c[q+8>>2]=B;c[q+12>>2]=J;c[q+24>>2]=0;break}}}while(0);q=(c[664852]|0)-1|0;c[664852]=q;if((q|0)==0){O=2659832}else{return}while(1){q=c[O>>2]|0;if((q|0)==0){break}else{O=q+8|0}}c[664852]=-1;return}function yA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==0){d=yx(b)|0;return d|0}if(b>>>0>4294967231){c[(d0()|0)>>2]=12;d=0;return d|0}if(b>>>0<11){e=16}else{e=b+11&-8}f=yB(a-8|0,e)|0;if((f|0)!=0){d=f+8|0;return d|0}f=yx(b)|0;if((f|0)==0){d=0;return d|0}e=c[a-4>>2]|0;g=(e&-8)-((e&3|0)==0?8:4)|0;e=g>>>0<b>>>0?g:b;yJ(f|0,a|0,e)|0;yz(a);d=f;return d|0}function yB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=a+4|0;e=c[d>>2]|0;f=e&-8;g=a;h=g+f|0;i=h;j=c[664848]|0;if(g>>>0<j>>>0){ca();return 0}k=e&3;if(!((k|0)!=1&g>>>0<h>>>0)){ca();return 0}l=g+(f|4)|0;m=c[l>>2]|0;if((m&1|0)==0){ca();return 0}if((k|0)==0){if(b>>>0<256){n=0;return n|0}do{if(f>>>0>=(b+4|0)>>>0){if((f-b|0)>>>0>c[169386]<<1>>>0){break}else{n=a}return n|0}}while(0);n=0;return n|0}if(f>>>0>=b>>>0){k=f-b|0;if(k>>>0<=15){n=a;return n|0}c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=k|3;c[l>>2]=c[l>>2]|1;yC(g+b|0,k);n=a;return n|0}if((i|0)==(c[664850]|0)){k=(c[664847]|0)+f|0;if(k>>>0<=b>>>0){n=0;return n|0}l=k-b|0;c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=l|1;c[664850]=g+b;c[664847]=l;n=a;return n|0}if((i|0)==(c[664849]|0)){l=(c[664846]|0)+f|0;if(l>>>0<b>>>0){n=0;return n|0}k=l-b|0;if(k>>>0>15){c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=k|1;c[g+l>>2]=k;o=g+(l+4)|0;c[o>>2]=c[o>>2]&-2;p=g+b|0;q=k}else{c[d>>2]=e&1|l|2;e=g+(l+4)|0;c[e>>2]=c[e>>2]|1;p=0;q=0}c[664846]=q;c[664849]=p;n=a;return n|0}if((m&2|0)!=0){n=0;return n|0}p=(m&-8)+f|0;if(p>>>0<b>>>0){n=0;return n|0}q=p-b|0;e=m>>>3;L311:do{if(m>>>0<256){l=c[g+(f+8)>>2]|0;k=c[g+(f+12)>>2]|0;o=2659416+(e<<1<<2)|0;do{if((l|0)!=(o|0)){if(l>>>0<j>>>0){ca();return 0}if((c[l+12>>2]|0)==(i|0)){break}ca();return 0}}while(0);if((k|0)==(l|0)){c[664844]=c[664844]&~(1<<e);break}do{if((k|0)==(o|0)){r=k+8|0}else{if(k>>>0<j>>>0){ca();return 0}s=k+8|0;if((c[s>>2]|0)==(i|0)){r=s;break}ca();return 0}}while(0);c[l+12>>2]=k;c[r>>2]=l}else{o=h;s=c[g+(f+24)>>2]|0;t=c[g+(f+12)>>2]|0;do{if((t|0)==(o|0)){u=g+(f+20)|0;v=c[u>>2]|0;if((v|0)==0){w=g+(f+16)|0;x=c[w>>2]|0;if((x|0)==0){y=0;break}else{z=x;A=w}}else{z=v;A=u}while(1){u=z+20|0;v=c[u>>2]|0;if((v|0)!=0){z=v;A=u;continue}u=z+16|0;v=c[u>>2]|0;if((v|0)==0){break}else{z=v;A=u}}if(A>>>0<j>>>0){ca();return 0}else{c[A>>2]=0;y=z;break}}else{u=c[g+(f+8)>>2]|0;if(u>>>0<j>>>0){ca();return 0}v=u+12|0;if((c[v>>2]|0)!=(o|0)){ca();return 0}w=t+8|0;if((c[w>>2]|0)==(o|0)){c[v>>2]=t;c[w>>2]=u;y=t;break}else{ca();return 0}}}while(0);if((s|0)==0){break}t=g+(f+28)|0;l=2659680+(c[t>>2]<<2)|0;do{if((o|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[664845]=c[664845]&~(1<<c[t>>2]);break L311}else{if(s>>>0<(c[664848]|0)>>>0){ca();return 0}k=s+16|0;if((c[k>>2]|0)==(o|0)){c[k>>2]=y}else{c[s+20>>2]=y}if((y|0)==0){break L311}}}while(0);if(y>>>0<(c[664848]|0)>>>0){ca();return 0}c[y+24>>2]=s;o=c[g+(f+16)>>2]|0;do{if((o|0)!=0){if(o>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[y+16>>2]=o;c[o+24>>2]=y;break}}}while(0);o=c[g+(f+20)>>2]|0;if((o|0)==0){break}if(o>>>0<(c[664848]|0)>>>0){ca();return 0}else{c[y+20>>2]=o;c[o+24>>2]=y;break}}}while(0);if(q>>>0<16){c[d>>2]=p|c[d>>2]&1|2;y=g+(p|4)|0;c[y>>2]=c[y>>2]|1;n=a;return n|0}else{c[d>>2]=c[d>>2]&1|b|2;c[g+(b+4)>>2]=q|3;d=g+(p|4)|0;c[d>>2]=c[d>>2]|1;yC(g+b|0,q);n=a;return n|0}return 0}function yC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=a;e=d+b|0;f=e;g=c[a+4>>2]|0;L387:do{if((g&1|0)==0){h=c[a>>2]|0;if((g&3|0)==0){return}i=d+(-h|0)|0;j=i;k=h+b|0;l=c[664848]|0;if(i>>>0<l>>>0){ca()}if((j|0)==(c[664849]|0)){m=d+(b+4)|0;if((c[m>>2]&3|0)!=3){n=j;o=k;break}c[664846]=k;c[m>>2]=c[m>>2]&-2;c[d+(4-h)>>2]=k|1;c[e>>2]=k;return}m=h>>>3;if(h>>>0<256){p=c[d+(8-h)>>2]|0;q=c[d+(12-h)>>2]|0;r=2659416+(m<<1<<2)|0;do{if((p|0)!=(r|0)){if(p>>>0<l>>>0){ca()}if((c[p+12>>2]|0)==(j|0)){break}ca()}}while(0);if((q|0)==(p|0)){c[664844]=c[664844]&~(1<<m);n=j;o=k;break}do{if((q|0)==(r|0)){s=q+8|0}else{if(q>>>0<l>>>0){ca()}t=q+8|0;if((c[t>>2]|0)==(j|0)){s=t;break}ca()}}while(0);c[p+12>>2]=q;c[s>>2]=p;n=j;o=k;break}r=i;m=c[d+(24-h)>>2]|0;t=c[d+(12-h)>>2]|0;do{if((t|0)==(r|0)){u=16-h|0;v=d+(u+4)|0;w=c[v>>2]|0;if((w|0)==0){x=d+u|0;u=c[x>>2]|0;if((u|0)==0){y=0;break}else{z=u;A=x}}else{z=w;A=v}while(1){v=z+20|0;w=c[v>>2]|0;if((w|0)!=0){z=w;A=v;continue}v=z+16|0;w=c[v>>2]|0;if((w|0)==0){break}else{z=w;A=v}}if(A>>>0<l>>>0){ca()}else{c[A>>2]=0;y=z;break}}else{v=c[d+(8-h)>>2]|0;if(v>>>0<l>>>0){ca()}w=v+12|0;if((c[w>>2]|0)!=(r|0)){ca()}x=t+8|0;if((c[x>>2]|0)==(r|0)){c[w>>2]=t;c[x>>2]=v;y=t;break}else{ca()}}}while(0);if((m|0)==0){n=j;o=k;break}t=d+(28-h)|0;l=2659680+(c[t>>2]<<2)|0;do{if((r|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[664845]=c[664845]&~(1<<c[t>>2]);n=j;o=k;break L387}else{if(m>>>0<(c[664848]|0)>>>0){ca()}i=m+16|0;if((c[i>>2]|0)==(r|0)){c[i>>2]=y}else{c[m+20>>2]=y}if((y|0)==0){n=j;o=k;break L387}}}while(0);if(y>>>0<(c[664848]|0)>>>0){ca()}c[y+24>>2]=m;r=16-h|0;t=c[d+r>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[664848]|0)>>>0){ca()}else{c[y+16>>2]=t;c[t+24>>2]=y;break}}}while(0);t=c[d+(r+4)>>2]|0;if((t|0)==0){n=j;o=k;break}if(t>>>0<(c[664848]|0)>>>0){ca()}else{c[y+20>>2]=t;c[t+24>>2]=y;n=j;o=k;break}}else{n=a;o=b}}while(0);a=c[664848]|0;if(e>>>0<a>>>0){ca()}y=d+(b+4)|0;z=c[y>>2]|0;do{if((z&2|0)==0){if((f|0)==(c[664850]|0)){A=(c[664847]|0)+o|0;c[664847]=A;c[664850]=n;c[n+4>>2]=A|1;if((n|0)!=(c[664849]|0)){return}c[664849]=0;c[664846]=0;return}if((f|0)==(c[664849]|0)){A=(c[664846]|0)+o|0;c[664846]=A;c[664849]=n;c[n+4>>2]=A|1;c[n+A>>2]=A;return}A=(z&-8)+o|0;s=z>>>3;L486:do{if(z>>>0<256){g=c[d+(b+8)>>2]|0;t=c[d+(b+12)>>2]|0;h=2659416+(s<<1<<2)|0;do{if((g|0)!=(h|0)){if(g>>>0<a>>>0){ca()}if((c[g+12>>2]|0)==(f|0)){break}ca()}}while(0);if((t|0)==(g|0)){c[664844]=c[664844]&~(1<<s);break}do{if((t|0)==(h|0)){B=t+8|0}else{if(t>>>0<a>>>0){ca()}m=t+8|0;if((c[m>>2]|0)==(f|0)){B=m;break}ca()}}while(0);c[g+12>>2]=t;c[B>>2]=g}else{h=e;m=c[d+(b+24)>>2]|0;l=c[d+(b+12)>>2]|0;do{if((l|0)==(h|0)){i=d+(b+20)|0;p=c[i>>2]|0;if((p|0)==0){q=d+(b+16)|0;v=c[q>>2]|0;if((v|0)==0){C=0;break}else{D=v;E=q}}else{D=p;E=i}while(1){i=D+20|0;p=c[i>>2]|0;if((p|0)!=0){D=p;E=i;continue}i=D+16|0;p=c[i>>2]|0;if((p|0)==0){break}else{D=p;E=i}}if(E>>>0<a>>>0){ca()}else{c[E>>2]=0;C=D;break}}else{i=c[d+(b+8)>>2]|0;if(i>>>0<a>>>0){ca()}p=i+12|0;if((c[p>>2]|0)!=(h|0)){ca()}q=l+8|0;if((c[q>>2]|0)==(h|0)){c[p>>2]=l;c[q>>2]=i;C=l;break}else{ca()}}}while(0);if((m|0)==0){break}l=d+(b+28)|0;g=2659680+(c[l>>2]<<2)|0;do{if((h|0)==(c[g>>2]|0)){c[g>>2]=C;if((C|0)!=0){break}c[664845]=c[664845]&~(1<<c[l>>2]);break L486}else{if(m>>>0<(c[664848]|0)>>>0){ca()}t=m+16|0;if((c[t>>2]|0)==(h|0)){c[t>>2]=C}else{c[m+20>>2]=C}if((C|0)==0){break L486}}}while(0);if(C>>>0<(c[664848]|0)>>>0){ca()}c[C+24>>2]=m;h=c[d+(b+16)>>2]|0;do{if((h|0)!=0){if(h>>>0<(c[664848]|0)>>>0){ca()}else{c[C+16>>2]=h;c[h+24>>2]=C;break}}}while(0);h=c[d+(b+20)>>2]|0;if((h|0)==0){break}if(h>>>0<(c[664848]|0)>>>0){ca()}else{c[C+20>>2]=h;c[h+24>>2]=C;break}}}while(0);c[n+4>>2]=A|1;c[n+A>>2]=A;if((n|0)!=(c[664849]|0)){F=A;break}c[664846]=A;return}else{c[y>>2]=z&-2;c[n+4>>2]=o|1;c[n+o>>2]=o;F=o}}while(0);o=F>>>3;if(F>>>0<256){z=o<<1;y=2659416+(z<<2)|0;C=c[664844]|0;b=1<<o;do{if((C&b|0)==0){c[664844]=C|b;G=y;H=2659416+(z+2<<2)|0}else{o=2659416+(z+2<<2)|0;d=c[o>>2]|0;if(d>>>0>=(c[664848]|0)>>>0){G=d;H=o;break}ca()}}while(0);c[H>>2]=n;c[G+12>>2]=n;c[n+8>>2]=G;c[n+12>>2]=y;return}y=n;G=F>>>8;do{if((G|0)==0){I=0}else{if(F>>>0>16777215){I=31;break}H=(G+1048320|0)>>>16&8;z=G<<H;b=(z+520192|0)>>>16&4;C=z<<b;z=(C+245760|0)>>>16&2;o=14-(b|H|z)+(C<<z>>>15)|0;I=F>>>((o+7|0)>>>0)&1|o<<1}}while(0);G=2659680+(I<<2)|0;c[n+28>>2]=I;c[n+20>>2]=0;c[n+16>>2]=0;o=c[664845]|0;z=1<<I;if((o&z|0)==0){c[664845]=o|z;c[G>>2]=y;c[n+24>>2]=G;c[n+12>>2]=n;c[n+8>>2]=n;return}if((I|0)==31){J=0}else{J=25-(I>>>1)|0}I=F<<J;J=c[G>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(F|0)){break}K=J+16+(I>>>31<<2)|0;G=c[K>>2]|0;if((G|0)==0){L=419;break}else{I=I<<1;J=G}}if((L|0)==419){if(K>>>0<(c[664848]|0)>>>0){ca()}c[K>>2]=y;c[n+24>>2]=J;c[n+12>>2]=n;c[n+8>>2]=n;return}K=J+8|0;L=c[K>>2]|0;I=c[664848]|0;if(J>>>0<I>>>0){ca()}if(L>>>0<I>>>0){ca()}c[L+12>>2]=y;c[K>>2]=y;c[n+8>>2]=L;c[n+12>>2]=J;c[n+24>>2]=0;return}function yD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0,P=0,Q=0.0,R=0.0,S=0.0;e=b;while(1){f=e+1|0;if((bf(a[e]|0)|0)==0){break}else{e=f}}g=a[e]|0;if((g<<24>>24|0)==45){i=f;j=1}else if((g<<24>>24|0)==43){i=f;j=0}else{i=e;j=0}e=-1;f=0;g=i;while(1){k=a[g]|0;if(((k<<24>>24)-48|0)>>>0<10){l=e}else{if(k<<24>>24!=46|(e|0)>-1){break}else{l=f}}e=l;f=f+1|0;g=g+1|0}l=g+(-f|0)|0;i=(e|0)<0;m=((i^1)<<31>>31)+f|0;n=(m|0)>18;o=(n?-18:-m|0)+(i?f:e)|0;e=n?18:m;do{if((e|0)==0){p=b;q=0.0}else{if((e|0)>9){m=l;n=e;f=0;while(1){i=a[m]|0;r=m+1|0;if(i<<24>>24==46){s=a[r]|0;t=m+2|0}else{s=i;t=r}u=(f*10|0)-48+(s<<24>>24)|0;r=n-1|0;if((r|0)>9){m=t;n=r;f=u}else{break}}v=+(u|0)*1.0e9;w=9;x=t;y=467}else{if((e|0)>0){v=0.0;w=e;x=l;y=467}else{z=0.0;A=0.0}}if((y|0)==467){f=x;n=w;m=0;while(1){r=a[f]|0;i=f+1|0;if(r<<24>>24==46){B=a[i]|0;C=f+2|0}else{B=r;C=i}D=(m*10|0)-48+(B<<24>>24)|0;i=n-1|0;if((i|0)>0){f=C;n=i;m=D}else{break}}z=+(D|0);A=v}E=A+z;do{if((k<<24>>24|0)==69|(k<<24>>24|0)==101){m=g+1|0;n=a[m]|0;if((n<<24>>24|0)==45){F=g+2|0;G=1}else if((n<<24>>24|0)==43){F=g+2|0;G=0}else{F=m;G=0}m=a[F]|0;if(((m<<24>>24)-48|0)>>>0<10){H=F;I=0;J=m}else{K=0;L=F;M=G;break}while(1){m=(I*10|0)-48+(J<<24>>24)|0;n=H+1|0;f=a[n]|0;if(((f<<24>>24)-48|0)>>>0<10){H=n;I=m;J=f}else{K=m;L=n;M=G;break}}}else{K=0;L=g;M=0}}while(0);n=o+((M|0)==0?K:-K|0)|0;m=(n|0)<0?-n|0:n;if((m|0)>511){c[(d0()|0)>>2]=34;N=1.0;O=14312;P=511;y=484}else{if((m|0)==0){Q=1.0}else{N=1.0;O=14312;P=m;y=484}}if((y|0)==484){while(1){y=0;if((P&1|0)==0){R=N}else{R=N*+h[O>>3]}m=P>>1;if((m|0)==0){Q=R;break}else{N=R;O=O+8|0;P=m;y=484}}}if((n|0)>-1){p=L;q=E*Q;break}else{p=L;q=E/Q;break}}}while(0);if((d|0)!=0){c[d>>2]=p}if((j|0)==0){S=q;return+S}S=-0.0-q;return+S}function yE(a){a=a|0;return+(+yD(a,0))}function yF(b){b=b|0;var c=0;c=b;while(a[c]|0){c=c+1|0}return c-b|0}function yG(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=b+e|0;if((e|0)>=20){d=d&255;e=b&3;g=d|d<<8|d<<16|d<<24;h=f&~3;if(e){e=b+4-e|0;while((b|0)<(e|0)){a[b]=d;b=b+1|0}}while((b|0)<(h|0)){c[b>>2]=g;b=b+4|0}}while((b|0)<(f|0)){a[b]=d;b=b+1|0}}function yH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;u=u+1|0;c[a>>2]=u;while((e|0)<40){if((c[d+(e<<2)>>2]|0)==0){c[d+(e<<2)>>2]=u;c[d+((e<<2)+4)>>2]=b;c[d+((e<<2)+8)>>2]=0;return 0}e=e+2|0}cN(116);cN(111);cN(111);cN(32);cN(109);cN(97);cN(110);cN(121);cN(32);cN(115);cN(101);cN(116);cN(106);cN(109);cN(112);cN(115);cN(32);cN(105);cN(110);cN(32);cN(97);cN(32);cN(102);cN(117);cN(110);cN(99);cN(116);cN(105);cN(111);cN(110);cN(32);cN(99);cN(97);cN(108);cN(108);cN(44);cN(32);cN(98);cN(117);cN(105);cN(108);cN(100);cN(32);cN(119);cN(105);cN(116);cN(104);cN(32);cN(97);cN(32);cN(104);cN(105);cN(103);cN(104);cN(101);cN(114);cN(32);cN(118);cN(97);cN(108);cN(117);cN(101);cN(32);cN(102);cN(111);cN(114);cN(32);cN(77);cN(65);cN(88);cN(95);cN(83);cN(69);cN(84);cN(74);cN(77);cN(80);cN(83);cN(10);ac(0);return 0}function yI(a,b){a=a|0;b=b|0;var d=0,e=0;while((d|0)<20){e=c[b+(d<<2)>>2]|0;if((e|0)==0)break;if((e|0)==(a|0)){return c[b+((d<<2)+4)>>2]|0}d=d+2|0}return 0}function yJ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function yK(a){a=a|0;if((a|0)<65)return a|0;if((a|0)>90)return a|0;return a-65+97|0}function yL(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;while(e>>>0<d>>>0){f=yK(a[b+e|0]|0)|0;g=yK(a[c+e|0]|0)|0;if((f|0)==(g|0)&(f|0)==0)return 0;if((f|0)==0)return-1;if((g|0)==0)return 1;if((f|0)==(g|0)){e=e+1|0;continue}else{return(f>>>0>g>>>0?1:-1)|0}}return 0}function yM(a,b){a=a|0;b=b|0;return yL(a,b,-1)|0}function yN(b,c,d){b=b|0;c=c|0;d=d|0;if((c|0)<(b|0)&(b|0)<(c+d|0)){c=c+d|0;b=b+d|0;while((d|0)>0){b=b-1|0;c=c-1|0;d=d-1|0;a[b]=a[c]|0}}else{yJ(b,c,d)|0}}function yO(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0;while((e|0)<(c|0)){f=d[a+e|0]|0;g=d[b+e|0]|0;if((f|0)!=(g|0))return((f|0)>(g|0)?1:-1)|0;e=e+1|0}return 0}function yP(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;while((e|0)<(d|0)){a[b+e|0]=f?0:a[c+e|0]|0;f=f?1:(a[c+e|0]|0)==0;e=e+1|0}return b|0}function yQ(b,c){b=b|0;c=c|0;var d=0;do{a[b+d|0]=a[c+d|0];d=d+1|0}while(a[c+(d-1)|0]|0);return b|0}function yR(b,c){b=b|0;c=c|0;var d=0,e=0;d=b+(yF(b)|0)|0;do{a[d+e|0]=a[c+e|0];e=e+1|0}while(a[c+(e-1)|0]|0);return b|0}function yS(b){b=b|0;var c=0;c=a[m+(b&255)|0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)|0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)|0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)|0]|0)+24|0}function yT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(F=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function yU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(F=e,a-c>>>0|0)|0}function yV(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}F=a<<c-32;return 0}function yW(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}F=0;return b>>>c-32|0}function yX(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}F=(b|0)<0?-1:0;return b>>c-32|0}function yY(b){b=b|0;var c=0;c=a[n+(b>>>24)|0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)|0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)|0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)|0]|0)+24|0}function yZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ab(d,c)|0;f=a>>>16;a=(e>>>16)+(ab(d,f)|0)|0;d=b>>>16;b=ab(d,c)|0;return(F=(a>>>16)+(ab(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function y_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=yU(e^a,f^b,e,f)|0;b=F;a=g^e;e=h^f;f=yU((y3(i,b,yU(g^c,h^d,g,h)|0,F,0)|0)^a,F^e,a,e)|0;return(F=F,f)|0}function y$(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=yU(h^a,j^b,h,j)|0;b=F;a=yU(k^d,l^e,k,l)|0;y3(m,b,a,F,g)|0;a=yU(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=F;i=f;return(F=j,a)|0}function y0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=yZ(e,a)|0;f=F;return(F=(ab(b,a)|0)+(ab(d,e)|0)+f|f&0,c|0|0)|0}function y1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=y3(a,b,c,d,0)|0;return(F=F,e)|0}function y2(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;y3(a,b,d,e,g)|0;i=f;return(F=c[g+4>>2]|0,c[g>>2]|0)|0}function y3(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(F=n,o)|0}else{if(!m){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(F=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(F=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(F=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((yS(l|0)|0)>>>0);return(F=n,o)|0}p=(yY(l|0)|0)-(yY(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(F=n,o)|0}else{if(!m){r=(yY(l|0)|0)-(yY(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(F=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(yY(j|0)|0)+33-(yY(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(F=n,o)|0}else{p=yS(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(F=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;G=0;H=0}else{g=d|0|0;d=k|e&0;e=yT(g,d,-1,-1)|0;k=F;i=w;w=v;v=u;u=t;t=s;s=0;while(1){I=w>>>31|i<<1;J=s|w<<1;j=u<<1|i>>>31|0;a=u>>>31|v<<1|0;yU(e,k,j,a)|0;b=F;h=b>>31|((b|0)<0?-1:0)<<1;K=h&1;L=yU(j,a,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;M=F;b=t-1|0;if((b|0)==0){break}else{i=I;w=J;v=M;u=L;t=b;s=K}}B=I;C=J;D=M;E=L;G=0;H=K}K=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(K|0)>>>31|(B|C)<<1|(C<<1|K>>>31)&0|G;o=(K<<1|0>>>31)&-2|H;return(F=n,o)|0}function y4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;eJ(a|0,b|0,c|0,d|0,e|0)}function y5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dB(a|0,b|0,c|0,d|0,e|0)}function y6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dm(a|0,b|0,c|0,d|0,e|0)}function y7(a,b){a=a|0;b=+b;bE(a|0,+b)}function y8(a){a=a|0;bs(a|0)}function y9(a){a=a|0;c7(a|0)}function za(a){a=a|0;c6(a|0)}function zb(a){a=a|0;fc(a|0)}function zc(a){a=a|0;cP(a|0)}function zd(a){a=a|0;du(a|0)}function ze(a){a=a|0;bQ(a|0)}function zf(a){a=a|0;e2(a|0)}function zg(a){a=a|0;ex(a|0)}function zh(a){a=a|0;ec(a|0)}function zi(a){a=a|0;cV(a|0)}function zj(a){a=a|0;fb(a|0)}function zk(a){a=a|0;dk(a|0)}function zl(a){a=a|0;cj(a|0)}function zm(a){a=a|0;cR(a|0)}function zn(a){a=a|0;fn(a|0)}function zo(a){a=a|0;bp(a|0)}function zp(a){a=a|0;bx(a|0)}function zq(a){a=a|0;dp(a|0)}function zr(a){a=a|0;a9(a|0)}function zs(a){a=a|0;bA(a|0)}function zt(a){a=a|0;ck(a|0)}function zu(a){a=a|0;be(a|0)}function zv(a){a=a|0;bn(a|0)}function zw(a){a=a|0;eg(a|0)}function zx(a,b){a=a|0;b=b|0;bJ(a|0,b|0)}function zy(a,b){a=a|0;b=b|0;co(a|0,b|0)}function zz(a,b){a=a|0;b=b|0;c5(a|0,b|0)}function zA(a,b){a=a|0;b=b|0;fe(a|0,b|0)}function zB(a,b){a=a|0;b=b|0;cA(a|0,b|0)}function zC(a,b){a=a|0;b=b|0;cT(a|0,b|0)}function zD(a,b){a=a|0;b=b|0;b$(a|0,b|0)}function zE(a,b){a=a|0;b=b|0;fo(a|0,b|0)}function zF(a,b){a=a|0;b=b|0;eG(a|0,b|0)}function zG(a,b){a=a|0;b=b|0;bZ(a|0,b|0)}function zH(a,b){a=a|0;b=b|0;bz(a|0,b|0)}function zI(a,b){a=a|0;b=b|0;d1(a|0,b|0)}function zJ(a,b){a=a|0;b=b|0;b5(a|0,b|0)}function zK(a,b){a=a|0;b=b|0;dX(a|0,b|0)}function zL(a,b){a=a|0;b=b|0;cc(a|0,b|0)}function zM(a,b){a=a|0;b=b|0;aZ(a|0,b|0)}function zN(a,b){a=a|0;b=b|0;dT(a|0,b|0)}function zO(a,b){a=a|0;b=b|0;cK(a|0,b|0)}function zP(a,b){a=a|0;b=b|0;fd(a|0,b|0)}function zQ(a,b){a=a|0;b=b|0;eM(a|0,b|0)}function zR(a,b){a=a|0;b=b|0;eI(a|0,b|0)}function zS(a,b){a=a|0;b=b|0;fj(a|0,b|0)}function zT(a,b){a=a|0;b=b|0;ea(a|0,b|0)}function zU(a,b){a=a|0;b=b|0;da(a|0,b|0)}function zV(a,b){a=a|0;b=b|0;bh(a|0,b|0)}function zW(a,b){a=a|0;b=b|0;bP(a|0,b|0)}function zX(a,b){a=a|0;b=b|0;cX(a|0,b|0)}function zY(a,b){a=a|0;b=b|0;dz(a|0,b|0)}function zZ(a,b){a=a|0;b=b|0;bM(a|0,b|0)}function z_(a,b){a=a|0;b=b|0;dS(a|0,b|0)}function z$(a,b){a=a|0;b=b|0;c0(a|0,b|0)}function z0(a,b){a=a|0;b=b|0;fl(a|0,b|0)}function z1(a){a=a|0;return dl(a|0)|0}function z2(a){a=a|0;return cN(a|0)|0}function z3(a){a=a|0;return cs(a|0)|0}function z4(a){a=a|0;return a_(a|0)|0}function z5(a){a=a|0;return b6(a|0)|0}function z6(a){a=a|0;return bK(a|0)|0}function z7(a){a=a|0;return cf(a|0)|0}function z8(a){a=a|0;return bv(a|0)|0}function z9(a){a=a|0;return a3(a|0)|0}function Aa(a){a=a|0;return dK(a|0)|0}function Ab(a){a=a|0;return el(a|0)|0}function Ac(a){a=a|0;return cr(a|0)|0}function Ad(a){a=a|0;return d4(a|0)|0}function Ae(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;dA(a|0,+b,+c,+d,+e)}function Af(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return a5(a|0,b|0,c|0,d|0)|0}function Ag(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return bR(a|0,b|0,c|0,d|0)|0}function Ah(a,b,c){a=a|0;b=b|0;c=c|0;return aX(a|0,b|0,c|0)|0}function Ai(a,b,c){a=a|0;b=b|0;c=c|0;return bN(a|0,b|0,c|0)|0}function Aj(a,b,c){a=a|0;b=b|0;c=c|0;return en(a|0,b|0,c|0)|0}function Ak(a,b,c){a=a|0;b=b|0;c=c|0;return a1(a|0,b|0,c|0)|0}function Al(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;bY(a|0,b|0,c|0,d|0,e|0,f|0)}function Am(a){a=+a;return+bL(+a)}function An(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;bC(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function Ao(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ef(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function Ap(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ed(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function Aq(a,b){a=a|0;b=b|0;return cS(a|0,b|0)|0}function Ar(a,b){a=a|0;b=b|0;return dJ(a|0,b|0)|0}function As(a,b){a=a|0;b=b|0;return c9(a|0,b|0)|0}function At(){return dN()|0}function Au(){return eN()|0}function Av(){return aQ()|0}function Aw(a,b,c){a=a|0;b=b|0;c=c|0;dQ(a|0,b|0,c|0)}function Ax(a,b,c){a=a|0;b=b|0;c=c|0;bS(a|0,b|0,c|0)}function Ay(a,b,c){a=a|0;b=b|0;c=c|0;br(a|0,b|0,c|0)}function Az(a,b,c){a=a|0;b=b|0;c=c|0;de(a|0,b|0,c|0)}function AA(a,b,c){a=a|0;b=b|0;c=c|0;aU(a|0,b|0,c|0)}function AB(a,b,c){a=a|0;b=b|0;c=c|0;cO(a|0,b|0,c|0)}function AC(a,b,c){a=a|0;b=b|0;c=c|0;dV(a|0,b|0,c|0)}function AD(a,b,c){a=a|0;b=b|0;c=c|0;bu(a|0,b|0,c|0)}function AE(a,b,c){a=a|0;b=b|0;c=c|0;cL(a|0,b|0,c|0)}function AF(a,b,c){a=a|0;b=b|0;c=c|0;a$(a|0,b|0,c|0)}function AG(a,b,c){a=a|0;b=b|0;c=c|0;dR(a|0,b|0,c|0)}function AH(a,b,c){a=a|0;b=b|0;c=c|0;cY(a|0,b|0,c|0)}function AI(a,b,c){a=a|0;b=b|0;c=c|0;b9(a|0,b|0,c|0)}function AJ(a,b,c){a=a|0;b=b|0;c=c|0;eV(a|0,b|0,c|0)}function AK(a,b,c){a=a|0;b=b|0;c=c|0;bd(a|0,b|0,c|0)}function AL(a,b,c){a=a|0;b=b|0;c=c|0;bq(a|0,b|0,c|0)}function AM(a,b,c){a=a|0;b=b|0;c=c|0;bU(a|0,b|0,c|0)}function AN(a,b,c){a=a|0;b=b|0;c=c|0;ba(a|0,b|0,c|0)}function AO(a,b,c){a=a|0;b=b|0;c=c|0;ce(a|0,b|0,c|0)}function AP(a,b,c){a=a|0;b=b|0;c=c|0;dP(a|0,b|0,c|0)}function AQ(a,b,c){a=a|0;b=b|0;c=c|0;eE(a|0,b|0,c|0)}function AR(a,b,c){a=a|0;b=b|0;c=c|0;eZ(a|0,b|0,c|0)}function AS(a,b,c){a=a|0;b=b|0;c=c|0;aV(a|0,b|0,c|0)}function AT(a,b,c){a=a|0;b=b|0;c=c|0;fa(a|0,b|0,c|0)}function AU(a,b,c){a=a|0;b=b|0;c=c|0;e8(a|0,b|0,c|0)}function AV(a,b,c){a=a|0;b=b|0;c=c|0;dx(a|0,b|0,c|0)}function AW(a,b,c){a=a|0;b=b|0;c=c|0;bH(a|0,b|0,c|0)}function AX(a,b,c){a=a|0;b=b|0;c=c|0;cy(a|0,b|0,c|0)}function AY(a,b,c){a=a|0;b=b|0;c=c|0;dw(a|0,b|0,c|0)}function AZ(){eH()}function A_(){cz()}function A$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dC(a|0,b|0,c|0,d|0)}function A0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;e1(a|0,b|0,c|0,d|0)}function A1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dY(a|0,b|0,c|0,d|0)}function A2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;aO(a|0,b|0,c|0,d|0)}function A3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dF(a|0,b|0,c|0,d|0)}function A4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cD(a|0,b|0,c|0,d|0)}function A5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dU(a|0,b|0,c|0,d|0)}function A6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ei(a|0,b|0,c|0,d|0)}function A7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cq(a|0,b|0,c|0,d|0)}function A8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ey(a|0,b|0,c|0,d|0)}function A9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ew(a|0,b|0,c|0,d|0)}function Ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bk(a|0,b|0,c|0,d|0)}function Bb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eS(a|0,b|0,c|0,d|0)}function Bc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bW(a|0,b|0,c|0,d|0)}function Bd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eb(a|0,b|0,c|0,d|0)}function Be(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dH(a|0,b|0,c|0,d|0)}function Bf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b4(a|0,b|0,c|0,d|0)}function Bg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cE(a|0,b|0,c|0,d|0)}function Bh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dI(a|0,b|0,c|0,d|0)}function Bi(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ek(a|0,b|0,c|0,d|0)}function Bj(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cm(a|0,b|0,c|0,d|0)}function Bk(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c$(a|0,b|0,c|0,d|0)}function Bl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ee(a|0,b|0,c|0,d|0)}function Bm(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eo(a|0,b|0,c|0,d|0)}function Bn(a,b,c){a=a|0;b=+b;c=+c;dr(a|0,+b,+c)}function Bo(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;bj(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function Bp(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;di(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function Bq(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;cC(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function Br(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;cx(a|0,+b,+c,+d)}function Bs(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eB(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function Bt(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;e3(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function Bu(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;dW(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function Bv(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return fp[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0)|0}function Bw(a,b,c){a=a|0;b=b|0;c=+c;fq[a&7](b|0,+c)}function Bx(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;fr[a&15](b|0,c|0,d|0,e|0,f|0)}function By(a,b){a=a|0;b=b|0;fs[a&255](b|0)}function Bz(a,b,c){a=a|0;b=b|0;c=c|0;ft[a&127](b|0,c|0)}function BA(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return fu[a&15](b|0,c|0,d|0,e|0,f|0,g|0)|0}function BB(a,b){a=a|0;b=b|0;return fv[a&127](b|0)|0}function BC(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;fw[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0)}function BD(a,b,c,d,e,f){a=a|0;b=b|0;c=+c;d=+d;e=+e;f=+f;fx[a&7](b|0,+c,+d,+e,+f)}function BE(a,b){a=a|0;b=+b;return fy[a&3](+b)|0}function BF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return fz[a&3](b|0,c|0,d|0,e|0,f|0)|0}function BG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return fA[a&63](b|0,c|0,d|0)|0}function BH(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;fB[a&3](b|0,c|0,d|0,e|0,f|0,+g)}function BI(a,b,c,d){a=a|0;b=b|0;c=+c;d=+d;fC[a&3](b|0,+c,+d)}function BJ(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=+d;e=+e;fD[a&3](b|0,+c,+d,+e)}function BK(a,b,c){a=a|0;b=b|0;c=c|0;return+fE[a&3](b|0,c|0)}function BL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;return fF[a&3](b|0,c|0,+d)|0}function BM(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;fG[a&7](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function BN(a,b,c){a=a|0;b=b|0;c=+c;return fH[a&3](b|0,+c)|0}function BO(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;fI[a&7](b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function BP(a,b){a=a|0;b=+b;return+fJ[a&3](+b)}function BQ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;fK[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0)}function BR(a,b,c){a=a|0;b=b|0;c=c|0;return fL[a&63](b|0,c|0)|0}function BS(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;fM[a&31](b|0,c|0,d|0,e|0,f|0,g|0)}function BT(a){a=a|0;return fN[a&63]()|0}function BU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fO[a&15](b|0,c|0,d|0,e|0)|0}function BV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fP[a&127](b|0,c|0,d|0)}function BW(a){a=a|0;fQ[a&1023]()}function BX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;fR[a&63](b|0,c|0,d|0,e|0)}function BY(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ac(0);return 0}function BZ(a,b){a=a|0;b=+b;ac(1)}function B_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ac(2)}function B$(a){a=a|0;ac(3)}function B0(a,b){a=a|0;b=b|0;ac(4)}function B1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ac(5);return 0}function B2(a){a=a|0;ac(6);return 0}function B3(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;ac(7)}function B4(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;ac(8)}function B5(a){a=+a;ac(9);return 0}function B6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ac(10);return 0}function B7(a,b,c){a=a|0;b=b|0;c=c|0;ac(11);return 0}function B8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;ac(12)}function B9(a,b,c){a=a|0;b=+b;c=+c;ac(13)}function Ca(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;ac(14)}function Cb(a,b){a=a|0;b=b|0;ac(15);return 0.0}function Cc(a,b,c){a=a|0;b=b|0;c=+c;ac(16);return 0}function Cd(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ac(17)}function Ce(a,b){a=a|0;b=+b;ac(18);return 0}function Cf(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ac(19)}function Cg(a){a=+a;ac(20);return 0.0}function Ch(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ac(21)}function Ci(a,b){a=a|0;b=b|0;ac(22);return 0}function Cj(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ac(23)}function Ck(){ac(24);return 0}function Cl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ac(25);return 0}function Cm(a,b,c){a=a|0;b=b|0;c=c|0;ac(26)}function Cn(){ac(27)}function Co(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ac(28)}
// EMSCRIPTEN_END_FUNCS
var fp=[BY,BY,lE,BY];var fq=[BZ,BZ,lo,BZ,y7,BZ,BZ,BZ];var fr=[B_,B_,y4,B_,lS,B_,t_,B_,y5,B_,y6,B_,B_,B_,B_,B_];var fs=[B$,B$,y8,B$,y9,B$,gZ,B$,iT,B$,l0,B$,za,B$,h7,B$,gK,B$,id,B$,gu,B$,zb,B$,rz,B$,jv,B$,zc,B$,zd,B$,xW,B$,kr,B$,hY,B$,ze,B$,zf,B$,zg,B$,wP,B$,zh,B$,lA,B$,zi,B$,wM,B$,kj,B$,rJ,B$,hX,B$,hZ,B$,ly,B$,zj,B$,w$,B$,wN,B$,wS,B$,zk,B$,zl,B$,zm,B$,k5,B$,hU,B$,xH,B$,h$,B$,zn,B$,iQ,B$,lb,B$,zo,B$,zp,B$,wQ,B$,zq,B$,rP,B$,ip,B$,mX,B$,rV,B$,zr,B$,ic,B$,km,B$,zs,B$,kd,B$,zt,B$,wO,B$,h_,B$,zu,B$,zv,B$,w_,B$,ow,B$,zw,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$,B$];var ft=[B0,B0,lB,B0,hW,B0,ln,B0,le,B0,iA,B0,p2,B0,wL,B0,zx,B0,zy,B0,yg,B0,lT,B0,zz,B0,zA,B0,zB,B0,zC,B0,zD,B0,zE,B0,lH,B0,zF,B0,k7,B0,oW,B0,zG,B0,w1,B0,zH,B0,zI,B0,zJ,B0,zK,B0,zL,B0,ov,B0,lp,B0,zM,B0,zN,B0,zO,B0,zP,B0,gF,B0,wD,B0,zQ,B0,zR,B0,l1,B0,ju,B0,zS,B0,zT,B0,zU,B0,zV,B0,k3,B0,kc,B0,gB,B0,lf,B0,zW,B0,zX,B0,lq,B0,li,B0,zY,B0,ki,B0,zZ,B0,z_,B0,k2,B0,z$,B0,z0,B0,kl,B0,gO,B0,B0,B0,B0,B0];var fu=[B1,B1,iR,B1,i3,B1,i2,B1,i4,B1,k1,B1,B1,B1,B1,B1];var fv=[B2,B2,w7,B2,jx,B2,jw,B2,z1,B2,k8,B2,w8,B2,h1,B2,ih,B2,ok,B2,nc,B2,g_,B2,kk,B2,jg,B2,xF,B2,z2,B2,hi,B2,k4,B2,z3,B2,js,B2,ii,B2,l3,B2,lD,B2,vZ,B2,z4,B2,lV,B2,z5,B2,yF,B2,z6,B2,z7,B2,z8,B2,kh,B2,k9,B2,rX,B2,ob,B2,z9,B2,gN,B2,rW,B2,Aa,B2,ji,B2,l2,B2,rK,B2,qO,B2,gQ,B2,Ab,B2,lZ,B2,g$,B2,Ac,B2,Ad,B2,rO,B2,lU,B2,jt,B2,kg,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2,B2];var fw=[B3,B3,l$,B3];var fx=[B4,B4,ll,B4,lm,B4,Ae,B4];var fy=[B5,B5,kq,B5];var fz=[B6,B6,ja,B6];var fA=[B7,B7,lQ,B7,i5,B7,jq,B7,Ah,B7,la,B7,Ai,B7,lG,B7,h4,B7,kf,B7,g4,B7,Aj,B7,jr,B7,k0,B7,ke,B7,w3,B7,Ak,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7,B7];var fB=[B8,B8,lj,B8];var fC=[B9,B9,Bn,B9];var fD=[Ca,Ca,Br,Ca];var fE=[Cb,Cb,lJ,Cb];var fF=[Cc,Cc,lz,Cc];var fG=[Cd,Cd,Bo,Cd,Bp,Cd,Bq,Cd];var fH=[Ce,Ce,ka,Ce];var fI=[Cf,Cf,Bs,Cf,Bt,Cf,Bu,Cf];var fJ=[Cg,Cg,Am,Cg];var fK=[Ch,Ch,jW,Ch,An,Ch,Ao,Ch,Ap,Ch,Ch,Ch,Ch,Ch,Ch,Ch];var fL=[Ci,Ci,w5,Ci,iS,Ci,lh,Ci,lg,Ci,rZ,Ci,ig,Ci,lY,Ci,h6,Ci,Aq,Ci,gc,Ci,w6,Ci,x1,Ci,Ar,Ci,ix,Ci,rY,Ci,h8,Ci,f7,Ci,As,Ci,gW,Ci,gX,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci,Ci];var fM=[Cj,Cj,jQ,Cj,jG,Cj,jT,Cj,jS,Cj,jF,Cj,jP,Cj,Al,Cj,jX,Cj,jO,Cj,jE,Cj,jR,Cj,jH,Cj,Cj,Cj,Cj,Cj,Cj,Cj];var fN=[Ck,Ck,j3,Ck,rL,Ck,h5,Ck,m0,Ck,At,Ck,wF,Ck,tO,Ck,w2,Ck,wK,Ck,iP,Ck,lX,Ck,rN,Ck,ks,Ck,Au,Ck,x_,Ck,tX,Ck,hh,Ck,Av,Ck,l_,Ck,nn,Ck,hV,Ck,lI,Ck,w4,Ck,lO,Ck,h3,Ck,Ck,Ck,Ck,Ck,Ck,Ck,Ck,Ck,Ck,Ck,Ck,Ck];var fO=[Cl,Cl,tZ,Cl,Af,Cl,Ag,Cl,lr,Cl,gG,Cl,Cl,Cl,Cl,Cl];var fP=[Cm,Cm,Aw,Cm,lL,Cm,k6,Cm,Ax,Cm,tI,Cm,Ay,Cm,Az,Cm,AA,Cm,AB,Cm,tJ,Cm,AC,Cm,AD,Cm,AE,Cm,AF,Cm,AG,Cm,AH,Cm,AI,Cm,AJ,Cm,AK,Cm,AL,Cm,AM,Cm,AN,Cm,AO,Cm,AP,Cm,AQ,Cm,AR,Cm,ik,Cm,AS,Cm,lk,Cm,ha,Cm,jU,Cm,AT,Cm,AU,Cm,xa,Cm,tS,Cm,AV,Cm,hb,Cm,jV,Cm,tH,Cm,AW,Cm,AX,Cm,AY,Cm,kb,Cm,tP,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm,Cm];var fQ=[Cn,Cn,o2,Cn,q5,Cn,tb,Cn,h0,Cn,ss,Cn,mE,Cn,xy,Cn,ro,Cn,mt,Cn,vy,Cn,of,Cn,tN,Cn,rl,Cn,mu,Cn,uM,Cn,ms,Cn,qZ,Cn,np,Cn,gH,Cn,qs,Cn,rR,Cn,sf,Cn,qI,Cn,lc,Cn,xA,Cn,rj,Cn,m4,Cn,qg,Cn,yh,Cn,m9,Cn,tj,Cn,sI,Cn,sL,Cn,sY,Cn,oH,Cn,xV,Cn,mz,Cn,mN,Cn,s8,Cn,AZ,Cn,no,Cn,r9,Cn,sG,Cn,hN,Cn,sm,Cn,mF,Cn,ng,Cn,xx,Cn,sN,Cn,su,Cn,mk,Cn,s0,Cn,sw,Cn,qo,Cn,nb,Cn,vD,Cn,lW,Cn,tL,Cn,qX,Cn,sj,Cn,sq,Cn,wJ,Cn,qd,Cn,qq,Cn,s5,Cn,sx,Cn,vj,Cn,wx,Cn,r1,Cn,mp,Cn,te,Cn,ia,Cn,yi,Cn,s1,Cn,qe,Cn,nk,Cn,w9,Cn,mS,Cn,qK,Cn,ml,Cn,sX,Cn,hl,Cn,xG,Cn,vk,Cn,oG,Cn,mJ,Cn,ql,Cn,sJ,Cn,ou,Cn,nd,Cn,gv,Cn,qF,Cn,uU,Cn,uV,Cn,uW,Cn,uX,Cn,uq,Cn,ij,Cn,up,Cn,mr,Cn,qx,Cn,oA,Cn,xv,Cn,sn,Cn,mn,Cn,qw,Cn,rp,Cn,vx,Cn,s3,Cn,gq,Cn,mw,Cn,p0,Cn,s4,Cn,vh,Cn,rA,Cn,lR,Cn,mA,Cn,tc,Cn,sU,Cn,qf,Cn,wi,Cn,s_,Cn,h2,Cn,sF,Cn,v2,Cn,sK,Cn,h9,Cn,u1,Cn,ie,Cn,sR,Cn,sD,Cn,qk,Cn,rI,Cn,xD,Cn,ge,Cn,mL,Cn,my,Cn,mo,Cn,mI,Cn,hj,Cn,sd,Cn,rn,Cn,v3,Cn,vi,Cn,wR,Cn,ld,Cn,qm,Cn,uC,Cn,op,Cn,w0,Cn,u$,Cn,sc,Cn,qB,Cn,lC,Cn,s9,Cn,wV,Cn,qD,Cn,sv,Cn,rm,Cn,qv,Cn,sg,Cn,qC,Cn,sO,Cn,sB,Cn,mv,Cn,pO,Cn,sy,Cn,vC,Cn,sE,Cn,sC,Cn,qp,Cn,na,Cn,q2,Cn,ux,Cn,sz,Cn,qz,Cn,qr,Cn,qi,Cn,sh,Cn,qJ,Cn,sZ,Cn,st,Cn,m1,Cn,mq,Cn,oB,Cn,tB,Cn,vX,Cn,qE,Cn,sH,Cn,mP,Cn,ox,Cn,m$,Cn,mB,Cn,qM,Cn,ta,Cn,o3,Cn,sV,Cn,vd,Cn,wI,Cn,vY,Cn,sW,Cn,r$,Cn,oT,Cn,gg,Cn,mQ,Cn,hk,Cn,mC,Cn,mx,Cn,s$,Cn,s2,Cn,mm,Cn,si,Cn,qu,Cn,oF,Cn,tM,Cn,uZ,Cn,qh,Cn,qY,Cn,s7,Cn,oz,Cn,rr,Cn,sT,Cn,so,Cn,sp,Cn,sl,Cn,mH,Cn,sM,Cn,vA,Cn,s6,Cn,vz,Cn,mO,Cn,oR,Cn,x9,Cn,wa,Cn,ib,Cn,mM,Cn,ri,Cn,mG,Cn,qy,Cn,lP,Cn,sb,Cn,rs,Cn,mD,Cn,qn,Cn,qL,Cn,qA,Cn,qj,Cn,sk,Cn,xN,Cn,sA,Cn,A_,Cn,sQ,Cn,rq,Cn,q$,Cn,td,Cn,rk,Cn,og,Cn,m7,Cn,mR,Cn,oD,Cn,mK,Cn,qH,Cn,sr,Cn,gi,Cn,oC,Cn,sP,Cn,sS,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn,Cn];var fR=[Co,Co,A$,Co,A0,Co,A1,Co,gb,Co,A2,Co,vO,Co,A3,Co,A4,Co,A5,Co,A6,Co,A7,Co,A8,Co,A9,Co,Ba,Co,Bb,Co,Bc,Co,iq,Co,Bd,Co,Be,Co,Bf,Co,Bg,Co,Bh,Co,g7,Co,Bi,Co,Bj,Co,Bk,Co,Bl,Co,Bm,Co,Co,Co,Co,Co,Co,Co];return{_saveSetjmp:yH,_testSetjmp:yI,_strncasecmp:yL,_strcat:yR,_free:yz,_main:f8,_memcmp:yO,_strncpy:yP,_memmove:yN,_tolower:yK,_memset:yG,_llvm_cttz_i32:yS,_malloc:yx,_memcpy:yJ,_strcasecmp:yM,_strlen:yF,_realloc:yA,_strcpy:yQ,_calloc:yy,runPostSets:f6,stackAlloc:fS,stackSave:fT,stackRestore:fU,setThrew:fV,setTempRet0:fY,setTempRet1:fZ,setTempRet2:f_,setTempRet3:f$,setTempRet4:f0,setTempRet5:f1,setTempRet6:f2,setTempRet7:f3,setTempRet8:f4,setTempRet9:f5,dynCall_iiiiiiii:Bv,dynCall_vif:Bw,dynCall_viiiii:Bx,dynCall_vi:By,dynCall_vii:Bz,dynCall_iiiiiii:BA,dynCall_ii:BB,dynCall_viiiiiiiiiii:BC,dynCall_viffff:BD,dynCall_if:BE,dynCall_iiiiii:BF,dynCall_iiii:BG,dynCall_viiiiif:BH,dynCall_viff:BI,dynCall_vifff:BJ,dynCall_fii:BK,dynCall_iiif:BL,dynCall_viiiiiiii:BM,dynCall_iif:BN,dynCall_viiiiiii:BO,dynCall_ff:BP,dynCall_viiiiiiiii:BQ,dynCall_iii:BR,dynCall_viiiiii:BS,dynCall_i:BT,dynCall_iiiii:BU,dynCall_viii:BV,dynCall_v:BW,dynCall_viiii:BX}})
// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_iiiiiiii": invoke_iiiiiiii, "invoke_vif": invoke_vif, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiiiiii": invoke_iiiiiii, "invoke_ii": invoke_ii, "invoke_viiiiiiiiiii": invoke_viiiiiiiiiii, "invoke_viffff": invoke_viffff, "invoke_if": invoke_if, "invoke_iiiiii": invoke_iiiiii, "invoke_iiii": invoke_iiii, "invoke_viiiiif": invoke_viiiiif, "invoke_viff": invoke_viff, "invoke_vifff": invoke_vifff, "invoke_fii": invoke_fii, "invoke_iiif": invoke_iiif, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_iif": invoke_iif, "invoke_viiiiiii": invoke_viiiiiii, "invoke_ff": invoke_ff, "invoke_viiiiiiiii": invoke_viiiiiiiii, "invoke_iii": invoke_iii, "invoke_viiiiii": invoke_viiiiii, "invoke_i": invoke_i, "invoke_iiiii": invoke_iiiii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_viiii": invoke_viiii, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_RWebInputDestroy": _RWebInputDestroy, "_RWebAudioStop": _RWebAudioStop, "_glClearColor": _glClearColor, "_sysconf": _sysconf, "_rand": _rand, "__scanString": __scanString, "_fclose": _fclose, "_RWebAudioInit": _RWebAudioInit, "_glGetVertexAttribPointerv": _glGetVertexAttribPointerv, "_glGetRenderbufferParameteriv": _glGetRenderbufferParameteriv, "_eglDestroySurface": _eglDestroySurface, "_strtoul": _strtoul, "_strtoull": _strtoull, "_glBindTexture": _glBindTexture, "_fflush": _fflush, "_glGetUniformiv": _glGetUniformiv, "_fabsf": _fabsf, "_strtol": _strtol, "_fputc": _fputc, "_glGetString": _glGetString, "_strtok": _strtok, "_fwrite": _fwrite, "_gluUnProject": _gluUnProject, "_send": _send, "_fputs": _fputs, "_glLineWidth": _glLineWidth, "_glUniform2fv": _glUniform2fv, "_emscripten_get_now": _emscripten_get_now, "_eglCreateContext": _eglCreateContext, "_glBindAttribLocation": _glBindAttribLocation, "_glCompileShader": _glCompileShader, "_isspace": _isspace, "_localtime": _localtime, "_glDeleteTextures": _glDeleteTextures, "_eglBindAPI": _eglBindAPI, "_glCompressedTexImage2D": _glCompressedTexImage2D, "_glStencilFuncSeparate": _glStencilFuncSeparate, "_read": _read, "_RWebAudioBufferSize": _RWebAudioBufferSize, "_glDeleteShader": _glDeleteShader, "_RWebInputInit": _RWebInputInit, "_glClearDepthf": _glClearDepthf, "_glUniform4iv": _glUniform4iv, "_glGetTexParameteriv": _glGetTexParameteriv, "_glClearStencil": _glClearStencil, "_glLoadIdentity": _glLoadIdentity, "_glUniform1fv": _glUniform1fv, "_glIsShader": _glIsShader, "_strstr": _strstr, "_glSampleCoverage": _glSampleCoverage, "_fsync": _fsync, "_glGenTextures": _glGenTextures, "_glDepthFunc": _glDepthFunc, "_remove": _remove, "_glCompressedTexSubImage2D": _glCompressedTexSubImage2D, "_ceilf": _ceilf, "_glUniform1f": _glUniform1f, "_opendir": _opendir, "_mkdir": _mkdir, "_glGetTexParameterfv": _glGetTexParameterfv, "_RWebAudioWrite": _RWebAudioWrite, "_glStencilMaskSeparate": _glStencilMaskSeparate, "_glCreateShader": _glCreateShader, "_round": _round, "_glUniform1i": _glUniform1i, "_strncmp": _strncmp, "_cosf": _cosf, "_glDeleteRenderbuffers": _glDeleteRenderbuffers, "_glLinkProgram": _glLinkProgram, "_snprintf": _snprintf, "_glUniform2i": _glUniform2i, "_fgetc": _fgetc, "_glStencilFunc": _glStencilFunc, "_vsnprintf": _vsnprintf, "_glShaderSource": _glShaderSource, "_readdir": _readdir, "_glVertexAttribPointer": _glVertexAttribPointer, "_glHint": _glHint, "_mknod": _mknod, "_glBindBuffer": _glBindBuffer, "_glVertexPointer": _glVertexPointer, "_fgets": _fgets, "_close": _close, "_getgid": _getgid, "_glGetAttachedShaders": _glGetAttachedShaders, "_glBindFramebuffer": _glBindFramebuffer, "_glIsFramebuffer": _glIsFramebuffer, "_strchr": _strchr, "_llvm_bswap_i16": _llvm_bswap_i16, "_glUniform4fv": _glUniform4fv, "_abort": _abort, "___setErrNo": ___setErrNo, "_glDeleteFramebuffers": _glDeleteFramebuffers, "_eglTerminate": _eglTerminate, "_glGetVertexAttribfv": _glGetVertexAttribfv, "_glIsBuffer": _glIsBuffer, "_emscripten_GetProcAddress": _emscripten_GetProcAddress, "_eglGetProcAddress": _eglGetProcAddress, "_ftell": _ftell, "_glDeleteProgram": _glDeleteProgram, "_exit": _exit, "_sprintf": _sprintf, "_glRenderbufferStorage": _glRenderbufferStorage, "_strrchr": _strrchr, "_glAttachShader": _glAttachShader, "_RWebInputPoll": _RWebInputPoll, "_glUniform3i": _glUniform3i, "_glIsProgram": _glIsProgram, "_glCheckFramebufferStatus": _glCheckFramebufferStatus, "__isLeapYear": __isLeapYear, "_gluProject": _gluProject, "_llvm_uadd_with_overflow_i32": _llvm_uadd_with_overflow_i32, "_localtime_r": _localtime_r, "_glUniform3f": _glUniform3f, "_glGetBufferParameteriv": _glGetBufferParameteriv, "_glFlush": _glFlush, "_glBlendEquationSeparate": _glBlendEquationSeparate, "_emscripten_get_canvas_size": _emscripten_get_canvas_size, "_glCopyTexImage2D": _glCopyTexImage2D, "_glDrawElements": _glDrawElements, "_glColorMask": _glColorMask, "_sinf": _sinf, "_gluLookAt": _gluLookAt, "_eglInitialize": _eglInitialize, "_recv": _recv, "__parseInt64": __parseInt64, "_glVertexAttrib1fv": _glVertexAttrib1fv, "_glUniform2iv": _glUniform2iv, "_cos": _cos, "_putchar": _putchar, "_glUniform1iv": _glUniform1iv, "_glActiveTexture": _glActiveTexture, "_glMatrixMode": _glMatrixMode, "_glBlendEquation": _glBlendEquation, "_strcmp": _strcmp, "_glVertexAttrib1f": _glVertexAttrib1f, "_RWebAudioWriteAvail": _RWebAudioWriteAvail, "_glGenerateMipmap": _glGenerateMipmap, "_memchr": _memchr, "_glDetachShader": _glDetachShader, "_glGetShaderiv": _glGetShaderiv, "__exit": __exit, "_strftime": _strftime, "_glVertexAttrib3f": _glVertexAttrib3f, "_glGenRenderbuffers": _glGenRenderbuffers, "_tzset": _tzset, "_RWebAudioSampleRate": _RWebAudioSampleRate, "_floorf": _floorf, "_glGetShaderPrecisionFormat": _glGetShaderPrecisionFormat, "_glVertexAttrib4fv": _glVertexAttrib4fv, "_glDepthMask": _glDepthMask, "_glDisableVertexAttribArray": _glDisableVertexAttribArray, "_glBegin": _glBegin, "_printf": _printf, "_glBindRenderbuffer": _glBindRenderbuffer, "_pread": _pread, "_fopen": _fopen, "_open": _open, "_glDrawArrays": _glDrawArrays, "_usleep": _usleep, "_llvm_pow_f32": _llvm_pow_f32, "__arraySum": __arraySum, "_glCopyTexSubImage2D": _glCopyTexSubImage2D, "_sqrtf": _sqrtf, "_glDisable": _glDisable, "_puts": _puts, "_glUniform4i": _glUniform4i, "_nanosleep": _nanosleep, "_glClear": _glClear, "_qsort": _qsort, "_glUniform2f": _glUniform2f, "_eglDestroyContext": _eglDestroyContext, "_isalpha": _isalpha, "_glEnableVertexAttribArray": _glEnableVertexAttribArray, "_rmdir": _rmdir, "_glUniform3fv": _glUniform3fv, "_glStencilOp": _glStencilOp, "_strdup": _strdup, "_glDepthRange": _glDepthRange, "_glUniform4f": _glUniform4f, "_glFramebufferTexture2D": _glFramebufferTexture2D, "_glUniformMatrix2fv": _glUniformMatrix2fv, "_glGenVertexArrays": _glGenVertexArrays, "_eglMakeCurrent": _eglMakeCurrent, "_glUniformMatrix3fv": _glUniformMatrix3fv, "_glutCreateWindow": _glutCreateWindow, "_glBufferData": _glBufferData, "_glBlendColor": _glBlendColor, "_glGetUniformLocation": _glGetUniformLocation, "_glIsEnabled": _glIsEnabled, "__formatString": __formatString, "_getenv": _getenv, "_glGetError": _glGetError, "_gettimeofday": _gettimeofday, "_glGetVertexAttribiv": _glGetVertexAttribiv, "_glTexParameteriv": _glTexParameteriv, "_glGetProgramiv": _glGetProgramiv, "_glVertexAttrib3fv": _glVertexAttrib3fv, "_glGetFloatv": _glGetFloatv, "_glBufferSubData": _glBufferSubData, "_glUniform3iv": _glUniform3iv, "_glReadPixels": _glReadPixels, "_glGenFramebuffers": _glGenFramebuffers, "_glFramebufferRenderbuffer": _glFramebufferRenderbuffer, "_emscripten_procAddressTable": _emscripten_procAddressTable, "_fscanf": _fscanf, "_ceil": _ceil, "___errno_location": ___errno_location, "_glGetIntegerv": _glGetIntegerv, "_RWebAudioFree": _RWebAudioFree, "_llvm_lifetime_start": _llvm_lifetime_start, "_glIsRenderbuffer": _glIsRenderbuffer, "_llvm_bswap_i32": _llvm_bswap_i32, "_sbrk": _sbrk, "__parseInt": __parseInt, "_ungetc": _ungetc, "_RWebAudioSetNonblockState": _RWebAudioSetNonblockState, "_glVertexAttrib2fv": _glVertexAttrib2fv, "_glGetFramebufferAttachmentParameteriv": _glGetFramebufferAttachmentParameteriv, "_glUseProgram": _glUseProgram, "_glTexImage2D": _glTexImage2D, "_glGetProgramInfoLog": _glGetProgramInfoLog, "_glTexSubImage2D": _glTexSubImage2D, "_glStencilMask": _glStencilMask, "_fread": _fread, "_glStencilOpSeparate": _glStencilOpSeparate, "_strtok_r": _strtok_r, "_glGetShaderInfoLog": _glGetShaderInfoLog, "_glIsTexture": _glIsTexture, "_eglCreateWindowSurface": _eglCreateWindowSurface, "_fprintf": _fprintf, "_glGetShaderSource": _glGetShaderSource, "_gluPerspective": _gluPerspective, "_eglChooseConfig": _eglChooseConfig, "_tan": _tan, "___buildEnvironment": ___buildEnvironment, "_feof": _feof, "__addDays": __addDays, "_strncat": _strncat, "_glScissor": _glScissor, "_glEnable": _glEnable, "_glBlendFuncSeparate": _glBlendFuncSeparate, "_floor": _floor, "__reallyNegative": __reallyNegative, "_glGetActiveAttrib": _glGetActiveAttrib, "_fseek": _fseek, "_sqrt": _sqrt, "_glTexParameterfv": _glTexParameterfv, "_write": _write, "_glGenBuffers": _glGenBuffers, "_glFinish": _glFinish, "_glGetAttribLocation": _glGetAttribLocation, "_glVertexAttrib4f": _glVertexAttrib4f, "_rewind": _rewind, "_sin": _sin, "_glBlendFunc": _glBlendFunc, "_glCreateProgram": _glCreateProgram, "_realpath": _realpath, "_stat": _stat, "_longjmp": _longjmp, "_atan": _atan, "_glViewport": _glViewport, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_time": _time, "_glVertexAttrib2f": _glVertexAttrib2f, "_closedir": _closedir, "_isgraph": _isgraph, "_readlink": _readlink, "_glGetUniformfv": _glGetUniformfv, "_llvm_va_end": _llvm_va_end, "_unlink": _unlink, "_gluOrtho2D": _gluOrtho2D, "_glUniformMatrix4fv": _glUniformMatrix4fv, "_glClearDepth": _glClearDepth, "_glGetActiveUniform": _glGetActiveUniform, "_glutDestroyWindow": _glutDestroyWindow, "_pwrite": _pwrite, "__isFloat": __isFloat, "_fabs": _fabs, "_glTexParameterf": _glTexParameterf, "_RWebAudioStart": _RWebAudioStart, "_glTexParameteri": _glTexParameteri, "_glFrontFace": _glFrontFace, "_glCullFace": _glCullFace, "_glDepthRangef": _glDepthRangef, "_glDeleteBuffers": _glDeleteBuffers, "_eglGetDisplay": _eglGetDisplay, "_emscripten_set_canvas_size": _emscripten_set_canvas_size, "_atan2": _atan2, "_atoi": _atoi, "_glGetBooleanv": _glGetBooleanv, "_eglQuerySurface": _eglQuerySurface, "_glPixelStorei": _glPixelStorei, "_readdir_r": _readdir_r, "_glValidateProgram": _glValidateProgram, "_glPolygonOffset": _glPolygonOffset, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stdout": _stdout, "_stderr": _stderr }, buffer);
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var _strncasecmp = Module["_strncasecmp"] = asm["_strncasecmp"];
var _strcat = Module["_strcat"] = asm["_strcat"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _memcmp = Module["_memcmp"] = asm["_memcmp"];
var _strncpy = Module["_strncpy"] = asm["_strncpy"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _memset = Module["_memset"] = asm["_memset"];
var _llvm_cttz_i32 = Module["_llvm_cttz_i32"] = asm["_llvm_cttz_i32"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _strcasecmp = Module["_strcasecmp"] = asm["_strcasecmp"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var _calloc = Module["_calloc"] = asm["_calloc"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_vif = Module["dynCall_vif"] = asm["dynCall_vif"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiiiiiiiii = Module["dynCall_viiiiiiiiiii"] = asm["dynCall_viiiiiiiiiii"];
var dynCall_viffff = Module["dynCall_viffff"] = asm["dynCall_viffff"];
var dynCall_if = Module["dynCall_if"] = asm["dynCall_if"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiiif = Module["dynCall_viiiiif"] = asm["dynCall_viiiiif"];
var dynCall_viff = Module["dynCall_viff"] = asm["dynCall_viff"];
var dynCall_vifff = Module["dynCall_vifff"] = asm["dynCall_vifff"];
var dynCall_fii = Module["dynCall_fii"] = asm["dynCall_fii"];
var dynCall_iiif = Module["dynCall_iiif"] = asm["dynCall_iiif"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_iif = Module["dynCall_iif"] = asm["dynCall_iif"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_ff = Module["dynCall_ff"] = asm["dynCall_ff"];
var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };
// TODO: strip out parts of this we do not need
//======= begin closure i64 code =======
// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */
var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };
  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.
    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };
  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.
  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};
  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };
  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };
  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };
  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };
  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.
  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;
  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);
  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);
  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };
  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };
  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (this.isZero()) {
      return '0';
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }
    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };
  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };
  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };
  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };
  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };
  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };
  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };
  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };
  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };
  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };
  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };
  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);
      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };
  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };
  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };
  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };
  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };
  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };
  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };
  //======= begin jsbn =======
  var navigator = { appName: 'Modern Browser' }; // polyfill a little
  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/
  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */
  // Basic JavaScript BN library - subset useful for RSA encryption.
  // Bits per digit
  var dbits;
  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);
  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }
  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }
  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.
  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;
  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }
  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }
  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }
  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }
  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }
  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }
  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }
  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }
  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }
  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }
  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }
  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }
  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }
  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }
  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }
  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }
  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }
  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }
  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }
  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }
  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }
  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }
  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }
  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }
  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }
  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  // jsbn2 stuff
  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }
  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }
  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }
  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }
  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }
  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  //======= end jsbn =======
  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();
//======= end closure i64 code =======
// === Auto-generated postamble setup entry stuff ===
function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;
var initialStackTop;
var preloadStartTime = null;
Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');
  args = args || [];
  if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
    Module.printErr('preload time: ' + (Date.now() - preloadStartTime) + ' ms');
  }
  ensureInitRuntime();
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);
  initialStackTop = STACKTOP;
  try {
    var ret = Module['_main'](argc, argv, 0);
    // if we're not running an evented main loop, it's time to exit
    if (!Module['noExitRuntime']) {
      exit(ret);
    }
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      throw e;
    }
  }
}
function run(args) {
  args = args || Module['arguments'];
  if (preloadStartTime === null) preloadStartTime = Date.now();
  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }
  preRun();
  if (runDependencies > 0) {
    // a preRun added a dependency, run will be called later
    return;
  }
  function doRun() {
    ensureInitRuntime();
    preMain();
    calledRun = true;
    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }
    postRun();
  }
  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;
function exit(status) {
  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;
  // exit the runtime
  exitRuntime();
  // throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;
function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }
  ABORT = true;
  EXITSTATUS = 1;
  throw 'abort() at ' + (new Error().stack);
}
Module['abort'] = Module.abort = abort;
// {{PRE_RUN_ADDITIONS}}
if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}
// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}
run();
// {{POST_RUN_ADDITIONS}}
// {{MODULE_ADDITIONS}}
