// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = eval('(function() { try { return Module || {} } catch(e) { return {} } })()');
// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}
// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };
  var nodeFS = require('fs');
  var nodePath = require('path');
  Module['read'] = function(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };
  Module['readBinary'] = function(filename) { return Module['read'](filename, true) };
  Module['load'] = function(f) {
    globalEval(read(f));
  };
  Module['arguments'] = process['argv'].slice(2);
  module.exports = Module;
}
else if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm
  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function() { throw 'no read() available (jsc?)' };
  }
  Module['readBinary'] = function(f) {
    return read(f, 'binary');
  };
  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  this['Module'] = Module;
}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };
  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  if (ENVIRONMENT_IS_WEB) {
    Module['print'] = function(x) {
      console.log(x);
    };
    Module['printErr'] = function(x) {
      console.log(x);
    };
    this['Module'] = Module;
  } else if (ENVIRONMENT_IS_WORKER) {
    // We can do very little here...
    var TRY_USE_DUMP = false;
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}
function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***
// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];
// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];
// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}
// === Auto-generated preamble library stuff ===
//========================================
// Runtime code shared with compiler
//========================================
var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (type == 'i64' || type == 'double' || vararg) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    var index = 0;
    type.flatIndexes = type.fields.map(function(field) {
      index++;
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        if (field[1] === '0') {
          // this is [0 x something]. When inside another structure like here, it must be at the end,
          // and it adds no size
          // XXX this happens in java-nbody for example... assert(index === type.fields.length, 'zero-length in the middle!');
          size = 0;
          alignSize = type.alignSize || QUANTUM_SIZE;
        } else {
          size = Types.types[field].flatSize;
          alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
        }
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2 + 2*i;
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;
      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }
      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          Math.floor((codePoint - 0x10000) / 0x400) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+7)>>3)<<3); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+7)>>3)<<3); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = ((((DYNAMICTOP)+7)>>3)<<3); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>(0))))+((+(((high)>>>(0))))*(+(4294967296)))) : ((+(((low)>>>(0))))+((+(((high)|(0))))*(+(4294967296))))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}
//========================================
// Runtime essentials
//========================================
var __THREW__ = 0; // Used in checking for thrown exceptions.
var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;
var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}
var globalScope = this;
// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;
// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = Module['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}
// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;
// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;
// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;
var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;
// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === 'string' ? types : null;
  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }
  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }
  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }
  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later
    setValue(ret+i, curr, type);
    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }
  return ret;
}
Module['allocate'] = allocate;
function Pointer_stringify(ptr, /* optional */ length) {
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;
  var ret = '';
  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;
// Memory management
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}
var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value, or (2) set Module.TOTAL_MEMORY before the program runs.');
}
var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 67108864;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;
// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');
var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);
// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');
Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;
function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}
var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited
var runtimeInitialized = false;
function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}
function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}
function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}
function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;
function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;
function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;
function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;
function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;
// Tools
// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;
function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;
// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;
function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}
if (!Math['imul']) Math['imul'] = function(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];
// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledInit = false, calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;
Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data
function loadMemoryInitializer(filename) {
  function applyData(data) {
    HEAPU8.set(data, STATIC_BASE);
  }
  // always do this asynchronously, to keep shell and web as similar as possible
  addOnPreRun(function() {
    if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
      applyData(Module['readBinary'](filename));
    } else {
      Browser.asyncLoad(filename, function(data) {
        applyData(data);
      }, function(data) {
        throw 'could not load memory initializer ' + filename;
      });
    }
  });
}
// === Body ===
STATIC_BASE = 8;
STATICTOP = STATIC_BASE + 818104;
var _stdout;
var _stderr;
/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } },{ func: function() { __GLOBAL__I_a() } });
var ___dso_handle;
var _stdout = _stdout=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stderr = _stderr=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
/* memory initializer */ allocate([0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,28,0,0,0,10,0,0,0,42,0,0,0,8,0,0,0,58,0,0,0,26,0,0,0,170,3,0,0,24,139,0,0,66,0,0,0,18,0,0,0,8,0,0,0,94,0,0,0,12,0,0,0,120,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,248,23,8,0,184,32,8,0,1,1,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,0,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,13,0,0,0,15,0,0,0,17,0,0,0,19,0,0,0,23,0,0,0,27,0,0,0,31,0,0,0,35,0,0,0,43,0,0,0,51,0,0,0,59,0,0,0,67,0,0,0,83,0,0,0,99,0,0,0,115,0,0,0,131,0,0,0,163,0,0,0,195,0,0,0,227,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,13,0,0,0,17,0,0,0,25,0,0,0,33,0,0,0,49,0,0,0,65,0,0,0,97,0,0,0,129,0,0,0,193,0,0,0,1,1,0,0,129,1,0,0,1,2,0,0,1,3,0,0,1,4,0,0,1,6,0,0,1,8,0,0,1,12,0,0,1,16,0,0,1,24,0,0,1,32,0,0,1,48,0,0,1,64,0,0,1,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,40,111,0,0,0,0,0,0,232,77,0,0,1,0,0,0,80,108,0,0,2,0,0,0,0,107,0,0,3,0,0,0,192,105,0,0,4,0,0,0,56,104,0,0,5,0,0,0,56,103,0,0,6,0,0,0,152,101,0,0,7,0,0,0,48,100,0,0,8,0,0,0,120,78,0,0,9,0,0,0,224,94,0,0,10,0,0,0,184,161,0,0,11,0,0,0,72,93,0,0,12,0,0,0,48,92,0,0,13,0,0,0,88,91,0,0,14,0,0,0,32,90,0,0,15,0,0,0,72,89,0,0,16,0,0,0,56,88,0,0,17,0,0,0,176,87,0,0,18,0,0,0,216,85,0,0,19,0,0,0,136,83,0,0,20,0,0,0,24,82,0,0,21,0,0,0,32,80,0,0,22,0,0,0,120,79,0,0,23,0,0,0,56,79,0,0,24,0,0,0,240,78,0,0,25,0,0,0,128,78,0,0,26,0,0,0,240,77,0,0,27,0,0,0,144,77,0,0,28,0,0,0,208,76,0,0,29,0,0,0,80,75,0,0,30,0,0,0,168,74,0,0,31,0,0,0,200,73,0,0,32,0,0,0,24,73,0,0,33,0,0,0,168,72,0,0,34,0,0,0,24,72,0,0,35,0,0,0,128,71,0,0,36,0,0,0,168,70,0,0,37,0,0,0,240,69,0,0,38,0,0,0,80,69,0,0,39,0,0,0,192,67,0,0,40,0,0,0,224,66,0,0,41,0,0,0,232,65,0,0,42,0,0,0,16,65,0,0,43,0,0,0,160,64,0,0,44,0,0,0,32,64,0,0,45,0,0,0,200,63,0,0,46,0,0,0,24,63,0,0,47,0,0,0,104,62,0,0,48,0,0,0,216,61,0,0,49,0,0,0,200,59,0,0,50,0,0,0,240,58,0,0,51,0,0,0,184,57,0,0,52,0,0,0,16,57,0,0,53,0,0,0,128,56,0,0,54,0,0,0,240,55,0,0,55,0,0,0,92,143,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,146,1,35,3,181,4,69,6,213,7,100,9,241,10,124,12,5,14,140,15,17,17,148,18,19,20,143,21,8,23,125,24,239,25,93,27,198,28,43,30,139,31,231,32,61,34,142,35,218,36,31,38,95,39,153,40,205,41,250,42,33,44,65,45,90,46,107,47,118,48,121,49,116,50,103,51,83,52,54,53,18,54,229,54,175,55,113,56,42,57,218,57,130,58,32,59,182,59,66,60,197,60,62,61,174,61,20,62,113,62,197,62,14,63,78,63,132,63,177,63,211,63,236,63,251,63,0,64,251,63,236,63,211,63,177,63,132,63,78,63,14,63,197,62,113,62,20,62,174,61,62,61,197,60,66,60,182,59,32,59,130,58,218,57,42,57,113,56,175,55,229,54,18,54,54,53,83,52,103,51,116,50,121,49,118,48,107,47,90,46,65,45,33,44,250,42,205,41,153,40,95,39,31,38,218,36,142,35,61,34,231,32,139,31,43,30,198,28,93,27,239,25,125,24,8,23,143,21,19,20,148,18,17,17,140,15,5,14,124,12,241,10,100,9,213,7,69,6,181,4,35,3,146,1,0,0,110,254,221,252,75,251,187,249,43,248,156,246,15,245,132,243,251,241,116,240,239,238,108,237,237,235,113,234,248,232,131,231,17,230,163,228,58,227,213,225,117,224,25,223,195,221,114,220,38,219,225,217,161,216,103,215,51,214,6,213,223,211,191,210,166,209,149,208,138,207,135,206,140,205,153,204,173,203,202,202,238,201,27,201,81,200,143,199,214,198,38,198,126,197,224,196,74,196,190,195,59,195,194,194,82,194,236,193,143,193,59,193,242,192,178,192,124,192,79,192,45,192,20,192,5,192,0,192,5,192,20,192,45,192,79,192,124,192,178,192,242,192,59,193,143,193,236,193,82,194,194,194,59,195,190,195,74,196,224,196,126,197,38,198,214,198,143,199,81,200,27,201,238,201,202,202,173,203,153,204,140,205,135,206,138,207,149,208,166,209,191,210,223,211,6,213,51,214,103,215,161,216,225,217,38,219,114,220,195,221,25,223,117,224,213,225,58,227,163,228,17,230,131,231,248,232,113,234,237,235,108,237,239,238,116,240,251,241,132,243,15,245,156,246,43,248,187,249,75,251,221,252,110,254,2,0,0,0,82,0,0,0,48,1,0,0,104,172,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,111,114,109,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,56,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,55,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,2,0,0,0,1,1,0,0,4,1,0,0,4,2,0,0,4,3,0,0,4,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,3,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,248,23,8,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,9,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,120,156,0,0,64,181,11,0,224,184,0,0,72,181,11,0,16,138,0,0,0,181,11,0,128,111,0,0,208,180,11,0,120,95,0,0,240,180,11,0,248,83,0,0,176,180,11,0,136,75,0,0,40,181,11,0,240,67,0,0,192,180,11,0,40,60,0,0,184,180,11,0,232,51,0,0,112,181,11,0,120,198,0,0,128,181,11,0,224,189,0,0,120,181,11,0,40,182,0,0,56,181,11,0,128,176,0,0,136,181,11,0,232,172,0,0,80,181,11,0,152,167,0,0,48,181,11,0,136,162,0,0,248,180,11,0,168,158,0,0,96,181,11,0,144,154,0,0,88,181,11,0,8,151,0,0,104,181,11,0,48,147,0,0,32,181,11,0,56,142,0,0,200,180,11,0,0,136,0,0,216,180,11,0,200,130,0,0,232,180,11,0,176,126,0,0,24,181,11,0,176,124,0,0,224,180,11,0,192,121,0,0,16,181,11,0,80,119,0,0,8,181,11,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,8,168,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,64,167,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,136,166,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,152,165,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,72,165,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,224,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,136,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,88,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,40,164,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,224,163,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,208,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,72,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,8,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,104,161,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,224,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,184,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,112,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,56,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,8,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,192,159,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,216,158,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,80,158,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,200,157,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,56,157,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,8,157,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,8,168,0,0,122,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,64,167,0,0,97,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,136,166,0,0,47,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,152,165,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,72,165,0,0,17,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,224,164,0,0,18,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,136,164,0,0,20,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,88,164,0,0,19,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,40,164,0,0,120,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,224,163,0,0,115,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,208,162,0,0,113,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,72,162,0,0,119,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,8,162,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,104,161,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,224,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,184,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,112,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,56,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,8,160,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,192,159,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,216,158,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,80,158,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,200,157,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,56,157,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,8,157,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,25,0,0,0,232,156,0,0,32,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,26,0,0,0,176,156,0,0,108,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,27,0,0,0,200,169,0,0,29,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,28,0,0,0,64,170,0,0,27,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,29,0,0,0,16,156,0,0,102,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,30,0,0,0,0,155,0,0,27,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,31,0,0,0,72,154,0,0,32,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,32,0,0,0,0,154,0,0,31,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,33,0,0,0,40,198,0,0,114,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,34,0,0,0,24,153,0,0,111,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,35,0,0,0,232,152,0,0,112,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,36,0,0,0,160,152,0,0,107,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,37,0,0,0,104,152,0,0,104,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,38,0,0,0,48,152,0,0,109,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,39,0,0,0,232,151,0,0,110,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,40,0,0,0,104,151,0,0,121,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,41,0,0,0,184,150,0,0,116,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,42,0,0,0,88,150,0,0,117,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,43,0,0,0,184,149,0,0,33,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,44,0,0,0,120,149,0,0,99,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,45,0,0,0,208,47,0,0,34,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,46,0,0,0,40,149,0,0,105,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,47,0,0,0,16,149,0,0,101,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,48,0,0,0,200,148,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,49,0,0,0,144,148,0,0,14,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,50,0,0,0,144,147,0,0,13,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,51,0,0,0,16,147,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,52,0,0,0,128,146,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,53,0,0,0,224,145,0,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,54,0,0,0,240,191,0,0,36,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,55,0,0,0,104,145,0,0,26,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,37,0,0,0,20,1,0,0,39,0,0,0,19,1,0,0,38,0,0,0,17,1,0,0,40,0,0,0,18,1,0,0,13,0,0,0,13,0,0,0,9,0,0,0,9,0,0,0,45,0,0,0,21,1,0,0,46,0,0,0,127,0,0,0,16,0,0,0,47,1,0,0,16,0,0,0,48,1,0,0,17,0,0,0,50,1,0,0,35,0,0,0,23,1,0,0,36,0,0,0,22,1,0,0,34,0,0,0,25,1,0,0,33,0,0,0,24,1,0,0,18,0,0,0,52,1,0,0,32,0,0,0,32,0,0,0,27,0,0,0,27,0,0,0,8,0,0,0,8,0,0,0,13,0,0,0,15,1,0,0,107,0,0,0,14,1,0,0,109,0,0,0,13,1,0,0,106,0,0,0,12,1,0,0,111,0,0,0,11,1,0,0,192,0,0,0,96,0,0,0,19,0,0,0,19,0,0,0,96,0,0,0,0,1,0,0,97,0,0,0,1,1,0,0,98,0,0,0,2,1,0,0,99,0,0,0,3,1,0,0,100,0,0,0,4,1,0,0,101,0,0,0,5,1,0,0,102,0,0,0,6,1,0,0,103,0,0,0,7,1,0,0,104,0,0,0,8,1,0,0,105,0,0,0,9,1,0,0,48,0,0,0,48,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,50,0,0,0,51,0,0,0,51,0,0,0,52,0,0,0,52,0,0,0,53,0,0,0,53,0,0,0,54,0,0,0,54,0,0,0,55,0,0,0,55,0,0,0,56,0,0,0,56,0,0,0,57,0,0,0,57,0,0,0,112,0,0,0,26,1,0,0,113,0,0,0,27,1,0,0,114,0,0,0,28,1,0,0,115,0,0,0,29,1,0,0,116,0,0,0,30,1,0,0,117,0,0,0,31,1,0,0,118,0,0,0,32,1,0,0,119,0,0,0,33,1,0,0,120,0,0,0,34,1,0,0,121,0,0,0,35,1,0,0,122,0,0,0,36,1,0,0,123,0,0,0,37,1,0,0,65,0,0,0,97,0,0,0,66,0,0,0,98,0,0,0,67,0,0,0,99,0,0,0,68,0,0,0,100,0,0,0,69,0,0,0,101,0,0,0,70,0,0,0,102,0,0,0,71,0,0,0,103,0,0,0,72,0,0,0,104,0,0,0,73,0,0,0,105,0,0,0,74,0,0,0,106,0,0,0,75,0,0,0,107,0,0,0,76,0,0,0,108,0,0,0,77,0,0,0,109,0,0,0,78,0,0,0,110,0,0,0,79,0,0,0,111,0,0,0,80,0,0,0,112,0,0,0,81,0,0,0,113,0,0,0,82,0,0,0,114,0,0,0,83,0,0,0,115,0,0,0,84,0,0,0,116,0,0,0,85,0,0,0,117,0,0,0,86,0,0,0,118,0,0,0,87,0,0,0,119,0,0,0,88,0,0,0,120,0,0,0,89,0,0,0,121,0,0,0,90,0,0,0,122,0,0,0,0,0,0,0,0,0,0,0,168,160,0,0,216,156,0,0,48,178,0,0,176,178,0,0,88,145,0,0,8,139,0,0,88,133,0,0,208,128,0,0,104,125,0,0,48,123,0,0,248,177,0,0,152,177,0,0,24,177,0,0,64,176,0,0,248,175,0,0,184,175,0,0,0,0,0,0,0,0,36,64,0,0,0,0,0,0,89,64,0,0,0,0,0,136,195,64,0,0,0,0,132,215,151,65,0,128,224,55,121,195,65,67,23,110,5,181,181,184,147,70,245,249,63,233,3,79,56,77,50,29,48,249,72,119,130,90,60,191,115,127,221,79,21,117,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,8,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,137,80,78,71,13,10,26,10,1,0,0,0,0,0,0,0,6,0,0,234,147,0,0,234,6,0,0,234,0,0,0,0,0,0,0,0,0,0,0,0,136,0,0,234,0,0,0,0,2,3,160,227,0,240,160,225,0,88,45,233,2,192,94,229,60,176,143,226,12,193,155,231,0,176,79,225,0,8,45,233,128,176,11,226,31,176,139,227,11,240,41,225,4,64,45,233,15,224,160,225,28,255,47,225,4,64,189,232,211,192,160,227,12,240,41,225,0,8,189,232,11,240,105,225,0,88,189,232,14,240,176,225,156,0,0,0,156,0,0,0,156,0,0,0,156,0,0,0,248,1,0,0,240,1,0,0,172,0,0,0,160,0,0,0,252,0,0,0,104,1,0,0,30,255,47,225,0,48,160,225,1,0,160,225,3,16,160,225,2,49,17,226,0,16,97,66,64,192,51,224,0,0,96,34,1,32,176,225,160,0,82,225,130,32,160,145,252,255,255,58,2,0,80,225,3,48,163,224,2,0,64,32,1,0,50,225,162,32,160,17,249,255,255,26,0,16,160,225,3,0,160,225,140,192,176,225,0,0,96,34,0,16,97,66,30,255,47,225,16,0,45,233,0,192,160,225,1,16,160,227,1,0,80,225,160,0,160,129,129,16,160,129,251,255,255,138,12,0,160,225,1,64,160,225,0,48,160,227,1,32,160,225,160,0,82,225,130,32,160,145,252,255,255,58,2,0,80,225,3,48,163,224,2,0,64,32,1,0,50,225,162,32,160,17,249,255,255,26,3,16,129,224,161,16,176,225,4,0,81,225,238,255,255,58,4,0,160,225,16,0,189,232,30,255,47,225,144,0,1,224,65,23,160,225,0,16,97,226,169,48,160,227,145,3,3,224,67,55,160,225,57,62,131,226,145,3,3,224,67,55,160,225,9,60,131,226,28,48,131,226,145,3,3,224,67,55,160,225,15,60,131,226,182,48,131,226,145,3,3,224,67,55,160,225,22,60,131,226,170,48,131,226,145,3,3,224,67,55,160,225,2,58,131,226,129,48,131,226,145,3,3,224,67,55,160,225,54,60,131,226,81,48,131,226,145,3,3,224,67,55,160,225,162,60,131,226,249,48,131,226,147,0,0,224,64,8,160,225,30,255,47,225,1,0,160,227,1,16,160,227,16,64,45,233,0,48,160,227,1,64,160,227,0,0,80,227,4,0,0,27,1,51,204,229,2,0,0,235,252,255,255,10,16,64,189,232,30,255,47,225,1,195,160,227,8,50,204,229,184,32,92,225,2,0,17,224,0,32,34,16,184,32,76,17,8,66,204,229,30,255,47,225,15,80,45,233,1,3,160,227,15,224,160,225,4,240,16,229,15,80,189,232,4,240,94,226,68,208,159,229,0,80,45,233,0,192,79,225,0,224,15,225,0,80,45,233,2,195,160,227,156,224,220,229,165,0,94,227,4,0,0,26,180,224,220,5,128,224,30,2,4,224,143,226,24,240,159,21,24,240,159,5,24,208,159,229,0,80,189,232,12,240,105,225,0,80,189,232,4,240,94,226,240,127,0,3,0,32,254,9,0,192,255,9,224,127,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,23,8,0,184,32,8,0,120,41,8,0,56,50,8,0,248,58,8,0,184,67,8,0,120,76,8,0,56,85,8,0,14,0,0,0,62,3,0,0,2,0,0,0,2,0,0,0,78,0,0,0,0,0,0,0,216,196,0,0,10,0,0,0,56,103,0,0,20,1,0,0,152,101,0,0,19,1,0,0,192,105,0,0,17,1,0,0,56,104,0,0,18,1,0,0,32,188,0,0,13,0,0,0,232,186,0,0,15,1,0,0,144,186,0,0,9,0,0,0,176,185,0,0,21,1,0,0,216,184,0,0,127,0,0,0,64,184,0,0,23,1,0,0,216,183,0,0,22,1,0,0,104,183,0,0,47,1,0,0,24,182,0,0,48,1,0,0,144,181,0,0,50,1,0,0,32,180,0,0,52,1,0,0,152,179,0,0,32,0,0,0,80,179,0,0,27,0,0,0,216,178,0,0,14,1,0,0,128,178,0,0,13,1,0,0,24,178,0,0,14,1,0,0,192,177,0,0,13,1,0,0,144,177,0,0,26,1,0,0,88,176,0,0,27,1,0,0,8,176,0,0,28,1,0,0,200,175,0,0,29,1,0,0,152,175,0,0,30,1,0,0,104,175,0,0,31,1,0,0,16,175,0,0,32,1,0,0,216,174,0,0,33,1,0,0,168,174,0,0,34,1,0,0,104,174,0,0,35,1,0,0,32,174,0,0,36,1,0,0,208,172,0,0,37,1,0,0,96,172,0,0,48,0,0,0,224,171,0,0,49,0,0,0,128,171,0,0,50,0,0,0,16,171,0,0,51,0,0,0,96,170,0,0,52,0,0,0,16,170,0,0,53,0,0,0,112,169,0,0,54,0,0,0,24,169,0,0,55,0,0,0,192,168,0,0,56,0,0,0,128,167,0,0,57,0,0,0,16,167,0,0,24,1,0,0,16,166,0,0,25,1,0,0,144,165,0,0,0,1,0,0,64,165,0,0,1,1,0,0,168,164,0,0,2,1,0,0,160,164,0,0,3,1,0,0,112,164,0,0,4,1,0,0,64,164,0,0,5,1,0,0,248,163,0,0,6,1,0,0,200,163,0,0,7,1,0,0,96,162,0,0,8,1,0,0,32,162,0,0,9,1,0,0,176,161,0,0,46,0,0,0,32,161,0,0,45,1,0,0,208,160,0,0,44,1,0,0,128,160,0,0,8,0,0,0,88,160,0,0,12,1,0,0,24,160,0,0,11,1,0,0,208,159,0,0,60,1,0,0,152,159,0,0,46,1,0,0,120,158,0,0,96,0,0,0,224,157,0,0,96,0,0,0,120,157,0,0,19,0,0,0,32,157,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,40,111,0,0,120,117,0,0,0,0,0,0,1,0,0,0,0,0,0,0,232,77,0,0,168,88,0,0,1,0,0,0,1,0,0,0,0,0,0,0,80,108,0,0,184,70,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,107,0,0,232,54,0,0,3,0,0,0,1,0,0,0,0,0,0,0,192,105,0,0,168,194,0,0,4,0,0,0,1,0,0,0,0,0,0,0,56,104,0,0,32,178,0,0,5,0,0,0,1,0,0,0,0,0,0,0,56,103,0,0,184,169,0,0,6,0,0,0,1,0,0,0,0,0,0,0,152,101,0,0,72,160,0,0,7,0,0,0,1,0,0,0,0,0,0,0,48,100,0,0,112,152,0,0,8,0,0,0,1,0,0,0,0,0,0,0,120,78,0,0,232,144,0,0,9,0,0,0,1,0,0,0,0,0,0,0,224,94,0,0,152,132,0,0,10,0,0,0,1,0,0,0,0,0,0,0,184,161,0,0,64,125,0,0,11,0,0,0,1,0,0,0,0,0,0,0,72,93,0,0,248,119,0,0,12,0,0,0,1,0,0,0,0,0,0,0,48,92,0,0,64,117,0,0,13,0,0,0,1,0,0,0,0,0,0,0,88,91,0,0,152,114,0,0,14,0,0,0,1,0,0,0,0,0,0,0,32,90,0,0,192,109,0,0,15,0,0,0,1,0,0,0,0,0,0,0,72,89,0,0,8,107,0,0,16,0,0,0,1,0,0,0,0,0,0,0,56,88,0,0,88,104,0,0,17,0,0,0,1,0,0,0,0,0,0,0,176,87,0,0,216,101,0,0,18,0,0,0,1,0,0,0,0,0,0,0,216,85,0,0,8,99,0,0,19,0,0,0,1,0,0,0,0,0,0,0,136,83,0,0,96,94,0,0,20,0,0,0,1,0,0,0,0,0,0,0,24,82,0,0,120,92,0,0,21,0,0,0,1,0,0,0,0,0,0,0,32,80,0,0,72,90,0,0,22,0,0,0,1,0,0,0,0,0,0,0,120,79,0,0,80,88,0,0,23,0,0,0,1,0,0,0,0,0,0,0,56,79,0,0,88,86,0,0,24,0,0,0,1,0,0,0,1,0,0,0,240,78,0,0,48,82,0,0,25,0,0,0,1,0,0,0,2,0,0,0,128,78,0,0,176,79,0,0,26,0,0,0,1,0,0,0,1,0,0,0,240,77,0,0,16,79,0,0,27,0,0,0,1,0,0,0,1,0,0,0,144,77,0,0,24,78,0,0,28,0,0,0,1,0,0,0,2,0,0,0,208,76,0,0,80,77,0,0,29,0,0,0,1,0,0,0,2,0,0,0,80,75,0,0,240,166,0,0,30,0,0,0,1,0,0,0,2,0,0,0,168,74,0,0,80,73,0,0,31,0,0,0,1,0,0,0,2,0,0,0,200,73,0,0,64,72,0,0,32,0,0,0,1,0,0,0,1,0,0,0,24,73,0,0,40,198,0,0,33,0,0,0,1,0,0,0,2,0,0,0,168,72,0,0,136,69,0,0,34,0,0,0,1,0,0,0,2,0,0,0,24,72,0,0,32,67,0,0,35,0,0,0,1,0,0,0,2,0,0,0,128,71,0,0,56,65,0,0,36,0,0,0,1,0,0,0,2,0,0,0,168,70,0,0,64,64,0,0,37,0,0,0,1,0,0,0,2,0,0,0,240,69,0,0,72,63,0,0,38,0,0,0,1,0,0,0,2,0,0,0,80,69,0,0,32,62,0,0,39,0,0,0,1,0,0,0,2,0,0,0,192,67,0,0,24,59,0,0,40,0,0,0,1,0,0,0,2,0,0,0,224,66,0,0,56,57,0,0,41,0,0,0,1,0,0,0,2,0,0,0,232,65,0,0,16,56,0,0,42,0,0,0,1,0,0,0,2,0,0,0,16,65,0,0,192,54,0,0,43,0,0,0,1,0,0,0,2,0,0,0,160,64,0,0,152,53,0,0,44,0,0,0,1,0,0,0,2,0,0,0,32,64,0,0,0,51,0,0,45,0,0,0,1,0,0,0,2,0,0,0,200,63,0,0,208,49,0,0,46,0,0,0,1,0,0,0,2,0,0,0,24,63,0,0,216,48,0,0,47,0,0,0,1,0,0,0,2,0,0,0,104,62,0,0,32,48,0,0,48,0,0,0,1,0,0,0,2,0,0,0,216,61,0,0,176,200,0,0,49,0,0,0,1,0,0,0,2,0,0,0,200,59,0,0,200,197,0,0,50,0,0,0,1,0,0,0,2,0,0,0,240,58,0,0,200,196,0,0,51,0,0,0,1,0,0,0,2,0,0,0,184,57,0,0,120,195,0,0,52,0,0,0,1,0,0,0,2,0,0,0,16,57,0,0,240,193,0,0,53,0,0,0,1,0,0,0,2,0,0,0,128,56,0,0,240,191,0,0,54,0,0,0,1,0,0,0,1,0,0,0,240,55,0,0,168,188,0,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,178,11,0,64,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,106,2,0,0,6,0,0,0,48,159,0,0,0,0,0,0,28,0,0,0,10,0,0,0,102,0,0,0,4,1,0,0,2,0,0,0,8,0,0,0,64,0,0,0,58,0,0,0,0,0,0,0,56,0,0,0,8,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,2,0,0,0,42,0,0,0,16,0,0,0,2,0,0,0,92,0,0,0,16,0,0,0,24,0,0,0,78,0,0,0,74,0,0,0,66,0,0,0,34,0,0,0,20,0,0,0,2,0,0,0,152,48,0,0,2,0,0,0,56,48,0,0,0,0,0,0,36,48,0,0,8,0,0,0,35,48,0,0,8,0,0,0,34,48,0,0,8,0,0,0,33,48,0,0,8,0,0,0,51,48,0,0,4,0,0,0,56,48,0,0,0,0,0,0,28,0,0,0,84,0,0,0,16,0,0,0,134,1,0,0,20,0,0,0,38,0,0,0,2,0,0,0,46,0,0,0,4,0,0,0,2,0,0,0,24,0,0,0,36,0,0,0,20,0,0,0,84,0,0,0,38,0,0,0,2,0,0,0,0,0,0,0,104,158,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,50,0,0,0,0,0,0,0,27,0,0,0,0,0,0,0,96,188,0,0,120,56,0,0,232,175,0,0,0,0,0,0,0,2,0,0,0,0,0,0,176,176,11,0,4,0,0,0,192,176,11,0,4,0,0,0,216,176,11,0,4,0,0,0,224,176,11,0,4,0,0,0,184,176,11,0,1,0,0,0,8,52,7,0,0,2,0,0,200,176,11,0,16,0,0,0,0,0,0,0,0,0,0,0,8,52,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,16,183,29,200,32,110,59,172,48,217,38,144,65,220,118,244,81,107,107,88,97,178,77,60,113,5,80,32,131,184,237,68,147,15,240,232,163,214,214,140,179,97,203,176,194,100,155,212,210,211,134,120,226,10,160,28,242,189,189,0,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,85,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,120,111,0,0,2,0,0,0,112,95,0,0,3,0,0,0,240,83,0,0,5,0,0,0,128,75,0,0,4,0,0,0,248,23,8,0,184,32,8,0,120,41,8,0,56,50,8,0,248,58,8,0,184,67,8,0,120,76,8,0,56,85,8,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,84,0,0,0,88,0,0,0,4,5,0,0,2,0,0,0,104,173,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,16,66,8,32,0,0,74,41,0,0,0,0,0,0,168,175,212,87,0,0,128,248,226,232,35,0,0,0,136,170,168,138,0,0,192,164,100,82,116,0,0,132,16,0,0,0,0,0,136,8,33,132,32,8,0,130,32,132,16,34,2,0,0,144,234,42,1,0,0,0,16,242,9,1,0,0,0,0,0,0,32,2,0,0,0,240,1,0,0,0,0,0,0,0,32,0,0,16,34,68,136,16,1,0,192,197,88,99,116,0,0,128,24,66,8,113,0,0,192,69,200,68,248,0,0,192,69,200,96,116,0,0,0,49,149,62,66,0,0,224,135,240,96,116,0,0,128,137,240,98,116,0,0,224,67,132,8,17,0,0,192,197,232,98,116,0,0,192,197,232,33,50,0,0,0,0,2,0,1,0,0,0,0,2,0,17,0,0,0,64,54,24,4,0,0,0,128,15,62,0,0,0,0,4,131,77,0,0,0,192,69,136,8,32,0,0,192,135,214,122,240,0,0,128,16,165,92,140,0,0,224,197,248,98,124,0,0,192,197,16,66,116,0,0,224,164,24,99,58,0,0,224,135,240,66,248].concat([0,0,224,135,240,66,8,0,0,192,197,144,99,244,0,0,32,198,248,99,140,0,0,192,17,66,8,113,0,0,128,67,8,33,124,0,0,32,166,50,74,138,0,0,32,132,16,66,248,0,0,32,198,189,107,141,0,0,96,206,90,107,206,0,0,192,197,24,99,116,0,0,224,197,248,66,8,0,0,192,197,24,99,246,0,0,224,197,248,98,140,0,0,192,197,224,96,116,0,0,224,19,66,8,33,0,0,32,198,24,99,116,0,0,32,198,168,20,33,0,0,32,214,90,149,82,0,0,32,70,69,84,140,0,0,32,198,232,8,33,0,0,224,67,68,68,248,0,0,78,8,33,132,16,14,0,33,8,65,8,66,16,0,14,33,132,16,66,14,0,128,168,8,0,0,0,0,0,0,0,0,0,31,0,128,32,0,0,0,0,0,0,0,7,125,244,0,0,33,132,23,99,124,0,0,0,0,31,66,240,0,0,16,66,31,99,244,0,0,0,0,23,127,240,0,0,92,136,39,132,16,0,0,0,0,23,99,244,208,1,33,132,23,99,140,0,0,128,0,67,8,33,0,0,0,1,134,16,66,232,0,66,8,169,140,146,0,0,134,16,66,8,33,0,0,0,128,85,107,173,0,0,0,128,23,99,140,0,0,0,0,23,99,116,0,0,0,128,23,99,124,33,0,0,0,31,99,244,16,2,0,128,54,67,8,0,0,0,0,31,28,124,0,0,64,8,39,132,224,0,0,0,128,24,99,244,0,0,0,128,24,149,34,0,0,0,128,88,171,82,0,0,0,128,168,136,138,0,0,0,128,24,99,244,208,1,0,128,143,136,248,0,0,136,16,34,8,33,8,0,132,16,66,8,33,4,0,130,16,130,8,33,2,0,0,0,96,50,0,0,0,0,0,0,0,0,0,0,63,132,16,66,8,225,3,0,0,0,0,0,0,0,0,0,0,0,64,4,0,152,16,71,8,33,68,0,0,0,0,0,80,10,0,0,0,0,0,168,0,0,132,124,66,8,33,4,0,132,124,242,9,33,4,0,68,1,0,0,0,0,0,0,72,69,84,2,0,0,138,0,31,62,124,0,0,0,0,68,4,65,0,0,192,166,148,83,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,32,0,0,0,0,0,8,17,0,0,0,0,0,74,81,0,0,0,0,0,148,42,0,0,0,0,0,0,0,192,24,0,0,0,0,0,0,62,0,0,0,0,0,0,62,0,0,0,0,0,64,21,0,0,0,0,128,175,149,2,0,0,138,0,31,28,124,0,0,0,0,130,32,34,0,0,0,0,155,114,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,10,196,24,29,33,0,0,0,0,0,0,0,0,0,128,0,66,8,33,0,0,0,32,174,20,71,0,0,152,16,79,68,248,0,0,0,4,47,165,15,0,0,32,70,71,62,33,0,0,132,16,2,8,33,4,0,152,16,23,163,35,100,0,64,1,0,0,0,0,0,192,135,86,90,240,0,0,4,49,197,0,0,0,0,0,0,34,147,36,0,0,0,0,224,33,132,0,0,0,0,0,0,0,0,0,192,135,84,74,240,0,0,224,3,0,0,0,0,0,128,56,2,0,0,0,0,0,16,242,9,249,0,0,6,17,225,0,0,0,0,6,25,100,0,0,0,0,136,0,0,0,0,0,0,0,0,41,165,116,34,0,192,223,107,41,165,148,2,0,0,64,0,0,0,0,0,0,0,0,96,136,0,196,16,226,0,0,0,0,68,41,2,0,0,0,0,0,128,36,137,76,0,0,48,166,68,168,22,1,0,48,166,68,137,148,1,0,81,46,85,168,22,1,0,128,0,130,96,116,0,0,130,0,226,92,140,0,0,68,0,226,92,140,0,0,68,1,226,92,140,0,0,84,1,226,92,140,0,0,64,1,226,92,140,0,0,196,17,226,92,140,0,0,128,59,231,83,202,0,0,192,197,16,66,116,68,0,130,128,31,94,248,0,0,68,128,31,94,248,0,0,68,129,31,94,248,0,0,64,129,31,94,248,0,0,130,0,71,8,113,0,0,68,0,71,8,113,0,0,68,1,71,8,113,0,0,64,1,71,8,113,0,0,192,73,241,132,116,0,0,84,129,89,107,206,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,84,1,23,99,116,0,0,64,1,23,99,116,0,0,0,68,69,84,4,0,0,0,48,169,173,108,0,0,130,128,24,99,116,0,0,68,128,24,99,116,0,0,68,129,24,99,116,0,0,64,129,24,99,116,0,0,136,196,24,29,33,0,0,64,8,39,165,19,2,0,192,73,233,164,116,1,0,130,0,7,125,244,0,0,68,0,7,125,244,0,0,68,1,7,125,244,0,0,84,1,7,125,244,0,0,64,1,7,125,244,0,0,196,17,7,125,244,0,0,0,0,139,124,178,0,0,0,0,31,66,240,68,0,130,0,23,127,240,0,0,68,0,23,127,240,0,0,68,1,23,127,240,0,0,64,1,23,127,240,0,0,130,0,67,8,33,0,0,68,0,67,8,33,0,0,68,1,67,8,33,0,0,64,1,67,8,33,0,0,192,34,232,99,116,0,0,84,129,23,99,140,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,170,0,23,99,116,0,0,64,1,23,99,116,0,0,0,16,240,1,1,0,0,0,48,169,173,108,0,0,130,128,24,99,244,0,0,68,128,24,99,244,0,0,68,129,24,99,244,0,0,64,129,24,99,244,0,0,68,128,24,99,244,208,1,32,132,23,99,124,33,0,64,129,24,99,244,208,1,248,152,0,0,176,152,0,0,136,152,0,0,64,152,0,0,248,151,0,0,192,151,0,0,208,150,0,0,104,150,0,0,32,0,0,0,24,0,0,0,30,0,0,0,86,0,0,0,40,0,0,0,254,0,0,0,62,0,0,0,0,188,0,0,6,0,0,0,4,0,0,0,10,0,0,0,12,0,0,0,56,0,0,0,36,0,0,0,30,0,0,0,224,1,0,0,16,0,0,0,48,172,0,0,0,0,0,0,0,0,0,0,64,45,0,0,104,45,0,0,52,58,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,169,170,63,49,54,58,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,142,227,63,49,54,58,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,205,204,204,63,49,54,58,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,137,136,136,63,67,111,110,102,105,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,113,117,97,114,101,32,112,105,120,101,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,111,114,101,32,112,114,111,118,105,100,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,117,115,116,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,110,112,117,116,95,100,101,98,117,103,95,101,110,97,98,108,101,0,0,0,0,0,0,77,117,116,101,32,65,117,100,105,111,0,0,0,0,0,0,115,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,109,111,118,105,101,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,69,110,97,98,108,101,32,104,111,116,107,101,121,115,0,0,105,110,112,117,116,95,100,117,116,121,95,99,121,99,108,101,0,0,0,0,0,0,0,0,68,105,115,107,32,73,109,97,103,101,32,65,112,112,101,110,100,0,0,0,0,0,0,0,115,99,97,108,101,95,121,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,117,110,109,117,116,101,32,97,117,100,105,111,46,10,0,0,0,105,110,112,117,116,95,116,117,114,98,111,95,112,101,114,105,111,100,0,0,0,0,0,0,68,105,115,107,32,73,110,100,101,120,0,0,0,0,0,0,115,99,97,108,101,95,120,0,65,117,100,105,111,32,117,110,109,117,116,101,100,46,0,0,83,108,111,119,32,109,111,116,105,111,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,82,79,84,65,84,73,79,78,58,32,37,117,10,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,115,105,122,101,0,0,0,0,0,0,0,69,115,116,105,109,97,116,101,100,32,77,111,110,105,116,111,114,32,70,80,83,0,0,0,115,99,97,108,101,0,0,0,65,117,100,105,111,32,109,117,116,101,100,46,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,112,97,116,104,0,0,0,0,0,0,0,67,114,111,112,32,79,118,101,114,115,99,97,110,32,40,114,101,108,111,97,100,41,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,88,77,76,58,32,73,110,118,97,108,105,100,32,112,114,111,112,101,114,116,121,32,102,111,114,32,102,105,108,116,101,114,46,10,0,0,86,111,108,117,109,101,58,32,37,46,49,102,32,100,66,0,78,101,116,112,108,97,121,32,102,108,105,112,32,112,108,97,121,101,114,115,0,0,0,0,115,116,100,105,110,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,0,0,61,61,61,32,67,111,110,102,105,103,32,61,61,61,10,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,89,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,76,73,78,69,65,82,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,100,106,117,115,116,105,110,103,32,97,115,112,101,99,116,32,114,97,116,105,111,32,116,111,32,37,46,50,102,10,0,0,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,112,111,114,116,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,45,37,109,37,100,45,37,72,37,77,37,83,46,0,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,88,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,78,69,65,82,69,83,84,46,10,0,0,0,0,0,0,65,117,100,105,111,32,109,117,116,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,86,83,121,110,99,32,83,119,97,112,32,73,110,116,101,114,118,97,108,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,76,85,84,32,102,105,108,116,101,114,32,116,121,112,101,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,98,32,109,111,117,115,101,32,115,116,97,116,101,58,32,37,115,46,10,0,0,0,0,0,0,0,70,111,117,110,100,32,82,79,77,32,105,110,32,118,98,97,45,111,118,101,114,32,108,105,115,116,46,10,0,0,0,0,103,108,67,111,112,121,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,105,110,32,118,101,99,52,32,99,111,108,111,114,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,72,87,32,114,101,110,100,101,114,32,70,66,79,32,35,37,117,44,32,101,114,114,111,114,58,32,48,120,37,117,46,10,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,108,111,97,100,0,0,0,0,0,115,116,121,108,101,0,0,0,66,108,97,99,107,32,70,114,97,109,101,32,73,110,115,101,114,116,105,111,110,0,0,0,111,118,101,114,108,97,121,37,117,95,110,97,109,101,0,0,110,101,97,114,101,115,116,0,60,33,45,45,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,117,109,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,0,0,0,0,68,83,80,32,99,111,110,102,105,103,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,115,97,118,101,0,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,32,70,114,97,109,101,115,0,0,0,0,108,105,110,101,97,114,0,0,82,101,116,114,111,65,114,99,104,58,32,85,110,112,97,117,115,101,100,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,105,110,100,101,120,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,102,105,108,101,110,97,109,101,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,97,117,115,101,100,46,10,0,0,0,0,0,84,97,107,101,32,115,99,114,101,101,110,115,104,111,116,0,98,108,111,99,107,95,115,114,97,109,95,111,118,101,114,119,114,105,116,101,0,0,0,0,83,116,97,114,116,32,98,117,116,116,111,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,77,111,118,105,101,32,102,111,114,109,97,116,32,115,101,101,109,115,32,116,111,32,104,97,118,101,32,97,32,100,105,102,102,101,114,101,110,116,32,115,101,114,105,97,108,105,122,101,114,32,118,101,114,115,105,111,110,46,32,87,105,108,108,32,109,111,115,116,32,108,105,107,101,108,121,32,102,97,105,108,46,10,0,0,86,83,121,110,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,73,68,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,82,101,97,99,104,101,100,32,101,110,100,32,111,102,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,0,0,0,99,104,101,97,116,95,115,101,116,116,105,110,103,115,95,112,97,116,104,0,0,0,0,0,82,111,116,97,116,105,111,110,0,0,0,0,0,0,0,0,102,105,108,116,101,114,0,0,109,101,110,117,95,116,111,103,103,108,101,0,0,0,0,0,82,101,119,105,110,100,105,110,103,46,0,0,0,0,0,0,67,104,101,97,116,32,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,77,69,83,83,65,71,69,58,32,37,115,10,0,0,0,0,0,99,104,101,97,116,95,100,97,116,97,98,97,115,101,95,112,97,116,104,0,0,0,0,0,84,111,103,103,108,101,32,70,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,103,114,97,98,95,109,111,117,115,101,95,116,111,103,103,108,101,0,0,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,46,0,0,0,0,97,117,116,111,115,97,118,101,95,105,110,116,101,114,118,97,108,0,0,0,0,0,0,0,67,117,115,116,111,109,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,84,111,111,32,109,97,110,121,32,116,101,120,116,117,114,101,32,105,109,97,103,101,115,46,32,73,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,100,105,115,107,95,110,101,120,116,0,0,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,32,114,101,119,105,110,100,46,0,0,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,45,0,0,0,112,97,117,115,101,95,110,111,110,97,99,116,105,118,101,0,37,102,0,0,0,0,0,0,65,115,112,101,99,116,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,65,77,32,97,100,100,114,101,115,115,32,115,112,101,99,105,102,105,99,101,100,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,100,105,115,107,95,101,106,101,99,116,95,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,10,0,0,0,0,0,0,0,37,115,32,124,124,32,70,80,83,58,32,37,54,46,49,102,32,124,124,32,70,114,97,109,101,115,58,32,37,100,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,117,100,105,111,32,114,97,116,101,32,99,111,110,116,114,111,108,32,119,97,115,32,100,101,115,105,114,101,100,44,32,98,117,116,32,100,114,105,118,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,110,101,101,100,101,100,32,102,101,97,116,117,114,101,115,46,10,0,0,0,0,0,0,0,102,97,115,116,102,111,114,119,97,114,100,95,114,97,116,105,111,0,0,0,0,0,0,0,102,105,108,101,95,112,97,116,104,46,99,0,0,0,0,0,73,110,116,101,103,101,114,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,105,110,112,117,116,32,115,108,111,116,32,102,111,114,32,105,109,112,111,114,116,46,10,0,0,0,0,111,118,101,114,108,97,121,95,110,101,120,116,0,0,0,0,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,43,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,115,108,111,119,109,111,116,105,111,110,95,114,97,116,105,111,0,0,0,0,0,0,0,0,83,104,97,100,101,114,32,79,112,116,105,111,110,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,118,111,108,117,109,101,95,100,111,119,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,71,97,109,101,73,68,32,105,110,32,82,79,77,32,105,115,58,32,37,115,10,0,0,0,103,108,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,79,69,83,95,112,97,99,107,101,100,95,100,101,112,116,104,95,115,116,101,110,99,105,108,0,0,0,0,0,0,0,0,114,101,119,105,110,100,95,103,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,71,76,83,76,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,83,99,97,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,110,102,105,103,32,107,101,121,58,32,37,115,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,111,114,32,73,68,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,118,111,108,117,109,101,95,117,112,0,0,0,0,0,0,0,61,34,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,80,114,101,118,105,111,117,115,32,115,104,97,100,101,114,0,114,101,119,105,110,100,95,98,117,102,102,101,114,95,115,105,122,101,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,70,105,108,116,101,114,0,0,0,0,0,0,0,101,113,117,97,108,0,0,0,101,110,97,98,108,101,95,104,111,116,107,101,121,0,0,0,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,97,118,101,32,115,116,97,116,101,115,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,114,101,119,105,110,100,95,101,110,97,98,108,101,0,0,0,83,104,97,100,101,114,32,35,37,117,0,0,0,0,0,0,109,97,115,107,0,0,0,0,115,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,0,0,78,101,120,116,32,115,104,97,100,101,114,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,115,99,97,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,115,116,97,116,101,32,102,114,111,109,32,109,111,118,105,101,46,10,0,0,0,83,104,97,100,101,114,32,80,97,115,115,101,115,0,0,0,105,110,112,117,116,95,115,108,111,116,0,0,0,0,0,0,110,101,116,112,108,97,121,95,102,108,105,112,95,112,108,97,121,101,114,115,0,0,0,0,37,115,46,98,115,118,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,111,112,97,99,105,116,121,0,0,0,76,111,97,100,32,83,104,97,100,101,114,32,80,114,101,115,101,116,0,0,0,0,0,0,119,114,97,109,0,0,0,0,97,117,100,105,111,95,109,117,116,101,0,0,0,0,0,0,37,115,37,117,46,98,115,118,0,0,0,0,0,0,0,0,82,101,115,101,116,32,103,97,109,101,0,0,0,0,0,0,46,114,101,116,114,111,97,114,99,104,45,99,111,114,101,45,111,112,116,105,111,110,115,46,99,102,103,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,0,0,0,68,101,102,97,117,108,116,32,70,105,108,116,101,114,0,0,115,101,109,97,110,116,105,99,0,0,0,0,0,0,0,0,100,115,112,95,99,111,110,102,105,103,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,0,111,118,101,114,108,97,121,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,65,112,112,108,121,32,83,104,97,100,101,114,32,67,104,97,110,103,101,115,0,0,0,0,105,100,0,0,0,0,0,0,115,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,70,114,97,109,101,97,100,118,97,110,99,101,0,0,0,0,114,103,117,105,95,98,114,111,119,115,101,114,95,100,105,114,101,99,116,111,114,121,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,101,110,100,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,37,115,32,40,37,100,44,32,37,100,32,58,32,37,52,117,120,37,52,117,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,111,111,32,109,97,110,121,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,115,32,46,46,46,10,0,0,0,0,0,99,104,101,97,116,95,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,108,121,32,115,104,97,100,101,114,46,10,0,0,0,0,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,110,32,101,120,105,115,116,105,110,103,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,83,101,116,32,66,111,116,116,111,109,45,82,105,103,104,116,32,67,111,114,110,101,114,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,80,121,116,104,111,110,32,115,99,114,105,112,116,46,10,0,0,0,0,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,109,105,110,117,115,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,0,80,97,117,115,101,32,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,100,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,0,0,0,0,83,101,116,32,85,112,112,101,114,45,76,101,102,116,32,67,111,114,110,101,114,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,108,97,110,103,117,97,103,101,32,105,115,32,110,111,116,32,80,121,116,104,111,110,46,10,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,112,108,117,115,0,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,58,32,34,37,115,34,46,0,0,0,0,0,0,0,103,108,84,101,120,73,109,97,103,101,51,68,79,69,83,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,116,97,116,101,32,116,114,97,99,107,101,114,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,77,97,120,32,116,101,120,116,117,114,101,32,115,105,122,101,58,32,37,100,32,112,120,44,32,114,101,110,100,101,114,98,117,102,102,101,114,32,115,105,122,101,58,32,37,117,32,112,120,46,10,0,0,0,0,99,111,114,101,95,111,112,116,105,111,110,115,95,112,97,116,104,0,0,0,0,0,0,0,78,47,65,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,66,105,116,32,100,101,112,116,104,32,111,102,32,84,71,65,32,105,109,97,103,101,32,105,115,32,119,114,111,110,103,46,32,79,110,108,121,32,51,50,45,98,105,116,32,97,110,100,32,50,52,45,98,105,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,37,115,32,40,37,52,117,120,37,52,117,44,32,37,117,32,120,32,37,117,32,115,99,97,108,101,41,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,111,118,101,114,108,97,121,0,0,0,0,0,0,0,99,108,97,115,115,0,0,0,115,104,97,100,101,114,95,112,114,101,118,0,0,0,0,0,32,10,9,12,11,13,0,0,82,101,116,114,111,65,114,99,104,58,32,9,9,37,115,10,0,0,0,0,0,0,0,0,46,99,103,112,0,0,0,0,77,111,118,105,101,32,114,101,99,111,114,100,32,116,111,103,103,108,101,0,0,0,0,0,108,105,98,114,101,116,114,111,95,112,97,116,104,0,0,0,83,101,116,32,115,99,97,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,97,108,114,101,97,100,121,32,105,109,112,111,114,116,101,100,46,10,0,0,115,104,97,100,101,114,95,110,101,120,116,0,0,0,0,0,46,99,103,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,117,115,101,115,32,116,104,114,101,97,100,101,100,32,97,117,100,105,111,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,0,105,110,112,117,116,95,106,111,121,112,97,100,95,100,114,105,118,101,114,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,67,71,80,32,102,97,105,108,101,100,46,10,0,0,63,63,63,0,0,0,0,0,114,101,115,101,116,0,0,0,46,115,104,97,100,101,114,0,83,101,108,101,99,116,32,98,117,116,116,111,110,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,82,67,51,50,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,82,79,77,32,102,105,108,101,32,97,110,100,32,115,97,118,101,100,32,82,79,77,32,99,104,101,99,107,115,117,109,32,105,110,32,114,101,112,108,97,121,32,102,105,108,101,32,104,101,97,100,101,114,59,32,114,101,112,108,97,121,32,104,105,103,104,108,121,32,108,105,107,101,108,121,32,116,111,32,100,101,115,121,110,99,32,111,110,32,112,108,97,121,98,97,99,107,46,10,0,78,47,65,32,40,115,116,111,99,107,41,0,0,0,0,0,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,0,102,114,97,109,101,95,97,100,118,97,110,99,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,111,116,32,105,110,118,97,108,105,100,32,100,105,115,107,32,105,110,100,101,120,32,102,114,111,109,32,108,105,98,114,101,116,114,111,46,10,0,0,0,0,0,97,117,100,105,111,95,100,115,112,95,112,108,117,103,105,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,0,114,101,112,101,97,116,0,0,112,97,117,115,101,95,116,111,103,103,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,66,83,82,77,58,32,37,115,10,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,45,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,86,65,82,73,65,66,76,69,83,46,10,0,0,0,0,0,0,97,117,100,105,111,95,100,114,105,118,101,114,0,0,0,0,37,115,32,40,37,115,41,0,99,108,97,109,112,95,116,111,95,101,100,103,101,0,0,0,109,111,118,105,101,95,114,101,99,111,114,100,95,116,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,83,82,77,58,32,37,115,10,0,0,0,0,118,105,100,101,111,95,103,108,95,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,60,85,115,101,32,116,104,105,115,32,100,105,114,101,99,116,111,114,121,62,0,0,0,0,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,0,114,101,119,105,110,100,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,83,117,102,97,109,105,32,116,117,114,98,111,32,65,47,66,32,82,65,77,46,10,0,0,0,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,43,0,0,0,0,0,0,0,0,118,105,100,101,111,95,100,114,105,118,101,114,0,0,0,0,37,48,50,120,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,101,110,100,105,110,103,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,37,115,124,122,105,112,0,0,97,98,115,111,108,117,116,101,0,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,100,101,99,114,101,97,115,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,83,82,77,58,32,37,115,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,114,101,115,97,109,112,108,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,97,117,100,105,111,95,118,111,108,117,109,101,0,0,0,0,91,86,66,65,93,32,83,121,110,99,32,115,116,97,116,115,58,32,65,117,100,105,111,32,102,114,97,109,101,115,58,32,37,117,44,32,86,105,100,101,111,32,102,114,97,109,101,115,58,32,37,117,44,32,65,70,47,86,70,58,32,37,46,50,102,10,0,0,0,0,0,0,99,102,103,0,0,0,0,0,118,105,101,119,112,111,114,116,0,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,105,110,99,114,101,97,115,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,32,37,115,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,32,98,117,102,102,101,114,46,10,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,95,100,101,108,116,97,0,0,0,0,0,0,0,0,99,103,124,103,108,115,108,0,115,111,117,114,99,101,0,0,101,120,105,116,95,101,109,117,108,97,116,111,114,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,66,83,88,32,40,80,41,82,65,77,46,10,0,0,80,76,84,69,0,0,0,0,103,108,71,101,116,66,117,102,102,101,114,80,111,105,110,116,101,114,118,79,69,83,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,76,85,84,115,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,32,72,87,32,114,101,110,100,101,114,32,40,37,117,32,120,32,37,117,41,46,10,0,0,0,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,84,71,65,32,112,105,120,101,108,115,46,10,0,0,0,0,115,104,97,100,101,114,0,0,99,103,112,124,103,108,115,108,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,111,118,101,114,108,97,121,32,99,97,108,108,101,100,58,32,34,37,115,34,46,10,0,0,0,0,115,99,97,108,101,95,37,115,37,117,0,0,0,0,0,0,116,111,103,103,108,101,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,67,104,101,97,116,58,32,35,37,117,32,91,37,115,93,58,32,37,115,0,0,0,0,0,60,47,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,80,111,115,115,105,98,108,101,32,118,97,108,117,101,115,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,71,97,109,101,98,111,121,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,116,111,103,103,108,101,0,0,0,0,0,0,0,97,117,100,105,111,95,115,121,110,99,0,0,0,0,0,0,47,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,95,37,115,37,117,0,115,97,118,101,95,115,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,84,67,58,32,37,115,10,0,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,0,0,0,0,0,97,117,100,105,111,95,108,97,116,101,110,99,121,0,0,0,37,99,32,37,45,42,46,42,115,32,37,45,42,115,0,0,121,0,0,0,0,0,0,0,108,111,97,100,95,115,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,37,115,10,0,0,0,0,0,83,97,118,101,32,115,116,97,116,101,0,0,0,0,0,0,97,117,100,105,111,95,100,101,118,105,99,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,118,105,101,32,102,105,108,101,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,66,83,86,49,32,102,105,108,101,46,10,0,0,0,0,0,0,120,0,0,0,0,0,0,0,104,111,108,100,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,114,101,103,117,108,97,114,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,97,117,100,105,111,95,98,108,111,99,107,95,102,114,97,109,101,115,0,0,0,0,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,37,117,0,0,0,0,0,116,111,103,103,108,101,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,102,97,105,108,101,100,0,0,76,111,97,100,32,115,116,97,116,101,0,0,0,0,0,0,97,117,100,105,111,95,111,117,116,95,114,97,116,101,0,0,63,0,0,0,0,0,0,0,114,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,115,117,99,99,101,101,100,101,100,0,0,0,0,0,0,0,97,117,100,105,111,95,101,110,97,98,108,101,0,0,0,0,85,110,107,110,111,119,110,0,112,121,116,104,111,110,0,0,114,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,117,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,32,37,115,46,10,0,70,97,115,116,32,102,111,114,119,97,114,100,32,104,111,108,100,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,37,117,95,106,111,121,112,97,100,95,105,110,100,101,120,0,0,0,0,0,44,0,0,0,0,0,0,0,102,97,108,115,101,0,0,0,83,117,112,101,114,83,99,111,112,101,0,0,0,0,0,0])
.concat([116,114,97,110,115,105,116,105,111,110,95,112,114,101,118,105,111,117,115,0,0,0,0,0,114,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,46,97,117,116,111,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,110,101,116,112,108,97,121,95,99,108,105,101,110,116,95,115,119,97,112,95,105,110,112,117,116,0,0,0,0,0,0,0,70,114,111,110,116,101,110,100,32,115,117,112,112,111,114,116,115,32,82,71,66,53,54,53,32,45,32,119,105,108,108,32,117,115,101,32,116,104,97,116,32,105,110,115,116,101,97,100,32,111,102,32,88,82,71,66,49,53,53,53,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,100,105,114,101,99,116,111,114,121,58,32,34,37,115,34,10,0,0,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,0,74,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,99,97,112,116,117,114,101,95,112,114,101,118,105,111,117,115,0,0,0,0,0,0,0,0,114,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,45,118,0,0,0,0,0,0,70,97,115,116,32,102,111,114,119,97,114,100,32,116,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,105,110,112,117,116,95,97,120,105,115,95,116,104,114,101,115,104,111,108,100,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,74,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,95,99,111,117,110,116,0,0,0,0,0,0,0,0,108,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,45,99,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,105,108,101,32,67,82,67,32,100,105,102,102,101,114,115,32,102,114,111,109,32,90,73,80,32,67,82,67,46,32,70,105,108,101,58,32,48,120,37,120,44,32,90,73,80,58,32,48,120,37,120,46,10,0,0,0,0,0,0,73,69,78,68,0,0,0,0,103,108,85,110,109,97,112,66,117,102,102,101,114,79,69,83,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,83,76,32,115,116,111,99,107,32,112,114,111,103,114,97,109,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,37,117,32,116,101,120,116,117,114,101,115,46,10,0,0,0,0,0,0,100,101,102,97,117,108,116,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,101,100,32,84,71,65,58,32,40,37,117,120,37,117,32,64,32,37,117,32,98,112,112,41,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,0,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,0,0,0,77,111,117,115,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,111,108,118,101,32,110,101,120,116,32,116,97,114,103,101,116,115,46,10,0,0,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,0,0,0,0,0,0,108,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,110,121,32,99,104,101,97,116,115,32,105,110,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,93,93,62,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,67,117,114,114,101,110,116,32,118,97,108,117,101,58,32,37,115,10,0,0,45,83,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,100,105,114,0,0,0,0,0,0,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,66,79,32,116,101,120,116,117,114,101,115,32,101,120,99,101,101,100,101,100,32,109,97,120,105,109,117,109,32,115,105,122,101,32,111,102,32,71,80,85,32,40,37,117,120,37,117,41,46,32,82,101,115,105,122,105,110,103,32,116,111,32,102,105,116,46,10,0,0,0,0,0,0,0,0,77,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,99,97,112,116,117,114,101,0,108,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,45,115,0,0,0,0,0,0,118,105,100,101,111,95,103,112,117,95,115,99,114,101,101,110,115,104,111,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,66,79,32,112,97,115,115,32,35,37,100,32,105,115,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,46,10,0,0,0,0,0,74,111,121,112,97,100,32,119,47,32,65,110,97,108,111,103,0,0,0,0,0,0,0,0,37,115,95,101,113,117,97,108,0,0,0,0,0,0,0,0,108,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,45,45,109,101,110,117,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,85,78,83,85,80,80,79,82,84,69,68,32,40,35,37,117,41,46,10,0,0,118,105,100,101,111,95,103,112,117,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,89,32,98,117,116,116,111,110,32,40,108,101,102,116,41,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,109,111,118,105,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,32,101,120,116,101,110,115,105,111,110,32,110,111,116,32,102,111,117,110,100,46,10,0,0,0,0,0,74,111,121,112,97,100,0,0,37,115,95,109,97,115,107,0,116,117,114,98,111,0,0,0,82,101,116,114,111,65,114,99,104,58,32,78,111,32,82,79,77,44,32,115,116,97,114,116,105,110,103,32,100,117,109,109,121,32,99,111,114,101,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,46,10,0,0,0,0,0,118,105,100,101,111,95,112,111,115,116,95,102,105,108,116,101,114,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,104,97,100,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,0,0,0,0,0,0,0,0,78,111,110,101,0,0,0,0,37,115,95,105,110,112,117,116,95,115,108,111,116,0,0,0,114,51,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,82,79,77,58,32,37,115,46,10,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,95,69,83,67,65,80,69,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,37,115,10,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,99,111,108,111,114,0,0,0,0,0,46,98,114,97,109,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,118,101,114,115,105,111,110,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,117,112,32,102,114,97,109,101,32,98,117,102,102,101,114,32,111,98,106,101,99,116,115,46,32,77,117,108,116,105,45,112,97,115,115,32,115,104,97,100,105,110,103,32,119,105,108,108,32,110,111,116,32,119,111,114,107,46,10,0,0,37,115,95,119,114,97,109,0,108,51,0,0,0,0,0,0,114,101,116,114,111,97,114,99,104,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,83,69,84,95,76,73,66,82,69,84,82,79,95,80,65,84,72,46,10,0,0,0,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,104,101,105,103,104,116,0,0,46,97,114,97,109,0,0,0,35,118,101,114,115,105,111,110,32,37,117,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,0,0,0,78,47,65,32,40,112,111,114,116,32,35,37,117,41,0,0,37,115,95,115,101,109,97,110,116,105,99,0,0,0,0,0,114,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,70,82,65,77,69,95,84,73,77,69,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,119,105,100,116,104,0,0,0,115,101,116,116,105,110,103,115,46,99,0,0,0,0,0,0,46,112,114,97,109,0,0,0,35,118,101,114,115,105,111,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,35,37,100,0,0,0,0,0,49,0,0,0,0,0,0,0,108,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,109,111,118,105,110,103,32,116,101,109,112,111,97,114,121,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,110,111,0,0,0,0,0,0,100,114,105,118,101,114,46,99,0,0,0,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,121,0,0,0,0,0,0,0,46,114,116,99,0,0,0,0,46,46,0,0,0,0,0,0,86,66,65,32,78,101,120,116,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,98,105,110,100,32,65,80,73,32,37,115,32,116,111,32,99,111,110,116,101,120,116,32,37,115,46,10,0,0,0,0,0,0,37,46,50,102,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,65,77,32,119,105,108,108,32,110,111,116,32,98,101,32,115,97,118,101,100,46,10,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,0,121,101,115,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,120,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,105,110,107,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,0,0,0,0,0,79,112,101,110,71,76,32,69,83,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,107,105,112,112,105,110,103,32,83,82,65,77,32,108,111,97,100,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,97,110,121,32,82,79,77,83,32,116,104,97,116,32,109,97,116,99,104,101,100,32,118,97,108,105,100,32,101,120,116,101,110,115,105,111,110,115,32,102,111,114,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,73,68,65,84,0,0,0,0,103,108,77,97,112,66,117,102,102,101,114,79,69,83,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,99,111,110,116,101,120,116,32,105,115,32,117,115,101,100,44,32,98,117,116,32,115,104,97,100,101,114,32,105,115,32,110,111,116,32,109,111,100,101,114,110,46,32,67,97,110,110,111,116,32,117,115,101,32,105,116,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,68,105,109,101,110,115,105,111,110,115,58,32,37,117,120,37,117,10,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,83,85,80,80,79,82,84,95,78,79,95,71,65,77,69,58,32,37,115,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,109,117,108,116,105,112,97,115,115,32,115,104,97,100,101,114,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,68,73,83,75,32,65,80,80,69,78,68,32,37,115,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,121,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,71,65,32,105,109,97,103,101,32,105,115,32,110,111,116,32,117,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,46,46,46,32,67,97,110,110,111,116,32,114,101,99,111,118,101,114,32,115,97,118,101,32,102,105,108,101,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,88,77,76,32,115,104,97,100,101,114,58,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,105,110,103,32,71,76,83,76,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,46,10,51,50,45,98,105,116,32,112,97,116,104,32,119,105,108,108,32,114,101,113,117,105,114,101,32,99,111,110,118,101,114,115,105,111,110,46,10,0,0,0,60,82,79,77,32,100,105,114,62,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,103,114,97,98,32,99,104,101,97,116,115,46,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,0,0,60,33,91,67,68,65,84,65,91,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,75,101,121,58,32,37,115,10,0,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,10,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,117,110,107,110,111,119,110,32,99,111,110,116,101,120,116,46,10,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,120,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,99,99,101,101,100,101,100,32,105,110,32,115,97,118,105,110,103,32,82,65,77,32,100,97,116,97,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,32,102,111,117,110,100,32,102,111,114,32,71,76,69,83,46,10,0,0,0,0,60,100,101,102,97,117,108,116,62,0,0,0,0,0,0,0,105,109,112,111,114,116,115,0,97,0,0,0,0,0,0,0,61,61,61,32,66,117,105,108,100,32,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,32,99,111,110,116,101,120,116,44,32,98,117,116,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,79,112,101,110,71,76,69,83,50,46,32,67,97,110,110,111,116,32,117,115,101,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,99,97,108,101,0,0,0,0,0,0,0,0,102,105,110,100,95,97,117,100,105,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,37,89,45,37,109,45,37,100,45,37,72,45,37,77,45,37,83,0,0,0,0,0,0,0,35,100,101,102,105,110,101,32,70,82,65,71,77,69,78,84,10,0,0,0,0,0,0,0,66,71,82,65,56,56,56,56,0,0,0,0,0,0,0,0,37,46,51,102,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,95,99,108,97,115,115,0,0,0,0,0,114,105,103,104,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,116,97,108,32,101,114,114,111,114,32,114,101,99,101,105,118,101,100,32,105,110,58,32,34,37,115,34,10,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,69,83,50,32,99,111,110,116,101,120,116,46,10,0,0,0,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,101,110,97,98,108,101,0,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,97,117,100,105,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,37,115,47,82,101,116,114,111,65,114,99,104,45,114,101,99,111,118,101,114,121,45,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,112,108,97,121,98,97,99,107,46,10,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,104,97,100,101,114,44,32,102,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,0,0,0,108,101,102,116,0,0,0,0,90,73,80,124,122,105,112,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,110,111,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,105,122,101,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,97,117,100,105,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,0,0,37,46,51,102,32,72,122,32,40,37,46,49,102,37,37,32,100,101,118,44,32,37,117,32,115,97,109,112,108,101,115,41,0,0,0,0,0,0,0,0,37,115,95,119,114,97,112,95,109,111,100,101,0,0,0,0,100,111,119,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,58,32,37,115,32,37,115,0,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,72,87,95,82,69,78,68,69,82,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,86,65,82,73,65,66,76,69,32,37,115,58,10,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,112,97,116,104,0,102,105,110,100,95,118,105,100,101,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,79,77,32,105,115,32,117,115,101,100,44,32,98,117,116,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,116,104,105,115,46,10,0,0,35,100,101,102,105,110,101,32,86,69,82,84,69,88,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,118,97,108,105,100,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,32,67,111,110,116,105,110,117,105,110,103,32,119,105,116,104,111,117,116,32,115,104,97,100,101,114,115,46,10,0,0,0,0,0,0,0,37,46,49,102,120,0,0,0,37,115,95,108,105,110,101,97,114,0,0,0,0,0,0,0,117,112,0,0,0,0,0,0,83,101,116,116,105,110,103,32,114,101,102,114,101,115,104,32,114,97,116,101,32,116,111,58,32,37,46,51,102,32,72,122,46,0,0,0,0,0,0,0,118,48,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,68,73,83,75,95,67,79,78,84,82,79,76,95,73,78,84,69,82,70,65,67,69,46,10,0,118,105,100,101,111,95,97,108,108,111,119,95,114,111,116,97,116,101,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,118,105,100,101,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,32,105,110,32,34,37,115,34,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,118,101,114,116,101,120,32,115,104,97,100,101,114,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,10,0,0,0,0,37,117,0,0,0,0,0,0,116,101,120,116,117,114,101,115,0,0,0,0,0,0,0,0,115,116,97,114,116,0,0,0,84,117,114,98,111,32,101,110,97,98,108,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,75,69,89,66,79,65,82,68,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,101,110,97,98,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,118,105,100,101,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,116,99,104,32,37,115,58,32,69,114,114,111,114,32,35,37,117,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,71,76,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,78,111,116,32,108,111,97,100,105,110,103,32,97,110,121,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,59,0,0,0,0,0,0,0,115,101,108,101,99,116,0,0,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,82,101,116,114,111,80,97,100,44,32,80,108,97,121,101,114,32,37,117,44,32,66,117,116,116,111,110,32,34,37,115,34,32,61,62,32,34,37,115,34,10,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,0,0,0,0,102,105,110,100,95,105,110,112,117,116,95,100,114,105,118,101,114,40,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,112,97,116,99,104,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,40,37,115,41,46,10,0,0,0,0,0,0,46,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,71,76,83,76,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,110,32,115,112,101,99,105,102,105,101,100,32,71,76,32,101,114,114,111,114,46,10,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,37,117,0,0,0,0,0,0,0,118,49,46,48,46,50,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,100,105,115,107,32,37,117,32,111,102,32,37,117,46,0,0,0,0,82,51,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,73,78,80,85,84,95,68,69,83,67,82,73,80,84,79,82,83,58,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,68,105,100,110,39,116,32,114,101,97,100,32,119,104,111,108,101,32,102,105,108,101,46,10,0,0,0,0,118,105,100,101,111,95,114,101,102,114,101,115,104,95,114,97,116,101,0,0,0,0,0,0,9,37,115,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,112,97,116,99,104,101,100,32,82,79,77,32,46,46,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,79,117,116,32,111,102,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,119,114,97,112,95,109,111,100,101,37,117,0,0,0,0,0,98,0,0,0,0,0,0,0,82,101,109,111,118,101,100,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,82,101,116,114,111,65,114,99,104,58,32,79,70,70,83,69,84,58,32,37,117,44,32,67,83,73,90,69,58,32,37,117,44,32,83,73,90,69,58,32,37,117,46,10,0,0,0,0,73,72,68,82,0,0,0,0,103,108,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,83,116,111,99,107,32,71,76,83,76,32,115,104,97,100,101,114,115,32,119,105,108,108,32,98,101,32,117,115,101,100,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,65,116,116,101,109,112,116,101,100,32,116,111,32,114,101,45,105,110,105,116,105,97,108,105,122,101,32,100,114,105,118,101,114,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,67,97,110,110,111,116,32,102,105,110,100,32,115,104,97,100,101,114,32,99,111,114,101,32,102,111,114,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,0,0,0,67,79,82,69,32,83,69,76,69,67,84,73,79,78,32,37,115,0,0,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,95,97,117,116,111,0,99,103,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,65,118,97,105,108,97,98,108,101,32,105,110,112,117,116,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,37,115,32,102,105,108,101,32,105,110,32,34,37,115,34,44,32,97,116,116,101,109,112,116,105,110,103,32,116,111,32,112,97,116,99,104,32,46,46,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,111,112,101,114,97,116,105,111,110,46,10,0,0,0,0,79,70,70,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,111,118,101,114,108,97,121,115,32,118,97,114,105,97,98,108,101,32,110,111,116,32,100,101,102,105,110,101,100,32,105,110,32,99,111,110,102,105,103,46,10,0,0,102,105,108,116,101,114,95,108,105,110,101,97,114,37,117,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,115,97,116,117,114,97,116,101,95,112,99,116,0,0,0,115,104,97,50,53,54,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,105,109,97,103,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,60,47,37,115,62,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,68,101,115,99,114,105,112,116,105,111,110,58,32,37,115,10,0,0,0,0,83,101,116,116,105,110,103,32,100,105,115,107,32,37,117,32,111,102,32,37,117,32,105,110,32,116,114,97,121,46,0,0,76,51,32,98,117,116,116,111,110,32,40,108,101,102,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,0,97,115,112,101,99,116,95,114,97,116,105,111,95,105,110,100,101,120,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,105,110,112,117,116,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,32,118,97,108,105,100,32,82,79,77,32,112,97,116,99,104,46,10,0,0,0,0,0,114,117,98,121,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,79,78,0,0,0,0,0,0,115,104,97,100,101,114,37,117,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,65,110,97,108,111,103,32,104,105,116,98,111,120,32,116,121,112,101,32,109,117,115,116,32,98,101,32,34,114,97,100,105,97,108,34,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,37,115,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,32,46,46,46,10,0,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,32,97,117,100,105,111,32,105,110,112,117,116,32,114,97,116,101,32,116,111,58,32,37,46,50,102,32,72,122,46,10,0,0,0,73,80,83,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,101,110,117,109,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,88,77,76,32,115,104,97,100,101,114,32,46,46,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,72,105,116,98,111,120,32,116,121,112,101,32,40,37,115,41,32,105,115,32,105,110,118,97,108,105,100,46,32,85,115,101,32,34,114,97,100,105,97,108,34,32,111,114,32,34,114,101,99,116,34,46,10,0,0,0,99,108,111,115,101,0,0,0,82,50,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,118,105,100,101,111,95,99,114,111,112,95,111,118,101,114,115,99,97,110,0,0,0,0,0,66,32,98,117,116,116,111,110,32,40,100,111,119,110,41,0,37,117,58,37,117,32,40,49,58,49,32,80,65,82,41,0,82,101,116,114,111,65,114,99,104,58,32,71,97,109,101,32,70,80,83,32,62,32,77,111,110,105,116,111,114,32,70,80,83,46,32,67,97,110,110,111,116,32,114,101,108,121,32,111,110,32,86,83,121,110,99,46,10,0,0,0,0,0,0,0,66,80,83,0,0,0,0,0,118,98,97,109,45,110,101,120,116,45,103,97,109,101,112,97,100,0,0,0,0,0,0,0,84,101,120,116,117,114,101,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,76,111,97,100,101,100,32,37,117,32,112,114,111,103,114,97,109,40,115,41,46,10,0,0,0,78,101,97,114,101,115,116,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,110,111,114,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,105,110,32,88,77,76,32,102,105,108,101,46,10,0,0,0,0,0,0,114,101,99,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,97,100,106,117,115,116,101,100,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,115,105,122,101,32,116,111,32,37,117,32,77,105,66,10,0,0,0,0,0,101,106,101,99,116,0,0,0,118,105,100,101,111,95,115,99,97,108,101,95,105,110,116,101,103,101,114,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,84,105,109,105,110,103,115,32,100,101,118,105,97,116,101,32,116,111,111,32,109,117,99,104,46,32,87,105,108,108,32,110,111,116,32,97,100,106,117,115,116,46,32,40,68,105,115,112,108,97,121,32,61,32,37,46,50,102,32,72,122,44,32,71,97,109,101,32,61,32,37,46,50,102,32,72,122,41,10,0,0,0,0,0,0,85,80,83,0,0,0,0,0,103,108,71,101,116,80,111,105,110,116,101,114,118,0,0,0,37,115,37,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,105,110,105,116,32,102,97,105,108,101,100,46,10,0,76,105,110,101,97,114,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,114,97,100,105,97,108,0,0,70,97,105,108,101,100,32,116,111,32,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,76,50,32,98,117,116,116,111,110,32,40,108,101,102,116,32])
.concat([115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,67,65,78,95,68,85,80,69,58,32,116,114,117,101,10,0,0,118,105,100,101,111,95,102,111,114,99,101,95,97,115,112,101,99,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,117,100,105,111,32,98,97,99,107,101,110,100,32,102,97,105,108,101,100,32,116,111,32,119,114,105,116,101,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,115,111,117,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,109,111,117,110,116,32,111,102,32,116,105,109,101,32,115,112,101,110,116,32,99,108,111,115,101,32,116,111,32,117,110,100,101,114,114,117,110,58,32,37,46,50,102,32,37,37,46,32,67,108,111,115,101,32,116,111,32,98,108,111,99,107,105,110,103,58,32,37,46,50,102,32,37,37,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,115,99,111,112,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,101,118,101,114,97,108,32,112,97,116,99,104,101,115,32,97,114,101,32,101,120,112,108,105,99,105,116,108,121,32,100,101,102,105,110,101,100,44,32,105,103,110,111,114,105,110,103,32,97,108,108,32,46,46,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,77,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,103,108,71,101,116,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,80,114,101,118,37,117,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,10,0,0,37,115,0,0,0,0,0,0,115,99,114,105,112,116,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,110,101,120,116,95,116,97,114,103,101,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,115,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,67,108,111,115,101,100,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,109,111,117,115,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,115,99,111,110,110,101,99,116,105,110,103,32,100,101,118,105,99,101,32,102,114,111,109,32,112,111,114,116,32,37,117,46,10,0,0,88,32,40,117,112,41,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,99,111,110,102,105,103,32,102,105,108,101,46,32,85,115,105,110,103,32,115,121,115,116,101,109,32,100,101,102,97,117,108,116,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,99,111,110,102,105,103,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,118,105,100,101,111,95,115,109,111,111,116,104,0,0,0,0,46,99,102,103,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,97,117,100,105,111,32,98,117,102,102,101,114,32,115,97,116,117,114,97,116,105,111,110,58,32,37,46,50,102,32,37,37,44,32,115,116,97,110,100,97,114,100,32,100,101,118,105,97,116,105,111,110,32,40,112,101,114,99,101,110,116,97,103,101,32,112,111,105,110,116,115,41,58,32,37,46,50,102,32,37,37,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,82,67,51,50,58,32,48,120,37,120,44,32,83,72,65,50,53,54,58,32,37,115,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,103,108,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,0,0,0,80,114,101,118,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,114,115,105,111,110,58,32,37,115,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,111,114,116,32,118,97,108,117,101,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,46,120,109,108,0,0,0,0,46,105,112,115,0,0,0,0,69,106,101,99,116,101,100,0,46,98,112,115,0,0,0,0,82,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,46,117,112,115,0,0,0,0,65,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,102,97,109,105,32,84,117,114,98,111,32,83,82,65,77,32,112,97,116,104,115,32,119,105,108,108,32,98,101,32,105,110,102,101,114,114,101,100,32,102,114,111,109,32,116,104,101,105,114,32,114,101,115,112,101,99,116,105,118,101,32,112,97,116,104,115,32,116,111,32,97,118,111,105,100,32,99,111,110,102,108,105,99,116,115,46,10,0,0,0,118,105,100,101,111,95,116,104,114,101,97,100,101,100,0,0,46,112,115,114,109,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,115,104,97,100,101,114,32,34,37,115,34,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,103,97,109,101,46,10,0,0,0,0,0,0,9,45,68,47,45,45,100,101,116,97,99,104,58,32,68,101,116,97,99,104,32,82,101,116,114,111,65,114,99,104,32,102,114,111,109,32,116,104,101,32,114,117,110,110,105,110,103,32,99,111,110,115,111,108,101,46,32,78,111,116,32,114,101,108,101,118,97,110,116,32,102,111,114,32,97,108,108,32,112,108,97,116,102,111,114,109,115,46,10,0,0,0,0,0,0,0,103,108,71,101,116,79,98,106,101,99,116,76,97,98,101,108,0,0,0,0,0,0,0,0,80,97,115,115,37,117,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,110,100,111,114,58,32,37,115,44,32,82,101,110,100,101,114,101,114,58,32,37,115,46,10,0,0,0,0,0,102,114,111,110,116,101,110,100,47,109,101,110,117,47,46,46,47,46,46,47,103,102,120,47,46,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,105,109,112,111,114,116,0,0,82,101,116,114,111,65,114,99,104,58,32,91,67,111,110,102,105,103,93,58,32,81,117,101,114,121,105,110,103,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,97,110,97,108,111,103,95,114,105,103,104,116,0,0,0,0,9,45,88,47,45,45,120,109,108,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,116,111,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,46,0,0,0,0,9,45,45,110,111,45,112,97,116,99,104,58,32,68,105,115,97,98,108,101,115,32,97,108,108,32,102,111,114,109,115,32,111,102,32,114,111,109,32,112,97,116,99,104,105,110,103,46,0,0,0,0,0,0,0,0,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,0,0,9,45,45,105,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,73,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,9,45,45,98,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,66,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,9,45,85,47,45,45,117,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,85,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,0,9,45,118,47,45,45,118,101,114,98,111,115,101,58,32,86,101,114,98,111,115,101,32,108,111,103,103,105,110,103,46,0,9,9,68,111,32,110,111,116,101,32,116,104,97,116,32,110,111,108,111,97,100,45,115,97,118,101,32,105,109,112,108,105,101,115,32,116,104,97,116,32,115,97,118,101,32,102,105,108,101,115,32,119,105,108,108,32,98,101,32,100,101,108,101,116,101,100,32,97,110,100,32,111,118,101,114,119,114,105,116,116,101,110,46,0,0,0,0,0,118,105,100,101,111,95,115,119,97,112,95,105,110,116,101,114,118,97,108,0,0,0,0,0,32,10,9,12,13,11,0,0,9,9,123,110,111,44,125,108,111,97,100,45,123,110,111,44,125,115,97,118,101,32,100,101,115,99,114,105,98,101,115,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,108,111,97,100,101,100,44,32,97,110,100,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,115,97,118,101,100,46,0,0,115,104,97,100,101,114,124,99,103,124,99,103,112,124,103,108,115,108,124,103,108,115,108,112,0,0,0,0,0,0,0,0,9,45,77,47,45,45,115,114,97,109,45,109,111,100,101,58,32,84,97,107,101,115,32,97,110,32,97,114,103,117,109,101,110,116,32,116,101,108,108,105,110,103,32,104,111,119,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,104,97,110,100,108,101,100,32,105,110,32,116,104,101,32,115,101,115,115,105,111,110,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,0,0,9,45,82,47,45,45,98,115,118,114,101,99,111,114,100,58,32,83,116,97,114,116,32,114,101,99,111,114,100,105,110,103,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,32,102,114,111,109,32,116,104,101,32,98,101,103,105,110,110,105,110,103,46,0,0,0,103,108,79,98,106,101,99,116,76,97,98,101,108,0,0,0,80,97,115,115,80,114,101,118,37,117,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,101,116,101,99,116,105,110,103,32,115,99,114,101,101,110,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,46,10,0,0,48,46,57,46,57,46,51,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,101,120,116,117,114,101,32,105,109,97,103,101,32,102,97,105,108,101,100,32,116,111,32,108,111,97,100,46,10,0,0,0,0,0,97,110,97,108,111,103,95,108,101,102,116,0,0,0,0,0,9,45,80,47,45,45,98,115,118,112,108,97,121,58,32,80,108,97,121,98,97,99,107,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,46,0,0,0,0,0,0,0,103,98,97,0,0,0,0,0,9,45,52,47,45,45,109,117,108,116,105,116,97,112,58,32,67,111,110,110,101,99,116,32,97,32,83,78,69,83,32,109,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,65,112,112,101,110,100,101,100,32,100,105,115,107,58,32,37,115,0,0,0,0,0,0,0,9,45,74,47,45,45,106,117,115,116,105,102,105,101,114,115,58,32,68,97,105,115,121,32,99,104,97,105,110,32,116,119,111,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,115,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,76,32,98,117,116,116,111,110,32,40,108,101,102,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,0,9,45,106,47,45,45,106,117,115,116,105,102,105,101,114,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,9,45,112,47,45,45,115,99,111,112,101,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,83,117,112,101,114,83,99,111,112,101,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,9,45,109,47,45,45,109,111,117,115,101,58,32,67,111,110,110,101,99,116,32,97,32,109,111,117,115,101,32,105,110,116,111,32,112,111,114,116,32,111,102,32,116,104,101,32,100,101,118,105,99,101,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,0,0,0,9,45,65,47,45,45,100,117,97,108,97,110,97,108,111,103,58,32,67,111,110,110,101,99,116,32,97,32,68,117,97,108,65,110,97,108,111,103,32,99,111,110,116,114,111,108,108,101,114,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,118,105,100,101,111,95,98,108,97,99,107,95,102,114,97,109,101,95,105,110,115,101,114,116,105,111,110,0,0,0,0,0,34,0,0,0,0,0,0,0,9,45,78,47,45,45,110,111,100,101,118,105,99,101,58,32,68,105,115,99,111,110,110,101,99,116,115,32,99,111,110,116,114,111,108,108,101,114,32,100,101,118,105,99,101,32,99,111,110,110,101,99,116,101,100,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,48,82,71,66,49,53,53,53,32,112,105,120,101,108,32,102,111,114,109,97,116,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,97,110,100,32,119,105,108,108,32,98,101,32,115,108,111,119,101,114,46,32,70,111,114,32,49,53,47,49,54,45,98,105,116,44,32,82,71,66,53,54,53,32,102,111,114,109,97,116,32,105,115,32,112,114,101,102,101,114,114,101,100,46,10,0,0,0,0,0,0,0,0,9,45,45,115,117,102,97,109,105,66,58,32,80,97,116,104,32,116,111,32,66,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,108,111,97,100,105,110,103,32,115,107,105,112,112,101,100,46,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,119,105,108,108,32,108,111,97,100,32,105,116,32,111,110,32,105,116,115,32,111,119,110,46,10,0,0,0,0,0,0,0,0,114,98,0,0,0,0,0,0,9,45,45,115,117,102,97,109,105,65,58,32,80,97,116,104,32,116,111,32,65,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,32,76,111,97,100,32,83,117,102,97,109,105,32,98,97,115,101,32,99,97,114,116,32,97,115,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,103,108,80,111,112,68,101,98,117,103,71,114,111,117,112,0,79,114,105,103,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,10,0,0,0,0,0,0,0,0,37,115,32,45,32,37,115,32,37,115,0,0,0,0,0,0,46,46,46,0,0,0,0,0,116,101,120,116,117,114,101,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,79,118,101,114,108,97,121,32,100,101,115,99,32,105,115,32,105,110,118,97,108,105,100,46,32,82,101,113,117,105,114,101,115,32,97,116,32,108,101,97,115,116,32,54,32,116,111,107,101,110,115,46,10,0,0,0,9,45,66,47,45,45,98,115,120,115,108,111,116,58,32,80,97,116,104,32,116,111,32,66,83,88,32,115,108,111,116,116,101,100,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,9,45,98,47,45,45,98,115,120,58,32,80,97,116,104,32,116,111,32,66,83,88,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,82,101,115,101,116,46,0,0,9,45,103,47,45,45,103,97,109,101,98,111,121,58,32,80,97,116,104,32,116,111,32,71,97,109,101,98,111,121,32,82,79,77,46,32,76,111,97,100,32,83,117,112,101,114,71,97,109,101,66,111,121,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,90,73,80,32,101,120,116,114,97,99,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,108,105,110,101,58,32,37,100,46,10,0,0,0,0,0,0,0,0,9,9,77,117,108,116,105,112,108,101,32,99,111,110,102,105,103,115,32,97,114,101,32,100,101,108,105,109,105,116,101,100,32,98,121,32,39,44,39,46,0,0,0,0,0,0,0,0,103,108,71,101,116,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,71,76,83,76,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,46,46,46,10,0,0,0,9,45,45,97,112,112,101,110,100,99,111,110,102,105,103,58,32,69,120,116,114,97,32,99,111,110,102,105,103,32,102,105,108,101,115,32,97,114,101,32,108,111,97,100,101,100,32,105,110,44,32,97,110,100,32,116,97,107,101,32,112,114,105,111,114,105,116,121,32,111,118,101,114,32,99,111,110,102,105,103,32,115,101,108,101,99,116,101,100,32,105,110,32,45,99,32,40,111,114,32,100,101,102,97,117,108,116,41,46,0,0,0,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,0,103,108,0,0,0,0,0,0,37,115,10,37,115,10,37,115,10,0,0,0,0,0,0,0,9,45,99,47,45,45,99,111,110,102,105,103,58,32,80,97,116,104,32,102,111,114,32,99,111,110,102,105,103,32,102,105,108,101,46,10,9,9,66,121,32,100,101,102,97,117,108,116,32,108,111,111,107,115,32,102,111,114,32,99,111,110,102,105,103,32,105,110,32,36,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,36,72,79,77,69,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,97,110,100,32,36,72,79,77,69,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,46,0,0,0,0,0,9,45,83,47,45,45,115,97,118,101,115,116,97,116,101,58,32,80,97,116,104,32,116,111,32,117,115,101,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,115,46,32,73,102,32,110,111,116,32,115,101,108,101,99,116,101,100,44,32,42,46,115,116,97,116,101,32,119,105,108,108,32,98,101,32,97,115,115,117,109,101,100,46,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,46,10,0,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,95,102,114,97,109,101,115,0,0,82,101,116,114,111,65,114,99,104,58,32,83,73,78,67,32,112,97,114,97,109,115,32,40,37,117,32,112,104,97,115,101,32,98,105,116,115,44,32,37,117,32,116,97,112,115,41,46,10,0,0,0,0,0,0,0,33,33,33,32,35,105,110,99,108,117,100,101,32,100,101,112,116,104,32,101,120,99,101,101,100,101,100,32,102,111,114,32,99,111,110,102,105,103,46,32,77,105,103,104,116,32,98,101,32,97,32,99,121,99,108,101,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,80,78,71,93,58,32,85,115,105,110,103,32,82,80,78,71,32,108,111,97,100,101,114,46,10,0,0,9,45,102,47,45,45,102,117,108,108,115,99,114,101,101,110,58,32,83,116,97,114,116,32,82,101,116,114,111,65,114,99,104,32,105,110,32,102,117,108,108,115,99,114,101,101,110,32,114,101,103,97,114,100,108,101,115,115,32,111,102,32,99,111,110,102,105,103,32,115,101,116,116,105,110,103,115,46,0,0,9,45,115,47,45,45,115,97,118,101,58,32,80,97,116,104,32,102,111,114,32,115,97,118,101,32,102,105,108,101,32,40,42,46,115,114,109,41,46,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,101,101,100,32,116,111,32,100,101,102,105,110,101,32,97,116,32,108,101,97,115,116,32,49,32,115,104,97,100,101,114,46,10,0,9,45,45,102,101,97,116,117,114,101,115,58,32,80,114,105,110,116,115,32,97,118,97,105,108,97,98,108,101,32,102,101,97,116,117,114,101,115,32,99,111,109,112,105,108,101,100,32,105,110,116,111,32,82,101,116,114,111,65,114,99,104,46,0,103,108,80,117,115,104,68,101,98,117,103,71,114,111,117,112,0,0,0,0,0,0,0,0,70,114,97,109,101,68,105,114,101,99,116,105,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,99,114,101,97,116,105,110,103,32,70,66,79,32,116,101,120,116,117,114,101,32,35,37,100,58,32,37,117,120,37,117,10,0,0,0,71,65,77,69,32,40,37,115,41,32,37,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,71,85,73,93,58,32,79,112,101,110,105,110,103,32,104,105,115,116,111,114,121,58,32,37,115,46,10,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,88,77,76,32,115,104,97,100,101,114,32,97,116,116,114,105,98,117,116,101,115,32,100,111,32,110,111,116,32,99,111,109,112,108,121,32,119,105,116,104,32,115,112,101,99,105,102,105,99,97,116,105,111,110,115,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,111,118,101,114,108,97,121,32,100,101,115,99,46,10,0,0,99,97,114,116,114,105,100,103,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,9,9,73,102,32,110,111,32,97,114,103,117,109,101,110,116,115,32,97,114,101,32,112,97,115,115,101,100,32,116,111,32,82,101,116,114,111,65,114,99,104,44,32,105,116,32,105,115,32,101,113,117,105,118,97,108,101,110,116,32,116,111,32,117,115,105,110,103,32,45,45,109,101,110,117,32,97,115,32,111,110,108,121,32,97,114,103,117,109,101,110,116,46,0,0,0,47,62,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,114,101,32,111,112,116,105,111,110,58,10,0,0,0,0,0,0,0,0,9,45,45,109,101,110,117,58,32,68,111,32,110,111,116,32,114,101,113,117,105,114,101,32,82,79,77,32,111,114,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,116,111,32,98,101,32,108,111,97,100,101,100,44,32,115,116,97,114,116,115,32,100,105,114,101,99,116,108,121,32,105,110,32,109,101,110,117,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,115,101,116,116,105,110,103,32,103,97,109,101,46,10,0,0,0,0,0,9,45,104,47,45,45,104,101,108,112,58,32,83,104,111,119,32,116,104,105,115,32,104,101,108,112,32,109,101,115,115,97,103,101,46,0,0,0,0,0,88,32,98,117,116,116,111,110,32,40,116,111,112,41,0,0,85,115,97,103,101,58,32,114,101,116,114,111,97,114,99,104,32,91,114,111,109,32,102,105,108,101,93,32,91,111,112,116,105,111,110,115,46,46,46,93,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,114,111,110,116,101,110,100,32,102,111,114,32,108,105,98,114,101,116,114,111,32,45,45,32,118,48,46,57,46,57,46,51,32,45,45,0,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,0,77,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,83,99,114,105,112,116,32,115,117,112,112,111,114,116,32,105,110,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,68,105,115,107,32,83,119,97,112,32,78,101,120,116,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,0,105,110,99,108,117,100,101,32,0,0,0,0,0,0,0,0,80,121,116,104,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,109,111,110,105,116,111,114,32,72,122,58,32,37,46,54,102,32,72,122,46,32,40,37,46,51,102,32,37,37,32,102,114,97,109,101,32,116,105,109,101,32,100,101,118,105,97,116,105,111,110,44,32,98,97,115,101,100,32,111,110,32,37,117,32,108,97,115,116,32,115,97,109,112,108,101,115,41,46,10,0,0,0,0,0,0,68,105,115,107,32,69,106,101,99,116,32,84,111,103,103,108,101,0,0,0,0,0,0,0,68,105,100,32,110,111,116,32,100,101,116,101,99,116,32,97,110,121,32,112,97,114,116,105,99,117,108,97,114,32,83,82,65,77,32,116,121,112,101,46,10,0,0,0,0,0,0,0,80,101,101,114,45,116,111,45,112,101,101,114,32,110,101,116,112,108,97,121,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,46,10,0,0,78,101,120,116,32,79,118,101,114,108,97,121,0,0,0,0,78,101,116,112,108,97,121,0,119,98,0,0,0,0,0,0,103,108,71,101,116,68,101,98,117,103,77,101,115,115,97,103,101,76,111,103,0,0,0,0,70,114,97,109,101,67,111,117,110,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,105,110,105,116,32,70,66,79,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,86,111,108,117,109,101,32,68,111,119,110,0,0,0,0,0,78,111,32,67,111,114,101,0,46,114,101,116,114,111,97,114,99,104,45,103,97,109,101,45,104,105,115,116,111,114,121,46,116,120,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,100,101,114,110,32,71,76,83,76,32,119,97,115,32,99,104,111,115,101,110,32,97,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,119,97,115,32,110,111,116,32,112,114,111,118,105,100,101,100,46,32,84,104,105,115,32,105,115,32,97,110,32,101,114,114,111,114,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,107,101,121,58,32,37,115,46,10,0,0,0,84,84,70,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,119,105,116,104,32,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,85,112,0,0,0,0,0,0,0,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,69,110,97,98,108,101,32,72,111,116,107,101,121,0,0,0,79,110,45,116,104,101,45,102,108,121,32,114,101,99,111,114,100,105,110,103,32,111,102,32,103,97,109,101,112,108,97,121,32,119,105,116,104,32,108,105,98,97,118,99,111,100,101,99,0,0,0,0,0,0,0,0,83,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,70,70,109,112,101,103,0,0,78,101,116,112,108,97,121,32,70,108,105,112,32,80,108,97,121,101,114,115,0,0,0,0,68,121,110,97,109,105,99,32,114,117,110,45,116,105,109,101,32,108,111,97,100,105,110,103,32,111,102,32,108,105,98,114,101,116,114,111,32,108,105,98,114,97,114,121,0,0,0,0,68,121,110,97,109,105,99,0,68,83,80,32,67,111,110,102,105,103,0,0,0,0,0,0,79,112,101,110,71,76,32,114,101,110,100,101,114,45,116,111,45,116,101,120,116,117,114,101,32,40,109,117,108,116,105,45,112,97,115,115,32,115,104,97,100,101,114,115,41,0,0,0,83,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,118,105,100,101,111,95,118,115,121,110,99,0,0,0,0,0,70,66,79,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,111,101,115,32,110,111,116,32,104,97,118,101,32,101,110,111,117,103,104,32,115,97,109,112,108,101,115,32,102,111,114,32,109,111,110,105,116,111,114,32,114,101,102,114,101,115,104,32,114,97,116,101,32,101,115,116,105,109,97,116,105,111,110,46,32,82,101,113,117,105,114,101,115,32,116,111,32,114,117,110,32,102,111,114,32,97,116,32,108,101,97,115,116,32,37,117,32,102,114,97,109,101,115,46,10,0,0,0,67,104,101,97,116,32,84,111,103,103,108,101,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,56,0,0,0,83,68,76,95,105,109,97,103,101,32,105,109,97,103,101,32,108,111,97,100,105,110,103,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,67,104,101,97,116,32,73,110,100,101,120,32,77,105,110,117,115,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,55,0,0,0,83,68,76,95,105,109,97,103,101,0,0,0,0,0,0,0,68,101,116,101,99,116,105,110,103,32,70,108,97,115,104,32,49,77,98,105,116,10,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,97,108,108,98,97,99,107,0,0,84,101,120,116,117,114,101,83,105,122,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,69,71,76,32,105,109,97,103,101,46,10,0,67,104,101,97,116,32,73,110,100,101,120,32,80,108,117,115,0,0,0,0,0,0,0,0,83,89,83,84,69,77,32,68,73,82,32,37,115,0,0,0,102,114,97,103,109,101,110,116,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,0,0,0,0,0,0,0,0,43,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,54,0,0,0,108,105,98,120,109,108,50,32,88,77,76,32,112,97,114,115,105,110,103,0,0,0,0,0,80,114,101,118,105,111,117,115,32,83,104,97,100,101,114,0,105,110,112,117,116,95,112,108,97,121,101,114,53,0,0,0,108,105,98,120,109,108,50,0,83,97,118,101,32,115,116,97,116,101,47,109,111,118,105,101,32,115,108,111,116,58,32,37,117,0,0,0,0,0,0,0,78,101,120,116,32,83,104,97,100,101,114,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,52,0,0,0,67,103,32,112,105,120,101,108,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,0,82,101,115,101,116,0,0,0,65,32,98,117,116,116,111,110,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,51,0,0,0,67,103,0,0,0,0,0,0,70,114,97,109,101,32,65,100,118,97,110,99,101,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,50,0,0,0,69,120,116,101,114,110,97,108,32,102,105,108,116,101,114,32,97,110,100,32,112,108,117,103,105,110,32,115,117,112,112,111,114,116,0,0,0,0,0,0,80,97,117,115,101,32,84,111,103,103,108,101,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,49,0,0,0,69,120,116,101,114,110,97,108,0,0,0,0,0,0,0,0,77,111,118,105,101,32,82,101,99,111,114,100,32,84,111,103,103,108,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,111,117,110,100,32,105,110,118,97,108,105,100,32,104,97,116,32,105,110,32,99,111,110,102,105,103,33,10,0,0,0,0,0,0,0,79,112,101,110,65,76,0,0,118,105,100,101,111,95,100,105,115,97,98,108,101,95,99,111,109,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,80,78,71,32,101,110,99,111,100,101,47,100,101,99,111,100,101,32,97,110,100,32,46,122,105,112,32,101,120,116,114,97,99,116,105,111,110,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,110,105,116,111,114,32,70,80,83,32,101,115,116,105,109,97,116,105,111,110,32,105,115,32,100,105,115,97,98,108,101,100,32,102,111,114,32,116,104,114,101,97,100,101,100,32,118,105,100,101,111,46,10,0,0,0,0,0,0,83,116,97,116,101,32,83,108,111,116,32,77,105,110,117,115,0,0,0,0,0,0,0,0,122,108,105,98,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,82,79,77,32,116,121,112,101,46,10,0,83,116,97,116,101,32,83,108,111,116,32,80,108,117,115,0,105,110,112,117,116,95,100,114,105,118,101,114,0,0,0,0,88,65,117,100,105,111,50,0,68,101,116,101,99,116,105,110,103,32,70,108,97,115,104,32,53,49,50,107,98,105,116,10,0,0,0,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,73,110,115,101,114,116,0,0,0,0,79,117,116,112,117,116,83,105,122,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,34,37,115,34,32,102,111,114,32,114,101,99,111,114,100,105,110,103,46,10,0,0,0,0,0,111,110,0,0,0,0,0,0,81,117,105,116,32,75,101,121,0,0,0,0,0,0,0,0,79,86,69,82,76,65,89,32,68,73,82,32,37,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,109,101,110,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,104,97,100,101,114,32,115,111,117,114,99,101,32,102,105,108,101,32,119,97,115,32,112,114,111,118,105,100,101,100,44,32,98,117,116,32,102,97,105,108,101,100,32,116,111,32,114,101,97,100,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,100,101,115,99,115,32,102,111,114,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,99,111,100,101,0,0,0,0,68,105,114,101,99,116,83,111,117,110,100,0,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,84,111,103,103,108,101,0,0,0,0,0,0,0,80,117,108,115,101,65,117,100,105,111,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,0,0,0,37,115,95,37,115,95,97,120,105,115,0,0,0,0,0,0,82,111,97,114,65,117,100,105,111,0,0,0,0,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,84,101,120,116,117,114,101,50,68,79,69,83,0,0,0,0,37,115,95,37,115,95,98,116,110,0,0,0,0,0,0,0,82,83,111,117,110,100,0,0,70,97,115,116,32,70,111,114,119,97,114,100,32,72,111,108,100,0,0,0,0,0,0,0,105,110,112,117,116,0,0,0,74,97,99,107,0,0,0,0,89,32,40,108,101,102,116,41,0,0,0,0,0,0,0,0,70,97,115,116,32,70,111,114,119,97,114,100,0,0,0,0,37,115,95,37,115,0,0,0,79,83,83,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,45,0,0,0,0,0,0,0,0,110,117,108,0,0,0,0,0,97,117,100,105,111,32,100,114,105,118,101,114,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,43,0,0,0,0,0,0,0,0,118,105,100,101,111,95,109,111,110,105,116,111,114,95,105,110,100,101,120,0,0,0,0,0,40,105,110,99,108,117,100,101,100,41,0,0,0,0,0,0,112,97,117,115,101,0,0,0,65,76,83,65,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,45,0,0,0,0,0,0,0,0,98,97,99,107,113,117,111,116,101,0,0,0,0,0,0,0,103,108,115,108,0,0,0,0,88,86,105,100,101,111,32,111,117,116,112,117,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,101,120,116,114,97,99,116,32,82,79,77,32,102,114,111,109,32,122,105,112,112,101,100,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,43,0,0,0,0,0,0,0,0,101,109,115,99,114,105,112,116,101,110,0,0,0,0,0,0,116,105,108,100,101,0,0,0,88,86,105,100,101,111,0,0,68,101,116,101,99,116,105,110,103,32,69,69,112,114,111,109,32,54,52,107,98,105,116,10,0,0,0,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,111,110,116,114,111,108,0,0,0,73,110,112,117,116,83,105,122,101,0,0,0,0,0,0,0,111,102,102,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,45,0,83,65,86,69,70,73,76,69,32,68,73,82,32,37,115,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,102,97,105,108,101,100,46,10,0,0,0,0,71,76,32,114,97,115,116,101,114,0,0,0,0,0,0,0,115,114,99,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,100,101,115,99,115,46,10,0,0,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,115,99,114,111,108,108,95,108,111,99,107,0,0,0,0,0,79,112,101,110,86,71,32,111,117,116,112,117,116,32,115,117,112,112,111,114,116,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,43,0,112,114,105,110,116,95,115,99,114,101,101,110,0,0,0,0,79,112,101,110,86,71,0,0,83,97,118,101,100,32,115,116,97,116,101,32,116,111,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,0,0,0])
.concat([76,101,102,116,32,65,110,97,108,111,103,32,88,32,45,0,100,105,118,105,100,101,0,0,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,43,0,82,105,103,104,116,32,68,45,112,97,100,0,0,0,0,0,109,117,108,116,105,112,108,121,0,0,0,0,0,0,0,0,69,71,76,0,0,0,0,0,84,117,114,98,111,32,69,110,97,98,108,101,0,0,0,0,98,97,99,107,115,112,97,99,101,0,0,0,0,0,0,0,75,77,83,47,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,66,32,40,98,111,116,116,111,109,41,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,82,51,32,66,117,116,116,111,110,0,0,0,0,0,0,110,117,109,108,111,99,107,0,75,77,83,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,51,32,66,117,116,116,111,110,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,114,101,97,116,105,110,103,32,70,66,79,32,37,100,32,64,32,37,117,120,37,117,10,0,0,0,0,0,99,97,112,115,108,111,99,107,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,79,86,69,82,83,67,65,78,58,32,37,117,10,0,0,0,0,79,112,101,110,71,76,32,100,114,105,118,101,114,0,0,0,82,101,116,114,111,80,97,100,32,82,50,32,66,117,116,116,111,110,0,0,0,0,0,0,118,105,100,101,111,95,119,105,110,100,111,119,101,100,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,37,115,32,61,32,34,37,115,34,32,37,115,10,0,0,0,112,101,114,105,111,100,0,0,114,0,0,0,0,0,0,0,79,112,101,110,71,76,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,105,110,105,116,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,50,32,66,117,116,116,111,110,0,0,0,0,0,0,107,101,121,112,97,100,57,0,84,104,114,101,97,100,105,110,103,32,115,117,112,112,111,114,116,0,0,0,0,0,0,0,122,105,112,0,0,0,0,0,82,101,116,114,111,80,97,100,32,82,32,66,117,116,116,111,110,0,0,0,0,0,0,0,107,101,121,112,97,100,56,0,84,104,114,101,97,100,115,0,68,101,116,101,99,116,105,110,103,32,69,69,112,114,111,109,32,56,107,98,105,116,10,0,103,108,73,115,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,0,0,76,85,84,84,101,120,67,111,111,114,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,32,86,83,121,110,99,32,61,62,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,32,66,117,116,116,111,110,0,0,0,0,0,0,0,83,65,86,69,83,84,65,84,69,32,68,73,82,32,37,115,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,37,115,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,104,97,118,101,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,105,110,32,97,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,110,117,109,98,101,114,32,111,102,32,100,101,115,99,115,32,102,114,111,109,32,99,111,110,102,105,103,32,107,101,121,58,32,37,115,46,10,0,0,0,0,99,104,101,97,116,0,0,0,107,101,121,112,97,100,55,0,83,68,76,32,100,114,105,118,101,114,115,0,0,0,0,0,82,101,116,114,111,80,97,100,32,88,32,66,117,116,116,111,110,0,0,0,0,0,0,0,107,101,121,112,97,100,54,0,83,68,76,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,0,82,101,116,114,111,80,97,100,32,65,32,66,117,116,116,111,110,0,0,0,0,0,0,0,107,101,121,112,97,100,53,0,9,37,115,58,10,9,9,37,115,58,32,37,115,10,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,107,101,121,112,97,100,52,0,70,101,97,116,117,114,101,115,58,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,107,101,121,112,97,100,51,0,107,101,121,112,97,100,50,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,88,82,71,66,56,56,56,56,46,10,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,45,45,109,101,110,117,32,119,97,115,32,117,115,101,100,44,32,98,117,116,32,82,79,77,32,102,105,108,101,32,119,97,115,32,112,97,115,115,101,100,32,97,115,32,119,101,108,108,46,10,0,107,101,121,112,97,100,49,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,69,114,114,111,114,32,112,97,114,115,105,110,103,32,97,114,103,117,109,101,110,116,115,46,10,0,0,107,101,121,112,97,100,48,0,82,101,116,114,111,80,97,100,32,83,116,97,114,116,32,66,117,116,116,111,110,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,0,37,115,32,61,32,34,37,115,34,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,32,105,110,32,45,45,115,114,97,109,45,109,111,100,101,46,10,0,0,112,97,103,101,100,111,119,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,112,104,105,99,115,32,100,114,105,118,101,114,32,100,105,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,97,110,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,112,105,99,107,32,97,32,115,117,105,116,97,98,108,101,32,100,114,105,118,101,114,46,10,0,0,0,82,101,116,114,111,80,97,100,32,83,101,108,101,99,116,32,66,117,116,116,111,110,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,114,101,115,111,108,118,101,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,33,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,81,117,105,116,32,82,101,116,114,111,65,114,99,104,0,0,108,111,97,100,45,115,97,118,101,0,0,0,0,0,0,0,112,97,103,101,117,112,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,116,111,32,34,37,115,34,46,10,0,82,101,116,114,111,80,97,100,32,89,32,66,117,116,116,111,110,0,0,0,0,0,0,0,82,101,115,116,97,114,116,32,82,101,116,114,111,65,114,99,104,0,0,0,0,0,0,0,108,111,97,100,45,110,111,115,97,118,101,0,0,0,0,0,110,117,109,57,0,0,0,0,114,101,118,101,114,115,101,100,0,0,0,0,0,0,0,0,103,108,71,101,110,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,0,0,0,67,111,108,111,114,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,51,50,45,98,105,116,32,70,66,79,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,49,54,45,98,105,116,46,10,0,0,0,0,82,101,116,114,111,80,97,100,32,66,32,66,117,116,116,111,110,0,0,0,0,0,0,0,83,72,65,68,69,82,32,68,73,82,32,37,115,0,0,0,82,101,116,114,111,65,114,99,104,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,115,117,99,99,101,101,100,101,100,46,10,0,0,0,118,101,114,116,101,120,0,0,82,101,115,116,97,114,116,32,71,97,109,101,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,115,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,99,104,101,97,116,32,102,111,114,32,103,97,109,101,58,32,34,37,115,34,10,0,0,110,111,108,111,97,100,45,115,97,118,101,0,0,0,0,0,110,117,109,56,0,0,0,0,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,0,82,101,115,117,109,101,32,71,97,109,101,0,0,0,0,0,110,111,108,111,97,100,45,110,111,115,97,118,101,0,0,0,76,111,97,100,101,100,32,115,116,97,116,101,32,102,114,111,109,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,110,117,109,55,0,0,0,0,84,97,107,101,32,83,99,114,101,101,110,115,104,111,116,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,115,99,111,110,110,101,99,116,32,100,101,118,105,99,101,32,102,114,111,109,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,110,117,109,54,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,0,0,0,0,0,0,0,76,101,102,116,32,68,45,112,97,100,0,0,0,0,0,0,76,111,97,100,32,83,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,109,111,117,115,101,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,110,117,109,53,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,58,32,37,115,46,10,0,0,0,83,97,118,101,32,83,116,97,116,101,0,0,0,0,0,0,112,97,114,115,101,95,105,110,112,117,116,40,41,0,0,0,110,117,109,52,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,82,71,66,53,54,53,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,46,10,0,0,0,0,0,68,105,115,107,32,79,112,116,105,111,110,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,0,110,117,109,51,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,99,111,110,102,105,103,32,102,114,111,109,58,32,37,115,46,10,0,0,0,0,83,101,116,116,105,110,103,115,0,0,0,0,0,0,0,0,104,115,58,102,118,83,58,109,58,112,52,106,74,65,58,103,58,98,58,99,58,66,58,89,58,90,58,85,58,68,78,58,88,58,80,58,82,58,77,58,0,0,0,0,0,0,0,0,110,117,109,50,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,121,0,0,0,0,0,0,35,105,110,99,108,117,100,101,32,34,37,115,34,10,0,0,80,97,116,104,32,79,112,116,105,111,110,115,0,0,0,0,102,101,97,116,117,114,101,115,0,0,0,0,0,0,0,0,110,117,109,49,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,111,112,101,110,32,118,105,100,101,111,32,100,114,105,118,101,114,32,46,46,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,47,101,116,99,0,0,0,0,110,117,108,108,0,0,0,0,47,112,114,111,99,47,37,117,47,37,115,0,0,0,0,0,73,110,112,117,116,32,79,112,116,105,111,110,115,0,0,0,100,101,116,97,99,104,0,0,110,117,109,48,0,0,0,0,115,105,110,99,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,114,101,99,111,118,101,114,32,46,46,46,10,0,0,37,115,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,0,65,117,100,105,111,32,79,112,116,105,111,110,115,0,0,0,120,109,108,0,0,0,0,0,102,49,50,0,0,0,0,0,111,114,105,103,105,110,97,108,0,0,0,0,0,0,0,0,103,108,68,101,108,101,116,101,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,86,101,114,116,101,120,67,111,111,114,100,0,0,0,0,0,46,116,103,97,0,0,0,0,65,82,77,95,97,114,103,98,56,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,111,107,105,110,103,32,102,111,114,32,99,111,110,102,105,103,32,105,110,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,66,82,79,87,83,69,82,32,68,73,82,32,37,115,0,0,98,105,116,109,97,112,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,76,101,103,97,99,121,32,115,104,97,100,101,114,115,32,97,114,101,32,100,101,112,114,101,99,97,116,101,100,46,10,0,0,0,0,0,0,0,86,105,100,101,111,32,79,112,116,105,111,110,115,0,0,0,111,118,101,114,108,97,121,37,117,95,102,117,108,108,95,115,99,114,101,101,110,0,0,0,110,97,109,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,110,111,45,112,97,116,99,104,0,0,0,0,0,0,0,0,102,49,49,0,0,0,0,0,37,115,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,67,111,114,101,32,79,112,116,105,111,110,115,0,0,0,0,105,112,115,0,0,0,0,0,102,49,48,0,0,0,0,0,37,115,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,76,111,97,100,32,71,97,109,101,0,0,0,0,0,0,0,98,112,115,0,0,0,0,0,102,57,0,0,0,0,0,0,72,79,77,69,0,0,0,0,76,111,97,100,32,71,97,109,101,32,40,72,105,115,116,111,114,121,41,0,0,0,0,0,117,112,115,0,0,0,0,0,102,56,0,0,0,0,0,0,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,0,114,103,117,105,46,99,103,112,0,0,0,0,0,0,0,0,115,114,97,109,45,109,111,100,101,0,0,0,0,0,0,0,102,55,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,48,82,71,66,49,53,53,53,46,10,0,114,103,117,105,46,103,108,115,108,112,0,0,0,0,0,0,98,115,118,114,101,99,111,114,100,0,0,0,0,0,0,0,102,54,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,46,46,46,10,0,98,115,118,112,108,97,121,0,102,53,0,0,0,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,120,0,0,0,0,0,0,82,51,0,0,0,0,0,0,115,117,102,97,109,105,66,0,102,52,0,0,0,0,0,0,105,110,105,116,95,118,105,100,101,111,95,105,110,112,117,116,40,41,0,0,0,0,0,0,112,97,116,104,47,97,46,111,117,116,0,0,0,0,0,0,76,51,0,0,0,0,0,0,115,117,102,97,109,105,65,0,102,51,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,83,82,65,77,46,10,0,0,0,0,0,0,82,50,0,0,0,0,0,0,109,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,102,50,0,0,0,0,0,0,109,105,114,114,111,114,105,110,103,69,110,97,98,108,101,32,61,32,37,100,46,10,0,0,3,3,11,0,0,0,0,0,103,108,66,105,110,100,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,84,101,120,67,111,111,114,100,0,0,0,0,0,0,0,0,79,69,83,95,114,103,98,56,95,114,103,98,97,56,0,0,79,86,69,82,76,65,89,32,37,115,0,0,0,0,0,0,73,78,70,79,32,45,32,76,111,97,100,105,110,103,32,37,115,32,46,46,46,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,114,101,112,111,114,116,115,32,97,32,71,76,69,83,50,32,115,116,121,108,101,32,115,104,97,100,101,114,46,10,0,0,76,50,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,114,101,99,116,32,34,37,115,34,32,105,110,116,111,32,97,116,32,108,101,97,115,116,32,102,111,117,114,32,116,111,107,101,110,115,46,10,0,0,0,115,99,97,108,101,95,121,37,117,0,0,0,0,0,0,0,98,115,120,115,108,111,116,0,102,49,0,0,0,0,0,0,82,0,0,0,0,0,0,0,115,99,97,108,101,95,120,37,117,0,0,0,0,0,0,0,98,115,120,0,0,0,0,0,37,115,37,117,0,0,0,0,107,112,95,109,105,110,117,115,0,0,0,0,0,0,0,0,66,117,116,116,111,110,32,108,97,121,111,117,116,59,32,111,114,105,103,105,110,97,108,124,114,101,118,101,114,115,101,100,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,115,99,97,108,101,37,117,0,115,97,118,101,115,116,97,116,101,0,0,0,0,0,0,0,107,112,95,112,108,117,115,0,68,111,119,110,32,68,45,112,97,100,0,0,0,0,0,0,83,101,108,101,99,116,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,116,116,114,105,98,117,116,101,46,10,0,0,0,0,0,0,0,0,115,104,97,100,101,114,115,0,100,117,97,108,97,110,97,108,111,103,0,0,0,0,0,0,115,117,98,116,114,97,99,116,0,0,0,0,0,0,0,0,79,117,116,32,88,32,61,32,37,100,32,61,62,32,73,110,32,88,32,61,32,37,100,10,0,0,0,0,0,0,0,0,83,116,97,114,116,0,0,0,115,99,97,108,101,95,116,121,112,101,95,121,37,117,0,0,106,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,97,100,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,89,83,84,69,77,95,68,73,82,69,67,84,79,82,89,58,32,34,37,115,34,46,10,0,0,0,0,0,105,110,112,117,116,95,100,101,118,105,99,101,95,112,37,117,0,0,0,0,0,0,0,0,89,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,95,120,37,117,0,0,106,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,101,115,99,97,112,101,0,0,105,110,112,117,116,95,100,112,97,100,95,101,109,117,108,97,116,105,111,110,95,112,37,117,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,37,117,0,0,0,0,115,99,111,112,101,0,0,0,115,112,97,99,101,0,0,0,99,117,115,116,111,109,95,98,103,109,95,101,110,97,98,108,101,0,0,0,0,0,0,0,118,105,100,101,111,95,121,115,99,97,108,101,0,0,0,0,66,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,112,97,114,115,101,32,115,104,97,100,101,114,32,115,111,117,114,99,101,32,40,37,115,41,46,10,0,0,0,0,0,0,0,0,110,111,100,101,118,105,99,101,0,0,0,0,0,0,0,0,97,108,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,112,105,120,101,108,32,99,111,110,118,101,114,116,101,114,46,10,0,0,0,115,99,114,101,101,110,95,111,114,105,101,110,116,97,116,105,111,110,0,0,0,0,0,0,99,112,117,83,97,118,101,84,121,112,101,32,61,32,37,100,46,10,0,0,0,0,0,0,109,111,117,115,101,0,0,0,65,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,73,110,118,97,108,105,100,32,119,114,97,112,112,105,110,103,32,116,121,112,101,32,37,115,46,32,86,97,108,105,100,32,111,110,101,115,32,97,114,101,58,32,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,32,40,100,101,102,97,117,108,116,41,44,32,99,108,97,109,112,95,116,111,95,101,100,103,101,44,32,114,101,112,101,97,116,32,97,110,100,32,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,100,101,102,97,117,108,116,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,32,82,101,119,105,110,100,105,110,103,32,119,105,108,108,32,98,101,32,100,105,115,97,98,108,101,100,46,10,0,0,99,116,114,108,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,66,108,111,99,107,105,110,103,32,83,82,65,77,32,111,118,101,114,119,114,105,116,101,46,10,0,0,0,0,82,105,103,104,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,112,97,116,104,32,116,111,32,116,101,120,116,117,114,101,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,97,112,112,101,110,100,99,111,110,102,105,103,0,0,0,0,115,104,105,102,116,0,0,0,2,3,7,0,0,0,0,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,51,68,79,69,83,0,0,0,0,0,0,0,77,86,80,77,97,116,114,105,120,0,0,0,0,0,0,0,100,111,101,115,110,39,116,32,101,120,105,115,116,0,0,0,115,116,97,116,101,95,115,108,111,116,0,0,0,0,0,0,37,115,46,122,105,112,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,117,110,105,102,111,114,109,32,97,110,100,32,97,116,116,114,105,98,32,112,114,101,102,105,120,58,32,37,115,10,0,0,0,76,101,102,116,0,0,0,0,44,32,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,97,100,100,114,101,115,115,32,97,115,115,105,103,110,101,100,32,116,111,32,115,101,109,97,110,116,105,99,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,32,116,111,32,34,37,115,34,46,32,67,104,101,99,107,32,112,101,114,109,105,115,115,105,111,110,115,46,10,0,0,0,0,63,62,10,0,0,0,0,0,99,111,110,102,105,103,0,0,114,115,104,105,102,116,0,0,115,111,117,110,100,95,109,111,100,101,0,0,0,0,0,0,68,111,119,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,46,10,0,103,97,109,101,98,111,121,0,82,101,116,114,111,65,114,99,104,58,32,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,104,111,109,101,0,0,0,0,99,117,114,114,101,110,116,95,114,101,115,111,108,117,116,105,111,110,95,105,100,0,0,0,85,112,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,46,10,0,0,118,101,114,98,111,115,101,0,101,110,100,0,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,91,82,80,78,71,93,58,32,69,114,114,111,114,32,105,110,32,108,105,110,101,32,37,100,46,10,0,0,0,0,0,0,68,80,97,100,32,69,109,117,108,97,116,105,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,101,120,116,101,114,110,97,108,32,115,111,117,114,99,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,100,101,108,0,0,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,79,69,83,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,103,108,115,108,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,37,115,10,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,111,117,108,100,110,39,116,32,105,110,105,116,32,102,111,110,116,32,114,101,110,100,101,114,101,114,46,10,0,0,0,0,0,0,0,68,101,118,105,99,101,32,84,121,112,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,115,97,118,101,0,0,0,0,105,110,115,101,114,116,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,80,69,82,70,79,82,77,65,78,67,69,95,76,69,86,69,76,58,32,37,117,46,10,0,0,0,0,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,70,66,79,32,116,97,114,103,101,116,115,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,70,66,79,46,10,0,0,119,0,0,0,0,0,0,0,68,101,118,105,99,101,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,104,101,108,112,0,0,0,0,116,97,98,0,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,0,0,0,80,108,97,121,101,114,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,109,101,110,117,0,0,0,0,107,112,95,101,110,116,101,114,0,0,0,0,0,0,0,0,105,110,102,111,95,109,115,103,95,101,110,97,98,108,101,0,118,105,100,101,111,95,120,115,99,97,108,101,0,0,0,0,99,103,112,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,118,101,114,108,97,121,32,105,110,116,101,114,102,97,99,101,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,118,105,100,101,111,32,100,114,105,118,101,114,46,10,0,82,101,116,114,111,65,114,99,104,58,32,83,105,110,99,32,114,101,115,97,109,112,108,101,114,32,91,67,93,10,0,0,46,112,110,103,0,0,0,0,79,118,101,114,108,97,121,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,121,32,97,116,116,114,58,32,37,117,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,114,119,101,98,97,117,100,105,111,0,0,0,0,0,0,0,83,101,112,32,49,51,32,50,48,49,51,0,0,0,0,0,101,110,116,101,114,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,102,117,108,108,115,99,114,101,101,110,10,0,0,116,114,105,112,108,101,95,98,117,102,102,101,114,105,110,103,95,101,110,97,98,108,101,0,101,120,101,0,0,0,0,0,79,118,101,114,108,97,121,32,79,112,97,99,105,116,121,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,120,32,97,116,116,114,58,32,37,117,10,0,66,117,105,108,116,58,32,37,115,10,0,0,0,0,0,0,82,71,85,73,32,109,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,34,115,104,97,100,101,114,115,34,32,112,97,114,97,109,46,10,0,0,0,0,0,0,79,117,116,32,89,32,61,32,37,100,32,61,62,32,73,110,32,89,32,61,32,37,100,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,103,97,109,109,97,95,99,111,114,114,101,99,116,105,111,110,0,0,0,0,0,0,0,0,79,118,101,114,108,97,121,32,80,114,101,115,101,116,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,32,97,116,116,114,58,32,37,117,10,0,0,0,52,46,50,46,49,32,67,111,109,112,97,116,105,98,108,101,32,67,108,97,110,103,32,51,46,50,32,40,116,97,103,115,47,82,69,76,69,65,83,69,95,51,50,47,102,105,110,97,108,41,0,0,0,0,0,0,102,108,97,115,104,83,105,122,101,32,61,32,37,100,46,10,0,0,0,0,0,0,0,0,5,5,4,0,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,101,120,105,115,116,115,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,77,69,78,85,32,37,115,0,37,117,120,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,99,111,110,102,105,103,32,102,105,108,101,58,32,37,115,46,10,0,0,0,112,114,101,102,105,120,0,0,83,121,115,116,101,109,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,114,101,99,116,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,37,117,59,0,0,0,0,0,60,63,120,109,108,0,0,0,100,97,116,97,98,97,115,101,0,0,0,0,0,0,0,0,67,108,97,110,103,47,76,76,86,77,32,40,37,115,41,32,37,117,45,98,105,116,10,0,71,114,97,98,32,109,111,117,115,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,99,111,109,112,97,116,47,99,111,109,112,97,116,46,99,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,99,111,110,102,105,103,46,32,65,115,115,117,109,105,110,103,32,115,121,115,116,101,109,32,100,105,114,101,99,116,111,114,121,32,105,115,32,115,97,109,101,32,102,111,108,100,101,114,32,97,115,32,103,97,109,101,58,32,34,37,115,34,46,10,0,0,0,0,0,79,118,101,114,108,97,121,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,10,67,111,109,112,105,108,101,114,58,32,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,73,110,105,116,105,110,103,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,119,105,116,104,32,115,105,122,101,58,32,37,117,32,77,66,10,0,0,0,0,0,0,98,109,112,0,0,0,0,0,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,83,97,118,101,102,105,108,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,97,32,100,105,102,102,101,114,101,110,116,32,118,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,116,104,97,110,32,116,104,105,115,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,68,105,115,107,32,110,101,120,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,85,115,105,110,103,32,82,88,77,76,32,97,115,32,100,114,111,112,32,105,110,32,102,111,114,32,108,105,98,120,109,108,50,46,32,66,101,104,97,118,105,111,114,32,109,105,103,104,116,32,98,101,32,118,101,114,121,32,98,117,103,103,121,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,85,112,32,68,45,112,97,100,0,0,0,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,102,114,97,109,101,32,99,111,117,110,116,32,109,111,100,32,97,116,116,114,58,32,37,117,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,65,80,73,58,32,37,117,10,0,0,0,0,46,115,116,97,116,101,0,0,83,104,97,100,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,65,80,73,58,32,37,117,10,0,68,105,115,107,32,101,106,101,99,116,32,116,111,103,103,108,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,72,85,84,68,79,87,78,46,10,0,0,0,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,66,114,111,119,115,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,108,97,115,116,32,115,116,97,116,101,32,115,108,111,116,58,32,35,37,117,10,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,0,68,101,98,117,103,32,73,110,102,111,32,77,101,115,115,97,103,101,115,0,0,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,0,59,32,0,0,0,0,0,0,65,117,116,111,45,108,111,97,100,105,110,103,32,115,97,118,101,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,32,37,115,46,0,0,0,0,79,118,101,114,108,97,121,32,110,101,120,116,0,0,0,0,114,119,101,98,105,110,112,117,116,0,0,0,0,0,0,0,46,115,114,109,0,0,0,0,61,61,61,32,67,111,110,102,105,103,32,101,110,100,32,61,61,61,10,0,0,0,0,0,37,120,0,0,0,0,0,0,67,111,110,102,105,103,32,83,97,118,101,32,79,110,32,69,120,105,116,0,0,0,0,0,111,117,116,115,99,97,108,101,95,121,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,97,117,116,111,32,115,97,118,101,115,116,97,116,101,32,105,110,58,32,37,115,10,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,37,117,120,37,117,10,0,0,0,0,0,0,0,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,46,37,115,0,0,0,0,0,82,101,119,105,110,100,32,71,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,111,117,116,115,99,97,108,101,95,120,0,0,0,0,0,0,86,111,108,117,109,101,32,45,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,0,99,111,110,102,105,103,95,115,97,118,101,95,111,110,95,101,120,105,116,0,0,0,0,0,82,101,119,105,110,100,0,0,111,117,116,115,99,97,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,10,0,0,0,0,82,84,67,32,61,32,37,100,46,10,0,0,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,81,117,101,114,121,105,110,103,32,71,76,32,101,120,116,101,110,115,105,111,110,58,32,37,115,32,61,62,32,37,115,10,0,0,0,0,0,106,111,121,112,97,100,95,97,117,116,111,99,111,110,102,105,103,95,100,105,114,0,0,0,83,72,65,68,69,82,32,37,115,0,0,0,0,0,0,0,71,76,69,83,50,0,0,0,78,111,32,111,112,116,105,111])
.concat([110,115,32,97,118,97,105,108,97,98,108,101,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,115,105,122,101,95,121,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,115,97,118,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,46,10,0,0,0,45,45,62,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,43,0,0,0,0,0,0,0,0,105,110,112,117,116,95,97,117,116,111,100,101,116,101,99,116,95,101,110,97,98,108,101,0,82,97,116,101,32,67,111,110,116,114,111,108,32,68,101,108,116,97,0,0,0,0,0,0,115,105,122,101,95,120,0,0,105,110,105,116,95,109,111,118,105,101,40,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,101,114,102,111,114,109,32,105,110,105,116,105,97,108,32,115,101,114,105,97,108,105,122,97,116,105,111,110,32,102,111,114,32,114,101,119,105,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,32,71,80,85,32,114,101,110,100,101,114,105,110,103,32,105,115,32,117,115,101,100,32,97,110,100,32,114,101,97,100,95,118,105,101,119,112,111,114,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,1,2,4,6,0,0,0,0,1,1,3,7,0,0,0,0,1,2,4,6,8,10,12,14,0,4,2,1,3,3,3,3,96,186,11,0,32,190,11,0,224,193,11,0,160,197,11,0,132,64,67,170,45,120,146,60,96,89,89,176,52,184,46,218,0,255,0,255,0,255,0,255,0,255,0,255,0,255,0,255,224,117,0,0,208,177,0,0,0,0,0,0,0,0,0,0,4,0,0,0,252,255,255,255,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,4,0,0,0,224,105,12,0,16,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,4,0,0,0,224,105,12,0,16,0,0,0,88,185,11,0,64,0,0,0,152,185,11,0,4,0,0,0,156,185,11,0,4,0,0,0,160,185,11,0,4,0,0,0,164,185,11,0,4,0,0,0,168,185,11,0,4,0,0,0,172,185,11,0,4,0,0,0,176,185,11,0,4,0,0,0,180,185,11,0,4,0,0,0,184,185,11,0,16,0,0,0,200,185,11,0,16,0,0,0,216,185,11,0,16,0,0,0,232,185,11,0,16,0,0,0,248,185,11,0,12,0,0,0,4,186,11,0,12,0,0,0,16,186,11,0,12,0,0,0,224,105,12,0,52,0,0,0,88,233,1,0,4,0,0,0,224,105,12,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,128,190,0,0,0,191,0,0,128,191,0,0,128,190,0,0,0,2,0,0,0,0,50,32,71,97,109,101,115,32,105,110,32,49,32,45,32,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,84,104,101,32,76,101,103,97,99,121,32,111,102,32,71,111,107,117,32,73,32,38,32,73,73,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,76,70,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,32,71,97,109,101,115,32,105,110,32,49,32,45,32,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,66,117,117,39,115,32,70,117,114,121,32,43,32,68,114,97,103,111,110,32,66,97,108,108,32,71,84,32,45,32,84,114,97,110,115,102,111,114,109,97,116,105,111,110,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,85,70,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,111,107,116,97,105,32,45,32,84,104,101,32,83,117,110,32,73,115,32,105,110,32,89,111,117,114,32,72,97,110,100,32,40,69,117,114,111,112,101,41,40,69,110,44,70,114,44,68,101,44,69,115,44,73,116,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,51,73,80,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,66,111,107,116,97,105,32,45,32,84,104,101,32,83,117,110,32,73,115,32,105,110,32,89,111,117,114,32,72,97,110,100,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,51,73,69,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,66,111,107,116,97,105,32,50,32,45,32,83,111,108,97,114,32,66,111,121,32,68,106,97,110,103,111,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,51,50,69,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,66,111,107,116,97,105,32,50,32,45,32,83,111,108,97,114,32,66,111,121,32,68,106,97,110,103,111,32,40,69,117,114,111,112,101,41,40,69,110,44,70,114,44,68,101,44,69,115,44,73,116,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,51,50,80,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,66,111,107,117,114,97,32,110,111,32,84,97,105,121,111,117,32,45,32,84,97,105,121,111,117,32,65,99,116,105,111,110,32,82,80,71,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,51,73,74,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,67,97,114,100,32,101,45,82,101,97,100,101,114,43,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,83,65,74,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,66,111,109,98,101,114,109,97,110,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,66,77,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,67,97,115,116,108,101,118,97,110,105,97,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,65,68,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,68,111,110,107,101,121,32,75,111,110,103,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,68,75,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,68,114,46,32,77,97,114,105,111,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,68,77,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,69,120,99,105,116,101,98,105,107,101,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,69,66,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,76,101,103,101,110,100,32,111,102,32,90,101,108,100,97,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,90,76,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,73,99,101,32,67,108,105,109,98,101,114,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,73,67,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,77,101,116,114,111,105,100,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,77,82,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,80,97,99,45,77,97,110,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,80,55,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,83,117,112,101,114,32,77,97,114,105,111,32,66,114,111,115,46,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,83,77,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,88,101,118,105,111,117,115,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,88,86,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,67,108,97,115,115,105,99,32,78,69,83,32,83,101,114,105,101,115,32,45,32,90,101,108,100,97,32,73,73,32,45,32,84,104,101,32,65,100,118,101,110,116,117,114,101,32,111,102,32,76,105,110,107,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,76,66,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,68,105,103,105,32,67,111,109,109,117,110,105,99,97,116,105,111,110,32,50,32,45,32,68,97,116,111,117,33,32,66,108,97,99,107,32,71,101,109,97,103,101,109,97,32,68,97,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,68,75,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,45,82,101,97,100,101,114,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,83,65,69,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,97,108,108,32,71,84,32,45,32,84,114,97,110,115,102,111,114,109,97,116,105,111,110,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,84,52,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,66,117,117,39,115,32,70,117,114,121,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,71,51,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,84,97,105,107,101,116,115,117,32,40,69,117,114,111,112,101,41,40,69,110,44,70,114,44,68,101,44,69,115,44,73,116,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,68,66,80,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,84,97,105,107,101,116,115,117,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,68,66,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,84,104,101,32,76,101,103,97,99,121,32,111,102,32,71,111,107,117,32,73,73,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,76,70,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,84,104,101,32,76,101,103,97,99,121,32,111,102,32,71,111,107,117,32,73,73,32,40,69,117,114,111,112,101,41,40,69,110,44,70,114,44,68,101,44,69,115,44,73,116,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,76,70,80,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,84,104,101,32,76,101,103,97,99,121,32,111,102,32,71,111,107,117,32,73,73,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,76,70,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,84,104,101,32,76,101,103,97,99,121,32,79,102,32,71,111,107,117,32,40,69,117,114,111,112,101,41,40,69,110,44,70,114,44,68,101,44,69,115,44,73,116,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,76,71,80,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,84,104,101,32,76,101,103,97,99,121,32,111,102,32,71,111,107,117,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,76,71,69,0,0,0,0,0,0,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,45,90,101,114,111,32,45,32,67,108,105,109,97,120,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,70,84,74,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,48,49,32,45,32,83,117,112,101,114,32,77,97,114,105,111,32,66,114,111,115,46,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,77,66,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105])
.concat([99,111,109,32,77,105,110,105,32,86,111,108,46,32,49,50,32,45,32,67,108,117,32,67,108,117,32,76,97,110,100,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,67,76,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,49,51,32,45,32,66,97,108,108,111,111,110,32,70,105,103,104,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,66,70,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,49,52,32,45,32,87,114,101,99,107,105,110,103,32,67,114,101,119,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,87,67,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,49,53,32,45,32,68,114,46,32,77,97,114,105,111,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,68,77,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,49,54,32,45,32,68,105,103,32,68,117,103,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,84,66,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,49,55,32,45,32,84,97,107,97,104,97,115,104,105,32,77,101,105,106,105,110,32,110,111,32,66,111,117,107,101,110,106,105,109,97,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,84,66,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,49,56,32,45,32,77,97,107,97,105,109,117,114,97,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,77,75,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,49,57,32,45,32,84,119,105,110,32,66,101,101,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,84,87,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,50,48,32,45,32,71,97,110,98,97,114,101,32,71,111,101,109,111,110,33,32,75,97,114,97,107,117,114,105,32,68,111,117,99,104,117,117,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,71,71,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,50,49,32,45,32,83,117,112,101,114,32,77,97,114,105,111,32,66,114,111,115,46,32,50,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,77,50,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,50,50,32,45,32,78,97,122,111,32,110,111,32,77,117,114,97,115,97,109,101,32,74,111,117,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,78,77,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,50,51,32,45,32,77,101,116,114,111,105,100,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,77,82,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,50,52,32,45,32,72,105,107,97,114,105,32,83,104,105,110,119,97,32,45,32,80,97,108,116,104,101,110,97,32,110,111,32,75,97,103,97,109,105,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,80,84,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,50,53,32,45,32,84,104,101,32,76,101,103,101,110,100,32,111,102,32,90,101,108,100,97,32,50,32,45,32,76,105,110,107,32,110,111,32,66,111,117,107,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,76,66,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,50,54,32,45,32,70,97,109,105,99,111,109,32,77,117,107,97,115,104,105,32,66,97,110,97,115,104,105,32,45,32,83,104,105,110,32,79,110,105,103,97,115,104,105,109,97,32,45,32,90,101,110,32,75,111,117,32,72,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,70,77,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,50,55,32,45,32,70,97,109,105,99,111,109,32,84,97,110,116,101,105,32,67,108,117,98,32,45,32,75,105,101,116,97,32,75,111,117,107,101,105,115,104,97,32,45,32,90,101,110,32,75,111,117,32,72,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,84,75,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,50,56,32,45,32,70,97,109,105,99,111,109,32,84,97,110,116,101,105,32,67,108,117,98,32,80,97,114,116,32,73,73,32,45,32,85,115,104,105,114,111,32,110,105,32,84,97,116,115,117,32,83,104,111,117,106,111,32,45,32,90,101,110,32,75,111,117,32,72,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,84,85,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,50,57,32,45,32,65,107,117,109,97,106,111,117,32,68,114,97,99,117,108,97,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,65,68,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,70,97,109,105,99,111,109,32,77,105,110,105,32,86,111,108,46,32,51,48,32,45,32,83,68,32,71,117,110,100,97,109,32,87,111,114,108,100,32,45,32,71,97,99,104,97,112,111,110,32,83,101,110,115,104,105,32,83,99,114,97,109,98,108,101,32,87,97,114,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,83,68,74,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,71,97,109,101,32,66,111,121,32,87,97,114,115,32,65,100,118,97,110,99,101,32,49,43,50,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,71,87,74,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,111,108,100,101,110,32,83,117,110,32,45,32,84,104,101,32,76,111,115,116,32,65,103,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,71,70,69,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,71,111,108,100,101,110,32,83,117,110,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,71,83,69,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,75,111,114,111,32,75,111,114,111,32,80,117,122,122,108,101,32,45,32,72,97,112,112,121,32,80,97,110,101,99,104,117,33,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,72,80,74,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,77,97,114,105,111,32,118,115,46,32,68,111,110,107,101,121,32,75,111,110,103,32,40,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,77,53,80,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,99,107,101,116,32,77,111,110,115,116,101,114,115,32,45,32,69,109,101,114,97,108,100,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,69,74,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,99,107,101,116,32,77,111,110,115,116,101,114,115,32,45,32,70,105,114,101,32,82,101,100,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,82,74,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,99,107,101,116,32,77,111,110,115,116,101,114,115,32,45,32,76,101,97,102,32,71,114,101,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,71,74,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,99,107,101,116,32,77,111,110,115,116,101,114,115,32,45,32,82,117,98,121,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,86,74,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,99,107,101,116,32,77,111,110,115,116,101,114,115,32,45,32,83,97,112,112,104,105,114,101,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,80,74,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,77,121,115,116,101,114,121,32,68,117,110,103,101,111,110,32,45,32,82,101,100,32,82,101,115,99,117,101,32,84,101,97,109,32,40,85,83,65,44,32,65,117,115,116,114,97,108,105,97,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,50,52,69,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,77,121,115,116,101,114,121,32,68,117,110,103,101,111,110,32,45,32,82,101,100,32,82,101,115,99,117,101,32,84,101,97,109,32,40,69,110,44,70,114,44,68,101,44,69,115,44,73,116,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,50,52,80,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,66,108,97,116,116,103,114,117,101,110,101,32,69,100,105,116,105,111,110,32,40,71,101,114,109,97,110,121,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,71,68,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,69,100,105,99,105,111,110,32,82,117,98,105,32,40,83,112,97,105,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,86,83,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,69,100,105,99,105,111,110,32,69,115,109,101,114,97,108,100,97,32,40,83,112,97,105,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,69,83,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,69,100,105,99,105,111,110,32,82,111,106,111,32,70,117,101,103,111,32,40,83,112,97,105,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,82,83,0,0,0,0,0,0,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,69,100,105,99,105,111,110,32,86,101,114,100,101,32,72,111,106,97,32,40,83,112,97,105,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,71,83,0,0,0,0,0,0,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,69,105,100,105,99,105,111,110,32,90])
.concat([97,102,105,114,111,32,40,83,112,97,105,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,80,83,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,69,109,101,114,97,108,100,32,86,101,114,115,105,111,110,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,69,69,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,70,101,117,101,114,114,111,116,101,32,69,100,105,116,105,111,110,32,40,71,101,114,109,97,110,121,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,82,68,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,70,105,114,101,32,82,101,100,32,86,101,114,115,105,111,110,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,82,69,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,76,101,97,102,32,71,114,101,101,110,32,86,101,114,115,105,111,110,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,71,69,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,82,117,98,105,110,32,69,100,105,116,105,111,110,32,40,71,101,114,109,97,110,121,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,86,68,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,82,117,98,121,32,86,101,114,115,105,111,110,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,86,69,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,83,97,112,112,104,105,114,101,32,86,101,114,115,105,111,110,32,40,85,83,65,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,80,69,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,83,97,112,104,105,114,32,69,100,105,116,105,111,110,32,40,71,101,114,109,97,110,121,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,80,68,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,83,109,97,114,97,103,100,32,69,100,105,116,105,111,110,32,40,71,101,114,109,97,110,121,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,69,68,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,86,101,114,115,105,111,110,32,69,109,101,114,97,117,100,101,32,40,70,114,97,110,99,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,69,70,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,86,101,114,115,105,111,110,32,82,111,117,103,101,32,70,101,117,32,40,70,114,97,110,99,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,82,70,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,86,101,114,115,105,111,110,32,82,117,98,105,115,32,40,70,114,97,110,99,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,86,70,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,86,101,114,115,105,111,110,32,83,97,112,104,105,114,32,40,70,114,97,110,99,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,80,70,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,86,101,114,115,105,111,110,32,86,101,114,116,32,70,101,117,105,108,108,101,32,40,70,114,97,110,99,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,71,70,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,86,101,114,115,105,111,110,101,32,82,117,98,105,110,111,32,40,73,116,97,108,121,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,86,73,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,86,101,114,115,105,111,110,101,32,82,111,115,115,111,32,70,117,111,99,111,32,40,73,116,97,108,121,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,82,73,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,86,101,114,115,105,111,110,101,32,83,109,101,114,97,108,100,111,32,40,73,116,97,108,121,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,69,73,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,86,101,114,115,105,111,110,101,32,86,101,114,100,101,32,70,111,103,108,105,97,32,40,73,116,97,108,121,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,80,71,73,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,45,32,86,101,114,115,105,111,110,101,32,90,97,102,102,105,114,111,32,40,73,116,97,108,121,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,80,73,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,82,111,99,107,109,97,110,32,69,88,69,32,52,46,53,32,45,32,82,101,97,108,32,79,112,101,114,97,116,105,111,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,82,52,74,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,82,111,99,107,121,32,40,69,117,114,111,112,101,41,40,69,110,44,70,114,44,68,101,44,69,115,44,73,116,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,82,79,80,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,101,110,110,101,110,32,75,97,122,111,107,117,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,75,65,74,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,83,104,105,110,32,66,111,107,117,114,97,32,110,111,32,84,97,105,121,111,117,32,45,32,71,121,97,107,117,115,104,117,117,32,110,111,32,83,97,98,97,116,97,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,51,51,74,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,83,117,112,101,114,32,77,97,114,105,111,32,65,100,118,97,110,99,101,32,52,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,52,74,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,117,112,101,114,32,77,97,114,105,111,32,65,100,118,97,110,99,101,32,52,32,45,32,83,117,112,101,114,32,77,97,114,105,111,32,66,114,111,115,46,32,51,32,40,69,117,114,111,112,101,41,40,69,110,44,70,114,44,68,101,44,69,115,44,73,116,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,52,80,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,117,112,101,114,32,77,97,114,105,111,32,65,100,118,97,110,99,101,32,52,32,45,32,83,117,112,101,114,32,77,97,114,105,111,32,66,114,111,115,32,51,32,45,32,83,117,112,101,114,32,77,97,114,105,111,32,65,100,118,97,110,99,101,32,52,32,118,49,46,49,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,88,52,69,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,111,112,32,71,117,110,32,45,32,67,111,109,98,97,116,32,90,111,110,101,115,32,40,85,83,65,41,40,69,110,44,70,114,44,68,101,44,69,115,44,73,116,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,50,89,69,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,111,115,104,105,32,110,111,32,66,97,110,121,117,117,105,110,114,121,111,107,117,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,89,71,74,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,111,115,104,105,32,45,32,84,111,112,115,121,45,84,117,114,118,121,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,89,71,69,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,117,45,71,105,45,79,104,33,32,71,88,32,45,32,68,117,101,108,32,65,99,97,100,101,109,121,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,89,71,69,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,89,117,45,71,105,45,79,104,33,32,45,32,85,108,116,105,109,97,116,101,32,77,97,115,116,101,114,115,32,45,32,50,48,48,54,32,40,69,117,114,111,112,101,41,40,69,110,44,74,112,44,70,114,44,68,101,44,69,115,44,73,116,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,89,54,80,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,111,107,117,32,66,111,107,117,114,97,32,110,111,32,84,97,105,121,111,117,32,45,32,84,97,105,121,111,117,32,83,104,111,117,110,101,110,32,68,106,97,110,103,111,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,51,50,74,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,2,0,0,0,3,0,0,0,7,0,0,0,6,0,0,0,4,0,0,0,5,0,0,0,11,0,0,0,10,0,0,0,16,255,0,0,0,0,0,0,17,255,0,0,18,255,0,0,19,255,0,0,20,255,0,0,0,0,0,0,0,0,0,0,22,255,0,0,23,255,0,0,0,0,0,0,0,0,0,0,24,255,0,0,25,255,0,0,0,0,0,0,0,0,0,0,26,255,0,0,0,0,0,0,27,255,0,0,28,255,0,0,29,255,0,0,30,255,0,0,0,0,0,0,0,0,0,0,32,255,0,0,33,255,0,0,0,0,0,0,0,0,0,0,34,255,0,0,35,255,0,0,0,0,0,0,0,0,0,0,36,255,0,0,37,255,0,0,0,0,0,0,0,0,0,0,38,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,255,0,0,49,255,0,0,50,255,0,0,51,255,0,0,52,255,0,0,53,255,0,0,54,255,0,0,55,255,0,0,56,255,0,0,57,255,0,0,58,255,0,0,59,255,0,0,60,255,0,0,61,255,0,0,62,255,0,0,63,255,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,8,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,7,0,0,0,6,0,0,0,4,0,0,0,5,0,0,0,11,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,4,3,2,8,0,0,0,0,0,32,2,0,0,0,0,0,255,3,0,0,0,0,0,0,0,0,1,0,0,64,1,0,0,64,1,0,0,0,0,0,0,0,5,0,0,1,1,0,5,5,9,9,17,17,4,0,116,5,0,0,194,0,0,0,184,2,0,0,24,4,0,0,54,0,0,0,136,1,0,0,116,3,0,0,226,4,0,0,80,2,0,0,86,5,0,0,88,2,0,0,194,5,0,0,182,1,0,0,0,3,0,0,218,0,0,0,102,0,0,0,110,3,0,0,142,1,0,0,56,0,0,0,28,1,0,0,58,4,0,0,40,2,0,0,252,0,0,0,230,4,0,0,18,2,0,0,34,0,0,0,244,3,0,0,208,5,0,0,160,0,0,0,16,0,0,0,182,4,0,0,152,2,0,0,208,1,0,0,76,0,0,0,154,1,0,0,148,3,0,0,242,4,0,0,18,1,0,0,62,2,0,0,88,4,0,0,176,5,0,0,166,1,0,0,246,1,0,0,14,4,0,0,94,5,0,0,124,1,0,0,168,2,0,0,226,3,0,0,70,2,0,0,26,1,0,0,254,5,0,0,156,3,0,0,254,2,0,0,180,1,0,0,192,5,0,0,94,0,0,0,174,3,0,0,96,2,0,0,220,3,0,0,122,2,0,0,134,0,0,0,176,0,0,0,148,4,0,0,52,3,0,0,188,0,0,0,106,1,0,0,218,4,0,0,174,2,0,0,36,2,0,0,38,1,0,0,150,5,0,0,100,3,0,0,220,1,0,0,238,3,0,0,156,1,0,0,24,1,0,0,250,4,0,0,194,4,0,0,64,2,0,0,192,1,0,0,134,2,0,0,180,4,0,0,44,4,0,0,102,1,0,0,226,1,0,0,234,3,0,0,142,4,0,0,150,0,0,0,208,4,0,0,40,0,0,0,250,1,0,0,132,2,0,0,196,1,0,0,64,5,0,0,86,1,0,0,214,1,0,0,100,1,0,0,70,5,0,0,22,3,0,0,154,2,0,0,146,0,0,0,132,4,0,0,236,3,0,0,246,5,0,0,202,3,0,0,182,0,0,0,252,1,0,0,8,4,0,0,208,3,0,0,250,5,0,0,72,1,0,0,142,2,0,0,188,2,0,0,198,4,0,0,10,3,0,0,210,0,0,0,98,3,0,0,138,5,0,0,142,0,0,0,188,3,0,0,50,2,0,0,66,4,0,0,166,5,0,0,174,1,0,0,238,2,0,0,174,0,0,0,116,0,0,0,100,2,0,0,244,1,0,0,244,1,0,0,244,1,0,0,244,1,0,0,166,0,0,0,166,0,0,0,166,0,0,0,166,0,0,0,172,3,0,0,172,3,0,0,172,3,0,0,172,3,0,0,50,3,0,0,50,3,0,0,50,3,0,0,50,3,0,0,170,2,0,0,170,2,0,0,170,2,0,0,170,2,0,0,206,2,0,0,206,2,0,0,206,2,0,0,206,2,0,0,92,5,0,0,92,5,0,0,92,5,0,0,92,5,0,0,2,4,0,0,2,4,0,0,2,4,0,0,2,4,0,0,158,0,0,0,158,0,0,0,158,0,0,0,158,0,0,0,46,3,0,0,46,3,0,0,46,3,0,0,46,3,0,0,30,4,0,0,30,4,0,0,30,4,0,0,30,4,0,0,108,1,0,0,108,1,0,0,108,1,0,0,108,1,0,0,80,5,0,0,80,5,0,0,80,5,0,0,80,5,0,0,176,3,0,0,176,3,0,0,176,3,0,0,176,3,0,0,252,3,0,0,252,3,0,0,252,3,0,0,252,3,0,0,42,5,0,0,42,5,0,0,42,5,0,0,42,5,0,0,78,1,0,0,78,1,0,0,78,1,0,0,78,1,0,0,248,5,0,0,248,5,0,0,248,5,0,0,248,5,0,0,70,1,0,0,70,1,0,0,70,1,0,0,70,1,0,0,2,2,0,0,2,2,0,0,2,2,0,0,2,2,0,0,158,4,0,0,158,4,0,0,158,4,0,0,158,4,0,0,178,0,0,0,178,0,0,0,178,0,0,0,178,0,0,0,248,1,0,0,248,1,0,0,248,1,0,0,248,1,0,0,156,0,0,0,156,0,0,0,156,0,0,0,156,0,0,0,178,2,0,0,178,2,0,0,178,2,0,0,178,2,0,0,216,4,0,0,216,4,0,0,216,4,0,0,216,4,0,0,250,2,0,0,250,2,0,0,250,2,0,0,250,2,0,0,204,0,0,0,204,0,0,0,204,0,0,0,204,0,0,0,20,1,0,0,20,1,0,0,20,1,0,0,20,1,0,0,112,3,0,0,112,3,0,0,112,3,0,0,112,3,0,0,90,4,0,0,90,4,0,0,90,4,0,0,90,4,0,0,200,5,0,0,200,5,0,0,200,5,0,0,200,5,0,0,206,4,0,0,30,0,0,0,110,1,0,0,156,2,0,0,244,0,0,0,170,0,0,0,58,1,0,0,234,5,0,0,200,4,0,0,28,0,0,0,20,2,0,0,94,3,0,0,2,5,0,0,166,3,0,0,44,2,0,0,218,3,0,0,88,5,0,0,206,1,0,0,84,2,0,0,116,4,0,0,88,5,0,0,130,4,0,0,30,3,0,0,2,1,0,0,88,5,0,0,210,5,0,0,142,3,0,0,232,4,0,0,106,3,0,0,106,3,0,0,88,5,0,0,88,5,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,116,1,0,0,22,5,0,0,22,5,0,0,22,5,0,0,22,5,0,0,22,5,0,0,22,5,0,0,22,5,0,0,22,5,0,0,226,2,0,0,226,2,0,0,226,2,0,0,226,2,0,0,226,2,0,0,226,2,0,0,226,2,0,0,226,2,0,0,112,5,0,0,112,5,0,0,112,5,0,0,112,5,0,0,112,5,0,0,112,5,0,0,112,5,0,0,112,5,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,40,3,0,0,40,3,0,0,40,3,0,0,40,3,0,0,40,3,0,0,40,3,0,0,40,3,0,0,40,3,0,0,78,4,0,0,78,4,0,0,78,4,0,0,78,4,0,0,78,4,0,0,78,4,0,0,78,4,0,0,78,4,0,0,220,5,0,0,220,5,0,0,220,5,0,0,220,5,0,0,220,5,0,0,220,5,0,0,220,5,0,0,220,5,0,0,28,5,0,0,28,5,0,0,28,5,0,0,28,5,0,0,28,5,0,0,28,5,0,0,28,5,0,0,28,5,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,42,4,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,4,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,114,2,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,222,3,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,60,1,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,156,5,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,242,2,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,46,5,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,118,5,0,0,160,2,0,0,160,2,0,0,160,2,0,0,160,2,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,90,3,0,0,90,3,0,0,90,3,0,0,90,3,0,0,22,2,0,0,22,2,0,0,22,2,0,0,22,2,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,120,1,0,0,120,1,0,0,120,1,0,0,120,1,0,0,236,0,0,0,236,0,0,0,236,0,0,0,236,0,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,196,4,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,20,3,0,0,138,2,0,0,138,2,0,0,138,2,0,0,138,2,0,0,212,3,0,0,212,3,0,0,212,3,0,0,212,3,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,202,2,0,0,202,2,0,0,202,2,0,0,202,2,0,0,226,0,0,0,226,0,0,0,226,0,0,0,226,0,0,0,82,0,0,0,82,0,0,0,82,0,0,0,82,0,0,0,38,4,0,0,38,4,0,0,38,4,0,0,38,4,0,0,144,1,0,0,144,1,0,0,144,1,0,0,144,1,0,0,70,0,0,0,70,0,0,0,70,0,0,0,70,0,0,0,82,5,0,0,82,5,0,0,82,5,0,0,82,5,0,0,202,4,0,0,202,4,0,0,202,4,0,0,202,4,0,0,164,2,0,0,164,2,0,0,164,2,0,0,164,2,0,0,124,0,0,0,124,0,0,0,124,0,0,0,124,0,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,246,3,0,0,246,3,0,0,246,3,0,0,246,3,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,140,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,88,5,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,224,2,0,0,144,233,11,0,2,0,0,0,148,233,11,0,2,0,0,0,150,233,11,0,2,0,0,0,152,233,11,0,2,0,0,0,154,233,11,0,2,0,0,0,156,233,11,0,2,0,0,0,158,233,11,0,2,0,0,0,160,233,11,0,2,0,0,0,162,233,11,0,2,0,0,0,164,233,11,0,2,0,0,0,166,233,11,0,2,0,0,0,168,233,11,0,2,0,0,0,170,233,11,0,2,0,0,0,172,233,11,0,2,0,0,0,174,233,11,0,2,0,0,0,176,233,11,0,2,0,0,0,178,233,11,0,2,0,0,0,180,233,11,0,2,0,0,0,182,233,11,0,2,0,0,0,64,185,11,0,2,0,0,0,72,185,11,0,2,0,0,0,48,185,11,0,2,0,0,0,56,185,11,0,2,0,0,0,192,233,11,0,2,0,0,0,194,233,11,0,2,0,0,0,196,233,11,0,2,0,0,0,198,233,11,0,2,0,0,0,32,185,11,0,2,0,0,0,40,185,11,0,2,0,0,0,16,185,11,0,2,0,0,0,24,185,11,0,2,0,0,0,208,233,11,0,2,0,0,0,210,233,11,0,2,0,0,0,212,233,11,0,2,0,0,0,214,233,11,0,2,0,0,0,216,233,11,0,2,0,0,0,218,233,11,0,2,0,0,0,248,184,11,0,2,0,0,0,8,185,11,0,2,0,0,0,88,186,11,0,2,0,0,0,232,208,11,0,2,0,0,0,136,184,11,0,2,0,0,0,144,184,11,0,2,0,0,0,152,184,11,0,2,0,0,0,160,184,11,0,2,0,0,0,168,184,11,0,2,0,0,0,176,184,11,0,2,0,0,0,88,184,11,0,2,0,0,0,96,184,11,0,2,0,0,0,104,184,11,0,2,0,0,0,112,184,11,0,2,0,0,0,120,184,11,0,2,0,0,0,128,184,11,0,2,0,0,0,40,184,11,0,2,0,0,0,48,184,11,0,2,0,0,0,56,184,11,0,2,0,0,0,64,184,11,0,2,0,0,0,72,184,11,0,2,0,0,0,80,184,11,0,2,0,0,0,248,183,11,0,2,0,0,0,0,184,11,0,2,0,0,0,8,184,11,0,2,0,0,0,16,184,11,0,2,0,0,0,24,184,11,0,2,0,0,0,32,184,11,0,2,0,0,0,144,234,11,0,2,0,0,0,146,234,11,0,2,0,0,0,148,234,11,0,2,0,0,0,150,234,11,0,2,0,0,0,152,234,11,0,2,0,0,0,154,234,11,0,2,0,0,0,156,234,11,0,2,0,0,0,158,234,11,0,2,0,0,0,192,234,11,0,2,0,0,0,144,235,11,0,2,0,0,0,146,235,11,0,2,0,0,0,152,235,11,0,2,0,0,0,152,181,11,0,1,0,0,0,228,181,11,0,4,0,0,0,200,181,11,0,1,0,0,0,208,105,12,0,4,0,0,0,88,233,11,0,4,0,0,0,112,218,11,0,4,0,0,0,192,181,11,0,1,0,0,0,192,105,12,0,4,0,0,0,80,233,11,0,4,0,0,0,104,218,11,0,4,0,0,0,184,181,11,0,1,0,0,0,176,105,12,0,4,0,0,0,72,233,11,0,4,0,0,0,96,218,11,0,4,0,0,0,176,181,11,0,1,0,0,0,160,105,12,0,4,0,0,0,64,233,11,0,4,0,0,0,88,218,11,0,4,0,0,0,176,122,12,0,4,0,0,0,224,183,11,0,4,0,0,0,168,122,12,0,4,0,0,0,216,183,11,0,4,0,0,0,160,122,12,0,4,0,0,0,208,183,11,0,4,0,0,0,152,122,12,0,4,0,0,0,200,183,11,0,4,0,0,0,224,208,11,0,1,0,0,0,160,181,11,0,1,0,0,0,240,184,11,0,1,0,0,0,0,185,11,0,1,0,0,0,224,184,11,0,1,0,0,0,232,184,11,0,1,0,0,0,72,203,0,0,1,0,0,0,72,254,1,0,1,0,0,0,68,218,11,0,4,0,0,0,104,231,1,0,4,0,0,0,216,63,2,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,2,2,4,4,8,8,4,0,128,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,0,0,5,0,0,1,1,0,7,7,9,9,13,13,4,0,1,0,0,0,0,0,0,0,182,3,0,0,228,5,0,0,190,3,0,0,50,1,0,0,234,2,0,0,14,5,0,0,96,0,0,0,98,2,0,0,182,3,0,0,118,4,0,0,190,3,0,0,128,3,0,0,234,2,0,0,188,4,0,0,96,0,0,0,188,4,0,0,222,1,0,0,154,0,0,0,134,4,0,0,32,3,0,0,52,1,0,0,246,4,0,0,178,3,0,0,92,2,0,0,222,1,0,0,110,0,0,0,134,4,0,0,254,1,0,0,52,1,0,0,174,4,0,0,178,3,0,0,120,4,0,0,218,5,0,0,138,1,0,0,176,2,0,0,212,0,0,0,10,1,0,0,54,2,0,0,130,3,0,0,228,4,0,0,218,5,0,0,250,3,0,0,176,2,0,0,188,4,0,0,10,1,0,0,188,4,0,0,130,3,0,0,188,4,0,0,62,4,0,0,96,1,0,0,172,1,0,0,178,5,0,0,120,3,0,0,132,1,0,0,60,0,0,0,222,4,0,0,62,4,0,0,94,4,0,0,172,1,0,0,188,4,0,0,120,3,0,0,174,4,0,0,60,0,0,0,120,4,0,0,98,5,0,0,122,1,0,0,212,5,0,0,220,4,0,0,44,0,0,0,32,2,0,0,66,3,0,0,106,5,0,0,98,5,0,0,188,4,0,0,212,5,0,0,36,5,0,0,44,0,0,0,188,4,0,0,66,3,0,0,188,4,0,0,114,3,0,0,26,2,0,0,38,0,0,0,212,4,0,0,198,0,0,0,172,2,0,0,234,0,0,0,152,5,0,0,114,3,0,0,188,4,0,0,38,0,0,0,150,3,0,0,198,0,0,0,198,1,0,0,234,0,0,0,104,4,0,0,130,1,0,0,118,3,0,0,52,4,0,0,84,0,0,0,228,0,0,0,228,2,0,0,104,3,0,0,148,5,0,0,130,1,0,0,188,4,0,0,52,4,0,0,188,4,0,0,228,0,0,0,188,4,0,0,104,3,0,0,188,4,0,0,168,5,0,0,232,5,0,0,100,0,0,0,164,1,0,0,112,2,0,0,18,5,0,0,192,3,0,0,104,2,0,0,168,5,0,0,188,4,0,0,100,0,0,0,188,4,0,0,112,2,0,0,198,1,0,0,192,3,0,0,104,4,0,0,112,0,0,0,102,2,0,0,98,4,0,0,190,5,0,0,180,5,0,0,176,1,0,0,236,2,0,0,34,5,0,0,112,0,0,0,118,1,0,0,98,4,0,0,106,0,0,0,180,5,0,0,188,4,0,0,236,2,0,0,188,4,0,0,40,5,0,0,6,3,0,0,56,1,0,0,236,5,0,0,196,3,0,0,198,2,0,0,108,0,0,0,20,5,0,0,40,5,0,0,166,4,0,0,56,1,0,0,100,5,0,0,196,3,0,0,36,3,0,0,108,0,0,0,20,4,0,0,194,1,0,0,198,5,0,0,92,4,0,0,126,5,0,0,22,1,0,0,24,5,0,0,252,2,0,0,184,1,0,0,194,1,0,0,74,4,0,0,92,4,0,0,188,4,0,0,22,1,0,0,188,4,0,0,252,2,0,0,188,4,0,0,114,5,0,0,254,4,0,0,14,2,0,0,80,3,0,0,26,0,0,0,8,1,0,0,76,5,0,0,32,4,0,0,114,5,0,0,218,2,0,0,14,2,0,0,188,4,0,0,26,0,0,0,36,3,0,0,76,5,0,0,20,4,0,0,144,3,0,0,146,1,0,0,214,0,0,0,130,5,0,0,50,5,0,0,202,0,0,0,72,0,0,0,26,4,0,0,144,3,0,0,162,3,0,0,214,0,0,0,140,3,0,0,50,5,0,0,188,4,0,0,72,0,0,0,188,4,0,0,124,4,0,0,140,0,0,0,52,5,0,0,232,3,0,0,62,5,0,0,94,1,0,0,146,2,0,0,184,4,0,0,124,4,0,0,16,2,0,0,52,5,0,0,68,5,0,0,62,5,0,0,150,2,0,0,146,2,0,0,162,0,0,0,140,2,0,0,82,1,0,0,58,5,0,0,224,3,0,0,76,3,0,0,12,2,0,0,8,0,0,0,178,4,0,0,140,2,0,0,186,2,0,0,58,5,0,0,188,4,0,0,76,3,0,0,188,4,0,0,8,0,0,0,188,4,0,0,200,0,0,0,182,2,0,0,70,3,0,0,110,5,0,0,4,0,0,0,6,2,0,0,130,2,0,0,172,4,0,0,200,0,0,0,40,4,0,0,70,3,0,0,188,4,0,0,4,0,0,0,150,2,0,0,130,2,0,0,162,0,0,0,46,1,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,64,1,0,0,188,4,0,0,114,1,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,230,2,0,0,16,5,0,0,158,5,0,0,162,1,0,0,184,3,0,0,230,5,0,0,98,0,0,0,90,2,0,0,230,2,0,0,188,4,0,0,158,5,0,0,244,2,0,0,184,3,0,0,190,1,0,0,98,0,0,0,238,4,0,0,120,5,0,0,86,3,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,126,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,160,3,0,0,248,3,0,0,192,4,0,0,18,0,0,0,154,4,0,0,216,1,0,0,228,3,0,0,72,5,0,0,160,3,0,0,188,4,0,0,192,4,0,0,24,3,0,0,154,4,0,0,254,3,0,0,228,3,0,0,232,0,0,0,28,3,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,202,5,0,0,188,4,0,0,46,2,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,8,5,0,0,90,0,0,0,204,1,0,0,16,3,0,0,112,4,0,0,206,5,0,0,30,1,0,0,34,2,0,0,8,5,0,0,188,4,0,0,204,1,0,0,150,4,0,0,112,4,0,0,84,1,0,0,30,1,0,0,200,3,0,0,42,1,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,84,5,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,216,2,0,0,50,4,0,0,232,1,0,0,160,1,0,0,164,3,0,0,252,4,0,0,246,0,0,0,42,2,0,0,216,2,0,0,188,4,0,0,232,1,0,0,2,3,0,0,164,3,0,0,126,0,0,0,246,0,0,0,214,3,0,0,46,4,0,0,210,2,0,0,158,1,0,0,86,0,0,0,96,3,0,0,24,2,0,0,230,0,0,0,64,3,0,0,46,4,0,0,188,4,0,0,158,1,0,0,214,4,0,0,96,3,0,0,188,4,0,0,230,0,0,0,188,4,0,0,180,0,0,0,28,2,0,0,140,4,0,0,204,4,0,0,240,0,0,0,244,5,0,0,102,3,0,0,144,5,0,0,180,0,0,0,188,4,0,0,140,4,0,0,216,3,0,0,240,0,0,0,152,4,0,0,102,3,0,0,68,4,0,0,172,5,0,0,186,1,0,0,58,2,0,0,76,4,0,0,68,0,0,0,72,2,0,0,248,2,0,0,26,5,0,0,172,5,0,0,188,4,0,0,58,2,0,0,90,5,0,0,68,0,0,0,188,4,0,0,248,2,0,0,188,4,0,0,234,1,0,0,172,0,0,0,124,3,0,0,42,3,0,0,68,1,0,0,74,5,0,0,240,3,0,0,228,1,0,0,234,1,0,0,188,4,0,0,124,3,0,0,240,1,0,0,68,1,0,0,162,4,0,0,240,3,0,0,76,1,0,0,198,3,0,0,242,5,0,0,74,1,0,0,48,3,0,0,38,3,0,0,144,4,0,0,180,3,0,0,146,5,0,0,198,3,0,0,188,4,0,0,74,1,0,0,108,3,0,0,38,3,0,0,188,4,0,0,180,3,0,0,188,4,0,0,240,5,0,0,194,3,0,0,8,3,0,0,54,1,0,0,118,0,0,0,38,5,0,0,56,5,0,0,200,1,0,0,240,5,0,0,188,4,0,0,8,3,0,0,132,0,0,0,118,0,0,0,48,4,0,0,56,5,0,0,80,1,0,0,142,5,0,0,240,2,0,0,64,4,0,0,164,5,0,0,242,0,0,0,52,2,0,0,122,3,0,0,224,4,0,0,142,5,0,0,188,4,0,0,64,4,0,0,152,0,0,0,242,0,0,0,188,4,0,0,122,3,0,0,188,4,0,0,136,3,0,0,232,2,0,0,46,0,0,0,22,4,0,0,72,4,0,0,56,2,0,0,248,0,0,0,102,5,0,0,136,3,0,0,188,4,0,0,46,0,0,0,250,0,0,0,72,4,0,0,150,1,0,0,248,0,0,0,82,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,244,4,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,148,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,194,2,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,154,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,242,3,0,0,208,0,0,0,208,0,0,0,208,0,0,0,208,0,0,0,208,0,0,0,208,0,0,0,208,0,0,0,208,0,0,0,208,0,0,0,208,0,0,0,208,0,0,0,208,0,0,0,208,0,0,0,208,0,0,0])
.concat([208,0,0,0,208,0,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,128,5,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,212,1,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,110,2,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,236,1,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,42,0,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,220,2,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,160,5,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,168,0,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,84,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,156,4,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,200,2,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,116,2,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,238,5,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,170,1,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,220,0,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,44,1,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,14,3,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,204,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,158,2,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,214,5,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,148,0,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,82,2,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,136,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,36,4,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,74,2,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,202,1,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,4,6,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,216,5,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,148,1,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,82,3,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,66,5,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,92,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,140,1,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,10,2,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,230,3,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,38,2,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,4,4,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,26,3,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,12,5,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,40,1,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,162,5,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,48,2,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,18,4,0,0,246,2,0,0,188,4,0,0,188,5,0,0,188,4,0,0,108,4,0,0,188,4,0,0,16,1,0,0,188,4,0,0,246,2,0,0,188,4,0,0,188,5,0,0,188,4,0,0,108,4,0,0,188,4,0,0,16,1,0,0,188,4,0,0,188,1,0,0,188,4,0,0,44,5,0,0,188,4,0,0,114,0,0,0,188,4,0,0,100,4,0,0,188,4,0,0,188,1,0,0,188,4,0,0,44,5,0,0,188,4,0,0,114,0,0,0,188,4,0,0,100,4,0,0,188,4,0,0,246,2,0,0,188,4,0,0,188,5,0,0,188,4,0,0,108,4,0,0,188,4,0,0,16,1,0,0,188,4,0,0,246,2,0,0,188,4,0,0,188,5,0,0,188,4,0,0,108,4,0,0,188,4,0,0,16,1,0,0,188,4,0,0,188,1,0,0,188,4,0,0,44,5,0,0,188,4,0,0,114,0,0,0,188,4,0,0,100,4,0,0,188,4,0,0,188,1,0,0,188,4,0,0,44,5,0,0,188,4,0,0,114,0,0,0,188,4,0,0,100,4,0,0,188,4,0,0,32,5,0,0,188,4,0,0,110,4,0,0,188,4,0,0,60,4,0,0,188,4,0,0,0,1,0,0,188,4,0,0,32,5,0,0,188,4,0,0,110,4,0,0,188,4,0,0,60,4,0,0,188,4,0,0,0,1,0,0,188,4,0,0,128,2,0,0,188,4,0,0,14,0,0,0,188,4,0,0,68,3,0,0,188,4,0,0,210,4,0,0,188,4,0,0,128,2,0,0,188,4,0,0,14,0,0,0,188,4,0,0,68,3,0,0,188,4,0,0,210,4,0,0,188,4,0,0,32,5,0,0,188,4,0,0,110,4,0,0,188,4,0,0,60,4,0,0,188,4,0,0,0,1,0,0,188,4,0,0,32,5,0,0,188,4,0,0,110,4,0,0,188,4,0,0,60,4,0,0,188,4,0,0,0,1,0,0,188,4,0,0,128,2,0,0,188,4,0,0,14,0,0,0,188,4,0,0,68,3,0,0,188,4,0,0,210,4,0,0,188,4,0,0,128,2,0,0,188,4,0,0,14,0,0,0,188,4,0,0,68,3,0,0,188,4,0,0,210,4,0,0,188,4,0,0,174,5,0,0,188,4,0,0,56,3,0,0,188,4,0,0,90,1,0,0,188,4,0,0,12,4,0,0,188,4,0,0,174,5,0,0,188,4,0,0,56,3,0,0,188,4,0,0,90,1,0,0,188,4,0,0,12,4,0,0,188,4,0,0,236,4,0,0,188,4,0,0,104,0,0,0,188,4,0,0,6,4,0,0,188,4,0,0,126,1,0,0,188,4,0,0,236,4,0,0,188,4,0,0,104,0,0,0,188,4,0,0,6,4,0,0,188,4,0,0,126,1,0,0,188,4,0,0,174,5,0,0,188,4,0,0,56,3,0,0,188,4,0,0,90,1,0,0,188,4,0,0,12,4,0,0,188,4,0,0,174,5,0,0,188,4,0,0,56,3,0,0,188,4,0,0,90,1,0,0,188,4,0,0,12,4,0,0,188,4,0,0,236,4,0,0,188,4,0,0,104,0,0,0,188,4,0,0,6,4,0,0,188,4,0,0,126,1,0,0,188,4,0,0,236,4,0,0,188,4,0,0,104,0,0,0,188,4,0,0,6,4,0,0,188,4,0,0,126,1,0,0,188,4,0,0,56,4,0,0,188,4,0,0,34,1,0,0,188,4,0,0,168,3,0,0,188,4,0,0,80,0,0,0,188,4,0,0,56,4,0,0,188,4,0,0,34,1,0,0,188,4,0,0,168,3,0,0,188,4,0,0,80,0,0,0,188,4,0,0,136,2,0,0,188,4,0,0,54,5,0,0,188,4,0,0,58,0,0,0,188,4,0,0,168,4,0,0,188,4,0,0,136,2,0,0,188,4,0,0,54,5,0,0,188,4,0,0,58,0,0,0,188,4,0,0,168,4,0,0,188,4,0,0,56,4,0,0,188,4,0,0,34,1,0,0,188,4,0,0,168,3,0,0,188,4,0,0,80,0,0,0,188,4,0,0,56,4,0,0,188,4,0,0,34,1,0,0,188,4,0,0,168,3,0,0,188,4,0,0,80,0,0,0,188,4,0,0,136,2,0,0,188,4,0,0,54,5,0,0,188,4,0,0,58,0,0,0,188,4,0,0,168,4,0,0,188,4,0,0,136,2,0,0,188,4,0,0,54,5,0,0,188,4,0,0,58,0,0,0,188,4,0,0,168,4,0,0,188,4,0,0,186,0,0,0,188,4,0,0,54,3,0,0,188,4,0,0,88,1,0,0,188,4,0,0,10,4,0,0,188,4,0,0,186,0,0,0,188,4,0,0,54,3,0,0,188,4,0,0,88,1,0,0,188,4,0,0,10,4,0,0,188,4,0,0,120,2,0,0,188,4,0,0,252,5,0,0,188,4,0,0,58,3,0,0,188,4,0,0,138,0,0,0,188,4,0,0,120,2,0,0,188,4,0,0,252,5,0,0,188,4,0,0,58,3,0,0,188,4,0,0,138,0,0,0,188,4,0,0,180,2,0,0,188,4,0,0,64,0,0,0,188,4,0,0,138,3,0,0,188,4,0,0,14,1,0,0,188,4,0,0,180,2,0,0,188,4,0,0,64,0,0,0,188,4,0,0,138,3,0,0,188,4,0,0,14,1,0,0,188,4,0,0,170,4,0,0,188,4,0,0,192,2,0,0,188,4,0,0,0,4,0,0,188,4,0,0,184,0,0,0,188,4,0,0,170,4,0,0,188,4,0,0,192,2,0,0,188,4,0,0,0,4,0,0,188,4,0,0,184,0,0,0,188,4,0,0,30,5,0,0,188,4,0,0,168,1,0,0,188,4,0,0,80,4,0,0,188,4,0,0,224,5,0,0,188,4,0,0,30,5,0,0,188,4,0,0,168,1,0,0,188,4,0,0,80,4,0,0,188,4,0,0,224,5,0,0,188,4,0,0,6,1,0,0,188,4,0,0,86,4,0,0,188,4,0,0,52,0,0,0,188,4,0,0,126,3,0,0,188,4,0,0,6,1,0,0,188,4,0,0,86,4,0,0,188,4,0,0,52,0,0,0,188,4,0,0,126,3,0,0,188,4,0,0,192,0,0,0,188,4,0,0,28,4,0,0,188,4,0,0,6,0,0,0,188,4,0,0,74,3,0,0,188,4,0,0,192,0,0,0,188,4,0,0,28,4,0,0,188,4,0,0,6,0,0,0,188,4,0,0,74,3,0,0,188,4,0,0,124,2,0,0,188,4,0,0,60,5,0,0,188,4,0,0,78,3,0,0,188,4,0,0,10,0,0,0,188,4,0,0,124,2,0,0,188,4,0,0,60,5,0,0,188,4,0,0,78,3,0,0,188,4,0,0,10,0,0,0,188,4,0,0,152,3,0,0,188,4,0,0,186,5,0,0,188,4,0,0,106,4,0,0,188,4,0,0,48,0,0,0,188,4,0,0,152,3,0,0,188,4,0,0,186,5,0,0,188,4,0,0,106,4,0,0,188,4,0,0,48,0,0,0,188,4,0,0,240,4,0,0,188,4,0,0,60,2,0,0,188,4,0,0,74,0,0,0,188,4,0,0,158,3,0,0,188,4,0,0,240,4,0,0,188,4,0,0,60,2,0,0,188,4,0,0,74,0,0,0,188,4,0,0,158,3,0,0,188,4,0,0,10,5,0,0,188,4,0,0,86,2,0,0,188,4,0,0,222,5,0,0,188,4,0,0,34,3,0,0,188,4,0,0,10,5,0,0,188,4,0,0,86,2,0,0,188,4,0,0,222,5,0,0,188,4,0,0,34,3,0,0,188,4,0,0,122,5,0,0,188,4,0,0,162,2,0,0,188,4,0,0,132,5,0,0,188,4,0,0,92,3,0,0,188,4,0,0,122,5,0,0,188,4,0,0,162,2,0,0,188,4,0,0,132,5,0,0,188,4,0,0,92,3,0,0,188,4,0,0,206,3,0,0,188,4,0,0,204,5,0,0,188,4,0,0,72,3,0,0,188,4,0,0,18,3,0,0,188,4,0,0,206,3,0,0,188,4,0,0,204,5,0,0,188,4,0,0,72,3,0,0,188,4,0,0,18,3,0,0,188,4,0,0,152,1,0,0,188,4,0,0,34,4,0,0,188,4,0,0,124,5,0,0,188,4,0,0,146,3,0,0,188,4,0,0,152,1,0,0,188,4,0,0,34,4,0,0,188,4,0,0,124,5,0,0,188,4,0,0,146,3,0,0,188,4,0,0,88,3,0,0,188,4,0,0,222,0,0,0,188,4,0,0,96,5,0,0,188,4,0,0,66,0,0,0,188,4,0,0,88,3,0,0,188,4,0,0,222,0,0,0,188,4,0,0,96,5,0,0,188,4,0,0,66,0,0,0,188,4,0,0,84,3,0,0,188,4,0,0,94,2,0,0,188,4,0,0,16,4,0,0,188,4,0,0,24,0,0,0,188,4,0,0,84,3,0,0,188,4,0,0,94,2,0,0,188,4,0,0,16,4,0,0,188,4,0,0,24,0,0,0,188,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,164,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,122,4,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,210,3,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,214,2,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,108,5,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,132,3,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,76,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,166,2,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,238,0,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,212,2,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,184,5,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,146,4,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,170,5,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,186,3,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,196,5,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,70,4,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,136,5,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,96,4,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,114,4,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,118,2,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,54,4,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,230,1,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,206,0,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,144,2,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,128,4,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,68,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,190,2,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,186,4,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,222,2,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0])
.concat([188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,188,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,176,4,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,0,0,0,6,0,0,0,8,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,4,4,4,4,4,4,4,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,152,47,138,66,145,68,55,113,207,251,192,181,165,219,181,233,91,194,86,57,241,17,241,89,164,130,63,146,213,94,28,171,152,170,7,216,1,91,131,18,190,133,49,36,195,125,12,85,116,93,190,114,254,177,222,128,167,6,220,155,116,241,155,193,193,105,155,228,134,71,190,239,198,157,193,15,204,161,12,36,111,44,233,45,170,132,116,74,220,169,176,92,218,136,249,118,82,81,62,152,109,198,49,168,200,39,3,176,199,127,89,191,243,11,224,198,71,145,167,213,81,99,202,6,103,41,41,20,133,10,183,39,56,33,27,46,252,109,44,77,19,13,56,83,84,115,10,101,187,10,106,118,46,201,194,129,133,44,114,146,161,232,191,162,75,102,26,168,112,139,75,194,163,81,108,199,25,232,146,209,36,6,153,214,133,53,14,244,112,160,106,16,22,193,164,25,8,108,55,30,76,119,72,39,181,188,176,52,179,12,28,57,74,170,216,78,79,202,156,91,243,111,46,104,238,130,143,116,111,99,165,120,20,120,200,132,8,2,199,140,250,255,190,144,235,108,80,164,247,163,249,190,242,120,113,198,103,230,9,106,133,174,103,187,114,243,110,60,58,245,79,165,127,82,14,81,140,104,5,155,171,217,131,31,25,205,224,91])
, "i8", ALLOC_NONE, Runtime.GLOBAL_BASE)
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}
  function _emscripten_set_canvas_size(width, height) {
      Browser.setCanvasSize(width, height);
    }
  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop) {
      Module['noExitRuntime'] = true;
      Browser.mainLoop.runner = function() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from non-main loop sources
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        if (Module['preMainLoop']) {
          Module['preMainLoop']();
        }
        Runtime.dynCall('v', func);
        if (Module['postMainLoop']) {
          Module['postMainLoop']();
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from the main loop itself
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        Browser.mainLoop.scheduler();
      }
      if (fps && fps > 0) {
        Browser.mainLoop.scheduler = function() {
          setTimeout(Browser.mainLoop.runner, 1000/fps); // doing this each time means that on exception, we stop
        }
      } else {
        Browser.mainLoop.scheduler = function() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        }
      }
      Browser.mainLoop.scheduler();
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:35,EIDRM:36,ECHRNG:37,EL2NSYNC:38,EL3HLT:39,EL3RST:40,ELNRNG:41,EUNATCH:42,ENOCSI:43,EL2HLT:44,EDEADLK:45,ENOLCK:46,EBADE:50,EBADR:51,EXFULL:52,ENOANO:53,EBADRQC:54,EBADSLT:55,EDEADLOCK:56,EBFONT:57,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:74,EDOTDOT:76,EBADMSG:77,ENOTUNIQ:80,EBADFD:81,EREMCHG:82,ELIBACC:83,ELIBBAD:84,ELIBSCN:85,ELIBMAX:86,ELIBEXEC:87,ENOSYS:88,ENOTEMPTY:90,ENAMETOOLONG:91,ELOOP:92,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:106,EPROTOTYPE:107,ENOTSOCK:108,ENOPROTOOPT:109,ESHUTDOWN:110,ECONNREFUSED:111,EADDRINUSE:112,ECONNABORTED:113,ENETUNREACH:114,ENETDOWN:115,ETIMEDOUT:116,EHOSTDOWN:117,EHOSTUNREACH:118,EINPROGRESS:119,EALREADY:120,EDESTADDRREQ:121,EMSGSIZE:122,EPROTONOSUPPORT:123,ESOCKTNOSUPPORT:124,EADDRNOTAVAIL:125,ENETRESET:126,EISCONN:127,ENOTCONN:128,ETOOMANYREFS:129,EUSERS:131,EDQUOT:132,ESTALE:133,ENOTSUP:134,ENOMEDIUM:135,EILSEQ:138,EOVERFLOW:139,ECANCELED:140,ENOTRECOVERABLE:141,EOWNERDEAD:142,ESTRPIPE:143};
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"No message of desired type",36:"Identifier removed",37:"Channel number out of range",38:"Level 2 not synchronized",39:"Level 3 halted",40:"Level 3 reset",41:"Link number out of range",42:"Protocol driver not attached",43:"No CSI structure available",44:"Level 2 halted",45:"Deadlock condition",46:"No record locks available",50:"Invalid exchange",51:"Invalid request descriptor",52:"Exchange full",53:"No anode",54:"Invalid request code",55:"Invalid slot",56:"File locking deadlock error",57:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",74:"Multihop attempted",76:"Cross mount point (not really error)",77:"Trying to read unreadable message",80:"Given log. name not unique",81:"f.d. invalid for this operation",82:"Remote address changed",83:"Can   access a needed shared lib",84:"Accessing a corrupted shared lib",85:".lib section in a.out corrupted",86:"Attempting to link in too many libs",87:"Attempting to exec a shared library",88:"Function not implemented",90:"Directory not empty",91:"File or path name too long",92:"Too many symbolic links",95:"Operation not supported on transport endpoint",96:"Protocol family not supported",104:"Connection reset by peer",105:"No buffer space available",106:"Address family not supported by protocol family",107:"Protocol wrong type for socket",108:"Socket operation on non-socket",109:"Protocol not available",110:"Can't send after socket shutdown",111:"Connection refused",112:"Address already in use",113:"Connection aborted",114:"Network is unreachable",115:"Network interface is not configured",116:"Connection timed out",117:"Host is down",118:"Host is unreachable",119:"Connection already in progress",120:"Socket already connected",121:"Destination address required",122:"Message too long",123:"Unknown protocol",124:"Socket type not supported",125:"Address not available",126:"Connection reset by network",127:"Socket is already connected",128:"Socket is not connected",129:"Too many references",131:"Too many users",132:"Quota exceeded",133:"Stale file handle",134:"Not supported",135:"No medium (in tape drive)",138:"Illegal byte sequence",139:"Value too large for defined data type",140:"Operation canceled",141:"State not recoverable",142:"Previous owner died",143:"Streams pipe error"};
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value
      return value;
    }
  var VFS=undefined;
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path, ext) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var f = PATH.splitPath(path)[2];
        if (ext && f.substr(-1 * ext.length) === ext) {
          f = f.substr(0, f.length - ext.length);
        }
        return f;
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.filter(function(p, index) {
          if (typeof p !== 'string') {
            throw new TypeError('Arguments to path.join must be strings');
          }
          return p;
        }).join('/'));
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            continue;
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  var MEMFS={CONTENT_OWNING:1,CONTENT_FLEXIBLE:2,CONTENT_FIXED:3,ensureFlexible:function (node) {
        if (node.contentMode !== MEMFS.CONTENT_FLEXIBLE) {
          var contents = node.contents;
          node.contents = Array.prototype.slice.call(contents);
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        }
      },mount:function (mount) {
        return MEMFS.create_node(null, '/', 0040000 | 0777, 0);
      },create_node:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            lookup: MEMFS.node_ops.lookup,
            mknod: MEMFS.node_ops.mknod,
            mknod: MEMFS.node_ops.mknod,
            rename: MEMFS.node_ops.rename,
            unlink: MEMFS.node_ops.unlink,
            rmdir: MEMFS.node_ops.rmdir,
            readdir: MEMFS.node_ops.readdir,
            symlink: MEMFS.node_ops.symlink
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek
          };
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek,
            read: MEMFS.stream_ops.read,
            write: MEMFS.stream_ops.write,
            allocate: MEMFS.stream_ops.allocate,
            mmap: MEMFS.stream_ops.mmap
          };
          node.contents = [];
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        } else if (FS.isLink(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            readlink: MEMFS.node_ops.readlink
          };
          node.stream_ops = {};
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = FS.chrdev_stream_ops;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.contents.length;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.ensureFlexible(node);
            var contents = node.contents;
            if (attr.size < contents.length) contents.length = attr.size;
            else while (attr.size > contents.length) contents.push(0);
          }
        },lookup:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.create_node(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.create_node(parent, newname, 0777 | 0120000, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          var node = stream.node;
          node.timestamp = Date.now();
          var contents = node.contents;
          if (length && contents.length === 0 && position === 0 && buffer.subarray) {
            // just replace it with the new data
            assert(buffer.length);
            if (canOwn && buffer.buffer === HEAP8.buffer && offset === 0) {
              node.contents = buffer; // this is a subarray of the heap, and we can own it
              node.contentMode = MEMFS.CONTENT_OWNING;
            } else {
              node.contents = new Uint8Array(buffer.subarray(offset, offset+length));
              node.contentMode = MEMFS.CONTENT_FIXED;
            }
            return length;
          }
          MEMFS.ensureFlexible(node);
          var contents = node.contents;
          while (contents.length < position) contents.push(0);
          for (var i = 0; i < length; i++) {
            contents[position + i] = buffer[offset + i];
          }
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.contents.length;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.ungotten = [];
          stream.position = position;
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.ensureFlexible(stream.node);
          var contents = stream.node.contents;
          var limit = offset + length;
          while (limit > contents.length) contents.push(0);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 0x02) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < contents.length) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);var FS={root:null,nodes:[null],devices:[null],streams:[null],nextInode:1,name_table:null,currentPath:"/",initialized:false,ignorePermissions:true,ErrnoError:function ErrnoError(errno) {
          this.errno = errno;
          for (var key in ERRNO_CODES) {
            if (ERRNO_CODES[key] === errno) {
              this.code = key;
              break;
            }
          }
          this.message = ERRNO_MESSAGES[errno];
        },handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + new Error().stack;
        return ___setErrNo(e.errno);
      },hashName:function (parentid, name) {
        var hash = 0;
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.name_table.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.name_table[hash];
        FS.name_table[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.name_table[hash] === node) {
          FS.name_table[hash] = node.name_next;
        } else {
          var current = FS.name_table[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.name_table[hash]; node; node = node.name_next) {
          if (node.parent.id === parent.id && node.name === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        var node = {
          id: FS.nextInode++,
          name: name,
          mode: mode,
          node_ops: {},
          stream_ops: {},
          rdev: rdev,
          parent: null,
          mount: null
        };
        if (!parent) {
          parent = node;  // root node sets parent to itself
        }
        node.parent = parent;
        node.mount = parent.mount;
        // compatibility
        var readMode = 292 | 73;
        var writeMode = 146;
        // NOTE we must use Object.defineProperties instead of individual calls to
        // Object.defineProperty in order to make closure compiler happy
        Object.defineProperties(node, {
          read: {
            get: function() { return (node.mode & readMode) === readMode; },
            set: function(val) { val ? node.mode |= readMode : node.mode &= ~readMode; }
          },
          write: {
            get: function() { return (node.mode & writeMode) === writeMode; },
            set: function(val) { val ? node.mode |= writeMode : node.mode &= ~writeMode; }
          },
          isFolder: {
            get: function() { return FS.isDir(node.mode); },
          },
          isDevice: {
            get: function() { return FS.isChrdev(node.mode); },
          },
        });
        FS.hashAddNode(node);
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return node.mounted;
      },isFile:function (mode) {
        return (mode & 0170000) === 0100000;
      },isDir:function (mode) {
        return (mode & 0170000) === 0040000;
      },isLink:function (mode) {
        return (mode & 0170000) === 0120000;
      },isChrdev:function (mode) {
        return (mode & 0170000) === 0020000;
      },isBlkdev:function (mode) {
        return (mode & 0170000) === 0060000;
      },isFIFO:function (mode) {
        return (mode & 0170000) === 0010000;
      },isSocket:function (mode) {
        return (mode & 0140000) === 0140000;
      },cwd:function () {
        return FS.currentPath;
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.currentPath, path);
        opts = opts || { recurse_count: 0 };
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
        // start at the root
        var current = FS.root;
        var current_path = '/';
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join(current_path, parts[i]);
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            current = current.mount.root;
          }
          // follow symlinks
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            return path ? PATH.join(node.mount.mountpoint, path) : node.mount.mountpoint;
          }
          path = path ? PATH.join(node.name, path) : node.name;
          node = node.parent;
        }
      },flagModes:{"r":0,"rs":8192,"r+":2,"w":1537,"wx":3585,"xw":3585,"w+":1538,"wx+":3586,"xw+":3586,"a":521,"ax":2569,"xa":2569,"a+":522,"ax+":2570,"xa+":2570},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 3;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 1024)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        return FS.nodePermissions(dir, 'x');
      },mayMknod:function (mode) {
        switch (mode & 0170000) {
          case 0100000:
          case 0020000:
          case 0060000:
          case 0010000:
          case 0140000:
            return 0;
          default:
            return ERRNO_CODES.EINVAL;
        }
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.currentPath) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 3) !== 0 ||  // opening for write
              (flags & 1024)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 1;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        // compatibility
        Object.defineProperties(stream, {
          object: {
            get: function() { return stream.node; },
            set: function(val) { stream.node = val; }
          },
          isRead: {
            get: function() { return (stream.flags & 3) !== 1; }
          },
          isWrite: {
            get: function() { return (stream.flags & 3) !== 0; }
          },
          isAppend: {
            get: function() { return (stream.flags & 8); }
          }
        });
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join(parent, part);
          try {
            FS.mkdir(current, 0777);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(path, mode | 146);
          var stream = FS.open(path, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(path, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
              if (!hasByteServing) chunkSize = datalength;
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp', 0777);
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev', 0777);
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', 0666, FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', 0666, FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', 0666, FS.makedev(6, 0));
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm', 0777);
        FS.mkdir('/dev/shm/tmp', 0777);
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=stdin.fd;
        assert(stdin.fd === 1, 'invalid handle for stdin (' + stdin.fd + ')');
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=stdout.fd;
        assert(stdout.fd === 2, 'invalid handle for stdout (' + stdout.fd + ')');
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=stderr.fd;
        assert(stderr.fd === 3, 'invalid handle for stderr (' + stderr.fd + ')');
      },staticInit:function () {
        FS.name_table = new Array(4096);
        FS.root = FS.createNode(null, '/', 0040000 | 0777, 0);
        FS.mount(MEMFS, {}, '/');
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },mount:function (type, opts, mountpoint) {
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          root: null
        };
        var lookup;
        if (mountpoint) {
          lookup = FS.lookupPath(mountpoint, { follow: false });
        }
        // create a root node for the fs
        var root = type.mount(mount);
        root.mount = mount;
        mount.root = root;
        // assign the mount info to the mountpoint's node
        if (lookup) {
          lookup.node.mount = mount;
          lookup.node.mounted = true;
          // compatibility update FS.root if we mount to /
          if (mountpoint === '/') {
            FS.root = mount.root;
          }
        }
        return root;
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode &= 4095;
        mode |= 0100000;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode &= 511 | 0001000;
        mode |= 0040000;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        mode |= 0020000;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
      },readlink:function (path) {
        var lookup = FS.lookupPath(path, { follow: false });
        var link = lookup.node;
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        path = PATH.normalize(path);
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 0666 : mode;
        if ((flags & 512)) {
          mode = (mode & 4095) | 0100000;
        } else {
          mode = 0;
        }
        var node;
        try {
          var lookup = FS.lookupPath(path, {
            follow: !(flags & 0200000)
          });
          node = lookup.node;
          path = lookup.path;
        } catch (e) {
          // ignore
        }
        // perhaps we need to create the node
        if ((flags & 512)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 2048)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~1024;
        }
        // check permissions
        var err = FS.mayOpen(node, flags);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // do truncation if necessary
        if ((flags & 1024)) {
          FS.truncate(node, 0);
        }
        // register the stream with the filesystem
        var stream = FS.createStream({
          path: path,
          node: node,
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        return stream.stream_ops.llseek(stream, offset, whence);
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        if (stream.flags & 8) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.errnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      }};function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module.print('exit(' + status + ') called');
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }
  var SOCKFS={mount:function (mount) {
        return FS.createNode(null, '/', 0040000 | 0777, 0);
      },nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 0140000, 0);
        node.sock = sock;
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              var url = 'ws://' + addr + ':' + port;
              // the node ws library API is slightly different than the browser's
              var opts = ENVIRONMENT_IS_NODE ? {} : ['binary'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
          var handleOpen = function () {
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
          var handleMessage = function(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
          };
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('error', function() {
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onmessage = function(event) {
              handleMessage(event.data);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (0 /* XXX missing C define POLLRDNORM */ | 1) : 0;
          }
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (0 /* XXX missing C define POLLRDNORM */ | 1);
          }
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 2;
          }
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 1:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODS.EOPNOTSUPP);
          }
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
              // push to queue for accept to pick up
              sock.pending.push(newsock);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
            }
          });
          sock.server.on('closed', function() {
            sock.server = null;
          });
          sock.server.on('error', function() {
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  Module["_strlen"] = _strlen;
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
          // Handle precision.
          var precisionSet = false;
          if (next == 46) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          } else {
            var precision = 6; // Standard default.
          }
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
              // Add sign if needed
              if (flagAlwaysSigned) {
                if (currArg < 0) {
                  prefix = '-' + prefix;
                } else {
                  prefix = '+' + prefix;
                }
              }
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
                // Add sign.
                if (flagAlwaysSigned && currArg >= 0) {
                  argText = '+' + argText;
                }
              }
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }
  function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i32=_memset;
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      var stream = FS.getStream(fildes);
      if (stream) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }
  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    } 
  Module["_saveSetjmp"] = _saveSetjmp;
  Module["_testSetjmp"] = _testSetjmp;var _setjmp=undefined;
  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _rmdir(path) {
      // int rmdir(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rmdir.html
      path = Pointer_stringify(path);
      try {
        FS.rmdir(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _remove(path) {
      // int remove(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/remove.html
      var ret = _unlink(path);
      if (ret == -1) ret = _rmdir(path);
      return ret;
    }
  function _strdup(ptr) {
      var len = _strlen(ptr);
      var newStr = _malloc(len + 1);
      (_memcpy(newStr, ptr, len)|0);
      HEAP8[(((newStr)+(len))|0)]=0;
      return newStr;
    }
  Module["_memcpy"] = _memcpy;var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
        var start = window['performance']['now']();
        while (window['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }
  var ___timespec_struct_layout={__size__:8,tv_sec:0,tv_nsec:4};function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_sec))>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_nsec))>>2)];
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_sec))>>2)]=0
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_nsec))>>2)]=0
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }
  function _strrchr(ptr, chr) {
      var ptr2 = ptr + _strlen(ptr);
      do {
        if (HEAP8[(ptr2)] == chr) return ptr2;
        ptr2--;
      } while (ptr2 >= ptr);
      return 0;
    }
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[(((px)+(i))|0)];
        var y = HEAPU8[(((py)+(i))|0)];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }
  var _llvm_pow_f32=Math.pow;
  function _round(x) {
      return (x < 0) ? -Math.round(-x) : Math.round(x);
    }var _roundf=_round;
  function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }
  function _isspace(chr) {
      return (chr == 32) || (chr >= 9 && chr <= 13);
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
      // Apply sign.
      ret *= multiplier;
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
      if (bits == 64) {
        return ((asm["setTempRet0"]((tempDouble=ret,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)),ret>>>0)|0);
      }
      return ret;
    }function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }
  function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      return _write(stream, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }
  function _llvm_lifetime_start() {}
  function _llvm_lifetime_end() {}
  var _llvm_memset_p0i8_i64=_memset;
  var ___dirent_struct_layout={__size__:1040,d_ino:0,d_name:4,d_off:1028,d_reclen:1032,d_type:1036};function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 1024;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 8;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStream(stream);
      stream.eof = false;
      return 0;
    }
  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStream(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }
  function _rewind(stream) {
      // void rewind(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rewind.html
      _fseek(stream, 0, 0);  // SEEK_SET.
      var streamObj = FS.getStream(stream);
      if (streamObj) streamObj.error = false;
    }
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStream(stream);
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)|0)]=streamObj.ungotten.pop()
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(stream, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return Math.floor(bytesRead / size);
    }
  function _feof(stream) {
      // int feof(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/feof.html
      stream = FS.getStream(stream);
      return Number(stream && stream.eof);
    }
  function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }function _fgets(s, n, stream) {
      // char *fgets(char *restrict s, int n, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgets.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return 0;
      if (streamObj.error || streamObj.eof) return 0;
      var byte_;
      for (var i = 0; i < n - 1 && byte_ != 10; i++) {
        byte_ = _fgetc(stream);
        if (byte_ == -1) {
          if (streamObj.error || (streamObj.eof && i == 0)) return 0;
          else if (streamObj.eof) break;
        }
        HEAP8[(((s)+(i))|0)]=byte_
      }
      HEAP8[(((s)+(i))|0)]=0
      return s;
    }
  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }
  Module["_tolower"] = _tolower; 
  Module["_strncasecmp"] = _strncasecmp; 
  Module["_strcasecmp"] = _strcasecmp;
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'root';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/emscripten';
        ENV['LANG'] = 'en_US.UTF-8';
        ENV['_'] = './this.program';
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        for (var j = 0; j < line.length; j++) {
          HEAP8[(((poolPtr)+(j))|0)]=line.charCodeAt(j);
        }
        HEAP8[(((poolPtr)+(j))|0)]=0;
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }
  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }
  var ___tm_struct_layout={__size__:44,tm_sec:0,tm_min:4,tm_hour:8,tm_mday:12,tm_mon:16,tm_year:20,tm_wday:24,tm_yday:28,tm_isdst:32,tm_gmtoff:36,tm_zone:40};
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
      var date = {
        tm_sec: HEAP32[(((tm)+(___tm_struct_layout.tm_sec))>>2)],
        tm_min: HEAP32[(((tm)+(___tm_struct_layout.tm_min))>>2)],
        tm_hour: HEAP32[(((tm)+(___tm_struct_layout.tm_hour))>>2)],
        tm_mday: HEAP32[(((tm)+(___tm_struct_layout.tm_mday))>>2)],
        tm_mon: HEAP32[(((tm)+(___tm_struct_layout.tm_mon))>>2)],
        tm_year: HEAP32[(((tm)+(___tm_struct_layout.tm_year))>>2)],
        tm_wday: HEAP32[(((tm)+(___tm_struct_layout.tm_wday))>>2)],
        tm_yday: HEAP32[(((tm)+(___tm_struct_layout.tm_yday))>>2)],
        tm_isdst: HEAP32[(((tm)+(___tm_struct_layout.tm_isdst))>>2)]
      };
      var pattern = Pointer_stringify(format);
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S',                 // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
      var leadingSomething = function(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
      var leadingNulls = function(value, digits) {
        return leadingSomething(value, digits, '0');
      };
      var compareByDay = function(date1, date2) {
        var sgn = function(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
      var getFirstWeekStartDate = function(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
      var getWeekBasedYear = function(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls(Math.floor(year/100),2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          return leadingNulls(date.tm_hour < 13 ? date.tm_hour : date.tm_hour-12, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour > 0 && date.tm_hour < 13) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ),
          // or by no characters if no timezone is determinable. 
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich). 
          // If tm_isdst is zero, the standard time offset is used. 
          // If tm_isdst is greater than zero, the daylight savings time offset is used. 
          // If tm_isdst is negative, no characters are returned. 
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%Z': function(date) {
          // Replaced by the timezone name or abbreviation, or by no bytes if no timezone information exists. [ tm_isdst]
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }
  var ___tm_current=allocate(4*26, "i8", ALLOC_STATIC);
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);
  var __tzname=allocate(8, "i32*", ALLOC_STATIC);
  var __daylight=allocate(1, "i32*", ALLOC_STATIC);
  var __timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
      HEAP32[((__timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((__daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset())
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((__tzname)>>2)]=winterNamePtr
      HEAP32[(((__tzname)+(4))>>2)]=summerNamePtr
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var offsets = ___tm_struct_layout;
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getDay()
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=start.getTimezoneOffset() * 60
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=dst
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezone
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }
  function _strtok_r(s, delim, lasts) {
      var skip_leading_delim = 1;
      var spanp;
      var c, sc;
      var tok;
      if (s == 0 && (s = getValue(lasts, 'i8*')) == 0) {
        return 0;
      }
      cont: while (1) {
        c = getValue(s++, 'i8');
        for (spanp = delim; (sc = getValue(spanp++, 'i8')) != 0;) {
          if (c == sc) {
            if (skip_leading_delim) {
              continue cont;
            } else {
              setValue(lasts, s, 'i8*');
              setValue(s - 1, 0, 'i8');
              return s - 1;
            }
          }
        }
        break;
      }
      if (c == 0) {
        setValue(lasts, 0, 'i8*');
        return 0;
      }
      tok = s - 1;
      for (;;) {
        c = getValue(s++, 'i8');
        spanp = delim;
        do {
          if ((sc = getValue(spanp++, 'i8')) == c) {
            if (c == 0) {
              s = 0;
            } else {
              setValue(s - 1, 0, 'i8');
            }
            setValue(lasts, s, 'i8*');
            return tok;
          }
        } while (sc != 0);
      }
      abort('strtok_r error!');
    }
  function _qsort(base, num, size, cmp) {
      if (num == 0 || size == 0) return;
      // forward calls to the JavaScript sort method
      // first, sort the items logically
      var keys = [];
      for (var i = 0; i < num; i++) keys.push(i);
      keys.sort(function(a, b) {
        return Module['dynCall_iii'](cmp, base+a*size, base+b*size);
      });
      // apply the sort
      var temp = _malloc(num*size);
      _memcpy(temp, base, num*size);
      for (var i = 0; i < num; i++) {
        if (keys[i] == i) continue; // already in place
        _memcpy(base+i*size, temp+keys[i]*size, size);
      }
      _free(temp);
    }
  function _opendir(dirname) {
      // DIR *opendir(const char *dirname);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/opendir.html
      // NOTE: Calculating absolute path redundantly since we need to associate it
      //       with the opened stream.
      var path = Pointer_stringify(dirname);
      if (!path) {
        ___setErrNo(ERRNO_CODES.ENOENT);
        return 0;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return 0;
      }
      if (!FS.isDir(node.mode)) {
        ___setErrNo(ERRNO_CODES.ENOTDIR);
        return 0;
      }
      var err = _open(dirname, 0, allocate([0, 0, 0, 0], 'i32', ALLOC_STACK));
      // open returns 0 on failure, not -1
      return err === -1 ? 0 : err;
    }
  function _readdir_r(dirp, entry, result) {
      // int readdir_r(DIR *dirp, struct dirent *entry, struct dirent **result);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        return ___setErrNo(ERRNO_CODES.EBADF);
      }
      var entries;
      try {
        entries = FS.readdir(stream.path);
      } catch (e) {
        return FS.handleFSError(e);
      }
      if (stream.position < 0 || stream.position >= entries.length) {
        HEAP32[((result)>>2)]=0
        return 0;
      }
      var id;
      var type;
      var name = entries[stream.position];
      var offset = stream.position + 1;
      if (!name.indexOf('.')) {
        id = 1;
        type = 4;
      } else {
        var child = FS.lookupNode(stream.node, name);
        id = child.id;
        type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
               FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
               FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
               8;                             // DT_REG, regular file.
      }
      HEAP32[(((entry)+(___dirent_struct_layout.d_ino))>>2)]=id
      HEAP32[(((entry)+(___dirent_struct_layout.d_off))>>2)]=offset
      HEAP32[(((entry)+(___dirent_struct_layout.d_reclen))>>2)]=name.length + 1
      for (var i = 0; i < name.length; i++) {
        HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=name.charCodeAt(i)
      }
      HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=0
      HEAP8[(((entry)+(___dirent_struct_layout.d_type))|0)]=type
      HEAP32[((result)>>2)]=entry
      stream.position++;
      return 0;
    }function _readdir(dirp) {
      // struct dirent *readdir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // TODO Is it supposed to be safe to execute multiple readdirs?
      if (!_readdir.entry) _readdir.entry = _malloc(___dirent_struct_layout.__size__);
      if (!_readdir.result) _readdir.result = _malloc(4);
      var err = _readdir_r(dirp, _readdir.entry, _readdir.result);
      if (err) {
        ___setErrNo(err);
        return 0;
      }
      return HEAP32[((_readdir.result)>>2)];
    }
  function _closedir(dirp) {
      // int closedir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/closedir.html
      return _close(dirp);
    }
  var ___stat_struct_layout={__size__:68,st_dev:0,st_ino:4,st_mode:8,st_nlink:12,st_uid:16,st_gid:20,st_rdev:24,st_size:28,st_atime:32,st_spare1:36,st_mtime:40,st_spare2:44,st_ctime:48,st_spare3:52,st_blksize:56,st_blocks:60,st_spare4:64};function _stat(path, buf, dontResolveLastLink) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/stat.html
      // int stat(const char *path, struct stat *buf);
      // NOTE: dontResolveLastLink is a shortcut for lstat(). It should never be
      //       used in client code.
      path = typeof path !== 'string' ? Pointer_stringify(path) : path;
      try {
        var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
        HEAP32[(((buf)+(___stat_struct_layout.st_dev))>>2)]=stat.dev;
        HEAP32[(((buf)+(___stat_struct_layout.st_ino))>>2)]=stat.ino
        HEAP32[(((buf)+(___stat_struct_layout.st_mode))>>2)]=stat.mode
        HEAP32[(((buf)+(___stat_struct_layout.st_nlink))>>2)]=stat.nlink
        HEAP32[(((buf)+(___stat_struct_layout.st_uid))>>2)]=stat.uid
        HEAP32[(((buf)+(___stat_struct_layout.st_gid))>>2)]=stat.gid
        HEAP32[(((buf)+(___stat_struct_layout.st_rdev))>>2)]=stat.rdev
        HEAP32[(((buf)+(___stat_struct_layout.st_size))>>2)]=stat.size
        HEAP32[(((buf)+(___stat_struct_layout.st_atime))>>2)]=Math.floor(stat.atime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_mtime))>>2)]=Math.floor(stat.mtime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_ctime))>>2)]=Math.floor(stat.ctime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_blksize))>>2)]=4096
        HEAP32[(((buf)+(___stat_struct_layout.st_blocks))>>2)]=stat.blocks
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _realpath(file_name, resolved_name) {
      // char *realpath(const char *restrict file_name, char *restrict resolved_name);
      // http://pubs.opengroup.org/onlinepubs/009604499/functions/realpath.html
      var absolute = FS.analyzePath(Pointer_stringify(file_name));
      if (absolute.error) {
        ___setErrNo(absolute.error);
        return 0;
      } else {
        var size = Math.min(4095, absolute.path.length);  // PATH_MAX - 1.
        for (var i = 0; i < size; i++) {
          HEAP8[(((resolved_name)+(i))|0)]=absolute.path.charCodeAt(i)
        }
        HEAP8[(((resolved_name)+(size))|0)]=0
        return resolved_name;
      }
    }
  function _getgid() {
      // gid_t getgid(void);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/getgid.html
      // We have just one process/group/user, all with ID 0.
      return 0;
    }var _getpid=_getgid;
  function _readlink(path, buf, bufsize) {
      // ssize_t readlink(const char *restrict path, char *restrict buf, size_t bufsize);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/readlink.html
      path = Pointer_stringify(path);
      var str;
      try {
        str = FS.readlink(path);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      str = str.slice(0, Math.max(0, bufsize - 1));
      writeStringToMemory(str, buf, true);
      return str.length;
    }
  var _sqrt=Math.sqrt;
  var _fabs=Math.abs;
  function ___errno_location() {
      return ___errno_state;
    }var ___errno=___errno_location;
  function __parseInt64(str, endptr, base, min, max, unsign) {
      var isNegative = false;
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      if (HEAP8[(str)] == 45) {
        str++;
        isNegative = true;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var ok = false;
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            ok = true; // we saw an initial zero, perhaps the entire thing is just "0"
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      start = str;
      // Get digits.
      var chr;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          str++;
          ok = true;
        }
      }
      if (!ok) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return ((asm["setTempRet0"](0),0)|0);
      }
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      try {
        var numberString = isNegative ? '-'+Pointer_stringify(start, str - start) : Pointer_stringify(start, str - start);
        i64Math.fromString(numberString, finalBase, min, max, unsign);
      } catch(e) {
        ___setErrNo(ERRNO_CODES.ERANGE); // not quite correct
      }
      return ((asm["setTempRet0"](((HEAP32[(((tempDoublePtr)+(4))>>2)])|0)),((HEAP32[((tempDoublePtr)>>2)])|0))|0);
    }function _strtoull(str, endptr, base) {
      return __parseInt64(str, endptr, base, 0, '18446744073709551615', true);  // ULONG_MAX.
    }
  var _getc=_fgetc;
  function _isgraph(chr) {
      return 0x20 < chr && chr < 0x7F;
    }
  function _llvm_bswap_i32(x) {
      return ((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24);
    }
  function _isalpha(chr) {
      return (chr >= 97 && chr <= 122) ||
             (chr >= 65 && chr <= 90);
    }
  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
        // Canvas event setup
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', {
              alpha: false
            });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var x, y;
          if (event.type == 'touchstart' ||
              event.type == 'touchend' ||
              event.type == 'touchmove') {
            var t = event.touches.item(0);
            if (t) {
              x = t.pageX - (window.scrollX + rect.left);
              y = t.pageY - (window.scrollY + rect.top);
            } else {
              return;
            }
          } else {
            x = event.pageX - (window.scrollX + rect.left);
            y = event.pageY - (window.scrollY + rect.top);
          }
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};var RI={temp:null,contexts:[],eventHandler:function (event) {
           var i;
           switch (event.type) {
              case 'mousemove':
                 var x = event['movementX'] || event['mozMovementX'] || event['webkitMovementX'];
                 var y = event['movementY'] || event['mozMovementY'] || event['webkitMovementY'];
                 for (i = 0; i < RI.contexts.length; i++) {
                    var oldX = HEAP32[(((RI.contexts[i].state)+(32))>>2)];
                    var oldY = HEAP32[(((RI.contexts[i].state)+(36))>>2)];
                    x += oldX;
                    y += oldY;
                    HEAP32[(((RI.contexts[i].state)+(32))>>2)]=x;
                    HEAP32[(((RI.contexts[i].state)+(36))>>2)]=y;
                 }
                 break;
              case 'mouseup':
              case 'mousedown':
                 var value;
                 var offset;
                 if (event.button === 0) offset = 40;
                 else if (event.button === 2) offset = 41;
                 else break;
                 if (event.type === 'mouseup') value = 0;
                 else value = 1;
                 for (i = 0; i < RI.contexts.length; i++) {
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 break;
              case 'keyup':
              case 'keydown':
                 var key = event.keyCode;
                 var offset = key >> 3;
                 var bit = 1 << (key & 7);
                 if (offset >= 32) throw 'key code error! bad code: ' + key;
                 for (i = 0; i < RI.contexts.length; i++) {
                    var value = HEAP8[(((RI.contexts[i].state)+(offset))|0)];
                    if (event.type === 'keyup') value &= ~bit;
                    else value |= bit;
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 event.preventDefault();
                 break;
              case 'blur':
              case 'visibilitychange':
                 for (i = 0; i < RI.contexts.length; i++) {
                    _memset(RI.contexts[i].state, 0, 42);
                 }
                 break;
           }
        }};function _RWebInputDestroy(context) {
        if (context === RI.contexts.length) {
           RI.contexts.pop();
           if (RI.contexts.length === 0) {
              document.removeEventListener('keyup', RI.eventHandler, false);
              document.removeEventListener('keydown', RI.eventHandler, false);
              document.removeEventListener('mousemove', RI.eventHandler, false);
              document.removeEventListener('mouseup', RI.eventHandler, false);
              document.removeEventListener('mousedown', RI.eventHandler, false);
              document.removeEventListener('blur', RI.eventHandler, false);
              document.removeEventListener('onvisbilitychange', RI.eventHandler, false);
           }
        }
     }
  function _RWebInputPoll(context) {
        context -= 1;
        var state = RI.contexts[context].state;
        _memcpy(RI.temp, state, 42);
        // reset mouse movements
        HEAP32[(((RI.contexts[context].state)+(32))>>2)]=0;
        HEAP32[(((RI.contexts[context].state)+(36))>>2)]=0;
        return RI.temp;
     }
  function _RWebInputInit(latency) {
        if (RI.contexts.length === 0) {
           document.addEventListener('keyup', RI.eventHandler, false);
           document.addEventListener('keydown', RI.eventHandler, false);
           document.addEventListener('mousemove', RI.eventHandler, false);
           document.addEventListener('mouseup', RI.eventHandler, false);
           document.addEventListener('mousedown', RI.eventHandler, false);
           document.addEventListener('blur', RI.eventHandler, false);
           document.addEventListener('onvisbilitychange', RI.eventHandler, false);
        }
        if (RI.temp === null) RI.temp = _malloc(42);
        var s = _malloc(42);
        _memset(s, 0, 42);
        RI.contexts.push({
           state: s
        });
        return RI.contexts.length;
     }
  function _strstr(ptr1, ptr2) {
      var check = 0, start;
      do {
        if (!check) {
          start = ptr1;
          check = ptr2;
        }
        var curr1 = HEAP8[((ptr1++)|0)];
        var curr2 = HEAP8[((check++)|0)];
        if (curr2 == 0) return start;
        if (curr2 != curr1) {
          // rewind to one character after start, to find ez in eeez
          ptr1 = start + 1;
          check = 0;
        }
      } while (curr1);
      return 0;
    }
  Module["_memmove"] = _memmove;var _llvm_memmove_p0i8_p0i8_i32=_memmove;
  Module["_memcmp"] = _memcmp;
  var RA={BUFFER_SIZE:256,context:null,buffers:[],numBuffers:0,bufIndex:0,bufOffset:0,startTime:0,nonblock:false,currentTimeWorkaround:false,setStartTime:function () {
           if (RA.context.currentTime) {
              RA.startTime = window['performance']['now']() - RA.context.currentTime * 1000;
              var time1 = RA.context.currentTime;
              _usleep(50);
              if (time1 === RA.context.currentTime) {
                 RA.currentTimeWorkaround = true;
                 if (RA.startTime === 0) throw 'startTime is 0';
              }
              Module["resumeMainLoop"]();
           } else window['setTimeout'](RA.setStartTime, 0);
        },getCurrentPerfTime:function () {
           if (!RA.currentTimeWorkaround) return RA.context.currentTime;
           else if (RA.startTime) return (window['performance']['now']() - RA.startTime) / 1000;
           else throw 'getCurrentPerfTime() called before start time set';
        },process:function (queueBuffers) {
           var currentTime = RA.getCurrentPerfTime();
           for (var i = 0; i < RA.bufIndex; i++) {
              if (RA.buffers[i].endTime < currentTime) {
                 var buf = RA.buffers.splice(i, 1);
                 RA.buffers[RA.numBuffers - 1] = buf[0];
                 i--;
                 RA.bufIndex--;
              }
           }
        },fillBuffer:function (buf, samples) {
           var count = 0;
           var leftBuffer = RA.buffers[RA.bufIndex].getChannelData(0);
           var rightBuffer = RA.buffers[RA.bufIndex].getChannelData(1);
           while (samples && RA.bufOffset !== RA.BUFFER_SIZE) {
              leftBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8))>>2)];
              rightBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8 + 4))>>2)];
              RA.bufOffset++;
              count++;
              samples--;
           }
           return count;
        },queueAudio:function () {
           var index = RA.bufIndex;
           var startTime;
           if (RA.bufIndex) startTime = RA.buffers[RA.bufIndex - 1].endTime;
           else startTime = RA.context.currentTime;
           RA.buffers[index].endTime = startTime + RA.buffers[index].duration;
           var bufferSource = RA.context.createBufferSource();
           bufferSource.buffer = RA.buffers[index];
           bufferSource.connect(RA.context.destination);
           bufferSource.start(startTime);
           RA.bufIndex++;
           RA.bufOffset = 0;
        },block:function () {
           do {
              RA.process();
           } while (RA.bufIndex === RA.numBuffers - 1);
        }};function _RWebAudioBufferSize() {
        return RA.numBuffers * RA.BUFFER_SIZE + RA.BUFFER_SIZE;
     }
  function _RWebAudioWriteAvail() {
        RA.process();
        return ((RA.numBuffers - RA.bufIndex) * RA.BUFFER_SIZE - RA.bufOffset) * 8;
     }
  function _RWebAudioFree() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return;
     }
  function _RWebAudioSetNonblockState(state) {
        RA.nonblock = state;
     }
  function _RWebAudioStart() {
        return true;
     }
  function _RWebAudioStop() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return true;
     }
  function _RWebAudioWrite(buf, size) {
        RA.process();
        var samples = size / 8;
        var count = 0;
        while (samples) {
           var fill = RA.fillBuffer(buf, samples);
           samples -= fill;
           count += fill;
           buf += fill * 8;
           if (RA.bufOffset === RA.BUFFER_SIZE) {
              if (RA.bufIndex === RA.numBuffers - 1) {
                 if (RA.nonblock) break;
                 else RA.block();
              }
              RA.queueAudio();
           }
        }
        return count * 8;
     }
  function _RWebAudioInit(latency) {
        var ac = window['AudioContext'] || window['webkitAudioContext'];
        if (!ac) return 0;
        RA.context = new ac();
        RA.numBuffers = ((latency * RA.context.sampleRate) / (1000 * RA.BUFFER_SIZE))|0;
        if (RA.numBuffers < 2) RA.numBuffers = 2;
        for (var i = 0; i < RA.numBuffers; i++) RA.buffers[i] = RA.context.createBuffer(2, RA.BUFFER_SIZE, RA.context.sampleRate);
        RA.nonblock = false;
        RA.startTime = 0;
        // chrome hack to get currentTime running
        RA.context.createGain();
        window['setTimeout'](RA.setStartTime, 0);
        Module["pauseMainLoop"]();
        return 1;
     }
  function _RWebAudioSampleRate() {
        return RA.context.sampleRate;
     }
  var _fabsf=Math.abs;
  var _sin=Math.sin;
  var _ceil=Math.ceil;
  function _emscripten_get_now() {
      if (!_emscripten_get_now.actual) {
        if (ENVIRONMENT_IS_NODE) {
            _emscripten_get_now.actual = function() {
              var t = process['hrtime']();
              return t[0] * 1e3 + t[1] / 1e6;
            }
        } else if (typeof dateNow !== 'undefined') {
          _emscripten_get_now.actual = dateNow;
        } else if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
          _emscripten_get_now.actual = function() { return window['performance']['now'](); };
        } else {
          _emscripten_get_now.actual = Date.now;
        }
      }
      return _emscripten_get_now.actual();
    }
  function _llvm_uadd_with_overflow_i32(x, y) {
      x = x>>>0;
      y = y>>>0;
      return ((asm["setTempRet0"](x+y > 4294967295),(x+y)>>>0)|0);
    }
  var GL={counter:1,buffers:[],programs:[],framebuffers:[],renderbuffers:[],textures:[],uniforms:[],shaders:[],currArrayBuffer:0,currElementArrayBuffer:0,byteSizeByTypeRoot:5120,byteSizeByType:[1,1,2,2,4,4,4,2,3,4,8],uniformTable:{},packAlignment:4,unpackAlignment:4,init:function () {
        Browser.moduleContextCreatedCallbacks.push(GL.initExtensions);
      },getNewId:function (table) {
        var ret = GL.counter++;
        for (var i = table.length; i < ret; i++) {
          table[i] = null;
        }
        return ret;
      },MINI_TEMP_BUFFER_SIZE:16,miniTempBuffer:null,miniTempBufferViews:[0],MAX_TEMP_BUFFER_SIZE:2097152,tempBufferIndexLookup:null,tempVertexBuffers:null,tempIndexBuffers:null,tempQuadIndexBuffer:null,generateTempBuffers:function (quads) {
        GL.tempBufferIndexLookup = new Uint8Array(GL.MAX_TEMP_BUFFER_SIZE+1);
        GL.tempVertexBuffers = [];
        GL.tempIndexBuffers = [];
        var last = -1, curr = -1;
        var size = 1;
        for (var i = 0; i <= GL.MAX_TEMP_BUFFER_SIZE; i++) {
          if (i > size) {
            size <<= 1;
          }
          if (size != last) {
            curr++;
            GL.tempVertexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, GL.tempVertexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, null);
            GL.tempIndexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempIndexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
            last = size;
          }
          GL.tempBufferIndexLookup[i] = curr;
        }
        if (quads) {
          // GL_QUAD indexes can be precalculated
          GL.tempQuadIndexBuffer = Module.ctx.createBuffer();
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempQuadIndexBuffer);
          var numIndexes = GL.MAX_TEMP_BUFFER_SIZE >> 1;
          var quadIndexes = new Uint16Array(numIndexes);
          var i = 0, v = 0;
          while (1) {
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+1;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+3;
            if (i >= numIndexes) break;
            v += 4;
          }
          Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, quadIndexes, Module.ctx.STATIC_DRAW);
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
        }
      },findToken:function (source, token) {
        function isIdentChar(ch) {
          if (ch >= 48 && ch <= 57) // 0-9
            return true;
          if (ch >= 65 && ch <= 90) // A-Z
            return true;
          if (ch >= 97 && ch <= 122) // a-z
            return true;
          return false;
        }
        var i = -1;
        do {
          i = source.indexOf(token, i + 1);
          if (i < 0) {
            break;
          }
          if (i > 0 && isIdentChar(source[i - 1])) {
            continue;
          }
          i += token.length;
          if (i < source.length - 1 && isIdentChar(source[i + 1])) {
            continue;
          }
          return true;
        } while (true);
        return false;
      },getSource:function (shader, count, string, length) {
        var source = '';
        for (var i = 0; i < count; ++i) {
          var frag;
          if (length) {
            var len = HEAP32[(((length)+(i*4))>>2)];
            if (len < 0) {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
            } else {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)], len);
            }
          } else {
            frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
          }
          source += frag;
        }
        // Let's see if we need to enable the standard derivatives extension
        type = Module.ctx.getShaderParameter(GL.shaders[shader], 0x8B4F /* GL_SHADER_TYPE */);
        if (type == 0x8B30 /* GL_FRAGMENT_SHADER */) {
          if (GL.findToken(source, "dFdx") ||
              GL.findToken(source, "dFdy") ||
              GL.findToken(source, "fwidth")) {
            source = "#extension GL_OES_standard_derivatives : enable\n" + source;
            var extension = Module.ctx.getExtension("OES_standard_derivatives");
          }
        }
        return source;
      },computeImageSize:function (width, height, sizePerPixel, alignment) {
        function roundedToNextMultipleOf(x, y) {
          return Math.floor((x + y - 1) / y) * y
        }
        var plainRowSize = width * sizePerPixel;
        var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
        return (height <= 0) ? 0 :
                 ((height - 1) * alignedRowSize + plainRowSize);
      },getTexPixelData:function (type, format, width, height, pixels, internalFormat) {
        var sizePerPixel;
        switch (type) {
          case 0x1401 /* GL_UNSIGNED_BYTE */:
            switch (format) {
              case 0x1906 /* GL_ALPHA */:
              case 0x1909 /* GL_LUMINANCE */:
                sizePerPixel = 1;
                break;
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4;
                break;
              case 0x190A /* GL_LUMINANCE_ALPHA */:
                sizePerPixel = 2;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            break;
          case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
          case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
          case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
            sizePerPixel = 2;
            break;
          case 0x1406 /* GL_FLOAT */:
            assert(GL.floatExt, 'Must have OES_texture_float to use float textures');
            switch (format) {
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3*4;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4*4;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            internalFormat = Module.ctx.RGBA;
            break;
          default:
            throw 'Invalid type (' + type + ')';
        }
        var bytes = GL.computeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
        if (type == 0x1401 /* GL_UNSIGNED_BYTE */) {
          pixels = HEAPU8.subarray((pixels),(pixels+bytes));
        } else if (type == 0x1406 /* GL_FLOAT */) {
          pixels = HEAPF32.subarray((pixels)>>2,(pixels+bytes)>>2);
        } else {
          pixels = HEAPU16.subarray((pixels)>>1,(pixels+bytes)>>1);
        }
        return {
          pixels: pixels,
          internalFormat: internalFormat
        }
      },initExtensions:function () {
        if (GL.initExtensions.done) return;
        GL.initExtensions.done = true;
        if (!Module.useWebGL) return; // an app might link both gl and 2d backends
        GL.miniTempBuffer = new Float32Array(GL.MINI_TEMP_BUFFER_SIZE);
        for (var i = 0; i < GL.MINI_TEMP_BUFFER_SIZE; i++) {
          GL.miniTempBufferViews[i] = GL.miniTempBuffer.subarray(0, i+1);
        }
        GL.maxVertexAttribs = Module.ctx.getParameter(Module.ctx.MAX_VERTEX_ATTRIBS);
        GL.compressionExt = Module.ctx.getExtension('WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('MOZ_WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('WEBKIT_WEBGL_compressed_texture_s3tc');
        GL.anisotropicExt = Module.ctx.getExtension('EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('MOZ_EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('WEBKIT_EXT_texture_filter_anisotropic');
        GL.floatExt = Module.ctx.getExtension('OES_texture_float');
        GL.elementIndexUintExt = Module.ctx.getExtension('OES_element_index_uint');
        GL.standardDerivativesExt = Module.ctx.getExtension('OES_standard_derivatives');
      }};function _glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        Module.ctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }
  function _glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        Module.ctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }
  function _glViewport(x0, x1, x2, x3) { Module.ctx.viewport(x0, x1, x2, x3) }
  function _glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.textures);
        var texture = Module.ctx.createTexture();
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }
  function _glBindTexture(target, texture) {
      Module.ctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }
  function _glTexParameteri(x0, x1, x2) { Module.ctx.texParameteri(x0, x1, x2) }
  function _glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      Module.ctx.pixelStorei(pname, param);
    }
  function _glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, internalFormat);
        pixels = data.pixels;
        internalFormat = data.internalFormat;
      } else {
        pixels = null;
      }
      Module.ctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixels);
    }
  function _glBindFramebuffer(target, framebuffer) {
      Module.ctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
    }
  function _glReadPixels(x, y, width, height, format, type, pixels) {
      assert(type == 0x1401 /* GL_UNSIGNED_BYTE */);
      var sizePerPixel;
      switch (format) {
        case 0x1907 /* GL_RGB */:
          sizePerPixel = 3;
          break;
        case 0x1908 /* GL_RGBA */:
          sizePerPixel = 4;
          break;
        default: throw 'unsupported glReadPixels format';
      }
      var totalSize = width*height*sizePerPixel;
      Module.ctx.readPixels(x, y, width, height, format, type, HEAPU8.subarray(pixels, pixels + totalSize));
    }
  function _glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        Module.ctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }
  function _glGetIntegerv(name_, p) {
      switch(name_) { // Handle a few trivial GLES values
        case 0x8DFA: // GL_SHADER_COMPILER
          HEAP32[((p)>>2)]=1;
          return;
        case 0x8DF9: // GL_NUM_SHADER_BINARY_FORMATS
          HEAP32[((p)>>2)]=0;
          return;
        case 0x86A2: // GL_NUM_COMPRESSED_TEXTURE_FORMATS
          // WebGL doesn't have GL_NUM_COMPRESSED_TEXTURE_FORMATS (it's obsolete since GL_COMPRESSED_TEXTURE_FORMATS returns a JS array that can be queried for length),
          // so implement it ourselves to allow C++ GLES2 code get the length.
          var formats = Module.ctx.getParameter(0x86A3 /*GL_COMPRESSED_TEXTURE_FORMATS*/);
          HEAP32[((p)>>2)]=formats.length;
          return;
      }
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAP8[(p)]=result ? 1 : 0;
          break;
        case "string":
          throw 'Native code calling glGetIntegerv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP32[((p)>>2)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetIntegerv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var id = GL.getNewId(GL.framebuffers);
        var framebuffer = Module.ctx.createFramebuffer();
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }
  function _glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.renderbuffers);
        var renderbuffer = Module.ctx.createRenderbuffer();
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }
  function _glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      Module.ctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }
  function _glBindRenderbuffer(target, renderbuffer) {
      Module.ctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }
  function _glRenderbufferStorage(x0, x1, x2, x3) { Module.ctx.renderbufferStorage(x0, x1, x2, x3) }
  function _glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      Module.ctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }
  function _glCheckFramebufferStatus(x0) { return Module.ctx.checkFramebufferStatus(x0) }
  function _glGetString(name_) {
      switch(name_) {
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x1F02 /* GL_VERSION */:
          return allocate(intArrayFromString(Module.ctx.getParameter(name_)), 'i8', ALLOC_NORMAL);
        case 0x1F03 /* GL_EXTENSIONS */:
          return allocate(intArrayFromString(Module.ctx.getSupportedExtensions().join(' ')), 'i8', ALLOC_NORMAL);
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          return allocate(intArrayFromString('OpenGL ES GLSL 1.00 (WebGL)'), 'i8', ALLOC_NORMAL);
        default:
          throw 'Failure: Invalid glGetString value: ' + name_;
      }
    }
  function _glDisable(x0) { Module.ctx.disable(x0) }
  function _glBlendFunc(x0, x1) { Module.ctx.blendFunc(x0, x1) }
  function _glClearColor(x0, x1, x2, x3) { Module.ctx.clearColor(x0, x1, x2, x3) }
  function _glClear(x0) { Module.ctx.clear(x0) }
  function _glDrawArrays(mode, first, count) {
      Module.ctx.drawArrays(mode, first, count);
    }
  function _glEnable(x0) { Module.ctx.enable(x0) }
  function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, -1);
        pixels = data.pixels;
      } else {
        pixels = null;
      }
      Module.ctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels);
    }
  function _glGetError() { return Module.ctx.getError() }
  var _cosf=Math.cos;
  var _sinf=Math.sin;
  function _glGetFloatv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAPF32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAPF32[((p)>>2)]=result ? 1.0 : 0.0;
          break;
        case "string":
            HEAPF32[((p)>>2)]=0;
        case "object":
          if (result === null) {
            throw 'Native code calling glGetFloatv(' + name_ + ') and it returns null';
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAPF32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetFloatv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGetBooleanv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP8[(p)]=result != 0;
          break;
        case "boolean":
          HEAP8[(p)]=result != 0;
          break;
        case "string":
          throw 'Native code calling glGetBooleanv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP8[(p)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP8[(((p)+(i))|0)]=result[i] != 0;
            }
          } else if (result instanceof WebGLBuffer ||
                     result instanceof WebGLProgram ||
                     result instanceof WebGLFramebuffer ||
                     result instanceof WebGLRenderbuffer ||
                     result instanceof WebGLTexture) {
            HEAP8[(p)]=1; // non-zero ID is always 1!
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
            throw 'Unknown object returned from WebGL getParameter';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data);
    }
  function _glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, data);
    }
  function _glGetTexParameterfv(target, pname, params) {
      HEAPF32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glGetTexParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      Module.ctx.texParameterf(target, pname, param);
    }
  function _glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      Module.ctx.texParameteri(target, pname, param);
    }
  function _glIsTexture(texture) {
      var texture = GL.textures[texture];
      if (!texture) return 0;
      return Module.ctx.isTexture(texture);
    }
  function _glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.buffers);
        var buffer = Module.ctx.createBuffer();
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }
  function _glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
        Module.ctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }
  function _glGetBufferParameteriv(target, value, data) {
      HEAP32[((data)>>2)]=Module.ctx.getBufferParameter(target, value);
    }
  function _glBufferData(target, size, data, usage) {
      switch (usage) { // fix usages, WebGL only has *_DRAW
        case 0x88E1: // GL_STREAM_READ
        case 0x88E2: // GL_STREAM_COPY
          usage = 0x88E0; // GL_STREAM_DRAW
          break;
        case 0x88E5: // GL_STATIC_READ
        case 0x88E6: // GL_STATIC_COPY
          usage = 0x88E4; // GL_STATIC_DRAW
          break;
        case 0x88E9: // GL_DYNAMIC_READ
        case 0x88EA: // GL_DYNAMIC_COPY
          usage = 0x88E8; // GL_DYNAMIC_DRAW
          break;
      }
      Module.ctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
    }
  function _glBufferSubData(target, offset, size, data) {
      Module.ctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }
  function _glIsBuffer(buffer) {
      var b = GL.buffers[buffer];
      if (!b) return 0;
      return Module.ctx.isBuffer(b);
    }
  function _glGetRenderbufferParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.ctx.getRenderbufferParameter(target, pname);
    }
  function _glIsRenderbuffer(renderbuffer) {
      var rb = GL.renderbuffers[renderbuffer];
      if (!rb) return 0;
      return Module.ctx.isRenderbuffer(rb);
    }
  function _glGetUniformfv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformiv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
      var ptable = GL.uniformTable[program];
      if (!ptable) ptable = GL.uniformTable[program] = {};
      var id = ptable[name];
      if (id) return id;
      var loc = Module.ctx.getUniformLocation(GL.programs[program], name);
      if (!loc) return -1;
      id = GL.getNewId(GL.uniforms);
      GL.uniforms[id] = loc;
      ptable[name] = id;
      return id;
    }
  function _glGetVertexAttribfv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribiv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribPointerv(index, pname, pointer) {
      HEAP32[((pointer)>>2)]=Module.ctx.getVertexAttribOffset(index, pname);
    }
  function _glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveUniform(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glUniform1f(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1f(location, v0);
    }
  function _glUniform2f(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2f(location, v0, v1);
    }
  function _glUniform3f(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3f(location, v0, v1, v2);
    }
  function _glUniform4f(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4f(location, v0, v1, v2, v3);
    }
  function _glUniform1i(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1i(location, v0);
    }
  function _glUniform2i(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2i(location, v0, v1);
    }
  function _glUniform3i(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3i(location, v0, v1, v2);
    }
  function _glUniform4i(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4i(location, v0, v1, v2, v3);
    }
  function _glUniform1iv(location, count, value) {
      location = GL.uniforms[location];
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform1iv(location, value);
    }
  function _glUniform2iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 2;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform2iv(location, value);
    }
  function _glUniform3iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 3;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform3iv(location, value);
    }
  function _glUniform4iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 4;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform4iv(location, value);
    }
  function _glUniform1fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[0];
        view[0] = HEAPF32[((value)>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      Module.ctx.uniform1fv(location, view);
    }
  function _glUniform2fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[1];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      Module.ctx.uniform2fv(location, view);
    }
  function _glUniform3fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[2];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      Module.ctx.uniform3fv(location, view);
    }
  function _glUniform4fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[3];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
        view[3] = HEAPF32[(((value)+(12))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniform4fv(location, view);
    }
  function _glUniformMatrix2fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[3];
        for (var i = 0; i < 4; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniformMatrix2fv(location, transpose, view);
    }
  function _glUniformMatrix3fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[8];
        for (var i = 0; i < 9; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      Module.ctx.uniformMatrix3fv(location, transpose, view);
    }
  function _glUniformMatrix4fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[15];
        for (var i = 0; i < 16; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      Module.ctx.uniformMatrix4fv(location, transpose, view);
    }
  function _glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
      if (target == Module.ctx.ARRAY_BUFFER) {
        GL.currArrayBuffer = buffer;
      } else if (target == Module.ctx.ELEMENT_ARRAY_BUFFER) {
        GL.currElementArrayBuffer = buffer;
      }
      Module.ctx.bindBuffer(target, bufferObj);
    }
  function _glVertexAttrib1fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+4)>>2);
      Module.ctx.vertexAttrib1fv(index, v);
    }
  function _glVertexAttrib2fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+8)>>2);
      Module.ctx.vertexAttrib2fv(index, v);
    }
  function _glVertexAttrib3fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+12)>>2);
      Module.ctx.vertexAttrib3fv(index, v);
    }
  function _glVertexAttrib4fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+16)>>2);
      Module.ctx.vertexAttrib4fv(index, v);
    }
  function _glGetAttribLocation(program, name) {
      program = GL.programs[program];
      name = Pointer_stringify(name);
      return Module.ctx.getAttribLocation(program, name);
    }
  function _glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveAttrib(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = Module.ctx.createShader(shaderType);
      return id;
    }
  function _glDeleteShader(shader) {
      Module.ctx.deleteShader(GL.shaders[shader]);
      GL.shaders[shader] = null;
    }
  function _glGetAttachedShaders(program, maxCount, count, shaders) {
      var result = Module.ctx.getAttachedShaders(GL.programs[program]);
      var len = result.length;
      if (len > maxCount) {
        len = maxCount;
      }
      HEAP32[((count)>>2)]=len;
      for (var i = 0; i < len; ++i) {
        var id = GL.shaders.indexOf(result[i]);
        assert(id !== -1, 'shader not bound to local id');
        HEAP32[(((shaders)+(i*4))>>2)]=id;
      }
    }
  function _glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
      Module.ctx.shaderSource(GL.shaders[shader], source);
    }
  function _glGetShaderSource(shader, bufSize, length, source) {
      var result = Module.ctx.getShaderSource(GL.shaders[shader]);
      result = result.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(result, source);
      if (length) {
        HEAP32[((length)>>2)]=result.length;
      }
    }
  function _glCompileShader(shader) {
      Module.ctx.compileShader(GL.shaders[shader]);
    }
  function _glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = Module.ctx.getShaderInfoLog(GL.shaders[shader]);
      // Work around a bug in Chromium which causes getShaderInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glGetShaderiv(shader, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getShaderInfoLog(GL.shaders[shader]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }
  function _glGetProgramiv(program, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getProgramInfoLog(GL.programs[program]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getProgramParameter(GL.programs[program], pname);
      }
    }
  function _glIsShader(shader) {
      var s = GL.shaders[shader];
      if (!s) return 0;
      return Module.ctx.isShader(s);
    }
  function _glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = Module.ctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }
  function _glDeleteProgram(program) {
      var program = GL.programs[program];
      Module.ctx.deleteProgram(program);
      program.name = 0;
      GL.programs[program] = null;
      GL.uniformTable[program] = null;
    }
  function _glAttachShader(program, shader) {
      Module.ctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glDetachShader(program, shader) {
      Module.ctx.detachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
      var result = Module.ctx.getShaderPrecisionFormat(shaderType, precisionType);
      HEAP32[((range)>>2)]=result.rangeMin;
      HEAP32[(((range)+(4))>>2)]=result.rangeMax;
      HEAP32[((precision)>>2)]=result.precision;
    }
  function _glLinkProgram(program) {
      Module.ctx.linkProgram(GL.programs[program]);
      GL.uniformTable[program] = {}; // uniforms no longer keep the same names after linking
    }
  function _glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = Module.ctx.getProgramInfoLog(GL.programs[program]);
      // Work around a bug in Chromium which causes getProgramInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glUseProgram(program) {
      Module.ctx.useProgram(program ? GL.programs[program] : null);
    }
  function _glValidateProgram(program) {
      Module.ctx.validateProgram(GL.programs[program]);
    }
  function _glIsProgram(program) {
      var program = GL.programs[program];
      if (!program) return 0;
      return Module.ctx.isProgram(program);
    }
  function _glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      Module.ctx.bindAttribLocation(GL.programs[program], index, name);
    }
  function _glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = Module.ctx.getFramebufferAttachmentParameter(target, attachment, pname);
      HEAP32[((params)>>2)]=params;
    }
  function _glIsFramebuffer(framebuffer) {
      var fb = GL.framebuffers[framebuffer];
      if (!fb) return 0;
      return Module.ctx.isFramebuffer(fb);
    }
  function _glVertexPointer(){ throw 'Legacy GL function (glVertexPointer) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glGenVertexArrays(){ throw 'Legacy GL function (glGenVertexArrays) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glMatrixMode(){ throw 'Legacy GL function (glMatrixMode) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glBegin(){ throw 'Legacy GL function (glBegin) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glLoadIdentity(){ throw 'Legacy GL function (glLoadIdentity) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _gluPerspective(fov, aspect, near, far) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix[GL.immediate.currentMatrix] =
        GL.immediate.matrix.lib.mat4.perspective(fov, aspect, near, far,
                                                 GL.immediate.matrix[GL.immediate.currentMatrix]);
    }
  function _gluLookAt(ex, ey, ez, cx, cy, cz, ux, uy, uz) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix.lib.mat4.lookAt(GL.immediate.matrix[GL.immediate.currentMatrix], [ex, ey, ez],
          [cx, cy, cz], [ux, uy, uz]);
    }
  function _gluProject(objX, objY, objZ, model, proj, view, winX, winY, winZ) {
      // The algorithm for this functions comes from Mesa
      var inVec = new Float32Array(4);
      var outVec = new Float32Array(4);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((model)>>3,(model+128)>>3),
          [objX, objY, objZ, 1.0], outVec);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          outVec, inVec);
      if (inVec[3] == 0.0) {
        return 0 /* GL_FALSE */;
      }
      inVec[0] /= inVec[3];
      inVec[1] /= inVec[3];
      inVec[2] /= inVec[3];
      // Map x, y and z to range 0-1 */
      inVec[0] = inVec[0] * 0.5 + 0.5;
      inVec[1] = inVec[1] * 0.5 + 0.5;
      inVec[2] = inVec[2] * 0.5 + 0.5;
      // Map x, y to viewport
      inVec[0] = inVec[0] * HEAP32[(((view)+(8))>>2)] + HEAP32[((view)>>2)];
      inVec[1] = inVec[1] * HEAP32[(((view)+(12))>>2)] + HEAP32[(((view)+(4))>>2)];
      HEAPF64[((winX)>>3)]=inVec[0];
      HEAPF64[((winY)>>3)]=inVec[1];
      HEAPF64[((winZ)>>3)]=inVec[2];
      return 1 /* GL_TRUE */;
    }
  function _gluUnProject(winX, winY, winZ, model, proj, view, objX, objY, objZ) {
      var result = GL.immediate.matrix.lib.mat4.unproject([winX, winY, winZ],
          HEAPF64.subarray((model)>>3,(model+128)>>3),
          HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          HEAP32.subarray((view)>>2,(view+16)>>2));
      if (result === null) {
        return 0 /* GL_FALSE */;
      }
      HEAPF64[((objX)>>3)]=result[0];
      HEAPF64[((objY)>>3)]=result[1];
      HEAPF64[((objZ)>>3)]=result[2];
      return 1 /* GL_TRUE */;
    }
  function _gluOrtho2D(left, right, bottom, top) {
      _glOrtho(left, right, bottom, top, -1, 1);
    }
  function _glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      Module.ctx.vertexAttribPointer(index, size, type, normalized, stride, ptr);
    }
  function _glEnableVertexAttribArray(index) {
      Module.ctx.enableVertexAttribArray(index);
    }
  function _glDisableVertexAttribArray(index) {
      Module.ctx.disableVertexAttribArray(index);
    }
  function _glDrawElements(mode, count, type, indices) {
      Module.ctx.drawElements(mode, count, type, indices);
    }
  function _glFinish() { Module.ctx.finish() }
  function _glFlush() { Module.ctx.flush() }
  function _glClearDepth(x0) { Module.ctx.clearDepth(x0) }
  function _glClearDepthf(x0) { Module.ctx.clearDepth(x0) }
  function _glDepthFunc(x0) { Module.ctx.depthFunc(x0) }
  function _glFrontFace(x0) { Module.ctx.frontFace(x0) }
  function _glCullFace(x0) { Module.ctx.cullFace(x0) }
  function _glLineWidth(x0) { Module.ctx.lineWidth(x0) }
  function _glClearStencil(x0) { Module.ctx.clearStencil(x0) }
  function _glDepthMask(x0) { Module.ctx.depthMask(x0) }
  function _glStencilMask(x0) { Module.ctx.stencilMask(x0) }
  function _glGenerateMipmap(x0) { Module.ctx.generateMipmap(x0) }
  function _glActiveTexture(x0) { Module.ctx.activeTexture(x0) }
  function _glBlendEquation(x0) { Module.ctx.blendEquation(x0) }
  function _glSampleCoverage(x0) { Module.ctx.sampleCoverage(x0) }
  function _glIsEnabled(x0) { return Module.ctx.isEnabled(x0) }
  function _glBlendEquationSeparate(x0, x1) { Module.ctx.blendEquationSeparate(x0, x1) }
  function _glDepthRange(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glDepthRangef(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glStencilMaskSeparate(x0, x1) { Module.ctx.stencilMaskSeparate(x0, x1) }
  function _glHint(x0, x1) { Module.ctx.hint(x0, x1) }
  function _glPolygonOffset(x0, x1) { Module.ctx.polygonOffset(x0, x1) }
  function _glVertexAttrib1f(x0, x1) { Module.ctx.vertexAttrib1f(x0, x1) }
  function _glTexParameterf(x0, x1, x2) { Module.ctx.texParameterf(x0, x1, x2) }
  function _glVertexAttrib2f(x0, x1, x2) { Module.ctx.vertexAttrib2f(x0, x1, x2) }
  function _glStencilFunc(x0, x1, x2) { Module.ctx.stencilFunc(x0, x1, x2) }
  function _glStencilOp(x0, x1, x2) { Module.ctx.stencilOp(x0, x1, x2) }
  function _glScissor(x0, x1, x2, x3) { Module.ctx.scissor(x0, x1, x2, x3) }
  function _glVertexAttrib3f(x0, x1, x2, x3) { Module.ctx.vertexAttrib3f(x0, x1, x2, x3) }
  function _glColorMask(x0, x1, x2, x3) { Module.ctx.colorMask(x0, x1, x2, x3) }
  function _glBlendFuncSeparate(x0, x1, x2, x3) { Module.ctx.blendFuncSeparate(x0, x1, x2, x3) }
  function _glBlendColor(x0, x1, x2, x3) { Module.ctx.blendColor(x0, x1, x2, x3) }
  function _glStencilFuncSeparate(x0, x1, x2, x3) { Module.ctx.stencilFuncSeparate(x0, x1, x2, x3) }
  function _glStencilOpSeparate(x0, x1, x2, x3) { Module.ctx.stencilOpSeparate(x0, x1, x2, x3) }
  function _glVertexAttrib4f(x0, x1, x2, x3, x4) { Module.ctx.vertexAttrib4f(x0, x1, x2, x3, x4) }
  function _glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }
  function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }function _emscripten_procAddressTable(name) {
  switch(name) {
  case "glPixelStorei": return 110; break;
  case "glGetString": return 72; break;
  case "glGetIntegerv": return 18; break;
  case "glGetFloatv": return 62; break;
  case "glGetBooleanv": return 80; break;
  case "glGenTextures": return 46; break;
  case "glDeleteTextures": return 68; break;
  case "glCompressedTexImage2D": return 2; break;
  case "glCompressedTexSubImage2D": return 4; break;
  case "glTexImage2D": return 8; break;
  case "glTexSubImage2D": return 6; break;
  case "glReadPixels": return 2; break;
  case "glBindTexture": return 60; break;
  case "glGetTexParameterfv": return 80; break;
  case "glGetTexParameteriv": return 14; break;
  case "glTexParameterfv": return 56; break;
  case "glTexParameteriv": return 2; break;
  case "glIsTexture": return 76; break;
  case "glGenBuffers": return 78; break;
  case "glDeleteBuffers": return 24; break;
  case "glGetBufferParameteriv": return 26; break;
  case "glBufferData": return 12; break;
  case "glBufferSubData": return 22; break;
  case "glIsBuffer": return 50; break;
  case "glGenRenderbuffers": return 122; break;
  case "glDeleteRenderbuffers": return 98; break;
  case "glBindRenderbuffer": return 4; break;
  case "glGetRenderbufferParameteriv": return 62; break;
  case "glIsRenderbuffer": return 80; break;
  case "glGetUniformfv": return 60; break;
  case "glGetUniformiv": return 24; break;
  case "glGetUniformLocation": return 32; break;
  case "glGetVertexAttribfv": return 10; break;
  case "glGetVertexAttribiv": return 36; break;
  case "glGetVertexAttribPointerv": return 18; break;
  case "glGetActiveUniform": return 6; break;
  case "glUniform1f": return 4; break;
  case "glUniform2f": return 2; break;
  case "glUniform3f": return 2; break;
  case "glUniform4f": return 6; break;
  case "glUniform1i": return 116; break;
  case "glUniform2i": return 12; break;
  case "glUniform3i": return 14; break;
  case "glUniform4i": return 8; break;
  case "glUniform1iv": return 20; break;
  case "glUniform2iv": return 34; break;
  case "glUniform3iv": return 28; break;
  case "glUniform4iv": return 48; break;
  case "glUniform1fv": return 32; break;
  case "glUniform2fv": return 54; break;
  case "glUniform3fv": return 82; break;
  case "glUniform4fv": return 44; break;
  case "glUniformMatrix2fv": return 2; break;
  case "glUniformMatrix3fv": return 16; break;
  case "glUniformMatrix4fv": return 4; break;
  case "glBindBuffer": return 32; break;
  case "glVertexAttrib1fv": return 76; break;
  case "glVertexAttrib2fv": return 64; break;
  case "glVertexAttrib3fv": return 118; break;
  case "glVertexAttrib4fv": return 22; break;
  case "glGetAttribLocation": return 72; break;
  case "glGetActiveAttrib": return 4; break;
  case "glCreateShader": return 48; break;
  case "glDeleteShader": return 1434; break;
  case "glGetAttachedShaders": return 38; break;
  case "glShaderSource": return 18; break;
  case "glGetShaderSource": return 50; break;
  case "glCompileShader": return 1414; break;
  case "glGetShaderInfoLog": return 42; break;
  case "glGetShaderiv": return 42; break;
  case "glGetProgramiv": return 38; break;
  case "glIsShader": return 52; break;
  case "glCreateProgram": return 18; break;
  case "glDeleteProgram": return 128; break;
  case "glAttachShader": return 16; break;
  case "glDetachShader": return 90; break;
  case "glLinkProgram": return 322; break;
  case "glGetProgramInfoLog": return 46; break;
  case "glUseProgram": return 384; break;
  case "glValidateProgram": return 828; break;
  case "glIsProgram": return 18; break;
  case "glBindAttribLocation": return 46; break;
  case "glBindFramebuffer": return 50; break;
  case "glGenFramebuffers": return 52; break;
  case "glDeleteFramebuffers": return 54; break;
  case "glFramebufferRenderbuffer": return 6; break;
  case "glFramebufferTexture2D": return 6; break;
  case "glGetFramebufferAttachmentParameteriv": return 34; break;
  case "glIsFramebuffer": return 44; break;
  case "glVertexAttribPointer": return 14; break;
  case "glEnableVertexAttribArray": return 88; break;
  case "glDisableVertexAttribArray": return 36; break;
  case "glDrawArrays": return 16; break;
  case "glDrawElements": return 20; break;
  case "glGetError": return 6; break;
  case "glFinish": return 14; break;
  case "glFlush": return 88; break;
  case "glClearDepth": return 354; break;
  case "glClearDepthf": return 972; break;
  case "glDepthFunc": return 1272; break;
  case "glEnable": return 902; break;
  case "glDisable": return 720; break;
  case "glFrontFace": return 620; break;
  case "glCullFace": return 190; break;
  case "glClear": return 1286; break;
  case "glLineWidth": return 1162; break;
  case "glClearStencil": return 2; break;
  case "glDepthMask": return 120; break;
  case "glStencilMask": return 1538; break;
  case "glCheckFramebufferStatus": return 20; break;
  case "glGenerateMipmap": return 466; break;
  case "glActiveTexture": return 268; break;
  case "glBlendEquation": return 772; break;
  case "glSampleCoverage": return 130; break;
  case "glIsEnabled": return 82; break;
  case "glBlendFunc": return 70; break;
  case "glBlendEquationSeparate": return 26; break;
  case "glDepthRange": return 114; break;
  case "glDepthRangef": return 112; break;
  case "glStencilMaskSeparate": return 14; break;
  case "glHint": return 44; break;
  case "glPolygonOffset": return 36; break;
  case "glVertexAttrib1f": return 28; break;
  case "glTexParameteri": return 66; break;
  case "glTexParameterf": return 68; break;
  case "glVertexAttrib2f": return 76; break;
  case "glStencilFunc": return 52; break;
  case "glStencilOp": return 74; break;
  case "glViewport": return 10; break;
  case "glClearColor": return 48; break;
  case "glScissor": return 36; break;
  case "glVertexAttrib3f": return 44; break;
  case "glColorMask": return 28; break;
  case "glRenderbufferStorage": return 30; break;
  case "glBlendFuncSeparate": return 26; break;
  case "glBlendColor": return 40; break;
  case "glStencilFuncSeparate": return 32; break;
  case "glStencilOpSeparate": return 24; break;
  case "glVertexAttrib4f": return 2; break;
  case "glCopyTexImage2D": return 6; break;
  case "glCopyTexSubImage2D": return 4; break;
  }
  return 0;
  }function _emscripten_GetProcAddress(name) {
    name = name.replace('EXT', '').replace('ARB', '');
    switch(name) { // misc renamings
      case 'glCreateProgramObject': name = 'glCreateProgram'; break;
      case 'glUseProgramObject': name = 'glUseProgram'; break;
      case 'glCreateShaderObject': name = 'glCreateShader'; break;
      case 'glAttachObject': name = 'glAttachShader'; break;
      case 'glDetachObject': name = 'glDetachShader'; break;
    }
    var ret = _emscripten_procAddressTable(name);
    if (!ret) Module.printErr('WARNING: getProcAddress failed for ' + name);
    return ret;
  }function _eglGetProcAddress(name_) {
      return _emscripten_GetProcAddress(Pointer_stringify(name_));
    }
  function _emscripten_get_canvas_size(width, height, isFullscreen) {
      var canvas = Module['canvas'];
      HEAP32[((width)>>2)]=canvas.width;
      HEAP32[((height)>>2)]=canvas.height;
      HEAP32[((isFullscreen)>>2)]=Browser.isFullScreen ? 1 : 0;
    }
  var EGL={eglErrorCode:12288,setErrorCode:function (code) {
        EGL.eglErrorCode = code;
      },chooseConfig:function (display, attribList, config, config_size, numConfigs) { 
        if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
          EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
          return 0;
        }
        // TODO: read attribList.
        if ((!config || !config_size) && !numConfigs) {
          EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
          return 0;
        }
        if (numConfigs) {
          HEAP32[((numConfigs)>>2)]=1; // Total number of supported configs: 1.
        }
        if (config && config_size > 0) {
          HEAP32[((config)>>2)]=62002; 
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      }};function _eglBindAPI(api) {
      if (api == 0x30A0 /* EGL_OPENGL_ES_API */) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } else { // if (api == 0x30A1 /* EGL_OPENVG_API */ || api == 0x30A2 /* EGL_OPENGL_API */) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
    }
  function _eglMakeCurrent(display, draw, read, context) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      //\todo An EGL_NOT_INITIALIZED error is generated if EGL is not initialized for dpy. 
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      if (read != 62006 || draw != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _glutDestroyWindow(name) {
      Module.ctx = Browser.destroyContext(Module['canvas'], true, true);
      return 1;
    }function _eglDestroyContext(display, context) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglDestroySurface(display, surface) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0; 
      }
      if (surface != 62006 /* Magic ID for the only EGLSurface supported by Emscripten */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 1;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglTerminate(display) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      // TODO: Tear down EGL here. Currently a no-op since we don't need to actually do anything here for the browser.
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglGetDisplay(nativeDisplayType) {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      // Note: As a 'conformant' implementation of EGL, we would prefer to init here only if the user
      //       calls this function with EGL_DEFAULT_DISPLAY. Other display IDs would be preferred to be unsupported
      //       and EGL_NO_DISPLAY returned. Uncomment the following code lines to do this.
      // Instead, an alternative route has been preferred, namely that the Emscripten EGL implementation
      // "emulates" X11, and eglGetDisplay is expected to accept/receive a pointer to an X11 Display object.
      // Therefore, be lax and allow anything to be passed in, and return the magic handle to our default EGLDisplay object.
  //    if (nativeDisplayType == 0 /* EGL_DEFAULT_DISPLAY */) {
          return 62000; // Magic ID for Emscripten 'default display'
  //    }
  //    else
  //      return 0; // EGL_NO_DISPLAY
    }
  function _eglInitialize(display, majorVersion, minorVersion) {
      if (display == 62000 /* Magic ID for Emscripten 'default display' */) {
        if (majorVersion) {
          HEAP32[((majorVersion)>>2)]=1; // Advertise EGL Major version: '1'
        }
        if (minorVersion) {
          HEAP32[((minorVersion)>>2)]=4; // Advertise EGL Minor version: '4'
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } 
      else {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
    }
  function _eglChooseConfig(display, attrib_list, configs, config_size, numConfigs) { 
      return EGL.chooseConfig(display, attrib_list, configs, config_size, numConfigs);
    }
  function _glutCreateWindow(name) {
      Module.ctx = Browser.createContext(Module['canvas'], true, true);
      return Module.ctx ? 1 /* a new GLUT window ID for the created context */ : 0 /* failure */;
    }function _eglCreateContext(display, config, hmm, contextAttribs) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      EGL.windowID = _glutCreateWindow();
      if (EGL.windowID != 0) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 62004; // Magic ID for Emscripten EGLContext
      } else {
        EGL.setErrorCode(0x3009 /* EGL_BAD_MATCH */); // By the EGL 1.4 spec, an implementation that does not support GLES2 (WebGL in this case), this error code is set.
        return 0; /* EGL_NO_CONTEXT */
      }
    }
  function _eglCreateWindowSurface(display, config, win, attrib_list) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (config != 62002 /* Magic ID for the only EGLConfig supported by Emscripten */) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0;
      }
      // TODO: Examine attrib_list! Parameters that can be present there are:
      // - EGL_RENDER_BUFFER (must be EGL_BACK_BUFFER)
      // - EGL_VG_COLORSPACE (can't be set)
      // - EGL_VG_ALPHA_FORMAT (can't be set)
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 62006; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglQuerySurface(display, surface, attribute, value) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (surface != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      if (!value) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      switch(attribute) {
      case 0x3028: // EGL_CONFIG_ID
        HEAP32[((value)>>2)]=62002;
          return 1;
      case 0x3058: // EGL_LARGEST_PBUFFER
        // Odd EGL API: If surface is not a pbuffer surface, 'value' should not be written to. It's not specified as an error, so true should(?) be returned.
        // Existing Android implementation seems to do so at least.
        return 1;
      case 0x3057: // EGL_WIDTH
        HEAP32[((value)>>2)]=Module.canvas.width;
        return 1;
      case 0x3056: // EGL_HEIGHT
        HEAP32[((value)>>2)]=Module.canvas.height;
        return 1;
      case 0x3090: // EGL_HORIZONTAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3091: // EGL_VERTICAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3092: // EGL_PIXEL_ASPECT_RATIO
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3086: // EGL_RENDER_BUFFER
        // The main surface is bound to the visible canvas window - it's always backbuffered. 
        // Alternative to EGL_BACK_BUFFER would be EGL_SINGLE_BUFFER.
        HEAP32[((value)>>2)]=0x3084; 
        return 1;
      case 0x3099: // EGL_MULTISAMPLE_RESOLVE
        HEAP32[((value)>>2)]=0x309A; 
        return 1;
      case 0x3093: // EGL_SWAP_BEHAVIOR
        // The two possibilities are EGL_BUFFER_PRESERVED and EGL_BUFFER_DESTROYED. Slightly unsure which is the
        // case for browser environment, but advertise the 'weaker' behavior to be sure.
        HEAP32[((value)>>2)]=0x3095;
        return 1;
      case 0x3080: // EGL_TEXTURE_FORMAT
      case 0x3081: // EGL_TEXTURE_TARGET
      case 0x3082: // EGL_MIPMAP_TEXTURE
      case 0x3083: // EGL_MIPMAP_LEVEL
        // This is a window surface, not a pbuffer surface. Spec:
        // "Querying EGL_TEXTURE_FORMAT, EGL_TEXTURE_TARGET, EGL_MIPMAP_TEXTURE, or EGL_MIPMAP_LEVEL for a non-pbuffer surface is not an error, but value is not modified."
        // So pass-through.
        return 1;
      default:
        EGL.setErrorCode(0x3004 /* EGL_BAD_ATTRIBUTE */);
        return 0;
      }
    }
  function _atexit(func, arg) {
      __ATEXIT__.unshift({ func: func, arg: arg });
    }var ___cxa_atexit=_atexit;
  var _floor=Math.floor;
  function _exp2(x) {
      return Math.pow(2, x);
    }
  function _abort() {
      Module['abort']();
    }
  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
        case 10: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
  function _memchr(ptr, chr, num) {
      chr = unSign(chr);
      for (var i = 0; i < num; i++) {
        if (HEAP8[(ptr)] == chr) return ptr;
        ptr++;
      }
      return 0;
    }
FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
___buildEnvironment(ENV);
Module["requestFullScreen"] = function(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function() { Browser.getUserMedia() }
GL.init()
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
staticSealed = true; // seal the static portion of memory
STACK_MAX = STACK_BASE + 5242880;
DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
assert(DYNAMIC_BASE < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY
 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);
var Math_min = Math.min;
function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vif(index,a1,a2) {
  try {
    Module["dynCall_vif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viffff(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viffff"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_if(index,a1) {
  try {
    return Module["dynCall_if"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiif(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiif"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viff(index,a1,a2,a3) {
  try {
    Module["dynCall_viff"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vifff(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_vifff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_fii(index,a1,a2) {
  try {
    return Module["dynCall_fii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiif(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iif(index,a1,a2) {
  try {
    return Module["dynCall_iif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ff(index,a1) {
  try {
    return Module["dynCall_ff"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_f(index) {
  try {
    return Module["dynCall_f"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_i(index) {
  try {
    return Module["dynCall_i"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env._stdout|0;var p=env.___dso_handle|0;var q=env._stderr|0;var r=+env.NaN;var s=+env.Infinity;var t=0;var u=0;var v=0;var w=0;var x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0.0;var G=0;var H=0;var I=0;var J=0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=0;var Q=global.Math.floor;var R=global.Math.abs;var S=global.Math.sqrt;var T=global.Math.pow;var U=global.Math.cos;var V=global.Math.sin;var W=global.Math.tan;var X=global.Math.acos;var Y=global.Math.asin;var Z=global.Math.atan;var _=global.Math.atan2;var $=global.Math.exp;var aa=global.Math.log;var ab=global.Math.ceil;var ac=global.Math.imul;var ad=env.abort;var ae=env.assert;var af=env.asmPrintInt;var ag=env.asmPrintFloat;var ah=env.min;var ai=env.invoke_iiiiiiii;var aj=env.invoke_vif;var ak=env.invoke_viiiii;var al=env.invoke_vi;var am=env.invoke_vii;var an=env.invoke_iiiiiii;var ao=env.invoke_ii;var ap=env.invoke_viiiiiiiiiii;var aq=env.invoke_viffff;var ar=env.invoke_if;var as=env.invoke_iiii;var at=env.invoke_viiiiif;var au=env.invoke_viff;var av=env.invoke_vifff;var aw=env.invoke_fii;var ax=env.invoke_iiif;var ay=env.invoke_viiiiiiii;var az=env.invoke_iif;var aA=env.invoke_viiiiiii;var aB=env.invoke_ff;var aC=env.invoke_viiiiiiiii;var aD=env.invoke_iii;var aE=env.invoke_viiiiii;var aF=env.invoke_f;var aG=env.invoke_i;var aH=env.invoke_iiiii;var aI=env.invoke_viii;var aJ=env.invoke_v;var aK=env.invoke_viiii;var aL=env._llvm_lifetime_end;var aM=env._lseek;var aN=env._RWebInputDestroy;var aO=env._RWebAudioStop;var aP=env._glClearColor;var aQ=env._sysconf;var aR=env._fclose;var aS=env._RWebAudioInit;var aT=env._glGetVertexAttribPointerv;var aU=env._glGetRenderbufferParameteriv;var aV=env._eglDestroySurface;var aW=env._strtoul;var aX=env._strtoull;var aY=env._glBindTexture;var aZ=env._fflush;var a_=env._glGetUniformiv;var a$=env._fabsf;var a0=env._strtol;var a1=env._fputc;var a2=env._glGetString;var a3=env._fwrite;var a4=env._gluUnProject;var a5=env._send;var a6=env._fputs;var a7=env._glLineWidth;var a8=env._glUniform2fv;var a9=env._emscripten_get_now;var ba=env._eglCreateContext;var bb=env._glBindAttribLocation;var bc=env._glCompileShader;var bd=env._isspace;var be=env._localtime;var bf=env._glDeleteTextures;var bg=env._eglBindAPI;var bh=env._glCompressedTexImage2D;var bi=env._glStencilFuncSeparate;var bj=env._read;var bk=env._RWebAudioBufferSize;var bl=env._glDeleteShader;var bm=env._RWebInputInit;var bn=env._glClearDepthf;var bo=env._glUniform4iv;var bp=env._glGetTexParameteriv;var bq=env._glClearStencil;var br=env._glLoadIdentity;var bs=env._glUniform1fv;var bt=env._glIsShader;var bu=env._strstr;var bv=env._glSampleCoverage;var bw=env._fsync;var bx=env._glGenTextures;var by=env._glDepthFunc;var bz=env._remove;var bA=env._glCompressedTexSubImage2D;var bB=env._glUniform1f;var bC=env._opendir;var bD=env._glGetTexParameterfv;var bE=env._RWebAudioWrite;var bF=env._glStencilMaskSeparate;var bG=env._glCreateShader;var bH=env._round;var bI=env._glUniform1i;var bJ=env._strncmp;var bK=env._cosf;var bL=env._glDeleteRenderbuffers;var bM=env._glLinkProgram;var bN=env._snprintf;var bO=env._glUniform2i;var bP=env._fgetc;var bQ=env._glStencilFunc;var bR=env._glShaderSource;var bS=env._readdir;var bT=env._glVertexAttribPointer;var bU=env._glHint;var bV=env._glBindBuffer;var bW=env._glVertexPointer;var bX=env._fgets;var bY=env._close;var bZ=env._getgid;var b_=env._glGetAttachedShaders;var b$=env._glBindFramebuffer;var b0=env._glIsFramebuffer;var b1=env._strchr;var b2=env._glUniform4fv;var b3=env._abort;var b4=env.___setErrNo;var b5=env._glDeleteFramebuffers;var b6=env._eglTerminate;var b7=env._glGetVertexAttribfv;var b8=env._glIsBuffer;var b9=env._emscripten_GetProcAddress;var ca=env._eglGetProcAddress;var cb=env._ftell;var cc=env._glDeleteProgram;var cd=env._exit;var ce=env._glRenderbufferStorage;var cf=env._strrchr;var cg=env._glAttachShader;var ch=env._RWebInputPoll;var ci=env._glUniform3i;var cj=env._glIsProgram;var ck=env._glCheckFramebufferStatus;var cl=env.__isLeapYear;var cm=env._gluProject;var cn=env._llvm_uadd_with_overflow_i32;var co=env._localtime_r;var cp=env._glUniform3f;var cq=env._glGetBufferParameteriv;var cr=env._glFlush;var cs=env._glBlendEquationSeparate;var ct=env._emscripten_get_canvas_size;var cu=env._glCopyTexImage2D;var cv=env._glDrawElements;var cw=env._glColorMask;var cx=env._sinf;var cy=env._gluLookAt;var cz=env._eglInitialize;var cA=env._recv;var cB=env.__parseInt64;var cC=env._glVertexAttrib1fv;var cD=env._glUniform2iv;var cE=env._putchar;var cF=env._glUniform1iv;var cG=env._glActiveTexture;var cH=env._glMatrixMode;var cI=env._glBlendEquation;var cJ=env._strcmp;var cK=env._glVertexAttrib1f;var cL=env._RWebAudioWriteAvail;var cM=env._glGenerateMipmap;var cN=env._memchr;var cO=env._glDetachShader;var cP=env._glGetShaderiv;var cQ=env.__exit;var cR=env._strftime;var cS=env._glVertexAttrib3f;var cT=env._glGenRenderbuffers;var cU=env._tzset;var cV=env._RWebAudioSampleRate;var cW=env._glGetShaderPrecisionFormat;var cX=env._glVertexAttrib4fv;var cY=env._glDepthMask;var cZ=env._glDisableVertexAttribArray;var c_=env._glBegin;var c$=env._printf;var c0=env._glBindRenderbuffer;var c1=env._pread;var c2=env._fopen;var c3=env._open;var c4=env._glDrawArrays;var c5=env._usleep;var c6=env._llvm_pow_f32;var c7=env.__arraySum;var c8=env._glCopyTexSubImage2D;var c9=env._glDisable;var da=env._puts;var db=env._glUniform4i;var dc=env._exp2;var dd=env._nanosleep;var de=env._glClear;var df=env._qsort;var dg=env._glUniform2f;var dh=env._eglDestroyContext;var di=env._isalpha;var dj=env._glEnableVertexAttribArray;var dk=env._rmdir;var dl=env._glUniform3fv;var dm=env._glStencilOp;var dn=env._strdup;var dp=env._glDepthRange;var dq=env._glUniform4f;var dr=env._glFramebufferTexture2D;var ds=env._glUniformMatrix2fv;var dt=env._glGenVertexArrays;var du=env._eglMakeCurrent;var dv=env._glUniformMatrix3fv;var dw=env._glutCreateWindow;var dx=env._glBufferData;var dy=env._glBlendColor;var dz=env._glGetUniformLocation;var dA=env._glIsEnabled;var dB=env.__formatString;var dC=env._getenv;var dD=env._glGetError;var dE=env._glGetVertexAttribiv;var dF=env._glTexParameteriv;var dG=env._glGetProgramiv;var dH=env._glVertexAttrib3fv;var dI=env._glGetFloatv;var dJ=env._glBufferSubData;var dK=env._glUniform3iv;var dL=env._glReadPixels;var dM=env._glGenFramebuffers;var dN=env._glFramebufferRenderbuffer;var dO=env._emscripten_procAddressTable;var dP=env._atexit;var dQ=env._ceil;var dR=env.___errno_location;var dS=env._glGetIntegerv;var dT=env._RWebAudioFree;var dU=env._llvm_lifetime_start;var dV=env._glIsRenderbuffer;var dW=env._llvm_bswap_i32;var dX=env._sbrk;var dY=env.__parseInt;var dZ=env._RWebAudioSetNonblockState;var d_=env._glVertexAttrib2fv;var d$=env._glGetFramebufferAttachmentParameteriv;var d0=env._glUseProgram;var d1=env._glTexImage2D;var d2=env._glGetProgramInfoLog;var d3=env._glTexSubImage2D;var d4=env._glStencilMask;var d5=env._fread;var d6=env._glStencilOpSeparate;var d7=env._strtok_r;var d8=env._glGetShaderInfoLog;var d9=env._glIsTexture;var ea=env._eglCreateWindowSurface;var eb=env._fprintf;var ec=env._glGetShaderSource;var ed=env._gluPerspective;var ee=env._eglChooseConfig;var ef=env.___buildEnvironment;var eg=env._feof;var eh=env.__addDays;var ei=env._glScissor;var ej=env._glEnable;var ek=env._glBlendFuncSeparate;var el=env._floor;var em=env.__reallyNegative;var en=env._glGetActiveAttrib;var eo=env._fseek;var ep=env._sqrt;var eq=env._glTexParameterfv;var er=env._write;var es=env._glGenBuffers;var et=env._glFinish;var eu=env._glGetAttribLocation;var ev=env._glVertexAttrib4f;var ew=env._rewind;var ex=env._sin;var ey=env._glBlendFunc;var ez=env._glCreateProgram;var eA=env._realpath;var eB=env._stat;var eC=env._longjmp;var eD=env._glViewport;var eE=env._emscripten_set_main_loop;var eF=env._time;var eG=env._glVertexAttrib2f;var eH=env._closedir;var eI=env._isgraph;var eJ=env._readlink;var eK=env._glGetUniformfv;var eL=env._unlink;var eM=env._gluOrtho2D;var eN=env._glUniformMatrix4fv;var eO=env._glClearDepth;var eP=env._glGetActiveUniform;var eQ=env._glutDestroyWindow;var eR=env._pwrite;var eS=env._fabs;var eT=env._glTexParameterf;var eU=env._RWebAudioStart;var eV=env._glTexParameteri;var eW=env._glFrontFace;var eX=env._glCullFace;var eY=env._glDepthRangef;var eZ=env._glDeleteBuffers;var e_=env._eglGetDisplay;var e$=env._emscripten_set_canvas_size;var e0=env._glGetBooleanv;var e1=env._eglQuerySurface;var e2=env._glPixelStorei;var e3=env._readdir_r;var e4=env._glValidateProgram;var e5=env._glPolygonOffset;
// EMSCRIPTEN_START_FUNCS
function fz(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7>>3<<3;return b|0}function fA(){return i|0}function fB(a){a=a|0;i=a}function fC(a,b){a=a|0;b=b|0;if((t|0)==0){t=a;u=b}}function fD(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0]}function fE(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0];a[k+4|0]=a[b+4|0];a[k+5|0]=a[b+5|0];a[k+6|0]=a[b+6|0];a[k+7|0]=a[b+7|0]}function fF(a){a=a|0;G=a}function fG(a){a=a|0;H=a}function fH(a){a=a|0;I=a}function fI(a){a=a|0;J=a}function fJ(a){a=a|0;K=a}function fK(a){a=a|0;L=a}function fL(a){a=a|0;M=a}function fM(a){a=a|0;N=a}function fN(a){a=a|0;O=a}function fO(a){a=a|0;P=a}function fP(){c[12944]=774428;c[12946]=774420;c[12948]=774432;c[12950]=774385;c[12952]=774424;c[12956]=774504;c[12958]=774496;c[12960]=774508;c[12962]=774461;c[12964]=774500}function fQ(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+20480|0;f=e|0;h=e+12288|0;e$(800,600);v3(505520,0,102392);j=c[191244]|0;if((j|0)!=0){aR(j|0)|0}v3(607928,0,158128);a[607930]=1;a[607929]=1;c[153016]=0;c[151983]=1;c[151984]=1;c[151985]=1;c[151986]=1;c[151987]=1;c[151988]=1;c[151989]=1;c[151990]=1;f$();j=f8(b,d)|0;if((j|0)!=0){k=j;i=e;return k|0}j=e+16384|0;d=vZ(113728)|0;b=(d|0)==0;do{if(!b){if((c[d-4>>2]&3|0)==0){break}v3(d|0,0,113728)}}while(0);l=d;c[d+28>>2]=149e3;c[d+32>>2]=640;c[d+4152>>2]=9760;m=4096;n=d+54|0;o=603809;while(1){p=m-1|0;if((p|0)==0){r=10;break}s=a[o]|0;a[n]=s;if(s<<24>>24==0){break}else{m=p;n=n+1|0;o=o+1|0}}do{if((r|0)==10){a[n]=0;if((a[o]|0)==0){break}else{t=o}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);t=vZ(12)|0;o=(t|0)==0;do{if(!o){if((c[t-4>>2]&3|0)==0){break}v3(t|0,0,12)}}while(0);c[d+40>>2]=t;n=vZ(12)|0;do{if((n|0)!=0){if((c[n-4>>2]&3|0)==0){break}v3(n|0,0,12)}}while(0);c[d+44>>2]=n;if(!o){o=t+8|0;n=t+4|0;m=c[n>>2]|0;if((c[o>>2]|0)>>>0<m>>>0){u=t}else{p=(m<<1)+2|0;c[n>>2]=p;n=t;c[n>>2]=v$(c[n>>2]|0,p*12|0)|0;u=n}n=dn(766672)|0;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)>>2]=n;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=4;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1}c[d+48>>2]=0;ik(l);o=c[191562]|0;do{if((o|0)==0){v=1.3333333730697632}else{if(!((c[191231]|0)==0|(c[191232]|0)==0)){v=1.3333333730697632;break}fa[c[(c[191559]|0)+44>>2]&127](o,764916);v=+((c[191231]|0)>>>0>>>0)/+((c[191232]|0)>>>0>>>0)}}while(0);g[3053]=v;c[36858]=l;if(b){b=c[191244]|0;l=(b|0)!=0?b:c[q>>2]|0;a3(39712,48,1,l|0)|0;l=c[191244]|0;b=(l|0)!=0?l:c[q>>2]|0;aZ(b|0)|0;if((a[764981]&1)==0){b=c[191244]|0;l=(b|0)!=0?b:c[q>>2]|0;eb(l|0,33568,(w=i,i=i+16|0,c[w>>2]=32512,c[w+8>>2]=832,w)|0)|0;i=w;l=c[191244]|0;b=(l|0)!=0?l:c[q>>2]|0;aZ(b|0)|0;cd(2);return 0}else{a[764983]=109;a[764984]=101;a[764985]=110;a[764986]=117;a[764987]=95;a[764988]=105;a[764989]=110;a[764990]=105;a[764991]=116;a[764992]=40;a[764993]=41;a[764994]=0;eC(766008,1);return 0}}v3(d|0,0,17);a[d+36|0]=1;c[d+113708>>2]=0;a[d+4172|0]=1;c[d+4168>>2]=33744;c[d+4164>>2]=28056;c[d+4160>>2]=24e3;a[d+4173|0]=0;b=h|0;h=cf(505636,46)|0;l=(h|0)==0?766672:h+1|0;L44:do{if((cJ(l|0,47392)|0)==0){r=32}else{if((cJ(l|0,47896)|0)==0){r=32;break}do{if((cJ(l|0,40432)|0)!=0){if((cJ(l|0,28824)|0)==0){break}h=(a[513837]|0)!=0?513837:599676;gq(b,h,44872);o=gG(b,0)|0;if((o|0)==0){gq(b,h,44784);h=gG(b,0)|0;if((h|0)==0){break L44}else{x=h}}else{x=o}o=d+4180|0;if(hZ(x,o)|0){h1(o,b)}gE(x);break L44}}while(0);o=4096;h=d+4256|0;u=505636;while(1){n=o-1|0;if((n|0)==0){r=41;break}p=a[u]|0;a[h]=p;if(p<<24>>24==0){break}else{o=n;h=h+1|0;u=u+1|0}}do{if((r|0)==41){a[h]=0;if((a[u]|0)==0){break}else{y=u}do{y=y+1|0;}while((a[y]|0)!=0)}}while(0);c[d+4252>>2]=1}}while(0);do{if((r|0)==32){y=gG(505636,0)|0;if((y|0)==0){break}x=d+4180|0;if(hZ(y,x)|0){h1(x,505636)}gE(y)}}while(0);if((a[628458]|0)!=0){L74:do{if((a[579192]|0)==0){gA(j,628458,37800)}else{d=4096;y=j;x=579192;while(1){l=d-1|0;if((l|0)==0){break}u=a[x]|0;a[y]=u;if(u<<24>>24==0){break L74}else{d=l;y=y+1|0;x=x+1|0}}a[y]=0;if((a[x]|0)==0){break}else{z=x}do{z=z+1|0;}while((a[z]|0)!=0)}}while(0);if((a[607928]&1)!=0){z=c[191244]|0;x=(z|0)!=0?z:c[q>>2]|0;eb(x|0,36512,(w=i,i=i+8|0,c[w>>2]=j,w)|0)|0;i=w;x=c[191244]|0;z=(x|0)!=0?x:c[q>>2]|0;aZ(z|0)|0}z=c[145822]|0;x=vZ(16)|0;do{if((x|0)==0){A=0}else{if((c[x-4>>2]&3|0)!=0){v3(x|0,0,16)}y=x;do{if((z|0)==0){B=0}else{d=z*12|0;if(z>>>0<=65535){B=d;break}B=((d>>>0)/(z>>>0)|0|0)==12?d:-1}}while(0);d=vZ(B)|0;if((d|0)==0){c[x>>2]=0;is(y);A=0;break}if((c[d-4>>2]&3|0)==0){l=x;c[l>>2]=d;C=l}else{v3(d|0,0,B|0);l=x;c[l>>2]=d;C=l}l=x+8|0;c[l>>2]=z;d=f|0;u=c2(j|0,41400)|0;if((u|0)!=0){h=x+4|0;c[h>>2]=0;L104:do{if((c[l>>2]|0)!=0){o=f+4096|0;n=f+8192|0;do{a[d]=0;if((bX(d|0,4096,u|0)|0)==0){break L104}p=cf(d|0,10)|0;if((p|0)!=0){a[p]=0}a[o]=0;if((bX(o|0,4096,u|0)|0)==0){break L104}p=cf(o|0,10)|0;if((p|0)!=0){a[p]=0}a[n]=0;if((bX(n|0,4096,u|0)|0)==0){break L104}p=cf(n|0,10)|0;if((p|0)!=0){a[p]=0}p=c[h>>2]|0;t=c[C>>2]|0;if((a[o]|0)==0){break L104}if((a[n]|0)==0){break L104}if((a[d]|0)!=0){c[t+(p*12|0)>>2]=dn(d|0)|0}c[t+(p*12|0)+4>>2]=dn(o|0)|0;c[t+(p*12|0)+8>>2]=dn(n|0)|0;p=(c[h>>2]|0)+1|0;c[h>>2]=p;}while(p>>>0<(c[l>>2]|0)>>>0)}}while(0);aR(u|0)|0}c[x+12>>2]=dn(j|0)|0;A=y}}while(0);c[(c[36858]|0)+113712>>2]=A}v=+a9()*1.0e3;A=+R(v)>=1.0?v>0.0?(ah(+Q(v/4294967296.0),4294967295.0)|0)>>>0:~~+ab((v- +(~~v>>>0))/4294967296.0)>>>0:0;x=(c[36858]|0)+113720|0;c[x>>2]=~~v>>>0;c[x+4>>2]=A;A=764968;x=c[A+4>>2]|0;C=764968;c[C>>2]=c[A>>2]|1;c[C+4>>2]=x;do{if((a[766053]&1)==0){L131:do{if((a[607964]&1)==0){x=4096;C=j;A=644842;while(1){f=x-1|0;if((f|0)==0){break}z=a[A]|0;a[C]=z;if(z<<24>>24==0){break L131}else{x=f;C=C+1|0;A=A+1|0}}a[C]=0;if((a[A]|0)==0){break}else{D=A}do{D=D+1|0;}while((a[D]|0)!=0)}else{bN(j|0,4096,46712,(w=i,i=i+8|0,c[w>>2]=640746,w)|0)|0;i=w}}while(0);L140:do{if((a[j]|0)!=0){y=4096;u=b;A=j;while(1){C=y-1|0;if((C|0)==0){r=99;break}x=a[A]|0;a[u]=x;if(x<<24>>24==0){break}else{y=C;u=u+1|0;A=A+1|0}}do{if((r|0)==99){a[u]=0;if((a[A]|0)==0){break}else{E=A}do{E=E+1|0;}while((a[E]|0)!=0)}}while(0);if((eA(b|0,j|0)|0)==0){F=4096;G=j;H=b}else{break}while(1){A=F-1|0;if((A|0)==0){break}u=a[H]|0;a[G]=u;if(u<<24>>24==0){break L140}else{F=A;G=G+1|0;H=H+1|0}}a[G]=0;if((a[H]|0)==0){break}else{I=H}do{I=I+1|0;}while((a[I]|0)!=0)}}while(0);A=c[(c[36858]|0)+113712>>2]|0;if((A|0)==0){break}ir(A,(a[j]|0)!=0?j:0,c[175554]|0)}}while(0);eE(96,((a[505608]&1)!=0?0:2147483647)|0,1);k=0;i=e;return k|0}function fR(){var b=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=i;i=i+8664|0;e=b|0;f=b+8|0;j=b+136|0;k=b+264|0;l=b+4360|0;m=b+8456|0;n=b+8464|0;o=b+8592|0;p=b+8656|0;if((a[702280]&1)!=0){a[702280]=0;r=c[36858]|0;if((a[r+4156|0]&1)!=0){v_(c[r+4152>>2]|0)}s=c[r+40>>2]|0;t=s+8|0;u=s|0;v=c[u>>2]|0;if((c[t>>2]|0)==0){w=v}else{x=0;y=v;while(1){v_(c[y+(x*12|0)>>2]|0);v=x+1|0;z=c[u>>2]|0;if(v>>>0<(c[t>>2]|0)>>>0){x=v;y=z}else{w=z;break}}}v_(w);v_(s);s=c[r+44>>2]|0;r=s+8|0;w=s|0;y=c[w>>2]|0;if((c[r>>2]|0)==0){A=y}else{x=0;t=y;while(1){v_(c[t+(x*12|0)>>2]|0);y=x+1|0;u=c[w>>2]|0;if(y>>>0<(c[r>>2]|0)>>>0){x=y;t=u}else{A=u;break}}}v_(A);v_(s);is(c[(c[36858]|0)+113712>>2]|0);v_(c[36858]|0);L173:do{if(!((a[764982]&1)==0|(a[628458]|0)==0)){s=o|0;A=gG(628458,0)|0;do{if((A|0)==0){t=vZ(20)|0;if((t|0)==0){break L173}if((c[t-4>>2]&3|0)==0){B=t;break}else{v3(t|0,0,20);B=t;break}}else{B=A}}while(0);if((a[607928]&1)!=0){A=c[191244]|0;t=(A|0)!=0?A:c[q>>2]|0;eb(t|0,48880,(C=i,i=i+8|0,c[C>>2]=628458,C)|0)|0;i=C;t=c[191244]|0;A=(t|0)!=0?t:c[q>>2]|0;aZ(A|0)|0}gJ(B,17824,583292);gJ(B,14408,587388);gJ(B,16112,(a[603772]&1)!=0?49992:20464);A=c[150945]|0;t=n|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,15648,t);gJ(B,27832,505636);gJ(B,27464,(a[509732]&1)!=0?49992:20464);D=+g[126406];bN(t|0,128,14680,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gJ(B,29744,t);D=+g[126396];bN(t|0,128,14680,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gJ(B,47880,t);D=+g[126397];bN(t|0,128,14680,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gJ(B,46008,t);gJ(B,30048,(a[505622]&1)!=0?49992:20464);gJ(B,30416,(a[505629]&1)!=0?49992:20464);gJ(B,31656,(a[505620]&1)!=0?49992:20464);D=+g[128458];bN(t|0,128,14680,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gJ(B,28224,t);gJ(B,38344,(a[505608]&1)!=0?49992:20464);gJ(B,37360,(a[505609]&1)!=0?49992:20464);A=c[126404]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,35952,t);gJ(B,34344,(a[505610]&1)!=0?49992:20464);A=c[126403]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,33112,t);A=c[126408]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,29368,t);gJ(B,20008,522116);gJ(B,19472,(a[530313]&1)!=0?49992:20464);D=+g[132579];bN(t|0,128,14680,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gJ(B,19232,t);if((a[599676]|0)==0){gJ(B,49440,21624)}else{gJ(B,49440,599676)}if((a[677610]|0)==0){gJ(B,50560,21624)}else{gJ(B,50560,677610)}if((a[681706]|0)==0){gJ(B,50096,21624)}else{gJ(B,50096,681706)}if((a[513837]|0)==0){gJ(B,22128,21624)}else{gJ(B,22128,513837)}if((a[603809]|0)==0){gJ(B,16712,21624)}else{gJ(B,16712,603809)}if((a[685802]|0)==0){gJ(B,16600,21624)}else{gJ(B,16600,685802)}gJ(B,16496,566896);D=+g[142748];bN(t|0,128,14680,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gJ(B,16360,t);D=+g[142749];bN(t|0,128,14680,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gJ(B,16216,t);gJ(B,48448,(c[191236]|0)!=0?49992:20464);A=764968;if((c[A>>2]&16384|0)==0&(c[A+4>>2]&0|0)==0){gJ(B,48200,20464)}else{gJ(B,48200,49992)}A=764968;if((c[A>>2]&128|0)==0&(c[A+4>>2]&0|0)==0){gJ(B,47864,20464)}else{gJ(B,47864,49992)}A=764968;if((c[A>>2]&65536|0)==0&(c[A+4>>2]&0|0)==0){gJ(B,47768,20464)}else{gJ(B,47768,49992)}A=764968;if((c[A>>2]&32768|0)==0&(c[A+4>>2]&0|0)==0){gJ(B,47592,20464)}else{gJ(B,47592,49992)}A=d[764948]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,47368,t);A=d[764949]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,47176,t);A=c[191223]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,47072,t);A=c[191231]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,23744,t);A=c[191232]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,23464,t);A=c[191229]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,24192,t);A=c[191230]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,23960,t);D=+g[130508];bN(t|0,128,14680,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gJ(B,26480,t);gJ(B,50704,(a[764982]&1)!=0?49992:20464);A=c[191238]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,46960,t);A=c[175548]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,46696,t);A=a[707057]&1;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,16416,t);A=c[191235]|0;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gJ(B,46176,t);A=764968;if((c[A>>2]&524288|0)==0&(c[A+4>>2]&0|0)==0){gJ(B,45984,20464);E=0}else{gJ(B,45984,49992);E=0}while(1){A=E+1|0;bN(s|0,64,45912,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=c[566852+(E<<2)>>2],C)|0)|0;i=C;gJ(B,s,t);bN(s|0,64,45840,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=c[566308+(E<<2)>>2],C)|0)|0;i=C;gJ(B,s,t);bN(s|0,64,20424,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;bN(t|0,128,27712,(C=i,i=i+8|0,c[C>>2]=c[566276+(E<<2)>>2],C)|0)|0;i=C;gJ(B,s,t);if(A>>>0<8){E=A}else{break}}gK(B,628458)|0;gE(B)}}while(0);if((a[764980]&1)!=0){gb()}B=c[189113]|0;if((B|0)!=0){E=B+4|0;n=c[E>>2]|0;o=B|0;if(n>>>0>1){t=1;s=n;while(1){n=c[(c[o>>2]|0)+(t<<2)>>2]|0;if((n|0)==0){F=s}else{v_(c[n+8>>2]|0);v_(c[(c[o>>2]|0)+(t<<2)>>2]|0);c[(c[o>>2]|0)+(t<<2)>>2]=0;F=c[E>>2]|0}n=t+1|0;if(n>>>0<F>>>0){t=n;s=F}else{break}}}c[E>>2]=1;E=B+12|0;v_(c[E>>2]|0);c[E>>2]=0;v_(c[o>>2]|0);v_(B);c[189113]=0}v3(505520,0,102392);B=c[191244]|0;if((B|0)==0){v3(607928,0,158128);a[607930]=1;a[607929]=1;c[153016]=0;c[151983]=1;c[151984]=1;c[151985]=1;c[151986]=1;c[151987]=1;c[151988]=1;c[151989]=1;c[151990]=1;cd(0)}aR(B|0)|0;v3(607928,0,158128);a[607930]=1;a[607929]=1;c[153016]=0;c[151983]=1;c[151984]=1;c[151985]=1;c[151986]=1;c[151987]=1;c[151988]=1;c[151989]=1;c[151990]=1;cd(0)}B=764968;o=c[B>>2]|0;E=c[B+4>>2]|0;if(a[7296]|0){if(!((o&32|0)==0&(E&0|0)==0)){B=c[36858]|0;a[B+52|0]=1;F=764968;s=c[F+4>>2]|0;t=764968;c[t>>2]=c[F>>2]&-33;c[t+4>>2]=s;s=B|0;B=c[s+4>>2]|0;c[s>>2]=c[s>>2]|256;c[s+4>>2]=B}fY();if((c[191604]|0)!=0){do{if((a[766263]&1)==0){B=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,51)|0;s=766424;if((c[s>>2]&0|B&1|0)==0&(c[s+4>>2]&524288|0)==0){H=0;break}if((a[148736]&1)!=0){H=1;break}s=c[191604]|0;B=s+28|0;t=c[B>>2]|0;F=s+20|0;c[F>>2]=t;n=c[s+12>>2]|0;A=s+16|0;c[A>>2]=n+(t*136|0);x=s+4|0;r=c[(c[x>>2]|0)+4>>2]|0;w=s|0;u=c[w>>2]|0;y=c[n+(t*136|0)+8>>2]|0;z=c[n+(t*136|0)+12>>2]|0;v=c[n+(t*136|0)+16>>2]|0;fv[r&15](u,y,z,v)|0;v=c[A>>2]|0;fe[c[(c[x>>2]|0)+12>>2]&7](c[w>>2]|0,+g[v+24>>2],+g[v+28>>2],+g[v+32>>2],+g[v+36>>2]);fa[c[(c[x>>2]|0)+16>>2]&127](c[w>>2]|0,(a[(c[A>>2]|0)+68|0]&1)!=0);a[s+9|0]=1;c[B>>2]=(((c[F>>2]|0)+1|0)>>>0)%((c[s+24>>2]|0)>>>0)|0;H=1}else{H=0}}while(0);a[148736]=H}if((a[766263]&1)==0){H=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,30)|0;s=766424;if((c[s>>2]&1073741824|H&1|0)==0&(c[s+4>>2]&0|0)==0){I=184}else{I=185}}else{I=184}do{if((I|0)==184){if(fc[c[(c[191559]|0)+12>>2]&127](c[191562]|0)|0){J=0;K=0;L=0}else{I=185;break}do{s=c[2008+(L<<2)>>2]|0;if((fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,2072,0,1,0,s)|0)<<16>>16==0){M=0;N=0}else{H=we(1,0,c[2008+((L|1)<<2)>>2]|0)|0;F=G;M=F;N=H}H=766424;F=c[H>>2]|0;B=c[H+4>>2]|0;H=we(1,0,s|0)|0;s=G;if((F&H|0)==0&(B&s|0)==0){O=0;P=0}else{s=we(1,0,c[2008+((L|1)<<2)>>2]|0)|0;B=G;O=B;P=s}K=N|K|P;J=M|J|O;L=L+2|0;}while(L>>>0<16);if((a[766263]&1)==0){s=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,55)|0;B=766424;H=(c[B>>2]&0|s&1|0)!=0|(c[B+4>>2]&8388608|0)!=0;S=H?0:0;T=H?256:0}else{S=0;T=0}H=T|K;B=S|J;s=c[36858]|0;F=s|0;A=B&~c[F+4>>2];w=s+8|0;c[w>>2]=H&~c[F>>2];c[w+4>>2]=A;do{if((K&15|0)==0&(J&0|0)==0){a[s+16|0]=0;I=200}else{A=((H>>>8|B<<24)&1^1)&255;a[s+16|0]=A;if((A&1)==0){I=200;break}if(!(a[7312]|0)){a[7312]=1;c[s+20>>2]=a[7304]|0?6:12;c[s+24>>2]=0;U=1;V=0;break}A=c[s+24>>2]|0;if(A>>>0<(c[s+20>>2]|0)>>>0){U=1;V=A;break}a[7312]=0;c[w>>2]=H;c[w+4>>2]=B;U=1;V=A}}while(0);if((I|0)==200){a[7312]=0;U=0;V=c[s+24>>2]|0}a[7304]=U;c[s+24>>2]=V+1;c[F>>2]=H;c[F+4>>2]=B;w=il(s)|0;A=c[191610]|0;do{if((A|0)!=0){x=c[A+24>>2]|0;if((x|0)==0){break}fw[x&127](c[191562]|0,(a[(c[36858]|0)+36|0]&1)!=0,0)}}while(0);fU();D=+a9()*1.0e3;A=+R(D)>=1.0?D>0.0?(ah(+Q(D/4294967296.0),4294967295.0)|0)>>>0:~~+ab((D- +(~~D>>>0))/4294967296.0)>>>0:0;s=(c[36858]|0)+113720|0;B=wd(~~D>>>0,A,c[s>>2]|0,c[s+4>>2]|0)|0;s=wk(B,G,1e3,0)|0;B=G;D=750.0/+g[128458];A=wd(~~D>>>0,+R(D)>=1.0?D>0.0?(ah(+Q(D/4294967296.0),4294967295.0)|0)>>>0:~~+ab((D- +(~~D>>>0))/4294967296.0)>>>0:0,s,B)|0;B=G;s=0;if((B|0)>(s|0)|(B|0)==(s|0)&A>>>0>0>>>0){s=A;A=m;c[m>>2]=0;c[m+4>>2]=0;c[m>>2]=(s>>>0)/1e3|0;c[A+4>>2]=((s>>>0)%1e3|0)*1e6|0;dd(A|0,0)|0}D=+a9()*1.0e3;A=+R(D)>=1.0?D>0.0?(ah(+Q(D/4294967296.0),4294967295.0)|0)>>>0:~~+ab((D- +(~~D>>>0))/4294967296.0)>>>0:0;s=c[36858]|0;B=s+113720|0;c[B>>2]=~~D>>>0;c[B+4>>2]=A;A=c[191610]|0;do{if((A|0)==0){W=s}else{B=c[A+24>>2]|0;if((B|0)==0){W=s;break}fw[B&127](c[191562]|0,0,0);W=c[36858]|0}}while(0);s=W+8|0;do{if((c[s>>2]&256|0)==0&(c[s+4>>2]&0|0)==0){X=0}else{if((a[764980]&1)==0){X=0;break}if((a[766053]&1)!=0){X=0;break}A=764968;B=c[A+4>>2]|0;F=764968;c[F>>2]=c[A>>2]|65;c[F+4>>2]=B;X=-1}}while(0);s=764968;B=c[s>>2]|0;F=c[s+4>>2]|0;if(!((B&64|0)==0&(F&0|0)==0)){s=764968;c[s>>2]=B&-65;c[s+4>>2]=F|0}do{if((X|0)<0){F=c[W+40>>2]|0;s=c[F+8>>2]|0;if((s|0)==0){Y=0;Z=W;_=F;$=0}else{B=c[(c[F>>2]|0)+((s-1|0)*12|0)+4>>2]|0;if((B|0)==4){break}else{Y=B;Z=W;_=F;$=s}}while(1){s=Z+48|0;F=_+8|0;if(($|0)!=0){B=$-1|0;c[F>>2]=B;v_(c[(c[_>>2]|0)+(B*12|0)>>2]|0)}if((s|0)!=0){c[s>>2]=c[(c[_>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]}F=c[36858]|0;s=c[F+40>>2]|0;B=c[s+8>>2]|0;if((B|0)==0){aa=Y}else{aa=c[(c[s>>2]|0)+((B-1|0)*12|0)+4>>2]|0}if((aa|0)==4){break}else{Y=aa;Z=F;_=s;$=B}}}}while(0);if((X|w|0)!=0){break}i=b;return}}while(0);if((I|0)==185){X=764968;$=c[X+4>>2]|0;_=764968;c[_>>2]=c[X>>2]|1;c[_+4>>2]=$}a[7296]=0;$=(a[766264]&1)!=0;_=c[191562]|0;if((a[607930]&1)!=0&(_|0)!=0){if((a[505608]&1)==0){I=229}else{if((a[702293]&1)==0){ac=$}else{I=229}}if((I|0)==229){ac=1}fa[c[(c[191559]|0)+8>>2]&127](_,ac)}ac=c[191561]|0;if((a[607929]&1)!=0&(ac|0)!=0){fa[c[(c[191558]|0)+16>>2]&127](ac,(a[526216]&1)==0|$);ad=c[191561]|0}else{ad=ac}c[176758]=$?c[176759]|0:c[176760]|0;do{if((ad|0)!=0){if(fc[c[(c[191558]|0)+12>>2]&127](ad)|0){break}$=c[191244]|0;ac=($|0)!=0?$:c[q>>2]|0;a3(13632,81,1,ac|0)|0;ac=c[191244]|0;$=(ac|0)!=0?ac:c[q>>2]|0;aZ($|0)|0;a[607929]=0}}while(0);ad=764968;$=c[ad+4>>2]|0;ac=764968;c[ac>>2]=c[ad>>2]&-5;c[ac+4>>2]=$;i=b;return}if((o&2|0)==0&(E&0|0)==0){if((o&1|0)==0&(E&0|0)==0){if((o&4|0)==0&(E&0|0)==0){a[702280]=1;i=b;return}$=764968;c[$>>2]=o|32;c[$+4>>2]=E;fa[c[(c[191559]|0)+8>>2]&127](c[191562]|0,0);$=c[191561]|0;if(($|0)!=0){ac=c[(c[191558]|0)+8>>2]|0;fc[ac&127]($)|0}a[7296]=1;i=b;return}do{if((a[764679]&1)==0){I=295}else{if((a[764680]&1)!=0){I=295;break}if((a[766263]&1)==0){$=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,30)|0;ac=766424;if(!((c[ac>>2]&1073741824|$&1|0)==0&(c[ac+4>>2]&0|0)==0)){break}}if(!(fc[c[(c[191559]|0)+12>>2]&127](c[191562]|0)|0)){break}f9();fY();ac=p;c[p>>2]=0;c[p+4>>2]=0;c[p>>2]=0;c[ac+4>>2]=1e7;dd(ac|0,0)|0;i=b;return}}while(0);L367:do{if((I|0)==295){if((a[766263]&1)==0){p=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,30)|0;ac=766424;if(!((c[ac>>2]&1073741824|p&1|0)==0&(c[ac+4>>2]&0|0)==0)){break}}if(!(fc[c[(c[191559]|0)+12>>2]&127](c[191562]|0)|0)){break}do{if((a[766263]&1)==0){ac=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,55)|0;p=766424;if((c[p>>2]&0|ac&1|0)==0&(c[p+4>>2]&8388608|0)==0){I=301;break}ae=a[9728]|0;I=303}else{I=301}}while(0);do{if((I|0)==301){if((a[766053]&1)==0){af=0;break}w=a[9728]|0;if((w&1)==0){ae=w;I=303}else{af=0}}}while(0);do{if((I|0)==303){if((ae&1)!=0){af=1;break}w=764968;p=c[w+4>>2]|0;ac=764968;c[ac>>2]=c[w>>2]|4;c[ac+4>>2]=p;a[9728]=1;p=707e3;c[p>>2]=0;c[p+4>>2]=0;break L367}}while(0);a[9728]=af;if((a[756456]&1)!=0){a[756456]=0;break}f9();p=c[189119]|0;if((p|0)!=0){ac=cb(c[p>>2]|0)|0;c[(c[p+12>>2]|0)+(c[p+20>>2]<<2)>>2]=ac}if((c[176746]|0)!=0){D=+a9()*1.0e3;ac=~~D>>>0;p=+R(D)>=1.0?D>0.0?(ah(+Q(D/4294967296.0),4294967295.0)|0)>>>0:~~+ab((D- +(~~D>>>0))/4294967296.0)>>>0:0;do{if((a[764679]&1)==0){w=(a[766264]&1)!=0;$=707e3;ad=c[$>>2]|0;_=c[$+4>>2]|0;$=(ad|0)==0&(_|0)==0|w;X=706992;Z=c[X>>2]|0;aa=c[X+4>>2]|0;X=wd(ac,p,ad,_)|0;_=$?Z:X;X=$?aa:G;if(w){ag=X;ai=_;aj=0;ak=0;break}if((a[764681]&1)==0){ag=X;ai=_;aj=p;ak=ac;break}D=(+(_>>>0)+ +(X|0)*4294967296.0)/+g[150946];ag=+R(D)>=1.0?D>0.0?(ah(+Q(D/4294967296.0),4294967295.0)|0)>>>0:~~+ab((D- +(~~D>>>0))/4294967296.0)>>>0:0;ai=~~D>>>0;aj=p;ak=ac}else{X=706992;ag=c[X+4>>2]|0;ai=c[X>>2]|0;aj=0;ak=0}}while(0);ac=707e3;c[ac>>2]=ak;c[ac+4>>2]=aj;fa[c[176746]&127](ai,ag)}fx[c[37208]&127]();do{if(+g[150947]>=0.0){D=+a9()*1.0e3;ac=+R(D)>=1.0?D>0.0?(ah(+Q(D/4294967296.0),4294967295.0)|0)>>>0:~~+ab((D- +(~~D>>>0))/4294967296.0)>>>0:0;p=702208;X=702200;_=c[X>>2]|0;w=c[X+4>>2]|0;X=wd(c[p>>2]|0,c[p+4>>2]|0,~~D>>>0,ac)|0;ac=wc(X,G,_,w)|0;w=G;_=0;if((w|0)>(_|0)|(w|0)==(_|0)&ac>>>0>999>>>0){_=wk(ac,w,1e3,0)|0;w=_;_=e;c[e>>2]=0;c[e+4>>2]=0;c[e>>2]=(w>>>0)/1e3|0;c[_+4>>2]=((w>>>0)%1e3|0)*1e6|0;dd(_|0,0)|0;_=702200;w=702208;ac=wc(c[w>>2]|0,c[w+4>>2]|0,c[_>>2]|0,c[_+4>>2]|0)|0;_=702208;c[_>>2]=ac;c[_+4>>2]=G;break}else{D=+a9()*1.0e3;_=+R(D)>=1.0?D>0.0?(ah(+Q(D/4294967296.0),4294967295.0)|0)>>>0:~~+ab((D- +(~~D>>>0))/4294967296.0)>>>0:0;ac=702208;c[ac>>2]=~~D>>>0;c[ac+4>>2]=_;break}}}while(0);_=c[189119]|0;if((_|0)==0){i=b;return}ac=_+20|0;c[ac>>2]=(c[ac>>2]|0)+1&c[_+16>>2];ac=_+33|0;a[_+32|0]=a[ac]&1^1;a[ac]=0;i=b;return}}while(0);e=764968;ag=c[e+4>>2]|0;ai=764968;c[ai>>2]=c[e>>2]&-2;c[ai+4>>2]=ag;i=b;return}ag=k|0;k=l|0;L411:do{if((a[644842]|0)==0){l=c[36858]|0;if((a[l+4176|0]&1)==0){al=l}else{I=248}}else{if((o&128|0)==0&(E&0|0)==0){I=248;break}gy(ag,644842,4096);bN(k|0,4096,45256,(C=i,i=i+8|0,c[C>>2]=ag,C)|0)|0;i=C;l=c[189113]|0;ai=l+4|0;if((c[ai>>2]|0)>>>0>=(c[l+8>>2]|0)>>>0){I=248;break}e=vZ(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}v3(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=1;aj=dn(k|0)|0;ak=c[ai>>2]|0;c[e+8>>2]=aj;aj=l|0;c[(c[aj>>2]|0)+(ak<<2)>>2]=e;ak=c[ai>>2]|0;c[ai>>2]=ak+1;if(ak>>>0>1){am=ak}else{I=248;break}while(1){ak=am>>>1;af=c[aj>>2]|0;ae=af+(ak<<2)|0;ac=c[ae>>2]|0;_=c[af+(am<<2)>>2]|0;if((c[_+4>>2]|0)>>>0<=(c[ac+4>>2]|0)>>>0){I=248;break L411}c[ae>>2]=_;c[(c[aj>>2]|0)+(am<<2)>>2]=ac;if(am>>>0>3){am=ak}else{I=248;break}}}}while(0);do{if((I|0)==248){am=c[36858]|0;E=c[am+4160>>2]|0;o=c[am+113712>>2]|0;if((o|0)==0){al=am;break}ir(o,(a[644842]|0)!=0?644842:0,(E|0)==0?766672:E);al=c[36858]|0}}while(0);v3(al|0,0,17);a[al+53|0]=1;il(al)|0;al=c[191610]|0;do{if((al|0)!=0){I=c[al+24>>2]|0;if((I|0)==0){break}fw[I&127](c[191562]|0,(a[(c[36858]|0)+36|0]&1)!=0,0)}}while(0);if((c[191559]|0)!=0){fU()}al=c[191610]|0;do{if((al|0)!=0){I=c[al+24>>2]|0;if((I|0)==0){break}fw[I&127](c[191562]|0,0,0)}}while(0);if((a[764980]&1)!=0){gb()}al=a[607928]&1;I=(a[628458]|0)!=0;E=I?628458:0;o=(a[677610]|0)!=0;am=o?677610:0;aj=(a[681706]|0)!=0;ai=aj?681706:0;e=(a[644842]|0)!=0;l=e?644842:0;ak=(c[36858]|0)+4176|0;ac=a[ak]&1;a[ak]=0;ak=f;_=j;if((a[764980]&1)!=0){gb()}v3(ak|0,0,128);ae=f|0;c[ae>>2]=dn(23392)|0;do{if(ac<<24>>24==0){af=(a[607928]&1)!=0;if(e){if(af){w=c[191244]|0;X=(w|0)!=0?w:c[q>>2]|0;eb(X|0,23080,(C=i,i=i+8|0,c[C>>2]=l,C)|0)|0;i=C;X=c[191244]|0;w=(X|0)!=0?X:c[q>>2]|0;aZ(w|0)|0}c[f+4>>2]=dn(l|0)|0;an=2;break}else{if(af){af=c[191244]|0;w=(af|0)!=0?af:c[q>>2]|0;a3(22864,40,1,w|0)|0;w=c[191244]|0;af=(w|0)!=0?w:c[q>>2]|0;aZ(af|0)|0}c[f+4>>2]=dn(22600)|0;an=2;break}}else{an=1}}while(0);if(o){c[f+(an<<2)>>2]=dn(22464)|0;c[f+(an+1<<2)>>2]=dn(am|0)|0;ao=an+2|0}else{ao=an}if(aj){c[f+(ao<<2)>>2]=dn(22096)|0;c[f+(ao+1<<2)>>2]=dn(ai|0)|0;ap=ao+2|0}else{ap=ao}if(I){c[f+(ap<<2)>>2]=dn(21400)|0;c[f+(ap+1<<2)>>2]=dn(E|0)|0;aq=ap+2|0}else{aq=ap}if(al<<24>>24==0){ar=aq}else{c[f+(aq<<2)>>2]=dn(21032)|0;ar=aq+1|0}v6(_|0,ak|0,128)|0;ak=f8(ar,ae)|0;ae=0;do{v_(c[j+(ae<<2)>>2]|0);ae=ae+1|0;}while(ae>>>0<32);if((ak|0)==0){if((a[607928]&1)!=0){ak=c[191244]|0;ae=(ak|0)!=0?ak:c[q>>2]|0;a3(43056,45,1,ae|0)|0;ae=c[191244]|0;ak=(ae|0)!=0?ae:c[q>>2]|0;aZ(ak|0)|0}ak=764968;ae=c[ak+4>>2]|0|0;j=764968;c[j>>2]=c[ak>>2]&-4|1;c[j+4>>2]=ae;i=b;return}gy(ag,644842,4096);bN(k|0,4096,41728,(C=i,i=i+8|0,c[C>>2]=ag,C)|0)|0;i=C;C=c[189113]|0;ag=C+4|0;L478:do{if((c[ag>>2]|0)>>>0<(c[C+8>>2]|0)>>>0){ae=vZ(12)|0;do{if((ae|0)!=0){if((c[ae-4>>2]&3|0)==0){break}v3(ae|0,0,12)}}while(0);c[ae+4>>2]=1;c[ae>>2]=90;j=dn(k|0)|0;ak=c[ag>>2]|0;c[ae+8>>2]=j;j=C|0;c[(c[j>>2]|0)+(ak<<2)>>2]=ae;ak=c[ag>>2]|0;c[ag>>2]=ak+1;if(ak>>>0>1){as=ak}else{break}while(1){ak=as>>>1;ar=c[j>>2]|0;_=ar+(ak<<2)|0;aq=c[_>>2]|0;f=c[ar+(as<<2)>>2]|0;if((c[f+4>>2]|0)>>>0<=(c[aq+4>>2]|0)>>>0){break L478}c[_>>2]=f;c[(c[j>>2]|0)+(as<<2)>>2]=aq;if(as>>>0>3){as=ak}else{break}}}}while(0);a[(c[36858]|0)+53|0]=1;as=c[191244]|0;a3(40696,52,1,((as|0)!=0?as:c[q>>2]|0)|0)|0;as=c[191244]|0;aZ(((as|0)!=0?as:c[q>>2]|0)|0)|0;i=b;return}function fS(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=d<<1;if((e|0)==0){return d|0}else{f=0}do{g=b[a+(f<<1)>>1]|0;h=(c[176768]|0)-1|0;c[176768]=h;b[(c[176767]|0)+(h<<1)>>1]=g;f=f+1|0;}while(f>>>0<e>>>0);return d|0}function fT(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0;b=i;i=i+24|0;d=b|0;if((a[595580]|0)==0){i=b;return}do{if((a[522063]&1)!=0|(c[176735]|0)!=0){e=c[191559]|0;if((c[e+48>>2]|0)==0){f=360;break}g=e+44|0;if((c[g>>2]|0)==0){f=360;break}v3(d|0,0,24);fa[c[g>>2]&127](c[191562]|0,d);g=d+8|0;e=c[g>>2]|0;if((e|0)==0){f=365;break}h=d+12|0;j=c[h>>2]|0;if((j|0)==0){f=365;break}k=vZ(ac(e*3|0,j)|0)|0;if((k|0)==0){f=365;break}if(fr[c[(c[191559]|0)+48>>2]&63](c[191562]|0,k)|0){j=c[g>>2]|0;g=hv(k,j,c[h>>2]|0,j*3|0,1)|0;v_(k);if(g){f=363;break}else{f=365;break}}else{v_(k);f=365;break}}else{f=360}}while(0);do{if((f|0)==360){d=c[191180]|0;k=d;if((k|0)==(-1|0)|(k|0)==0){k=c[191244]|0;g=(k|0)!=0?k:c[q>>2]|0;a3(51544,103,1,g|0)|0;g=c[191244]|0;k=(g|0)!=0?g:c[q>>2]|0;aZ(k|0)|0;f=365;break}else{k=c[191181]|0;g=c[191182]|0;j=c[191183]|0;if(hv(d+(ac(g-1|0,j)|0)|0,k,g,-j|0,0)|0){f=363;break}else{f=365;break}}}}while(0);do{if((f|0)==363){if((a[607928]&1)==0){l=38064;break}j=c[191244]|0;g=(j|0)!=0?j:c[q>>2]|0;a3(47032,30,1,g|0)|0;g=c[191244]|0;j=(g|0)!=0?g:c[q>>2]|0;aZ(j|0)|0;l=38064}else if((f|0)==365){j=c[191244]|0;a3(29688,50,1,((j|0)!=0?j:c[q>>2]|0)|0)|0;j=c[191244]|0;aZ(((j|0)!=0?j:c[q>>2]|0)|0)|0;l=25712}}while(0);j=c[189113]|0;g=j+4|0;k=c[g>>2]|0;if(k>>>0>1){d=j|0;h=1;e=k;while(1){k=c[(c[d>>2]|0)+(h<<2)>>2]|0;if((k|0)==0){m=e}else{v_(c[k+8>>2]|0);v_(c[(c[d>>2]|0)+(h<<2)>>2]|0);c[(c[d>>2]|0)+(h<<2)>>2]=0;m=c[g>>2]|0}k=h+1|0;if(k>>>0<m>>>0){h=k;e=m}else{break}}}c[g>>2]=1;g=j+12|0;v_(c[g>>2]|0);c[g>>2]=0;g=c[189113]|0;j=g+4|0;m=(c[j>>2]|0)>>>0<(c[g+8>>2]|0)>>>0;if((a[764679]&1)!=0){L529:do{if(m){e=vZ(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}v3(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=1;h=dn(l|0)|0;d=c[j>>2]|0;c[e+8>>2]=h;h=g|0;c[(c[h>>2]|0)+(d<<2)>>2]=e;d=c[j>>2]|0;c[j>>2]=d+1;if(d>>>0>1){n=d}else{break}while(1){d=n>>>1;k=c[h>>2]|0;o=k+(d<<2)|0;p=c[o>>2]|0;r=c[k+(n<<2)>>2]|0;if((c[r+4>>2]|0)>>>0<=(c[p+4>>2]|0)>>>0){break L529}c[o>>2]=r;c[(c[h>>2]|0)+(n<<2)>>2]=p;if(n>>>0>3){n=d}else{break}}}}while(0);fU();i=b;return}if(!m){i=b;return}m=vZ(12)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}v3(m|0,0,12)}}while(0);c[m+4>>2]=1;c[m>>2]=180;n=dn(l|0)|0;l=c[j>>2]|0;c[m+8>>2]=n;n=g|0;c[(c[n>>2]|0)+(l<<2)>>2]=m;m=c[j>>2]|0;c[j>>2]=m+1;if(m>>>0>1){s=m}else{i=b;return}while(1){m=s>>>1;j=c[n>>2]|0;l=j+(m<<2)|0;g=c[l>>2]|0;h=c[j+(s<<2)>>2]|0;if((c[h+4>>2]|0)>>>0<=(c[g+4>>2]|0)>>>0){f=389;break}c[l>>2]=h;c[(c[n>>2]|0)+(s<<2)>>2]=g;if(s>>>0>3){s=m}else{f=390;break}}if((f|0)==389){i=b;return}else if((f|0)==390){i=b;return}}function fU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[191180]|0;d=(b|0)==-1?0:b;b=c[191181]|0;e=c[191182]|0;f=c[191183]|0;if((a[607930]&1)==0){return}c[191180]=d;c[191181]=b;c[191182]=e;c[191183]=f;do{if((c[175572]|0)==0){g=d;if((g|0)==(-1|0)|(g|0)==0){h=d;i=f;break}c[191570]=b;c[191571]=e;c[191573]=b;c[191574]=e;c[191572]=f;c[191575]=b<<1;hU(766280,c[191602]|0,d);h=c[191602]|0;i=c[191575]|0}else{h=d;i=f}}while(0);f=hb(c[189113]|0)|0;c[191611]=f;if(fb[c[(c[191559]|0)+4>>2]&15](c[191562]|0,h,b,e,i,f)|0){return}a[607930]=0;return}function fV(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((a[607930]&1)==0){return}c[191180]=b;c[191181]=d;c[191182]=e;c[191183]=f;do{if((c[175572]|0)==0){g=b;if((g|0)==(-1|0)|(g|0)==0){h=b;i=f;break}c[191570]=d;c[191571]=e;c[191573]=d;c[191574]=e;c[191572]=f;c[191575]=d<<1;hU(766280,c[191602]|0,b);h=c[191602]|0;i=c[191575]|0}else{h=b;i=f}}while(0);f=hb(c[189113]|0)|0;c[191611]=f;if(fb[c[(c[191559]|0)+4>>2]&15](c[191562]|0,h,d,e,i,f)|0){return}a[607930]=0;return}function fW(b,c){b=b|0;c=c|0;var d=0,e=0;d=c>>>0>1024?1024:c;if(fX(b,d<<1)|0){e=a[607929]&1}else{e=0}a[607929]=e;return d|0}function fX(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0.0,r=0,s=0;f=i;i=i+24|0;j=f|0;if((a[764679]&1)!=0){k=1;i=f;return k|0}if((a[707057]&1)!=0){k=1;i=f;return k|0}if((a[607929]&1)==0){k=0;i=f;return k|0}v3(j|0,0,24);l=c[176756]|0;m=+g[176778]*30517578125.0e-15;if((e|0)==0){n=l}else{o=0;do{g[l+(o<<2)>>2]=m*+(b[d+(o<<1)>>1]|0);o=o+1|0;}while(o>>>0<e>>>0);n=c[176756]|0}c[j>>2]=n;c[j+8>>2]=e>>>1;c[j+4>>2]=c[176765];if((a[707092]&1)==0){p=+h[88381]}else{e=fc[c[(c[191558]|0)+32>>2]&127](c[191561]|0)|0;n=739888;o=c[n>>2]|0;d=wc(o,c[n+4>>2]|0,1,0)|0;n=739888;c[n>>2]=d;c[n+4>>2]=G;c[707120+((o&8191)<<2)>>2]=e;o=(c[176776]|0)>>>1;m=+h[88387]*(+(e-o|0)/+(o|0)*+g[132579]+1.0);h[88381]=m;p=m}o=j+16|0;h[o>>3]=p;if((a[764681]&1)!=0){h[o>>3]=p*+g[150946]}fa[c[(c[176755]|0)+4>>2]&127](c[176754]|0,j);o=c[176765]|0;e=c[j+12>>2]|0;if((a[707056]&1)!=0){if((fg[c[(c[191558]|0)+4>>2]&63](c[191561]|0,o,e<<3)|0)>=0){k=1;i=f;return k|0}j=c[191244]|0;n=(j|0)!=0?j:c[q>>2]|0;a3(30808,81,1,n|0)|0;n=c[191244]|0;j=(n|0)!=0?n:c[q>>2]|0;aZ(j|0)|0;k=0;i=f;return k|0}j=c[176766]|0;n=e<<1;if((n|0)==0){r=j}else{d=0;do{l=~~(+g[o+(d<<2)>>2]*32768.0);if((l|0)>32767){s=32767}else{s=(l|0)<-32768?-32768:l&65535}b[j+(d<<1)>>1]=s;d=d+1|0;}while(d>>>0<n>>>0);r=c[176766]|0}if((fg[c[(c[191558]|0)+4>>2]&63](c[191561]|0,r,e<<2)|0)>=0){k=1;i=f;return k|0}e=c[191244]|0;a3(30808,81,1,((e|0)!=0?e:c[q>>2]|0)|0)|0;e=c[191244]|0;aZ(((e|0)!=0?e:c[q>>2]|0)|0)|0;k=0;i=f;return k|0}function fY(){var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0,S=0,T=0.0,U=0,V=0,W=0.0,X=0.0;d=i;i=i+16|0;e=d|0;e9[c[(c[191560]|0)+4>>2]&2047](c[191563]|0);f=c[191604]|0;if((f|0)==0){i=d;return}h=e;v3(766424,0,16);j=(a[(c[f+16>>2]|0)+68|0]&1)!=0?65542:6;if((fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,0,0,j,0,2)|0)<<16>>16==0){a[(c[191604]|0)+9|0]=0;i=d;return}f=e|0;k=e+8|0;l=e+10|0;m=e+12|0;n=e+14|0;o=0;do{p=fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,0,0,j,o,0)|0;q=fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,0,0,j,o,1)|0;r=c[191604]|0;v3(h|0,0,16);L635:do{if((a[r+8|0]&1)==0){a[r+9|0]=0;s=0;t=0}else{u=c[r+16>>2]|0;v=(+((p<<16>>16)+32767|0)/65535.0- +g[u+24>>2])/+g[u+32>>2];w=(+((q<<16>>16)+32767|0)/65535.0- +g[u+28>>2])/+g[u+36>>2];x=u+4|0;y=c[x>>2]|0;do{if((y|0)==0){z=r+9|0}else{A=r+28|0;B=0;C=y;while(1){D=u|0;E=c[D>>2]|0;F=E+(B*104|0)|0;G=c[E+(B*104|0)+8>>2]|0;do{if((G|0)==1){H=+g[F>>2];I=+R(+(v-H));J=+g[E+(B*104|0)+12>>2];if(I>J){K=C;break}I=+g[E+(B*104|0)+4>>2];L=+R(+(w-I));M=+g[E+(B*104|0)+16>>2];if(L>M){K=C}else{N=H;O=J;P=I;Q=M;S=458}}else if((G|0)==0){M=+g[F>>2];I=+g[E+(B*104|0)+12>>2];J=(v-M)/I;H=+g[E+(B*104|0)+4>>2];L=+g[E+(B*104|0)+16>>2];T=(w-H)/L;if(J*J+T*T>1.0){K=C}else{N=M;O=I;P=H;Q=L;S=458}}else{K=C}}while(0);do{if((S|0)==458){S=0;F=c[E+(B*104|0)+20>>2]|0;if((F|0)==0){G=E+(B*104|0)+24|0;U=c[G>>2]|0;V=c[G+4>>2]|0;G=c[f+4>>2]|V;c[f>>2]=c[f>>2]|U;c[f+4>>2]=G;if((U&0|0)==0&(V&524288|0)==0){K=C;break}c[A>>2]=c[(c[D>>2]|0)+(B*104|0)+36>>2];K=c[x>>2]|0;break}L=+g[E+(B*104|0)+32>>2];H=(v-N)/O/L;I=(w-P)/Q/L;if(+R(+H)>1.0){W=H>0.0?1.0:-1.0}else{W=H}if(+R(+I)>1.0){X=I>0.0?1.0:-1.0}else{X=I}V=(F|0)==2?2:0;b[e+8+(V<<1)>>1]=~~(W*32767.0);b[e+8+((V|1)<<1)>>1]=~~(X*32767.0);K=C}}while(0);E=B+1|0;if(E>>>0<K>>>0){B=E;C=K}else{break}}C=c[f>>2]|0;B=c[f+4>>2]|0;A=r+9|0;if((C|0)==0&(B|0)==0){z=A;break}if((a[A]&1)==0){s=B;t=C;break L635}v3(h|0,0,16);s=0;t=0;break L635}}while(0);a[z]=0;s=0;t=0}}while(0);r=766424;q=c[r+4>>2]|s;p=766424;c[p>>2]=c[r>>2]|t;c[p+4>>2]=q;if((b[383216]|0)==0){b[383216]=b[k>>1]|0}if((b[383217]|0)==0){b[383217]=b[l>>1]|0}if((b[383218]|0)==0){b[383218]=b[m>>1]|0}if((b[383219]|0)==0){b[383219]=b[n>>1]|0}o=o+1|0;}while((fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,0,0,j,o,2)|0)<<16>>16!=0);i=d;return}function fZ(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0;b=i;if((a[603772]&1)==0|(c[189115]|0)!=0){i=b;return}if((c[176727]|0)!=0){d=c[191244]|0;e=(d|0)!=0?d:c[q>>2]|0;a3(17928,76,1,e|0)|0;e=c[191244]|0;d=(e|0)!=0?e:c[q>>2]|0;aZ(d|0)|0;i=b;return}d=fu[c[37204]&31]()|0;c[189117]=d;if((d|0)==0){e=c[191244]|0;f=(e|0)!=0?e:c[q>>2]|0;a3(16024,85,1,f|0)|0;f=c[191244]|0;e=(f|0)!=0?f:c[q>>2]|0;aZ(e|0)|0;i=b;return}e=d+3|0;f=e&-4;g=vZ(f)|0;if((g|0)==0){c[189116]=0;h=c[191244]|0;j=(h|0)!=0?h:c[q>>2]|0;a3(13816,66,1,j|0)|0;j=c[191244]|0;h=(j|0)!=0?j:c[q>>2]|0;aZ(h|0)|0;i=b;return}if((c[g-4>>2]&3|0)!=0){v3(g|0,0,f|0)}c[189116]=g;if(!(fr[c[37206]&63](g,d)|0)){d=c[191244]|0;g=(d|0)!=0?d:c[q>>2]|0;a3(51464,73,1,g|0)|0;g=c[191244]|0;d=(g|0)!=0?g:c[q>>2]|0;aZ(d|0)|0;v_(c[189116]|0);c[189116]=0;i=b;return}if((a[607928]&1)!=0){d=c[191244]|0;g=(d|0)!=0?d:c[q>>2]|0;d=((c[150944]|0)>>>0)/1e6|0;eb(g|0,49376,(k=i,i=i+8|0,c[k>>2]=d,k)|0)|0;i=k;d=c[191244]|0;g=(d|0)!=0?d:c[q>>2]|0;aZ(g|0)|0}g=c[150944]|0;d=c[189116]|0;L704:do{if(f<<2>>>0<g>>>0){h=vZ(32)|0;if((h|0)==0){l=514;break}if((c[h-4>>2]&3|0)!=0){v3(h|0,0,32)}j=h;c[h+16>>2]=1;m=e>>>2;c[h+24>>2]=m;n=g-1|0;o=n>>>1|n;n=o>>>2|o;o=n>>>4|n;n=o>>>8|o;o=(n>>>16|n)+1|0;n=o>>>1;p=(o-g|0)>>>0<(g-n|0)>>>0?o:n;n=p>>>3;c[h+4>>2]=n;c[h+8>>2]=n-1;if((a[607928]&1)!=0){o=c[191244]|0;r=(o|0)!=0?o:c[q>>2]|0;o=p>>>23<<3;eb(r|0,30352,(k=i,i=i+8|0,c[k>>2]=o,k)|0)|0;i=k;o=c[191244]|0;r=(o|0)!=0?o:c[q>>2]|0;aZ(r|0)|0}r=n<<3;n=vZ(r)|0;do{if((n|0)==0){c[h>>2]=0;s=h+12|0}else{if((c[n-4>>2]&3|0)==0){c[h>>2]=n}else{v3(n|0,0,r|0);c[h>>2]=n}o=m<<2;p=vZ(o)|0;if((p|0)==0){t=h+12|0;c[t>>2]=0;s=t;break}if((c[p-4>>2]&3|0)==0){c[h+12>>2]=p;v6(p|0,d|0,f)|0;c[189115]=j;if((h|0)==0){break L704}i=b;return}else{v3(p|0,0,o|0);c[h+12>>2]=p;v6(p|0,d|0,f)|0;c[189115]=j;i=b;return}}}while(0);v_(n);v_(c[s>>2]|0);v_(h);l=514}else{l=514}}while(0);if((l|0)==514){c[189115]=0}l=c[191244]|0;a3(46400,78,1,((l|0)!=0?l:c[q>>2]|0)|0)|0;l=c[191244]|0;aZ(((l|0)!=0?l:c[q>>2]|0)|0)|0;i=b;return}function f_(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;a=i;i=i+4608|0;b=c[175548]|0;d=a|0;if((b|0)==0){bN(d|0,4096,31240,(e=i,i=i+8|0,c[e>>2]=669418,e)|0)|0;i=e}else{bN(d|0,4096,45496,(e=i,i=i+16|0,c[e>>2]=669418,c[e+8>>2]=b,e)|0)|0;i=e}b=a+4096|0;if(gi(d)|0){f=c[175548]|0;bN(b|0,512,43256,(e=i,i=i+8|0,c[e>>2]=f,e)|0)|0;i=e}else{bN(b|0,512,41992,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e}e=c[189113]|0;d=e+4|0;f=c[d>>2]|0;if(f>>>0>1){g=e|0;h=1;j=f;while(1){f=c[(c[g>>2]|0)+(h<<2)>>2]|0;if((f|0)==0){k=j}else{v_(c[f+8>>2]|0);v_(c[(c[g>>2]|0)+(h<<2)>>2]|0);c[(c[g>>2]|0)+(h<<2)>>2]=0;k=c[d>>2]|0}f=h+1|0;if(f>>>0<k>>>0){h=f;j=k}else{break}}}c[d>>2]=1;d=e+12|0;v_(c[d>>2]|0);c[d>>2]=0;d=c[189113]|0;e=d+4|0;if((c[e>>2]|0)>>>0>=(c[d+8>>2]|0)>>>0){i=a;return}k=vZ(12)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}v3(k|0,0,12)}}while(0);c[k+4>>2]=2;c[k>>2]=180;j=dn(b|0)|0;b=c[e>>2]|0;c[k+8>>2]=j;j=d|0;c[(c[j>>2]|0)+(b<<2)>>2]=k;k=c[e>>2]|0;c[e>>2]=k+1;if(k>>>0>1){l=k}else{i=a;return}while(1){k=l>>>1;e=c[j>>2]|0;b=e+(k<<2)|0;d=c[b>>2]|0;h=c[e+(l<<2)>>2]|0;if((c[h+4>>2]|0)>>>0<=(c[d+4>>2]|0)>>>0){m=547;break}c[b>>2]=h;c[(c[j>>2]|0)+(l<<2)>>2]=d;if(l>>>0>3){l=k}else{m=548;break}}if((m|0)==547){i=a;return}else if((m|0)==548){i=a;return}}function f$(){var a=0,b=0,d=0;a=i;if((c[189113]|0)!=0){i=a;return}b=vZ(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)!=0){v3(b|0,0,16)}c[b+8>>2]=9;d=vZ(36)|0;if((d|0)==0){c[b>>2]=0;v_(b);break}if((c[d-4>>2]&3|0)!=0){v3(d|0,0,36)}c[b>>2]=d;c[b+4>>2]=1;c[189113]=b;i=a;return}}while(0);c[189113]=0;a=c[191244]|0;eb(((a|0)!=0?a:c[q>>2]|0)|0,33568,(a=i,i=i+16|0,c[a>>2]=19896,c[a+8>>2]=1408,a)|0)|0;i=a;a=c[191244]|0;aZ(((a|0)!=0?a:c[q>>2]|0)|0)|0;cd(2)}function f0(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+4608|0;d=c[175548]|0;if((a[603801]&1)==0){e=d}else{f=d+1|0;c[175548]=f;e=f}f=b|0;if((e|0)==0){bN(f|0,4096,31240,(g=i,i=i+8|0,c[g>>2]=669418,g)|0)|0;i=g}else{bN(f|0,4096,45496,(g=i,i=i+16|0,c[g>>2]=669418,c[g+8>>2]=e,g)|0)|0;i=g}e=b+4096|0;if(gh(f)|0){d=c[175548]|0;bN(e|0,512,40936,(g=i,i=i+8|0,c[g>>2]=d,g)|0)|0;i=g}else{bN(e|0,512,39992,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g}g=c[189113]|0;f=g+4|0;d=c[f>>2]|0;if(d>>>0>1){h=g|0;j=1;k=d;while(1){d=c[(c[h>>2]|0)+(j<<2)>>2]|0;if((d|0)==0){l=k}else{v_(c[d+8>>2]|0);v_(c[(c[h>>2]|0)+(j<<2)>>2]|0);c[(c[h>>2]|0)+(j<<2)>>2]=0;l=c[f>>2]|0}d=j+1|0;if(d>>>0<l>>>0){j=d;k=l}else{break}}}c[f>>2]=1;f=g+12|0;v_(c[f>>2]|0);c[f>>2]=0;f=c[189113]|0;g=f+4|0;if((c[g>>2]|0)>>>0>=(c[f+8>>2]|0)>>>0){i=b;return}l=vZ(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}v3(l|0,0,12)}}while(0);c[l+4>>2]=2;c[l>>2]=180;k=dn(e|0)|0;e=c[g>>2]|0;c[l+8>>2]=k;k=f|0;c[(c[k>>2]|0)+(e<<2)>>2]=l;l=c[g>>2]|0;c[g>>2]=l+1;if(l>>>0>1){m=l}else{i=b;return}while(1){l=m>>>1;g=c[k>>2]|0;e=g+(l<<2)|0;f=c[e>>2]|0;j=c[g+(m<<2)>>2]|0;if((c[j+4>>2]|0)>>>0<=(c[f+4>>2]|0)>>>0){n=585;break}c[e>>2]=j;c[(c[k>>2]|0)+(m<<2)>>2]=f;if(m>>>0>3){m=l}else{n=583;break}}if((n|0)==583){i=b;return}else if((n|0)==585){i=b;return}}function f1(b){b=b|0;a[505592]=b&1;a[766257]=a[706968]&1;a[766258]=0;gC();b=c[176743]|0;do{if((b|0)!=0){if((a[766257]&1)!=0){break}fx[b&127]()}}while(0);gD();if((a[766259]&1)!=0){c[191562]=0}if((a[766260]&1)!=0){c[191561]=0}if((a[766261]&1)!=0){c[191563]=0}a[766259]=0;a[766260]=0;a[766261]=0;gB();a[766257]=0;b=c[191560]|0;if((b|0)==0){return}e9[c[b+4>>2]&2047](c[191563]|0);return}function f2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[607928]&1)!=0){b=c[191244]|0;d=(b|0)!=0?b:c[q>>2]|0;a3(37024,27,1,d|0)|0;d=c[191244]|0;b=(d|0)!=0?d:c[q>>2]|0;aZ(b|0)|0}b=c[189113]|0;d=b+4|0;e=c[d>>2]|0;if(e>>>0>1){f=b|0;g=1;h=e;while(1){e=c[(c[f>>2]|0)+(g<<2)>>2]|0;if((e|0)==0){i=h}else{v_(c[e+8>>2]|0);v_(c[(c[f>>2]|0)+(g<<2)>>2]|0);c[(c[f>>2]|0)+(g<<2)>>2]=0;i=c[d>>2]|0}e=g+1|0;if(e>>>0<i>>>0){g=e;h=i}else{break}}}c[d>>2]=1;d=b+12|0;v_(c[d>>2]|0);c[d>>2]=0;d=c[189113]|0;b=d+4|0;if((c[b>>2]|0)>>>0>=(c[d+8>>2]|0)>>>0){j=c[37210]|0;fx[j&127]();f3();return}i=vZ(12)|0;do{if((i|0)!=0){if((c[i-4>>2]&3|0)==0){break}v3(i|0,0,12)}}while(0);c[i+4>>2]=1;c[i>>2]=120;h=dn(35144)|0;g=c[b>>2]|0;c[i+8>>2]=h;h=d|0;c[(c[h>>2]|0)+(g<<2)>>2]=i;i=c[b>>2]|0;c[b>>2]=i+1;if(i>>>0>1){k=i}else{j=c[37210]|0;fx[j&127]();f3();return}while(1){i=k>>>1;b=c[h>>2]|0;g=b+(i<<2)|0;d=c[g>>2]|0;f=c[b+(k<<2)>>2]|0;if((c[f+4>>2]|0)>>>0<=(c[d+4>>2]|0)>>>0){l=617;break}c[g>>2]=f;c[(c[h>>2]|0)+(k<<2)>>2]=d;if(k>>>0>3){k=i}else{l=618;break}}if((l|0)==617){j=c[37210]|0;fx[j&127]();f3();return}else if((l|0)==618){j=c[37210]|0;fx[j&127]();f3();return}}function f3(){var b=0,d=0,e=0,f=0,g=0;b=i;d=0;do{e=c[607932+(d<<2)>>2]|0;L865:do{if((e|0)!=1){fa[c[37198]&127](d,e);switch(e|0){case 5:{if((a[607928]&1)==0){break L865}f=c[191244]|0;eb(((f|0)!=0?f:c[q>>2]|0)|0,31440,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[191244]|0;aZ(((f|0)!=0?f:c[q>>2]|0)|0)|0;break L865;break};case 0:{if((a[607928]&1)==0){break L865}f=c[191244]|0;eb(((f|0)!=0?f:c[q>>2]|0)|0,31488,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[191244]|0;aZ(((f|0)!=0?f:c[q>>2]|0)|0)|0;break L865;break};case 772:{if((a[607928]&1)==0){break L865}f=c[191244]|0;eb(((f|0)!=0?f:c[q>>2]|0)|0,31288,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[191244]|0;aZ(((f|0)!=0?f:c[q>>2]|0)|0)|0;break L865;break};case 260:{if((a[607928]&1)==0){break L865}f=c[191244]|0;eb(((f|0)!=0?f:c[q>>2]|0)|0,30992,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[191244]|0;aZ(((f|0)!=0?f:c[q>>2]|0)|0)|0;break L865;break};case 516:{if((a[607928]&1)==0){break L865}f=c[191244]|0;eb(((f|0)!=0?f:c[q>>2]|0)|0,31336,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[191244]|0;aZ(((f|0)!=0?f:c[q>>2]|0)|0)|0;break L865;break};case 257:{if((a[607928]&1)==0){break L865}f=c[191244]|0;eb(((f|0)!=0?f:c[q>>2]|0)|0,31120,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[191244]|0;aZ(((f|0)!=0?f:c[q>>2]|0)|0)|0;break L865;break};case 2:{if((a[607928]&1)==0){break L865}f=c[191244]|0;eb(((f|0)!=0?f:c[q>>2]|0)|0,31392,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[191244]|0;aZ(((f|0)!=0?f:c[q>>2]|0)|0)|0;break L865;break};default:{break L865}}}}while(0);d=d+1|0;}while(d>>>0<8);i=b;return}function f4(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+256|0;if((c[176732]|0)==0){i=e;return}f=e|0;a[f]=0;if(fc[c[176728]&127](b)|0){g=b?32048:31384;bN(f|0,256,32736,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=0}else{g=b?30408:30008;bN(f|0,256,30680,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=1}if((a[f]|0)==0){i=e;return}do{if(j){g=c[191244]|0;b=(g|0)!=0?g:c[q>>2]|0;eb(b|0,29656,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[191244]|0;g=(b|0)!=0?b:c[q>>2]|0;aZ(g|0)|0}else{if((a[607928]&1)==0){break}g=c[191244]|0;b=(g|0)!=0?g:c[q>>2]|0;eb(b|0,47400,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[191244]|0;g=(b|0)!=0?b:c[q>>2]|0;aZ(g|0)|0}}while(0);if(!d){i=e;return}d=c[189113]|0;h=d+4|0;j=c[h>>2]|0;if(j>>>0>1){g=d|0;b=1;k=j;while(1){j=c[(c[g>>2]|0)+(b<<2)>>2]|0;if((j|0)==0){l=k}else{v_(c[j+8>>2]|0);v_(c[(c[g>>2]|0)+(b<<2)>>2]|0);c[(c[g>>2]|0)+(b<<2)>>2]=0;l=c[h>>2]|0}j=b+1|0;if(j>>>0<l>>>0){b=j;k=l}else{break}}}c[h>>2]=1;h=d+12|0;v_(c[h>>2]|0);c[h>>2]=0;h=c[189113]|0;d=h+4|0;if((c[d>>2]|0)>>>0>=(c[h+8>>2]|0)>>>0){i=e;return}l=vZ(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}v3(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;k=dn(f|0)|0;f=c[d>>2]|0;c[l+8>>2]=k;k=h|0;c[(c[k>>2]|0)+(f<<2)>>2]=l;l=c[d>>2]|0;c[d>>2]=l+1;if(l>>>0>1){m=l}else{i=e;return}while(1){l=m>>>1;d=c[k>>2]|0;f=d+(l<<2)|0;h=c[f>>2]|0;b=c[d+(m<<2)>>2]|0;if((c[b+4>>2]|0)>>>0<=(c[h+4>>2]|0)>>>0){n=663;break}c[f>>2]=b;c[(c[k>>2]|0)+(m<<2)>>2]=h;if(m>>>0>3){m=l}else{n=666;break}}if((n|0)==663){i=e;return}else if((n|0)==666){i=e;return}}function f5(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+256|0;e=c[176732]|0;if((e|0)==0){i=d;return}f=d|0;a[f]=0;g=fu[e&31]()|0;e=g>>>0>b>>>0;do{if(fc[c[176731]&127](b)|0){if(e){h=b+1|0;bN(f|0,256,29304,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=0;break}else{bN(f|0,256,28464,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=0;break}}else{if(e){h=b+1|0;bN(f|0,256,28064,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=1;break}else{bN(f|0,256,27736,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=1;break}}}while(0);if((a[f]|0)==0){i=d;return}do{if(k){g=c[191244]|0;b=(g|0)!=0?g:c[q>>2]|0;eb(b|0,29656,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[191244]|0;g=(b|0)!=0?b:c[q>>2]|0;aZ(g|0)|0}else{if((a[607928]&1)==0){break}g=c[191244]|0;b=(g|0)!=0?g:c[q>>2]|0;eb(b|0,47400,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[191244]|0;g=(b|0)!=0?b:c[q>>2]|0;aZ(g|0)|0}}while(0);j=c[189113]|0;k=j+4|0;g=c[k>>2]|0;if(g>>>0>1){b=j|0;e=1;h=g;while(1){g=c[(c[b>>2]|0)+(e<<2)>>2]|0;if((g|0)==0){l=h}else{v_(c[g+8>>2]|0);v_(c[(c[b>>2]|0)+(e<<2)>>2]|0);c[(c[b>>2]|0)+(e<<2)>>2]=0;l=c[k>>2]|0}g=e+1|0;if(g>>>0<l>>>0){e=g;h=l}else{break}}}c[k>>2]=1;k=j+12|0;v_(c[k>>2]|0);c[k>>2]=0;k=c[189113]|0;j=k+4|0;if((c[j>>2]|0)>>>0>=(c[k+8>>2]|0)>>>0){i=d;return}l=vZ(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}v3(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;h=dn(f|0)|0;f=c[j>>2]|0;c[l+8>>2]=h;h=k|0;c[(c[h>>2]|0)+(f<<2)>>2]=l;l=c[j>>2]|0;c[j>>2]=l+1;if(l>>>0>1){m=l}else{i=d;return}while(1){l=m>>>1;j=c[h>>2]|0;f=j+(l<<2)|0;k=c[f>>2]|0;e=c[j+(m<<2)>>2]|0;if((c[e+4>>2]|0)>>>0<=(c[k+4>>2]|0)>>>0){n=699;break}c[f>>2]=e;c[(c[h>>2]|0)+(m<<2)>>2]=k;if(m>>>0>3){m=l}else{n=700;break}}if((n|0)==699){i=d;return}else if((n|0)==700){i=d;return}}function f6(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0;d=i;i=i+216|0;e=d|0;f=d+72|0;g=d+144|0;h=4096;j=644842;k=b;while(1){l=h-1|0;if((l|0)==0){m=704;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=4096;p=640746;r=b;break}else{h=l;j=j+1|0;k=k+1|0}}do{if((m|0)==704){a[j]=0;if((a[k]|0)==0){o=4096;p=640746;r=b;break}else{s=k}while(1){h=s+1|0;if((a[h]|0)==0){o=4096;p=640746;r=b;break}else{s=h}}}}while(0);while(1){s=o-1|0;if((s|0)==0){m=708;break}k=a[r]|0;a[p]=k;if(k<<24>>24==0){break}else{o=s;p=p+1|0;r=r+1|0}}do{if((m|0)==708){a[p]=0;if((a[r]|0)==0){break}else{t=r}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);t=cf(640746,46)|0;if((t|0)!=0){a[t]=0}if((a[628456]&1)==0){gs(648938,640746,50408)}if((a[628457]&1)==0){gs(669418,640746,49960)}do{if((eB(648938,g|0)|0)>=0){if((c[g+8>>2]&61440|0)!=16384){break}gt(648938,50408);if((a[607928]&1)==0){break}t=c[191244]|0;r=(t|0)!=0?t:c[q>>2]|0;eb(r|0,31872,(u=i,i=i+8|0,c[u>>2]=648938,u)|0)|0;i=u;r=c[191244]|0;t=(r|0)!=0?r:c[q>>2]|0;aZ(t|0)|0}}while(0);do{if((eB(669418,f|0)|0)>=0){if((c[f+8>>2]&61440|0)!=16384){break}gt(669418,49960);if((a[607928]&1)==0){break}g=c[191244]|0;t=(g|0)!=0?g:c[q>>2]|0;eb(t|0,31784,(u=i,i=i+8|0,c[u>>2]=669418,u)|0)|0;i=u;t=c[191244]|0;g=(t|0)!=0?t:c[q>>2]|0;aZ(g|0)|0}}while(0);if((a[599676]|0)==0){gz(599676,b)}if((a[628458]|0)==0){i=d;return}if((eB(628458,e|0)|0)<0){i=d;return}if((c[e+8>>2]&61440|0)!=16384){i=d;return}gt(628458,31672);if((a[607928]&1)!=0){e=c[191244]|0;b=(e|0)!=0?e:c[q>>2]|0;eb(b|0,31608,(u=i,i=i+8|0,c[u>>2]=628458,u)|0)|0;i=u;u=c[191244]|0;b=(u|0)!=0?u:c[q>>2]|0;aZ(b|0)|0}b=c2(628458,34720)|0;if((b|0)!=0){aR(b|0)|0;i=d;return}a[628458]=0;if((a[607928]&1)==0){i=d;return}b=c[191244]|0;a3(31544,59,1,((b|0)!=0?b:c[q>>2]|0)|0)|0;b=c[191244]|0;aZ(((b|0)!=0?b:c[q>>2]|0)|0)|0;i=d;return}function f7(){var b=0,d=0,e=0;b=c[153016]|0;do{if((b|0)==2|(b|0)==3){if((a[628456]&1)==0){gr(648938,616168,50408)}gr(657130,648938,32248);if((a[628457]&1)!=0){break}gr(669418,616168,49960)}else if((b|0)==1){if((a[628456]&1)==0){gr(648938,612072,50408)}if((a[628457]&1)==0){gr(669418,612072,49960)}gr(653034,648938,23984)}else if((b|0)==4){if(!((a[628456]&1)==0|(a[620264]|0)==0|(a[624360]|0)==0)){d=c[191244]|0;e=(d|0)!=0?d:c[q>>2]|0;a3(32120,109,1,e|0)|0;e=c[191244]|0;d=(e|0)!=0?e:c[q>>2]|0;aZ(d|0)|0}gr(661226,620264,50408);gr(665322,624360,50408);if((a[628457]&1)!=0){break}gr(669418,(a[620264]|0)!=0?620264:624360,49960)}else{gr(653034,648938,23984)}}while(0);gr(756480,648938,766672);if((a[640746]|0)==0){return}if((a[689902]|0)==0){gs(689902,640746,32096)}if((a[693998]|0)==0){gs(693998,640746,32056)}if((a[698094]|0)==0){gs(698094,640746,32040)}if((a[673514]|0)==0){gs(673514,640746,32032)}if((a[595580]|0)!=0){return}gz(595580,640746);return}function f8(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ai=0,aj=0,ak=0,an=0,ap=0,aq=0,ar=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aC=0,aE=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0.0,dV=0.0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0;f=i;i=i+13008|0;j=1;k=0;l=i;i=i+168|0;c[l>>2]=0;while(1)switch(j|0){case 1:m=f|0;n=f+8|0;o=f+16|0;p=f+24|0;r=f+32|0;s=f+40|0;v=f+48|0;w=f+56|0;x=f+64|0;y=f+72|0;z=f+144|0;A=f+216|0;B=f+4312|0;C=f+8408|0;D=f+12504|0;E=f+12512|0;a[607930]=1;a[607929]=1;c[153016]=0;c[151983]=1;c[151984]=1;c[151985]=1;c[151986]=1;c[151987]=1;c[151988]=1;c[151989]=1;c[151990]=1;F=v4(766008,j,l)|0;j=510;break;case 510:if((F|0)>0){j=2;break}else{j=3;break};case 2:G=c[191244]|0;as(8,((G|0)!=0?G:c[q>>2]|0)|0,26016,(H=i,i=i+8|0,c[H>>2]=764983,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;I=F;j=509;break;case 3:a[764981]=1;a[766052]=0;a[766053]=0;a[628456]=0;a[628457]=0;if((d|0)<2){j=4;break}else{j=5;break};case 4:a[766053]=1;j=182;break;case 5:c[1648]=0;c[D>>2]=0;c[E>>2]=47840;c[E+4>>2]=0;c[E+8>>2]=D;c[E+12>>2]=77;c[E+16>>2]=47752;c[E+20>>2]=0;c[E+24>>2]=0;c[E+28>>2]=104;c[E+32>>2]=47528;c[E+36>>2]=1;c[E+40>>2]=0;c[E+44>>2]=115;c[E+48>>2]=47304;c[E+52>>2]=0;c[E+56>>2]=0;c[E+60>>2]=102;c[E+64>>2]=47160;c[E+68>>2]=0;c[E+72>>2]=0;c[E+76>>2]=118;c[E+80>>2]=47024;c[E+84>>2]=1;c[E+88>>2]=0;c[E+92>>2]=103;c[E+96>>2]=46944;c[E+100>>2]=1;c[E+104>>2]=0;c[E+108>>2]=99;c[E+112>>2]=46600;c[E+116>>2]=1;c[E+120>>2]=D;c[E+124>>2]=67;c[E+128>>2]=46224;c[E+132>>2]=1;c[E+136>>2]=0;c[E+140>>2]=109;c[E+144>>2]=46096;c[E+148>>2]=1;c[E+152>>2]=0;c[E+156>>2]=78;c[E+160>>2]=45968;c[E+164>>2]=0;c[E+168>>2]=0;c[E+172>>2]=112;c[E+176>>2]=45888;c[E+180>>2]=0;c[E+184>>2]=0;c[E+188>>2]=106;c[E+192>>2]=45768;c[E+196>>2]=0;c[E+200>>2]=0;c[E+204>>2]=74;c[E+208>>2]=45680;c[E+212>>2]=1;c[E+216>>2]=0;c[E+220>>2]=65;c[E+224>>2]=45576;c[E+228>>2]=1;c[E+232>>2]=0;c[E+236>>2]=83;c[E+240>>2]=45488;c[E+244>>2]=1;c[E+248>>2]=0;c[E+252>>2]=98;c[E+256>>2]=45448;c[E+260>>2]=1;c[E+264>>2]=0;c[E+268>>2]=66;c[E+272>>2]=45128;c[E+276>>2]=0;c[E+280>>2]=0;c[E+284>>2]=52;c[E+288>>2]=45056;c[E+292>>2]=1;c[E+296>>2]=0;c[E+300>>2]=89;c[E+304>>2]=44992;c[E+308>>2]=1;c[E+312>>2]=0;c[E+316>>2]=90;c[E+320>>2]=44944;c[E+324>>2]=1;c[E+328>>2]=0;c[E+332>>2]=80;c[E+336>>2]=44888;c[E+340>>2]=1;c[E+344>>2]=0;c[E+348>>2]=82;c[E+352>>2]=44800;c[E+356>>2]=1;c[E+360>>2]=0;c[E+364>>2]=77;c[E+368>>2]=44752;c[E+372>>2]=1;c[E+376>>2]=0;c[E+380>>2]=85;c[E+384>>2]=44704;c[E+388>>2]=1;c[E+392>>2]=D;c[E+396>>2]=66;c[E+400>>2]=44640;c[E+404>>2]=1;c[E+408>>2]=D;c[E+412>>2]=73;c[E+416>>2]=44560;c[E+420>>2]=0;c[E+424>>2]=D;c[E+428>>2]=110;c[E+432>>2]=44232;c[E+436>>2]=1;c[E+440>>2]=0;c[E+444>>2]=88;c[E+448>>2]=44120;c[E+452>>2]=0;c[E+456>>2]=0;c[E+460>>2]=68;c[E+464>>2]=43984;c[E+468>>2]=0;c[E+472>>2]=D;c[E+476>>2]=102;v3(E+480|0,0,16);J=e+(d<<2)|0;K=0;j=6;break;case 6:c[D>>2]=0;if((K|0)==0){j=7;break}else{L=K;j=8;break};case 7:c[1648]=1;L=1;j=8;break;case 8:if((d|0)==1){M=L;j=162;break}else{j=9;break};case 9:N=e+(L<<2)|0;O=c[N>>2]|0;if((O|0)==0){P=-1;S=-1;j=17;break}else{T=0;U=O;j=10;break};case 10:if((a[U]|0)==45){j=11;break}else{j=12;break};case 11:if((a[U+1|0]|0)==45){j=12;break}else{V=T;j=13;break};case 12:G=T+1|0;W=c[e+(G+L<<2)>>2]|0;if((W|0)==0){V=-1;j=13;break}else{T=G;U=W;j=10;break};case 13:X=0;Y=O;j=14;break;case 14:if((a[Y]|0)==45){j=15;break}else{j=16;break};case 15:if((a[Y+1|0]|0)==45){P=X;S=V;j=17;break}else{j=16;break};case 16:W=X+1|0;G=c[e+(W+L<<2)>>2]|0;if((G|0)==0){P=-1;S=V;j=17;break}else{X=W;Y=G;j=14;break};case 17:Z=(S|0)==-1;_=(P|0)==-1;if(Z&_){M=L;j=162;break}else{j=18;break};case 18:if((S|0)>0){j=19;break}else{j=21;break};case 19:if((S|0)<(P|0)|_){j=20;break}else{j=21;break};case 20:aI(40,N|0,e+(S+L<<2)|0,J|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=28;break;case 21:if((P|0)>0){j=22;break}else{j=25;break};case 22:if((P|0)<(S|0)|Z){j=23;break}else{j=25;break};case 23:aI(40,N|0,e+(P+L<<2)|0,J|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((S|0)==0){j=28;break}else{j=24;break};case 24:$=c[1648]|0;j=40;break;case 25:aa=(S|0)==0;ac=(P|0)==0;if(aa|ac){j=27;break}else{j=26;break};case 26:G=c[191244]|0;as(8,((G|0)!=0?G:c[q>>2]|0)|0,33568,(H=i,i=i+16|0,c[H>>2]=49160,c[H+8>>2]=190,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(1328,2);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 27:if(aa){j=28;break}else{j=39;break};case 28:ad=c[1648]|0;ae=c[e+(ad<<2)>>2]|0;af=ae+1|0;ag=a[af]|0;if(ag<<24>>24==58){j=160;break}else{j=29;break};case 29:ai=as(4,43856,ag<<24>>24|0,41)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((ai|0)==0){j=160;break}else{j=30;break};case 30:aj=ae+2|0;G=(a[ai+1|0]|0)==58;ak=G&(a[aj]|0)!=0;if(G){j=31;break}else{j=36;break};case 31:if(ak){j=32;break}else{j=33;break};case 32:c[37238]=aj;an=ad+1|0;ap=aj;j=34;break;case 33:G=c[e+(ad+1<<2)>>2]|0;c[37238]=G;an=ad+2|0;ap=G;j=34;break;case 34:c[1648]=an;if((ap|0)==0){j=160;break}else{j=35;break};case 35:aq=a[ai]|0;ar=an;j=49;break;case 36:if(ak){j=37;break}else{j=38;break};case 37:G=ao(46,aj|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aI(50,af|0,aj|0,G+1|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aq=a[ai]|0;ar=ad;j=49;break;case 38:G=ad+1|0;c[1648]=G;aq=a[ai]|0;ar=G;j=49;break;case 39:if(ac){$=L;j=40;break}else{j=160;break};case 40:at=0;j=41;break;case 41:au=c[E+(at<<4)>>2]|0;if((au|0)==0){j=160;break}else{j=42;break};case 42:G=aD(8,au|0,(c[e+($<<2)>>2]|0)+2|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((G|0)==0){j=44;break}else{j=43;break};case 43:at=at+1|0;j=41;break;case 44:av=$+1|0;if((c[E+(at<<4)+4>>2]|0)==0){aw=av;j=47;break}else{j=45;break};case 45:ax=c[e+(av<<2)>>2]|0;if((ax|0)==0){j=160;break}else{j=46;break};case 46:c[37238]=ax;aw=$+2|0;j=47;break;case 47:c[1648]=aw;ay=c[E+(at<<4)+8>>2]|0;az=c[E+(at<<4)+12>>2]|0;if((ay|0)==0){aq=az;ar=aw;j=49;break}else{j=48;break};case 48:c[ay>>2]=az;j=139;break;case 49:switch(aq|0){case 68:{j=50;break};case 104:{j=51;break};case 52:{j=52;break};case 106:{j=53;break};case 74:{j=54;break};case 65:{j=55;break};case 115:{j=58;break};case 102:{j=64;break};case 103:{j=65;break};case 98:{j=71;break};case 66:{j=77;break};case 89:{j=83;break};case 90:{j=89;break};case 83:{j=95;break};case 118:{j=101;break};case 109:{j=102;break};case 78:{j=105;break};case 112:{j=108;break};case 99:{j=109;break};case 80:case 82:{j=114;break};case 77:{j=120;break};case 85:{j=128;break};case 88:{j=134;break};case 0:{j=139;break};case 63:{j=160;break};case-1:{M=ar;j=162;break};default:{j=161;break}}break;case 50:K=c[1648]|0;j=6;break;case 51:aJ(56);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(1328,0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 52:c[151984]=257;j=50;break;case 53:c[151984]=516;j=50;break;case 54:c[151984]=772;j=50;break;case 55:G=as(34,c[37238]|0,0,0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aA=G-1|0;if(aA>>>0>7){j=56;break}else{j=57;break};case 56:G=c[191244]|0;aH(2,43728,57,1,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aJ(56);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(164,43600);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 57:c[607932+(aA<<2)>>2]=5;j=50;break;case 58:aC=4096;aE=648938;aK=c[37238]|0;j=59;break;case 59:aL=aC-1|0;if((aL|0)==0){j=61;break}else{j=60;break};case 60:G=a[aK]|0;a[aE]=G;if(G<<24>>24==0){j=63;break}else{aC=aL;aE=aE+1|0;aK=aK+1|0;j=59;break};case 61:a[aE]=0;if((a[aK]|0)==0){j=63;break}else{aM=aK;j=62;break};case 62:G=aM+1|0;if((a[G]|0)==0){j=63;break}else{aM=G;j=62;break};case 63:a[628456]=1;j=50;break;case 64:a[607931]=1;j=50;break;case 65:aN=4096;aO=612072;aP=c[37238]|0;j=66;break;case 66:aQ=aN-1|0;if((aQ|0)==0){j=68;break}else{j=67;break};case 67:G=a[aP]|0;a[aO]=G;if(G<<24>>24==0){j=70;break}else{aN=aQ;aO=aO+1|0;aP=aP+1|0;j=66;break};case 68:a[aO]=0;if((a[aP]|0)==0){j=70;break}else{aR=aP;j=69;break};case 69:G=aR+1|0;if((a[G]|0)==0){j=70;break}else{aR=G;j=69;break};case 70:c[153016]=1;j=50;break;case 71:aS=4096;aT=616168;aU=c[37238]|0;j=72;break;case 72:aV=aS-1|0;if((aV|0)==0){j=74;break}else{j=73;break};case 73:G=a[aU]|0;a[aT]=G;if(G<<24>>24==0){j=76;break}else{aS=aV;aT=aT+1|0;aU=aU+1|0;j=72;break};case 74:a[aT]=0;if((a[aU]|0)==0){j=76;break}else{aW=aU;j=75;break};case 75:G=aW+1|0;if((a[G]|0)==0){j=76;break}else{aW=G;j=75;break};case 76:c[153016]=2;j=50;break;case 77:aX=4096;aY=616168;aZ=c[37238]|0;j=78;break;case 78:a_=aX-1|0;if((a_|0)==0){j=80;break}else{j=79;break};case 79:G=a[aZ]|0;a[aY]=G;if(G<<24>>24==0){j=82;break}else{aX=a_;aY=aY+1|0;aZ=aZ+1|0;j=78;break};case 80:a[aY]=0;if((a[aZ]|0)==0){j=82;break}else{a$=aZ;j=81;break};case 81:G=a$+1|0;if((a[G]|0)==0){j=82;break}else{a$=G;j=81;break};case 82:c[153016]=3;j=50;break;case 83:a0=4096;a1=620264;a2=c[37238]|0;j=84;break;case 84:a3=a0-1|0;if((a3|0)==0){j=86;break}else{j=85;break};case 85:G=a[a2]|0;a[a1]=G;if(G<<24>>24==0){j=88;break}else{a0=a3;a1=a1+1|0;a2=a2+1|0;j=84;break};case 86:a[a1]=0;if((a[a2]|0)==0){j=88;break}else{a4=a2;j=87;break};case 87:G=a4+1|0;if((a[G]|0)==0){j=88;break}else{a4=G;j=87;break};case 88:c[153016]=4;j=50;break;case 89:a5=4096;a6=624360;a7=c[37238]|0;j=90;break;case 90:a8=a5-1|0;if((a8|0)==0){j=92;break}else{j=91;break};case 91:G=a[a7]|0;a[a6]=G;if(G<<24>>24==0){j=94;break}else{a5=a8;a6=a6+1|0;a7=a7+1|0;j=90;break};case 92:a[a6]=0;if((a[a7]|0)==0){j=94;break}else{a9=a7;j=93;break};case 93:G=a9+1|0;if((a[G]|0)==0){j=94;break}else{a9=G;j=93;break};case 94:c[153016]=4;j=50;break;case 95:ba=4096;bb=669418;bc=c[37238]|0;j=96;break;case 96:bd=ba-1|0;if((bd|0)==0){j=98;break}else{j=97;break};case 97:G=a[bc]|0;a[bb]=G;if(G<<24>>24==0){j=100;break}else{ba=bd;bb=bb+1|0;bc=bc+1|0;j=96;break};case 98:a[bb]=0;if((a[bc]|0)==0){j=100;break}else{be=bc;j=99;break};case 99:G=be+1|0;if((a[G]|0)==0){j=100;break}else{be=G;j=99;break};case 100:a[628457]=1;j=50;break;case 101:a[607928]=1;j=50;break;case 102:G=as(34,c[37238]|0,0,0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;bf=G-1|0;if(bf>>>0>7){j=103;break}else{j=104;break};case 103:G=c[191244]|0;aH(2,43480,52,1,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aJ(56);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(164,43600);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 104:c[607932+(bf<<2)>>2]=2;j=50;break;case 105:G=as(34,c[37238]|0,0,0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;bg=G-1|0;if(bg>>>0>7){j=106;break}else{j=107;break};case 106:G=c[191244]|0;aH(2,43312,58,1,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aJ(56);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(164,43600);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 107:c[607932+(bg<<2)>>2]=0;j=50;break;case 108:c[151984]=260;j=50;break;case 109:bh=4096;bi=628458;bj=c[37238]|0;j=110;break;case 110:bk=bh-1|0;if((bk|0)==0){j=112;break}else{j=111;break};case 111:G=a[bj]|0;a[bi]=G;if(G<<24>>24==0){j=50;break}else{bh=bk;bi=bi+1|0;bj=bj+1|0;j=110;break};case 112:a[bi]=0;if((a[bj]|0)==0){j=50;break}else{bl=bj;j=113;break};case 113:G=bl+1|0;if((a[G]|0)==0){j=50;break}else{bl=G;j=113;break};case 114:bm=4096;bn=760577;bo=c[37238]|0;j=115;break;case 115:bp=bm-1|0;if((bp|0)==0){j=117;break}else{j=116;break};case 116:G=a[bo]|0;a[bn]=G;if(G<<24>>24==0){j=119;break}else{bm=bp;bn=bn+1|0;bo=bo+1|0;j=115;break};case 117:a[bn]=0;if((a[bo]|0)==0){j=119;break}else{bq=bo;j=118;break};case 118:G=bq+1|0;if((a[G]|0)==0){j=119;break}else{bq=G;j=118;break};case 119:a[764674]=(aq|0)==80|0;a[764673]=(aq|0)==82|0;j=50;break;case 120:br=c[37238]|0;G=aD(8,br|0,43240)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((G|0)==0){j=121;break}else{j=122;break};case 121:a[764676]=1;a[764677]=1;j=50;break;case 122:G=aD(8,br|0,43184)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((G|0)==0){j=123;break}else{j=124;break};case 123:a[764676]=1;j=50;break;case 124:G=aD(8,br|0,42864)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((G|0)==0){j=125;break}else{j=126;break};case 125:a[764677]=1;j=50;break;case 126:G=aD(8,br|0,42752)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((G|0)==0){j=50;break}else{j=127;break};case 127:G=c[191244]|0;aH(2,42456,54,1,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aJ(56);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(164,43600);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 128:bs=4096;bt=689902;bu=c[37238]|0;j=129;break;case 129:bv=bs-1|0;if((bv|0)==0){j=131;break}else{j=130;break};case 130:G=a[bu]|0;a[bt]=G;if(G<<24>>24==0){j=133;break}else{bs=bv;bt=bt+1|0;bu=bu+1|0;j=129;break};case 131:a[bt]=0;if((a[bu]|0)==0){j=133;break}else{bw=bu;j=132;break};case 132:G=bw+1|0;if((a[G]|0)==0){j=133;break}else{bw=G;j=132;break};case 133:a[689899]=1;j=50;break;case 134:bx=4096;by=673514;bz=c[37238]|0;j=135;break;case 135:bA=bx-1|0;if((bA|0)==0){j=137;break}else{j=136;break};case 136:G=a[bz]|0;a[by]=G;if(G<<24>>24==0){j=50;break}else{bx=bA;by=by+1|0;bz=bz+1|0;j=135;break};case 137:a[by]=0;if((a[bz]|0)==0){j=50;break}else{bB=bz;j=138;break};case 138:G=bB+1|0;if((a[G]|0)==0){j=50;break}else{bB=G;j=138;break};case 139:switch(c[D>>2]|0){case 77:{j=140;break};case 67:{j=141;break};case 66:{j=146;break};case 73:{j=152;break};case 110:{j=158;break};case 102:{j=159;break};default:{j=50;break}}break;case 140:a[766053]=1;j=50;break;case 141:bC=4096;bD=632554;bE=c[37238]|0;j=142;break;case 142:bF=bC-1|0;if((bF|0)==0){j=144;break}else{j=143;break};case 143:G=a[bE]|0;a[bD]=G;if(G<<24>>24==0){j=50;break}else{bC=bF;bD=bD+1|0;bE=bE+1|0;j=142;break};case 144:a[bD]=0;if((a[bE]|0)==0){j=50;break}else{bG=bE;j=145;break};case 145:G=bG+1|0;if((a[G]|0)==0){j=50;break}else{bG=G;j=145;break};case 146:bH=4096;bI=693998;bJ=c[37238]|0;j=147;break;case 147:bK=bH-1|0;if((bK|0)==0){j=149;break}else{j=148;break};case 148:G=a[bJ]|0;a[bI]=G;if(G<<24>>24==0){j=151;break}else{bH=bK;bI=bI+1|0;bJ=bJ+1|0;j=147;break};case 149:a[bI]=0;if((a[bJ]|0)==0){j=151;break}else{bL=bJ;j=150;break};case 150:G=bL+1|0;if((a[G]|0)==0){j=151;break}else{bL=G;j=150;break};case 151:a[689900]=1;j=50;break;case 152:bM=4096;bN=698094;bO=c[37238]|0;j=153;break;case 153:bP=bM-1|0;if((bP|0)==0){j=155;break}else{j=154;break};case 154:G=a[bO]|0;a[bN]=G;if(G<<24>>24==0){j=157;break}else{bM=bP;bN=bN+1|0;bO=bO+1|0;j=153;break};case 155:a[bN]=0;if((a[bO]|0)==0){j=157;break}else{bQ=bO;j=156;break};case 156:G=bQ+1|0;if((a[G]|0)==0){j=157;break}else{bQ=G;j=156;break};case 157:a[689901]=1;j=50;break;case 158:a[689898]=1;j=50;break;case 159:ao(22,10)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;ao(88,42104)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=41984,c[H+8>>2]=41936,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=41576,c[H+8>>2]=41512,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=41408,c[H+8>>2]=41304,c[H+16>>2]=24184,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=41176,c[H+8>>2]=41104,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=41064,c[H+8>>2]=40992,c[H+16>>2]=24184,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=40928,c[H+8>>2]=40872,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=40576,c[H+8>>2]=40440,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=40320,c[H+8>>2]=40232,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=40192,c[H+8>>2]=40232,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=40144,c[H+8>>2]=40232,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=40104,c[H+8>>2]=40232,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=40040,c[H+8>>2]=40232,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=39976,c[H+8>>2]=40232,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=39936,c[H+8>>2]=40232,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=39528,c[H+8>>2]=40232,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=39448,c[H+8>>2]=39312,c[H+16>>2]=24184,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=39272,c[H+8>>2]=40232,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=39176,c[H+8>>2]=39104,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=39064,c[H+8>>2]=38992,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=38920,c[H+8>>2]=38864,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=38624,c[H+8>>2]=38520,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=38360,c[H+8>>2]=38280,c[H+16>>2]=24184,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=38256,c[H+8>>2]=38208,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=38176,c[H+8>>2]=38104,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=38048,c[H+8>>2]=37992,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=37664,c[H+8>>2]=37576,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;aD(20,42056,(H=i,i=i+24|0,c[H>>2]=37392,c[H+8>>2]=37312,c[H+16>>2]=23936,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;al(1328,0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 160:aJ(56);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(164,43600);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 161:G=c[191244]|0;aH(2,42336,46,1,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(164,43600);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 162:bR=(M|0)<(d|0);if((a[766053]&1)==0){j=165;break}else{j=163;break};case 163:if(bR){j=164;break}else{j=168;break};case 164:G=c[191244]|0;aH(2,42232,71,1,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(164,43600);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 165:if(bR){j=166;break}else{j=167;break};case 166:al(542,c[e+(M<<2)>>2]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=168;break;case 167:a[766052]=1;j=168;break;case 168:if((a[628456]&1)==0){j=175;break}else{j=169;break};case 169:G=aD(4,648938,z|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((G|0)<0){j=175;break}else{j=170;break};case 170:if((c[z+8>>2]&61440|0)==16384){bS=4096;bT=677610;bU=648938;j=171;break}else{j=175;break};case 171:bV=bS-1|0;if((bV|0)==0){j=173;break}else{j=172;break};case 172:G=a[bU]|0;a[bT]=G;if(G<<24>>24==0){j=175;break}else{bS=bV;bT=bT+1|0;bU=bU+1|0;j=171;break};case 173:a[bT]=0;if((a[bU]|0)==0){j=175;break}else{bW=bU;j=174;break};case 174:G=bW+1|0;if((a[G]|0)==0){j=175;break}else{bW=G;j=174;break};case 175:if((a[628457]&1)==0){j=182;break}else{j=176;break};case 176:G=aD(4,669418,y|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((G|0)<0){j=182;break}else{j=177;break};case 177:if((c[y+8>>2]&61440|0)==16384){bX=4096;bY=681706;bZ=669418;j=178;break}else{j=182;break};case 178:b_=bX-1|0;if((b_|0)==0){j=180;break}else{j=179;break};case 179:G=a[bZ]|0;a[bY]=G;if(G<<24>>24==0){j=182;break}else{bX=b_;bY=bY+1|0;bZ=bZ+1|0;j=178;break};case 180:a[bY]=0;if((a[bZ]|0)==0){j=182;break}else{b$=bZ;j=181;break};case 181:G=b$+1|0;if((a[G]|0)==0){j=182;break}else{b$=G;j=181;break};case 182:if((a[607928]&1)==0){j=185;break}else{j=183;break};case 183:G=c[191244]|0;aH(2,25656,49,1,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=c[q>>2]|0;aH(2,49360,11,1,G|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;as(8,G|0,49112,(H=i,i=i+16|0,c[H>>2]=48520,c[H+8>>2]=32,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;as(8,G|0,48280,(H=i,i=i+8|0,c[H>>2]=48144,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;if((a[607928]&1)==0){j=185;break}else{j=184;break};case 184:G=c[191244]|0;aH(2,25296,50,1,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=185;break;case 185:if((a[764884]&1)==0){j=186;break}else{j=233;break};case 186:a[505520]=103;a[505521]=108;a[505522]=0;a[522068]=114;a[522069]=119;a[522070]=101;a[522071]=98;a[522072]=97;a[522073]=117;a[522074]=100;a[522075]=105;a[522076]=111;a[522077]=0;a[530360]=114;a[530361]=119;a[530362]=101;a[530363]=98;a[530364]=105;a[530365]=110;a[530366]=112;a[530367]=117;a[530368]=116;a[530369]=0;g[126396]=3.0;g[126397]=3.0;a[505592]=a[607931]&1;a[505593]=1;c[126399]=0;c[126400]=0;c[126401]=0;a[522060]=0;a[505608]=1;a[505609]=0;c[126404]=0;a[505610]=0;c[126403]=1;a[513836]=0;a[505620]=1;a[505621]=1;a[505629]=0;a[505622]=1;g[126406]=-1.0;a[505628]=0;c[126408]=4;a[509732]=0;a[522064]=1;a[522036]=1;g[130508]=48.0;a[522037]=1;g[130510]=.05000000074505806;g[130511]=.05000000074505806;g[130512]=1.0;g[130513]=1.0;g[130514]=0.0;g[128458]=59.95000076293945;a[522061]=0;a[522062]=0;a[522063]=1;a[522100]=1;c[130526]=48e3;c[130527]=0;g[130528]=48.0e3;c[131553]=64;a[526216]=1;a[530313]=1;g[132579]=.004999999888241291;g[132580]=0.0;a[603772]=0;c[150944]=20971520;c[150945]=1;g[150946]=3.0;g[150947]=-1.0;a[603792]=0;v3(603796,0,7);a[603803]=1;a[603804]=0;b[301903]=-10181;a[603808]=0;c[145822]=100;v6(530424,3376,2240)|0;v6(532664,2376,1e3)|0;v6(534904,2376,1e3)|0;v6(537144,2376,1e3)|0;v6(539384,2376,1e3)|0;v6(541624,2376,1e3)|0;v6(543864,2376,1e3)|0;v6(546104,2376,1e3)|0;b0=0;j=187;break;case 187:G=548360+(b0*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[548376+(b0*40|0)>>2]=-1;G=b0+1|0;if(G>>>0<56){b0=G;j=187;break}else{b1=0;j=213;break};case 188:if((a[530424+(b2*40|0)|0]&1)==0){j=191;break}else{j=189;break};case 189:if((b2|0)==(c[530428+(b2*40|0)>>2]|0)){j=191;break}else{j=190;break};case 190:G=c[191244]|0;as(8,((G|0)!=0?G:c[q>>2]|0)|0,33568,(H=i,i=i+16|0,c[H>>2]=23768,c[H+8>>2]=251,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(1328,2);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 191:G=b2+1|0;if((G|0)<56){b2=G;j=188;break}else{b3=0;j=192;break};case 192:if((a[532664+(b3*40|0)|0]&1)==0){j=194;break}else{j=193;break};case 193:if((b3|0)==(c[532668+(b3*40|0)>>2]|0)){j=194;break}else{j=190;break};case 194:G=b3+1|0;if((G|0)<56){b3=G;j=192;break}else{b4=0;j=195;break};case 195:if((a[534904+(b4*40|0)|0]&1)==0){j=197;break}else{j=196;break};case 196:if((b4|0)==(c[534908+(b4*40|0)>>2]|0)){j=197;break}else{j=190;break};case 197:G=b4+1|0;if((G|0)<56){b4=G;j=195;break}else{b5=0;j=198;break};case 198:if((a[537144+(b5*40|0)|0]&1)==0){j=200;break}else{j=199;break};case 199:if((b5|0)==(c[537148+(b5*40|0)>>2]|0)){j=200;break}else{j=190;break};case 200:G=b5+1|0;if((G|0)<56){b5=G;j=198;break}else{b6=0;j=201;break};case 201:if((a[539384+(b6*40|0)|0]&1)==0){j=203;break}else{j=202;break};case 202:if((b6|0)==(c[539388+(b6*40|0)>>2]|0)){j=203;break}else{j=190;break};case 203:G=b6+1|0;if((G|0)<56){b6=G;j=201;break}else{b7=0;j=204;break};case 204:if((a[541624+(b7*40|0)|0]&1)==0){j=206;break}else{j=205;break};case 205:if((b7|0)==(c[541628+(b7*40|0)>>2]|0)){j=206;break}else{j=190;break};case 206:G=b7+1|0;if((G|0)<56){b7=G;j=204;break}else{b8=0;j=207;break};case 207:if((a[543864+(b8*40|0)|0]&1)==0){j=209;break}else{j=208;break};case 208:if((b8|0)==(c[543868+(b8*40|0)>>2]|0)){j=209;break}else{j=190;break};case 209:G=b8+1|0;if((G|0)<56){b8=G;j=207;break}else{b9=0;j=210;break};case 210:if((a[546104+(b9*40|0)|0]&1)==0){j=212;break}else{j=211;break};case 211:if((b9|0)==(c[546108+(b9*40|0)>>2]|0)){j=212;break}else{j=190;break};case 212:G=b9+1|0;if((G|0)<56){b9=G;j=210;break}else{j=220;break};case 213:G=550600+(b1*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[550616+(b1*40|0)>>2]=-1;G=b1+1|0;if(G>>>0<56){b1=G;j=213;break}else{ca=0;j=214;break};case 214:G=552840+(ca*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[552856+(ca*40|0)>>2]=-1;G=ca+1|0;if(G>>>0<56){ca=G;j=214;break}else{cb=0;j=215;break};case 215:G=555080+(cb*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[555096+(cb*40|0)>>2]=-1;G=cb+1|0;if(G>>>0<56){cb=G;j=215;break}else{cc=0;j=216;break};case 216:G=557320+(cc*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[557336+(cc*40|0)>>2]=-1;G=cc+1|0;if(G>>>0<56){cc=G;j=216;break}else{cd=0;j=217;break};case 217:G=559560+(cd*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[559576+(cd*40|0)>>2]=-1;G=cd+1|0;if(G>>>0<56){cd=G;j=217;break}else{ce=0;j=218;break};case 218:G=561800+(ce*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[561816+(ce*40|0)>>2]=-1;G=ce+1|0;if(G>>>0<56){ce=G;j=218;break}else{cf=0;j=219;break};case 219:G=564040+(cf*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[564056+(cf*40|0)>>2]=-1;G=cf+1|0;if(G>>>0<56){cf=G;j=219;break}else{b2=0;j=188;break};case 220:g[141568]=.5;a[566886]=1;c[141722]=6;c[141723]=3;g[142748]=1.0;g[142749]=1.0;a[566884]=0;a[566885]=1;c[141569]=0;c[141570]=1;c[141571]=2;c[141572]=3;c[141573]=4;c[141574]=5;c[141575]=6;c[141576]=7;a[764982]=0;v3(764916,0,16);a[764884]=1;aJ(80);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cg=(a[607928]&1)!=0;if((a[628458]|0)==0){j=224;break}else{j=221;break};case 221:if(cg){j=222;break}else{j=223;break};case 222:G=c[191244]|0;as(8,((G|0)!=0?G:c[q>>2]|0)|0,43800,(H=i,i=i+8|0,c[H>>2]=628458,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=223;break;case 223:G=ao(64,628458)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if(G){j=233;break}else{j=230;break};case 224:if(cg){j=225;break}else{j=226;break};case 225:G=c[191244]|0;aH(2,43672,35,1,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=226;break;case 226:ch=ao(64,0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((a[628458]|0)==0){j=229;break}else{j=227;break};case 227:if((a[607928]&1)==0){j=229;break}else{j=228;break};case 228:G=c[191244]|0;as(8,((G|0)!=0?G:c[q>>2]|0)|0,43544,(H=i,i=i+8|0,c[H>>2]=628458,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if(ch){j=233;break}else{j=230;break};case 229:if(ch){j=233;break}else{j=230;break};case 230:G=c[191244]|0;as(8,((G|0)!=0?G:c[q>>2]|0)|0,43384,(H=i,i=i+8|0,c[H>>2]=628458,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((a[764981]&1)==0){j=231;break}else{j=232;break};case 231:G=c[191244]|0;as(8,((G|0)!=0?G:c[q>>2]|0)|0,33568,(H=i,i=i+16|0,c[H>>2]=43208,c[H+8>>2]=832,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;G=c[191244]|0;ao(40,((G|0)!=0?G:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(1328,2);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 232:a[764983]=112;a[764984]=97;a[764985]=114;a[764986]=115;a[764987]=101;a[764988]=95;a[764989]=99;a[764990]=111;a[764991]=110;a[764992]=102;a[764993]=105;a[764994]=103;a[764995]=95;a[764996]=102;a[764997]=105;a[764998]=108;a[764999]=101;a[765e3]=40;a[765001]=41;a[765002]=0;am(106,766008,1);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 233:G=(a[766053]&1)!=0;W=G?590:1126;c[37216]=G?22:34;c[37228]=G?82:70;c[37234]=G?22:12;c[37218]=G?1258:1462;c[37220]=G?136:144;c[37196]=W;c[37190]=G?812:1506;c[37202]=G?494:474;c[37200]=G?318:638;c[37194]=G?360:1358;c[37192]=G?708:434;c[37198]=G?66:12;c[37210]=G?2:60;c[37208]=G?86:38;c[37204]=G?4:8;c[37206]=G?18:6;c[37186]=G?40:30;c[37232]=G?32:24;c[37230]=G?58:72;c[37214]=G?24:68;c[37212]=G?2:30;c[37188]=G?48:90;c[37222]=G?30:10;c[37226]=G?12:2;c[37224]=G?32:10;al(W|0,36);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(c[37218]|0,702216);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=c[175554]|0;if((W|0)==0){j=234;break}else{ci=W;j=235;break};case 234:c[175554]=20328;ci=20328;j=235;break;case 235:W=c[175555]|0;if((W|0)==0){j=236;break}else{cj=W;j=237;break};case 236:c[175555]=27120;cj=27120;j=237;break;case 237:aH(4,764740,64,26688,(H=i,i=i+16|0,c[H>>2]=ci,c[H+8>>2]=cj,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[175556]|0;ck=4096;cl=702808;cm=(W|0)==0?26432:W;j=238;break;case 238:cn=ck-1|0;if((cn|0)==0){j=240;break}else{j=239;break};case 239:W=a[cm]|0;a[cl]=W;if(W<<24>>24==0){j=242;break}else{ck=cn;cl=cl+1|0;cm=cm+1|0;j=238;break};case 240:a[cl]=0;if((a[cm]|0)==0){j=242;break}else{co=cm;j=241;break};case 241:W=co+1|0;if((a[W]|0)==0){j=242;break}else{co=W;j=241;break};case 242:a[702292]=a[702229]&1;cp=0;j=243;break;case 243:if(cp>>>0<2){j=244;break}else{j=245;break};case 244:cq=c[11664+(cp<<2)>>2]|0;W=aD(14,522068,c[cq+28>>2]|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=252;break}else{cp=cp+1|0;j=243;break};case 245:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,26496,(H=i,i=i+8|0,c[H>>2]=522068,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=a[607928]|0;if((W&1)==0){cr=W;j=247;break}else{j=246;break};case 246:W=c[191244]|0;aH(2,26168,29,1,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cr=a[607928]|0;j=247;break;case 247:if((cr&1)==0){cs=cr;j=249;break}else{j=248;break};case 248:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,28248,(H=i,i=i+8|0,c[H>>2]=48128,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cs=a[607928]|0;j=249;break;case 249:if((cs&1)==0){j=251;break}else{j=250;break};case 250:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,28248,(H=i,i=i+8|0,c[H>>2]=44080,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=251;break;case 251:al(780,25888);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 252:c[191558]=cq;W=aD(14,505520,35608)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=258;break}else{j=253;break};case 253:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,27488,(H=i,i=i+8|0,c[H>>2]=505520,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=a[607928]|0;if((W&1)==0){ct=W;j=255;break}else{j=254;break};case 254:W=c[191244]|0;aH(2,27200,29,1,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;ct=a[607928]|0;j=255;break;case 255:if((ct&1)==0){j=257;break}else{j=256;break};case 256:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,28248,(H=i,i=i+8|0,c[H>>2]=35608,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=257;break;case 257:al(780,26832);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 258:c[191559]=72;W=aD(14,530360,50392)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=264;break}else{j=259;break};case 259:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,29392,(H=i,i=i+8|0,c[H>>2]=530360,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=a[607928]|0;if((W&1)==0){cu=W;j=261;break}else{j=260;break};case 260:W=c[191244]|0;aH(2,28880,29,1,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cu=a[607928]|0;j=261;break;case 261:if((cu&1)==0){j=263;break}else{j=262;break};case 262:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,28248,(H=i,i=i+8|0,c[H>>2]=50392,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=263;break;case 263:al(780,27848);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 264:c[191560]=7352;W=a[607928]|0;if((W&1)==0){cv=W;j=266;break}else{j=265;break};case 265:W=c[191244]|0;G=(W|0)!=0?W:c[q>>2]|0;W=aG(c[37234]|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;as(8,G|0,5e4,(H=i,i=i+8|0,c[H>>2]=W,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cv=a[607928]|0;j=266;break;case 266:if((cv&1)==0){j=268;break}else{j=267;break};case 267:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,49920,(H=i,i=i+8|0,c[H>>2]=1,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=268;break;case 268:W=aG(c[37234]|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==1){j=270;break}else{j=269;break};case 269:W=c[191244]|0;aH(2,49528,117,1,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=270;break;case 270:aJ(c[37216]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cw=(a[766053]&1)==0;W=a[766052]&1;a[764678]=cw?W^1:0;if(W<<24>>24==0){j=273;break}else{j=271;break};case 271:if(cw){j=272;break}else{j=369;break};case 272:W=ao(74,c[153016]|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if(W){j=369;break}else{j=493;break};case 273:if(cw){j=274;break}else{j=369;break};case 274:aJ(28);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=ao(74,c[153016]|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if(W){j=275;break}else{j=493;break};case 275:cx=A|0;cy=B|0;cz=C|0;if((a[603801]&1)==0){j=289;break}else{j=276;break};case 276:am(108,cx|0,669418);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aI(22,cy|0,669418,4096);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cA=as(22,cx|0,0,0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((cA|0)==0){j=289;break}else{j=277;break};case 277:cB=cA+4|0;cC=cA|0;if((c[cB>>2]|0)==0){j=278;break}else{cD=0;cE=0;j=279;break};case 278:cF=c[cC>>2]|0;cG=0;j=287;break;case 279:cH=c[(c[cC>>2]|0)+(cD<<3)>>2]|0;aI(22,cz|0,cH|0,4096);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=ao(46,cy|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=as(18,cz|0,cy|0,W|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((G|0)==0){j=280;break}else{cI=cE;j=284;break};case 280:G=ao(46,cH|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cJ=cH+G|0;j=281;break;case 281:if(cJ>>>0>cH>>>0){j=282;break}else{j=283;break};case 282:G=cJ-1|0;if(((a[G]|0)-48|0)>>>0<10){cJ=G;j=281;break}else{j=283;break};case 283:G=as(14,cJ|0,0,0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cI=G>>>0>cE>>>0?G:cE;j=284;break;case 284:G=cD+1|0;cK=c[cB>>2]|0;if(G>>>0<cK>>>0){cD=G;cE=cI;j=279;break}else{j=285;break};case 285:G=c[cC>>2]|0;if((cK|0)==0){cF=G;cG=cI;j=287;break}else{cL=0;cM=G;j=286;break};case 286:al(1214,c[cM+(cL<<3)>>2]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=cL+1|0;W=c[cC>>2]|0;if(G>>>0<(c[cB>>2]|0)>>>0){cL=G;cM=W;j=286;break}else{cF=W;cG=cI;j=287;break};case 287:al(1214,cF|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(1214,cA|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;c[175548]=cG;if((a[607928]&1)==0){j=289;break}else{j=288;break};case 288:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,50168,(H=i,i=i+8|0,c[H>>2]=cG,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=289;break;case 289:if((a[764676]&1)==0){j=290;break}else{j=323;break};case 290:switch(c[153016]|0){case 0:{j=291;break};case 1:{j=299;break};case 2:case 3:{j=307;break};case 4:{j=315;break};default:{j=325;break}}break;case 291:cN=ao(c[37224]|0,0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cO=ao(c[37226]|0,0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((cN|0)==0|(cO|0)==0){j=295;break}else{j=292;break};case 292:c[x>>2]=0;cP=aD(26,648938,x|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cQ=c[x>>2]|0;if((cP|0)<1|(cP|0)>(cN|0)){j=294;break}else{j=293;break};case 293:v6(cO|0,cQ|0,cP)|0;j=294;break;case 294:al(1214,cQ|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=295;break;case 295:cR=ao(c[37224]|0,1)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cS=ao(c[37226]|0,1)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((cR|0)==0|(cS|0)==0){j=325;break}else{j=296;break};case 296:c[w>>2]=0;cT=aD(26,653034,w|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cU=c[w>>2]|0;if((cT|0)<1|(cT|0)>(cR|0)){j=298;break}else{j=297;break};case 297:v6(cS|0,cU|0,cT)|0;j=298;break;case 298:al(1214,cU|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=325;break;case 299:cV=ao(c[37224]|0,1280)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cW=ao(c[37226]|0,1280)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((cV|0)==0|(cW|0)==0){j=303;break}else{j=300;break};case 300:c[v>>2]=0;cX=aD(26,648938,v|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;cY=c[v>>2]|0;if((cX|0)<1|(cX|0)>(cV|0)){j=302;break}else{j=301;break};case 301:v6(cW|0,cY|0,cX)|0;j=302;break;case 302:al(1214,cY|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=303;break;case 303:cZ=ao(c[37224]|0,1537)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;c_=ao(c[37226]|0,1537)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((cZ|0)==0|(c_|0)==0){j=325;break}else{j=304;break};case 304:c[s>>2]=0;c$=aD(26,653034,s|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;c0=c[s>>2]|0;if((c$|0)<1|(c$|0)>(cZ|0)){j=306;break}else{j=305;break};case 305:v6(c_|0,c0|0,c$)|0;j=306;break;case 306:al(1214,c0|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=325;break;case 307:c1=ao(c[37224]|0,256)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;c2=ao(c[37226]|0,256)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((c1|0)==0|(c2|0)==0){j=311;break}else{j=308;break};case 308:c[r>>2]=0;c3=aD(26,648938,r|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;c4=c[r>>2]|0;if((c3|0)<1|(c3|0)>(c1|0)){j=310;break}else{j=309;break};case 309:v6(c2|0,c4|0,c3)|0;j=310;break;case 310:al(1214,c4|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=311;break;case 311:c5=ao(c[37224]|0,512)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;c6=ao(c[37226]|0,512)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((c5|0)==0|(c6|0)==0){j=325;break}else{j=312;break};case 312:c[p>>2]=0;c7=aD(26,657130,p|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;c8=c[p>>2]|0;if((c7|0)<1|(c7|0)>(c5|0)){j=314;break}else{j=313;break};case 313:v6(c6|0,c8|0,c7)|0;j=314;break;case 314:al(1214,c8|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=325;break;case 315:c9=ao(c[37224]|0,768)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;da=ao(c[37226]|0,768)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((c9|0)==0|(da|0)==0){j=319;break}else{j=316;break};case 316:c[o>>2]=0;db=aD(26,661226,o|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;dc=c[o>>2]|0;if((db|0)<1|(db|0)>(c9|0)){j=318;break}else{j=317;break};case 317:v6(da|0,dc|0,db)|0;j=318;break;case 318:al(1214,dc|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=319;break;case 319:dd=ao(c[37224]|0,1024)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;de=ao(c[37226]|0,1024)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((dd|0)==0|(de|0)==0){j=325;break}else{j=320;break};case 320:c[n>>2]=0;df=aD(26,665322,n|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;dg=c[n>>2]|0;if((df|0)<1|(df|0)>(dd|0)){j=322;break}else{j=321;break};case 321:v6(de|0,dg|0,df)|0;j=322;break;case 322:al(1214,dg|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=325;break;case 323:if((a[607928]&1)==0){j=325;break}else{j=324;break};case 324:W=c[191244]|0;aH(2,24296,31,1,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=325;break;case 325:if((a[603803]&1)==0){j=338;break}else{j=326;break};case 326:aI(70,cx|0,669418,20528);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;dh=aD(16,cx|0,34720)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((dh|0)==0){j=338;break}else{j=327;break};case 327:ao(90,dh|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((a[607928]&1)==0){j=329;break}else{j=328;break};case 328:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,50488,(H=i,i=i+8|0,c[H>>2]=cx,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=329;break;case 329:W=ao(60,cx|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aH(4,cy|0,4096,50336,(H=i,i=i+16|0,c[H>>2]=cx,c[H+8>>2]=W?20296:20232,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;di=c[189113]|0;dj=di+4|0;if((c[dj>>2]|0)>>>0<(c[di+8>>2]|0)>>>0){j=330;break}else{j=336;break};case 330:dk=ao(14,12)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((dk|0)==0){j=333;break}else{j=331;break};case 331:if((c[dk-4>>2]&3|0)==0){j=333;break}else{j=332;break};case 332:v3(dk|0,0,12);j=333;break;case 333:W=dk;c[dk+4>>2]=1;c[dk>>2]=180;G=ao(70,cy|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;dl=c[dj>>2]|0;c[dk+8>>2]=G;dm=di|0;c[(c[dm>>2]|0)+(dl<<2)>>2]=W;W=c[dj>>2]|0;c[dj>>2]=W+1;if(W>>>0>1){dn=W;j=334;break}else{j=336;break};case 334:dp=dn>>>1;W=c[dm>>2]|0;dq=W+(dp<<2)|0;dr=c[dq>>2]|0;ds=c[W+(dn<<2)>>2]|0;if((c[ds+4>>2]|0)>>>0>(c[dr+4>>2]|0)>>>0){j=335;break}else{j=336;break};case 335:c[dq>>2]=ds;c[(c[dm>>2]|0)+(dn<<2)>>2]=dr;if(dn>>>0>3){dn=dp;j=334;break}else{j=336;break};case 336:if((a[607928]&1)==0){j=338;break}else{j=337;break};case 337:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,47400,(H=i,i=i+8|0,c[H>>2]=cy,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=338;break;case 338:if((a[764674]&1)==0){j=351;break}else{j=339;break};case 339:W=aD(34,760577,0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;c[189119]=W;if((W|0)==0){j=340;break}else{j=341;break};case 340:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,12264,(H=i,i=i+8|0,c[H>>2]=760577,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(164,51448);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;return 0;case 341:a[760576]=1;dt=c[189113]|0;du=dt+4|0;if((c[du>>2]|0)>>>0<(c[dt+8>>2]|0)>>>0){j=342;break}else{j=348;break};case 342:dv=ao(14,12)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((dv|0)==0){j=345;break}else{j=343;break};case 343:if((c[dv-4>>2]&3|0)==0){j=345;break}else{j=344;break};case 344:v3(dv|0,0,12);j=345;break;case 345:W=dv;c[dv+4>>2]=2;c[dv>>2]=180;dl=ao(70,51344)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;G=c[du>>2]|0;c[dv+8>>2]=dl;dw=dt|0;c[(c[dw>>2]|0)+(G<<2)>>2]=W;W=c[du>>2]|0;c[du>>2]=W+1;if(W>>>0>1){dx=W;j=346;break}else{j=348;break};case 346:dy=dx>>>1;W=c[dw>>2]|0;dz=W+(dy<<2)|0;dA=c[dz>>2]|0;dB=c[W+(dx<<2)>>2]|0;if((c[dB+4>>2]|0)>>>0>(c[dA+4>>2]|0)>>>0){j=347;break}else{j=348;break};case 347:c[dz>>2]=dB;c[(c[dw>>2]|0)+(dx<<2)>>2]=dA;if(dx>>>0>3){dx=dy;j=346;break}else{j=348;break};case 348:if((a[607928]&1)==0){j=350;break}else{j=349;break};case 349:W=c[191244]|0;aH(2,50752,36,1,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=350;break;case 350:c[150945]=1;j=369;break;case 351:if((a[764673]&1)==0){j=369;break}else{j=352;break};case 352:aH(4,cx|0,4096,16168,(H=i,i=i+8|0,c[H>>2]=760577,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=aD(34,760577,1)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;c[189119]=W;dC=c[189113]|0;dD=dC+4|0;dE=c[dD>>2]|0;if(dE>>>0>1){j=353;break}else{j=357;break};case 353:dF=dC|0;dG=1;dH=dE;j=354;break;case 354:dI=c[(c[dF>>2]|0)+(dG<<2)>>2]|0;if((dI|0)==0){dJ=dH;j=356;break}else{j=355;break};case 355:al(1214,c[dI+8>>2]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(1214,c[(c[dF>>2]|0)+(dG<<2)>>2]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;c[(c[dF>>2]|0)+(dG<<2)>>2]=0;dJ=c[dD>>2]|0;j=356;break;case 356:W=dG+1|0;if(W>>>0<dJ>>>0){dG=W;dH=dJ;j=354;break}else{j=357;break};case 357:c[dD>>2]=1;W=dC+12|0;al(1214,c[W>>2]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;c[W>>2]=0;dK=c[189113]|0;dL=dK+4|0;if((c[dL>>2]|0)>>>0<(c[dK+8>>2]|0)>>>0){j=358;break}else{j=364;break};case 358:dM=(c[189119]|0)!=0?cx:15992;dN=ao(14,12)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((dN|0)==0){j=361;break}else{j=359;break};case 359:if((c[dN-4>>2]&3|0)==0){j=361;break}else{j=360;break};case 360:v3(dN|0,0,12);j=361;break;case 361:W=dN;c[dN+4>>2]=1;c[dN>>2]=180;G=ao(70,dM|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;dl=c[dL>>2]|0;c[dN+8>>2]=G;dO=dK|0;c[(c[dO>>2]|0)+(dl<<2)>>2]=W;W=c[dL>>2]|0;c[dL>>2]=W+1;if(W>>>0>1){dP=W;j=362;break}else{j=364;break};case 362:dQ=dP>>>1;W=c[dO>>2]|0;dR=W+(dQ<<2)|0;dS=c[dR>>2]|0;dT=c[W+(dP<<2)>>2]|0;if((c[dT+4>>2]|0)>>>0>(c[dS+4>>2]|0)>>>0){j=363;break}else{j=364;break};case 363:c[dR>>2]=dT;c[(c[dO>>2]|0)+(dP<<2)>>2]=dS;if(dP>>>0>3){dP=dQ;j=362;break}else{j=364;break};case 364:if((c[189119]|0)==0){j=368;break}else{j=365;break};case 365:if((a[607928]&1)==0){j=367;break}else{j=366;break};case 366:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,15856,(H=i,i=i+8|0,c[H>>2]=760577,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=367;break;case 367:c[150945]=1;j=369;break;case 368:W=c[191244]|0;aH(2,15320,51,1,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=369;break;case 369:al(c[37190]|0,8);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(c[37202]|0,86);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(c[37200]|0,22);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(c[37192]|0,6);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(c[37194]|0,92);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(c[37220]|0,702232);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;dU=+aF(2);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;dV=dU*1.0e3;W=+R(dV)>=1.0?dV>0.0?(ah(+Q(dV/4294967296.0),4294967295.0)|0)>>>0:~~+ab((dV- +(~~dV>>>0))/4294967296.0)>>>0:0;dl=702208;c[dl>>2]=~~dV>>>0;c[dl+4>>2]=W;dV=+aB(2,+(1.0e6/(+h[87782]*+g[150947])));if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=+R(dV)>=1.0?dV>0.0?(ah(+Q(dV/4294967296.0),4294967295.0)|0)>>>0:~~+ab((dV- +(~~dV>>>0))/4294967296.0)>>>0:0;dl=702200;c[dl>>2]=~~dV>>>0;c[dl+4>>2]=W;aJ(54);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aJ(78);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aJ(40);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((a[764678]&1)==0){j=370;break}else{j=371;break};case 370:a[764678]=0;j=372;break;case 371:W=a[764677]&1;a[764678]=W^1;if(W<<24>>24==0){j=374;break}else{j=372;break};case 372:if((a[607928]&1)==0){j=374;break}else{j=373;break};case 373:W=c[191244]|0;aH(2,24120,35,1,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=374;break;case 374:if((c[189119]|0)!=0|(a[587388]|0)==0){j=492;break}else{j=375;break};case 375:aJ(c[37232]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;dW=ao(14,16)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((dW|0)==0){dX=0;j=491;break}else{j=376;break};case 376:if((c[dW-4>>2]&3|0)==0){j=378;break}else{j=377;break};case 377:v3(dW|0,0,16);j=378;break;case 378:dY=dW;dZ=dW+12|0;c[dZ>>2]=1;d_=ao(14,12)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((d_|0)==0){j=382;break}else{j=379;break};case 379:if((c[d_-4>>2]&3|0)==0){j=380;break}else{j=381;break};case 380:W=dW;c[W>>2]=d_;d$=W;j=383;break;case 381:v3(d_|0,0,12);W=dW;c[W>>2]=d_;d$=W;j=383;break;case 382:c[dW>>2]=0;c[dZ>>2]=0;j=484;break;case 383:d0=ao(54,587388)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((d0|0)==0){j=384;break}else{j=385;break};case 384:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,21680,(H=i,i=i+8|0,c[H>>2]=587388,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=484;break;case 385:d1=d0|0;W=c[d1>>2]|0;if((W|0)==0){j=386;break}else{d2=W;j=387;break};case 386:al(498,dY|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=486;break;case 387:if((c[d2+20>>2]|0)==0){j=388;break}else{j=389;break};case 388:W=aD(8,c[d2>>2]|0,49096)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=390;break}else{j=389;break};case 389:W=c[d2+16>>2]|0;if((W|0)==0){j=485;break}else{d2=W;j=387;break};case 390:d3=c[d2+12>>2]|0;if((d3|0)==0){j=485;break}else{j=391;break};case 391:if((a[764812]|0)==0){d4=d3;j=392;break}else{d5=d3;j=398;break};case 392:if((c[d4+20>>2]|0)==0){j=393;break}else{j=397;break};case 393:W=aD(8,c[d4>>2]|0,36720)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=394;break}else{j=397;break};case 394:d6=d4+8|0;j=395;break;case 395:d7=c[d6>>2]|0;if((d7|0)==0){j=397;break}else{j=396;break};case 396:W=aD(8,29200,c[d7>>2]|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=397;break}else{d6=d7+8|0;j=395;break};case 397:W=c[d4+16>>2]|0;if((W|0)==0){j=485;break}else{d4=W;j=392;break};case 398:if((c[d5+20>>2]|0)==0){j=399;break}else{j=405;break};case 399:W=aD(8,c[d5>>2]|0,36720)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=400;break}else{j=405;break};case 400:d8=d5+8|0;j=401;break;case 401:d9=c[d8>>2]|0;if((d9|0)==0){j=405;break}else{j=402;break};case 402:W=aD(8,29200,c[d9>>2]|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=403;break}else{d8=d9+8|0;j=401;break};case 403:ea=c[d9+4>>2]|0;if((ea|0)==0){j=405;break}else{j=404;break};case 404:W=aD(8,ea|0,764812)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=406;break}else{j=405;break};case 405:W=c[d5+16>>2]|0;if((W|0)==0){j=485;break}else{d5=W;j=398;break};case 406:W=c[d5+12>>2]|0;eb=dW+8|0;if((W|0)==0){j=465;break}else{ec=W;j=407;break};case 407:ed=c[ec>>2]|0;W=aD(8,ed|0,44504)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=408;break}else{j=411;break};case 408:ee=c[ec+4>>2]|0;if((ee|0)==0){j=463;break}else{j=409;break};case 409:if((a[607928]&1)==0){j=463;break}else{j=410;break};case 410:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,43144,(H=i,i=i+8|0,c[H>>2]=ee,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=463;break;case 411:W=aD(8,ed|0,41920)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=412;break}else{j=463;break};case 412:ef=c[eb>>2]|0;if((ef|0)==(c[dZ>>2]|0)){j=414;break}else{j=413;break};case 413:eg=ef;eh=c[d$>>2]|0;j=416;break;case 414:c[dZ>>2]=ef<<1;W=aD(44,c[d$>>2]|0,ef*24|0|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;ei=W;c[d$>>2]=ei;if((W|0)==0){j=464;break}else{j=415;break};case 415:eg=c[eb>>2]|0;eh=ei;j=416;break;case 416:ej=eh+(eg*12|0)|0;ek=c[ec+12>>2]|0;if((ek|0)==0){j=463;break}else{j=417;break};case 417:v3(ej|0,0,12);el=ej|0;em=eh+(eg*12|0)+8|0;en=ek;eo=1;ep=0;eq=0;j=418;break;case 418:er=c[en>>2]|0;W=aD(8,er|0,40840)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=419;break}else{j=420;break};case 419:c[el>>2]=c[en+4>>2];es=eo;et=ep;eu=eq;j=461;break;case 420:W=aD(8,er|0,39928)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=421;break}else{es=eo;et=ep;eu=eq;j=461;break};case 421:if(eo){ev=ep;j=440;break}else{j=422;break};case 422:ew=(eq|0)!=0;if(ew){j=423;break}else{ex=2;j=424;break};case 423:W=ao(46,eq|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;ex=W+2|0;j=424;break;case 424:ey=aD(44,eq|0,ex|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((ey|0)==0){j=425;break}else{j=426;break};case 425:c[em>>2]=0;j=463;break;case 426:if(ew){j=427;break}else{j=434;break};case 427:ez=ao(46,ey|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;eA=ez>>>0>ex>>>0?0:ex-ez|0;if((eA|0)==0){eB=38840;j=431;break}else{j=428;break};case 428:eC=ey+ez|0;if((eA|0)==1){eD=38840;eE=eC;j=430;break}else{j=429;break};case 429:eF=ey+(ez+1)|0;a[eC]=43;if((eA|0)==2){eD=38841;eE=eF;j=430;break}else{j=490;break};case 430:a[eE]=0;eB=eD;j=431;break;case 431:if((a[eB]|0)==0){j=433;break}else{eG=eB;j=432;break};case 432:W=eG+1|0;if((a[W]|0)==0){j=433;break}else{eG=W;j=432;break};case 433:c[em>>2]=ey;ev=ey;j=440;break;case 434:if((ex|0)==1){eH=38840;eI=ey;j=436;break}else if((ex|0)==0){eJ=38840;j=437;break}else{j=435;break};case 435:eK=ey+1|0;a[ey]=43;if((ex|0)==2){eH=38841;eI=eK;j=436;break}else{j=489;break};case 436:a[eI]=0;eJ=eH;j=437;break;case 437:if((a[eJ]|0)==0){j=439;break}else{eL=eJ;j=438;break};case 438:W=eL+1|0;if((a[W]|0)==0){j=439;break}else{eL=W;j=438;break};case 439:c[em>>2]=ey;ev=ey;j=440;break;case 440:eM=c[en+4>>2]|0;if((eM|0)==0){j=463;break}else{j=441;break};case 441:eN=(ev|0)!=0;if(eN){j=442;break}else{eO=1;j=443;break};case 442:W=ao(46,ev|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;eO=W+1|0;j=443;break;case 443:W=ao(46,eM|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;eP=W+eO|0;eQ=aD(44,ev|0,eP|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((eQ|0)==0){j=444;break}else{j=445;break};case 444:c[em>>2]=0;j=463;break;case 445:if(eN){j=446;break}else{j=454;break};case 446:eR=ao(46,eQ|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;eS=eR>>>0>eP>>>0?0:eP-eR|0;if((eS|0)==0){eT=eM;j=451;break}else{j=447;break};case 447:eU=eS;eV=eQ+eR|0;eW=eM;j=448;break;case 448:eX=eU-1|0;if((eX|0)==0){j=450;break}else{j=449;break};case 449:W=a[eW]|0;a[eV]=W;if(W<<24>>24==0){j=453;break}else{eU=eX;eV=eV+1|0;eW=eW+1|0;j=448;break};case 450:a[eV]=0;eT=eW;j=451;break;case 451:if((a[eT]|0)==0){j=453;break}else{eY=eT;j=452;break};case 452:W=eY+1|0;if((a[W]|0)==0){j=453;break}else{eY=W;j=452;break};case 453:c[em>>2]=eQ;es=0;et=eQ;eu=eQ;j=461;break;case 454:if((eP|0)==0){eZ=eM;j=458;break}else{e_=eP;e$=eQ;e0=eM;j=455;break};case 455:e1=e_-1|0;if((e1|0)==0){j=457;break}else{j=456;break};case 456:W=a[e0]|0;a[e$]=W;if(W<<24>>24==0){j=460;break}else{e_=e1;e$=e$+1|0;e0=e0+1|0;j=455;break};case 457:a[e$]=0;eZ=e0;j=458;break;case 458:if((a[eZ]|0)==0){j=460;break}else{e2=eZ;j=459;break};case 459:W=e2+1|0;if((a[W]|0)==0){j=460;break}else{e2=W;j=459;break};case 460:c[em>>2]=eQ;es=0;et=eQ;eu=eQ;j=461;break;case 461:W=c[en+16>>2]|0;if((W|0)==0){j=462;break}else{en=W;eo=es;ep=et;eq=eu;j=418;break};case 462:c[eb>>2]=(c[eb>>2]|0)+1;j=463;break;case 463:W=c[ec+16>>2]|0;if((W|0)==0){j=465;break}else{ec=W;j=407;break};case 464:W=c[191244]|0;aH(2,25184,68,1,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=485;break;case 465:if((c[eb>>2]|0)==0){j=466;break}else{j=467;break};case 466:W=c[191244]|0;as(8,((W|0)!=0?W:c[q>>2]|0)|0,21992,(H=i,i=i+8|0,c[H>>2]=587388,H)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;i=H;W=c[191244]|0;ao(40,((W|0)!=0?W:c[q>>2]|0)|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=485;break;case 467:if((a[591484]|0)==0){j=481;break}else{j=468;break};case 468:e3=aD(46,591484,0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((e3|0)==0){j=481;break}else{j=469;break};case 469:e4=e3+4|0;j=470;break;case 470:e5=c[e4>>2]|0;if((e5|0)==0){j=472;break}else{j=471;break};case 471:W=aD(8,764812,c[e5+4>>2]|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=473;break}else{e4=e5+12|0;j=470;break};case 472:al(578,e3|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=481;break;case 473:e6=ao(70,c[e5+8>>2]|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=as(6,e6|0,27720,m|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=477;break}else{e7=W;j=474;break};case 474:e8=as(14,e7|0,0,0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if(e8>>>0<(c[eb>>2]|0)>>>0){j=475;break}else{j=476;break};case 475:a[(c[d$>>2]|0)+(e8*12|0)+4|0]=1;j=476;break;case 476:W=as(6,0,27720,m|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((W|0)==0){j=477;break}else{e7=W;j=474;break};case 477:al(1214,e6|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(578,e3|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aJ(c[37232]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=c[eb>>2]|0;if((W|0)==0){j=481;break}else{e9=0;fa=0;fb=W;j=478;break};case 478:fc=c[d$>>2]|0;if((a[fc+(fa*12|0)+4|0]&1)==0){fd=e9;fe=fb;j=480;break}else{j=479;break};case 479:W=e9+1|0;aI(c[37230]|0,e9|0,1,c[fc+(fa*12|0)+8>>2]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;fd=W;fe=c[eb>>2]|0;j=480;break;case 480:W=fa+1|0;if(W>>>0<fe>>>0){e9=fd;fa=W;fb=fe;j=478;break}else{j=481;break};case 481:ff=c[d1>>2]|0;if((ff|0)==0){j=483;break}else{j=482;break};case 482:al(520,ff|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=483;break;case 483:al(1214,d0|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;dX=dY;j=491;break;case 484:al(498,dY|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;dX=0;j=491;break;case 485:al(498,dY|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=486;break;case 486:fg=c[d1>>2]|0;if((fg|0)==0){j=488;break}else{j=487;break};case 487:al(520,fg|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=488;break;case 488:al(1214,d0|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;dX=0;j=491;break;case 489:a[eK]=0;j=439;break;case 490:a[eF]=0;j=433;break;case 491:c[191220]=dX;j=492;break;case 492:a[764981]=0;a[764980]=1;I=0;j=509;break;case 493:aJ(6);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;fh=c[176743]|0;if((fh|0)==0){j=496;break}else{j=494;break};case 494:if((a[766257]&1)==0){j=495;break}else{j=496;break};case 495:aJ(fh|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=496;break;case 496:aJ(72);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;if((a[766259]&1)==0){j=498;break}else{j=497;break};case 497:c[191562]=0;j=498;break;case 498:if((a[766260]&1)==0){j=500;break}else{j=499;break};case 499:c[191561]=0;j=500;break;case 500:if((a[766261]&1)==0){j=502;break}else{j=501;break};case 501:c[191563]=0;j=502;break;case 502:a[766259]=0;a[766260]=0;a[766261]=0;aJ(c[37188]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;aJ(c[37228]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;fi=c[176752]|0;if((fi|0)==0){j=508;break}else{j=503;break};case 503:fj=fi+4104|0;if((c[fj>>2]|0)==0){j=504;break}else{j=505;break};case 504:fk=fi|0;j=507;break;case 505:fl=fi|0;fm=0;j=506;break;case 506:W=c[fi+4100>>2]|0;aI(4,c[fl>>2]|0,c[W+(fm<<4)+4>>2]|0,c[(c[c[W+(fm<<4)+8>>2]>>2]|0)+(c[W+(fm<<4)+12>>2]<<3)>>2]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;W=fm+1|0;if(W>>>0<(c[fj>>2]|0)>>>0){fm=W;j=506;break}else{fk=fl;j=507;break};case 507:aD(28,c[fk>>2]|0,fi+4|0)|0;if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;al(1384,c[176752]|0);if((t|0)!=0&(u|0)!=0){k=v5(c[t>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}t=u=0;j=508;break;case 508:v3(702216,0,4800);a[764980]=0;I=1;j=509;break;case 509:i=f;return I|0;case-1:if((k|0)==1){F=u;j=510}t=u=0;break}return 0}function f9(){var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,a_=0,a$=0,a0=0,a1=0,a2=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0;d=i;i=i+9216|0;e=d|0;f=d+256|0;j=d+768|0;k=d+4864|0;l=d+8960|0;a[766263]=0;m=532360;if((c[133089]|0)==0&((c[m>>2]|0)==65535&(c[m+4>>2]|0)==0)&(c[133094]|0)==-1){n=774}else{m=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,48)|0;o=766424;p=(c[o>>2]&0|m&1|0)==0&(c[o+4>>2]&65536|0)==0;a[766263]=p&1;if(p){r=0}else{n=774}}do{if((n|0)==774){p=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,43)|0;o=766424;if((c[o>>2]&0|p&1|0)==0&(c[o+4>>2]&2048|0)==0){r=0;break}if((a[766496]&1)!=0){r=1;break}fT();r=1}}while(0);a[766496]=r;r=a[607929]|0;if((r&1)==0){s=r}else{do{if((a[766263]&1)==0){r=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,45)|0;o=766424;if((c[o>>2]&0|r&1|0)==0&(c[o+4>>2]&8192|0)==0){t=0;break}if((a[766560]&1)!=0){t=1;break}o=a[707057]&1;a[707057]=o^1;r=o<<24>>24==0?12616:12488;o=c[189113]|0;p=o+4|0;m=c[p>>2]|0;if(m>>>0>1){u=o|0;v=1;w=m;while(1){m=c[(c[u>>2]|0)+(v<<2)>>2]|0;if((m|0)==0){x=w}else{v_(c[m+8>>2]|0);v_(c[(c[u>>2]|0)+(v<<2)>>2]|0);c[(c[u>>2]|0)+(v<<2)>>2]=0;x=c[p>>2]|0}m=v+1|0;if(m>>>0<x>>>0){v=m;w=x}else{break}}}c[p>>2]=1;w=o+12|0;v_(c[w>>2]|0);c[w>>2]=0;w=c[189113]|0;v=w+4|0;L1091:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){u=vZ(12)|0;do{if((u|0)!=0){if((c[u-4>>2]&3|0)==0){break}v3(u|0,0,12)}}while(0);c[u+4>>2]=1;c[u>>2]=180;m=dn(r|0)|0;y=c[v>>2]|0;c[u+8>>2]=m;m=w|0;c[(c[m>>2]|0)+(y<<2)>>2]=u;y=c[v>>2]|0;c[v>>2]=y+1;if(y>>>0>1){z=y}else{break}while(1){y=z>>>1;A=c[m>>2]|0;B=A+(y<<2)|0;C=c[B>>2]|0;D=c[A+(z<<2)>>2]|0;if((c[D+4>>2]|0)>>>0<=(c[C+4>>2]|0)>>>0){break L1091}c[B>>2]=D;c[(c[m>>2]|0)+(z<<2)>>2]=C;if(z>>>0>3){z=y}else{break}}}}while(0);v=c[191561]|0;do{if((v|0)!=0){w=c[191558]|0;if((a[707057]&1)!=0){o=c[w+8>>2]|0;fc[o&127](v)|0;break}if(fc[c[w+12>>2]&127](v)|0){break}w=c[191244]|0;o=(w|0)!=0?w:c[q>>2]|0;a3(12392,45,1,o|0)|0;o=c[191244]|0;w=(o|0)!=0?o:c[q>>2]|0;aZ(w|0)|0;a[607929]=0}}while(0);if((a[607928]&1)==0){t=1;break}v=c[191244]|0;w=(v|0)!=0?v:c[q>>2]|0;eb(w|0,47400,(E=i,i=i+8|0,c[E>>2]=r,E)|0)|0;i=E;w=c[191244]|0;v=(w|0)!=0?w:c[q>>2]|0;aZ(v|0)|0;t=1}else{t=0}}while(0);a[766560]=t;s=a[607929]|0}t=l|0;do{if((s&1)!=0){l=a[766263]|0;if((l&1)==0){z=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,49)|0;x=766424;F=(c[x>>2]&0|z&1|0)!=0|(c[x+4>>2]&131072|0)!=0;H=a[766263]|0}else{F=0;H=l}if((H&1)==0){l=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,50)|0;x=766424;I=(c[x>>2]&0|l&1|0)!=0|(c[x+4>>2]&262144|0)!=0}else{I=0}if(!(F|I)){break}J=F?.5:0.0;if(I){K=J+-.5}else{K=J}J=K+ +g[176777];g[176777]=J;do{if(J>12.0){g[176777]=12.0;L=12.0}else{if(J>=-80.0){L=J;break}g[176777]=-80.0;L=-80.0}}while(0);J=L;bN(t|0,256,12736,(E=i,i=i+8|0,h[E>>3]=J,E)|0)|0;i=E;r=c[189113]|0;x=r+4|0;l=c[x>>2]|0;if(l>>>0>1){z=r|0;v=1;w=l;while(1){l=c[(c[z>>2]|0)+(v<<2)>>2]|0;if((l|0)==0){M=w}else{v_(c[l+8>>2]|0);v_(c[(c[z>>2]|0)+(v<<2)>>2]|0);c[(c[z>>2]|0)+(v<<2)>>2]=0;M=c[x>>2]|0}l=v+1|0;if(l>>>0<M>>>0){v=l;w=M}else{break}}}c[x>>2]=1;w=r+12|0;v_(c[w>>2]|0);c[w>>2]=0;w=c[189113]|0;v=w+4|0;L1136:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){z=vZ(12)|0;do{if((z|0)!=0){if((c[z-4>>2]&3|0)==0){break}v3(z|0,0,12)}}while(0);c[z+4>>2]=1;c[z>>2]=180;l=dn(t|0)|0;o=c[v>>2]|0;c[z+8>>2]=l;l=w|0;c[(c[l>>2]|0)+(o<<2)>>2]=z;o=c[v>>2]|0;c[v>>2]=o+1;if(o>>>0>1){N=o}else{break}while(1){o=N>>>1;p=c[l>>2]|0;m=p+(o<<2)|0;u=c[m>>2]|0;y=c[p+(N<<2)>>2]|0;if((c[y+4>>2]|0)>>>0<=(c[u+4>>2]|0)>>>0){break L1136}c[m>>2]=y;c[(c[l>>2]|0)+(N<<2)>>2]=u;if(N>>>0>3){N=o}else{break}}}}while(0);if((a[607928]&1)!=0){v=c[191244]|0;w=(v|0)!=0?v:c[q>>2]|0;eb(w|0,47400,(E=i,i=i+8|0,c[E>>2]=t,E)|0)|0;i=E;w=c[191244]|0;v=(w|0)!=0?w:c[q>>2]|0;aZ(v|0)|0}g[176778]=+T(10.0,+(+g[176777]/20.0))}}while(0);c[191177]=(c[191177]|0)+1;a[764682]=(fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,9680,0,1,0,16)|0)<<16>>16!=0|0;a[764683]=(fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,9680,1,1,0,16)|0)<<16>>16!=0|0;a[764684]=(fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,9680,2,1,0,16)|0)<<16>>16!=0|0;a[764685]=(fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,9680,3,1,0,16)|0)<<16>>16!=0|0;a[764686]=(fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,9680,4,1,0,16)|0)<<16>>16!=0|0;a[764687]=(fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,9680,5,1,0,16)|0)<<16>>16!=0|0;a[764688]=(fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,9680,6,1,0,16)|0)<<16>>16!=0|0;a[764689]=(fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,9680,7,1,0,16)|0)<<16>>16!=0|0;do{if((a[766263]&1)==0){t=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,54)|0;N=766424;if((c[N>>2]&0|t&1|0)==0&(c[N+4>>2]&4194304|0)==0){O=0;break}N=c[(c[191560]|0)+28>>2]|0;if((N|0)==0){O=0;break}if((a[766576]&1)!=0){O=1;break}t=a[766584]&1;M=t^1;a[766584]=M;if((a[607928]&1)==0){P=N;Q=M}else{M=c[191244]|0;N=(M|0)!=0?M:c[q>>2]|0;M=t<<24>>24==0?24184:23936;eb(N|0,13216,(E=i,i=i+8|0,c[E>>2]=M,E)|0)|0;i=E;M=c[191244]|0;N=(M|0)!=0?M:c[q>>2]|0;aZ(N|0)|0;P=c[(c[191560]|0)+28>>2]|0;Q=a[766584]|0}fa[P&127](c[191563]|0,(Q&1)!=0);N=c[191610]|0;if((N|0)==0){O=1;break}M=c[N+32>>2]|0;if((M|0)==0){O=1;break}fa[M&127](c[191562]|0,(a[766584]&1)==0);O=1}else{O=0}}while(0);a[766576]=O;if((c[191604]|0)!=0){do{if((a[766263]&1)==0){O=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,51)|0;Q=766424;if((c[Q>>2]&0|O&1|0)==0&(c[Q+4>>2]&524288|0)==0){R=0;break}if((a[148736]&1)!=0){R=1;break}Q=c[191604]|0;O=Q+28|0;P=c[O>>2]|0;M=Q+20|0;c[M>>2]=P;N=c[Q+12>>2]|0;t=Q+16|0;c[t>>2]=N+(P*136|0);I=Q+4|0;F=c[(c[I>>2]|0)+4>>2]|0;H=Q|0;s=c[H>>2]|0;v=c[N+(P*136|0)+8>>2]|0;w=c[N+(P*136|0)+12>>2]|0;r=c[N+(P*136|0)+16>>2]|0;fv[F&15](s,v,w,r)|0;r=c[t>>2]|0;fe[c[(c[I>>2]|0)+12>>2]&7](c[H>>2]|0,+g[r+24>>2],+g[r+28>>2],+g[r+32>>2],+g[r+36>>2]);fa[c[(c[I>>2]|0)+16>>2]&127](c[H>>2]|0,(a[(c[t>>2]|0)+68|0]&1)!=0);a[Q+9|0]=1;c[O>>2]=(((c[M>>2]|0)+1|0)>>>0)%((c[Q+24>>2]|0)>>>0)|0;R=1}else{R=0}}while(0);a[148736]=R}if((a[766263]&1)==0){R=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,35)|0;Q=766424;S=((c[Q>>2]&0|R&1|0)!=0|(c[Q+4>>2]&8|0)!=0)&1}else{S=0}do{if((a[764679]&1)==0){if((a[766263]&1)!=0){U=0;break}Q=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,36)|0;R=766424;U=((c[R>>2]&0|Q&1|0)!=0|(c[R+4>>2]&16|0)!=0)&1}else{U=0}}while(0);R=U|S;if((a[603792]&1)==0){V=1}else{V=fc[c[(c[191559]|0)+16>>2]&127](c[191562]|0)|0}do{if(R<<24>>24==0|V^1){n=863}else{if((a[766536]&1)!=0){n=863;break}S=a[764679]&1;a[764679]=S^1;U=(a[607928]&1)!=0;if(S<<24>>24==0){if(U){S=c[191244]|0;Q=(S|0)!=0?S:c[q>>2]|0;a3(13992,19,1,Q|0)|0;Q=c[191244]|0;S=(Q|0)!=0?Q:c[q>>2]|0;aZ(S|0)|0}S=c[191561]|0;if((S|0)==0){break}Q=c[(c[191558]|0)+8>>2]|0;fc[Q&127](S)|0;break}if(U){U=c[191244]|0;S=(U|0)!=0?U:c[q>>2]|0;a3(13792,21,1,S|0)|0;S=c[191244]|0;U=(S|0)!=0?S:c[q>>2]|0;aZ(U|0)|0}U=c[191561]|0;if((U|0)==0){break}if((a[707057]&1)!=0){break}if(fc[c[(c[191558]|0)+12>>2]&127](U)|0){break}U=c[191244]|0;S=(U|0)!=0?U:c[q>>2]|0;a3(13632,81,1,S|0)|0;S=c[191244]|0;U=(S|0)!=0?S:c[q>>2]|0;aZ(U|0)|0;a[607929]=0}}while(0);do{if((n|0)==863){U=(a[9720]&1)==0;if(!V){if(U){break}if((a[607928]&1)!=0){S=c[191244]|0;Q=(S|0)!=0?S:c[q>>2]|0;a3(13992,19,1,Q|0)|0;Q=c[191244]|0;S=(Q|0)!=0?Q:c[q>>2]|0;aZ(S|0)|0}a[764679]=1;S=c[191561]|0;if((S|0)==0){break}Q=c[(c[191558]|0)+8>>2]|0;fc[Q&127](S)|0;break}if(!U){break}if((a[607928]&1)!=0){U=c[191244]|0;S=(U|0)!=0?U:c[q>>2]|0;a3(13792,21,1,S|0)|0;S=c[191244]|0;U=(S|0)!=0?S:c[q>>2]|0;aZ(U|0)|0}a[764679]=0;U=c[191561]|0;if((U|0)==0){break}if((a[707057]&1)!=0){break}if(fc[c[(c[191558]|0)+12>>2]&127](U)|0){break}U=c[191244]|0;S=(U|0)!=0?U:c[q>>2]|0;a3(13632,81,1,S|0)|0;S=c[191244]|0;U=(S|0)!=0?S:c[q>>2]|0;aZ(U|0)|0;a[607929]=0}}while(0);a[9720]=V&1;a[766536]=R;do{if((a[766263]&1)==0){R=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,36)|0;V=766424;if((c[V>>2]&0|R&1|0)==0&(c[V+4>>2]&16|0)==0){W=0;X=0;break}W=a[766544]&1^1;X=1}else{W=0;X=0}}while(0);a[764680]=W;a[766544]=X;do{if((a[766263]&1)==0){X=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,33)|0;W=766424;if((c[W>>2]&0|X&1|0)==0&(c[W+4>>2]&2|0)==0){Y=0;Z=0;break}Y=a[766552]&1^1;Z=1}else{Y=0;Z=0}}while(0);a[764680]=(a[764680]&1|Y|0)!=0|0;a[766552]=Z;do{if((a[766263]&1)==0){Z=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,29)|0;Y=766424;if((c[Y>>2]&536870912|Z&1|0)==0&(c[Y+4>>2]&0|0)==0){_=0;n=896;break}if((a[766592]&1)!=0){_=1;n=896;break}a[505592]=a[505592]&1^1;a[766257]=a[706968]&1;a[766258]=0;gC();Y=c[176743]|0;do{if((Y|0)!=0){if((a[766257]&1)!=0){break}fx[Y&127]()}}while(0);gD();if((a[766259]&1)!=0){c[191562]=0}if((a[766260]&1)!=0){c[191561]=0}if((a[766261]&1)!=0){c[191563]=0}a[766259]=0;a[766260]=0;a[766261]=0;gB();a[766257]=0;Y=c[191560]|0;if((Y|0)!=0){e9[c[Y+4>>2]&2047](c[191563]|0)}a[766592]=1;if((a[764679]&1)==0){break}fU()}else{_=0;n=896}}while(0);if((n|0)==896){a[766592]=_}do{if((a[764679]&1)!=0){if((a[764680]&1)!=0){break}i=d;return}}while(0);_=a[766263]|0;if((_&1)==0){Y=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,25)|0;Z=766424;$=(c[Z>>2]&33554432|Y&1|0)!=0|(c[Z+4>>2]&0|0)!=0;aa=a[766263]|0}else{$=0;aa=_}if((aa&1)==0){aa=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,26)|0;_=766424;ab=(c[_>>2]&67108864|aa&1|0)!=0|(c[_+4>>2]&0|0)!=0}else{ab=0}do{if($){if((a[766608]&1)!=0){n=915;break}_=a[766264]&1;a[766264]=_^1;aa=_<<24>>24==0;Z=c[191562]|0;if((a[607930]&1)!=0&(Z|0)!=0){if((a[505608]&1)==0){n=910}else{if((a[702293]&1)==0){ac=aa}else{n=910}}if((n|0)==910){ac=1}fa[c[(c[191559]|0)+8>>2]&127](Z,ac)}Z=c[191561]|0;if((a[607929]&1)!=0&(Z|0)!=0){fa[c[(c[191558]|0)+16>>2]&127](Z,(_&a[526216])<<24>>24==0)}c[176758]=aa?c[176759]|0:c[176760]|0}else{n=915}}while(0);do{if((n|0)==915){if((a[766600]&1|0)==(ab&1|0)){break}a[766264]=ab&1;ac=c[191562]|0;if((a[607930]&1)!=0&(ac|0)!=0){if((a[505608]&1)==0){n=919}else{if((a[702293]&1)==0){ad=ab}else{n=919}}if((n|0)==919){ad=1}fa[c[(c[191559]|0)+8>>2]&127](ac,ad)}ac=c[191561]|0;if((a[607929]&1)!=0&(ac|0)!=0){fa[c[(c[191558]|0)+16>>2]&127](ac,(a[526216]&1)==0|ab)}c[176758]=ab?c[176759]|0:c[176760]|0}}while(0);a[766608]=$&1;a[766600]=ab&1;do{if((a[766263]&1)==0){ab=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,31)|0;$=766424;if((c[$>>2]&-2147483648|ab&1|0)==0&(c[$+4>>2]&0|0)==0){ae=0;break}if((a[766464]&1)!=0){ae=1;break}$=e|0;ab=(c[175548]|0)+1|0;c[175548]=ab;ad=c[189113]|0;if((ad|0)==0){af=ab}else{ab=ad+4|0;ac=c[ab>>2]|0;if(ac>>>0>1){aa=ad|0;_=1;Z=ac;while(1){ac=c[(c[aa>>2]|0)+(_<<2)>>2]|0;if((ac|0)==0){ag=Z}else{v_(c[ac+8>>2]|0);v_(c[(c[aa>>2]|0)+(_<<2)>>2]|0);c[(c[aa>>2]|0)+(_<<2)>>2]=0;ag=c[ab>>2]|0}ac=_+1|0;if(ac>>>0<ag>>>0){_=ac;Z=ag}else{break}}}c[ab>>2]=1;Z=ad+12|0;v_(c[Z>>2]|0);c[Z>>2]=0;af=c[175548]|0}bN($|0,256,38928,(E=i,i=i+8|0,c[E>>2]=af,E)|0)|0;i=E;Z=c[189113]|0;L1299:do{if((Z|0)!=0){_=Z+4|0;if((c[_>>2]|0)>>>0>=(c[Z+8>>2]|0)>>>0){break}aa=vZ(12)|0;do{if((aa|0)!=0){if((c[aa-4>>2]&3|0)==0){break}v3(aa|0,0,12)}}while(0);c[aa+4>>2]=1;c[aa>>2]=180;ac=dn($|0)|0;Y=c[_>>2]|0;c[aa+8>>2]=ac;ac=Z|0;c[(c[ac>>2]|0)+(Y<<2)>>2]=aa;Y=c[_>>2]|0;c[_>>2]=Y+1;if(Y>>>0>1){ah=Y}else{break}while(1){Y=ah>>>1;W=c[ac>>2]|0;X=W+(Y<<2)|0;V=c[X>>2]|0;R=c[W+(ah<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[V+4>>2]|0)>>>0){break L1299}c[X>>2]=R;c[(c[ac>>2]|0)+(ah<<2)>>2]=V;if(ah>>>0>3){ah=Y}else{break}}}}while(0);if((a[607928]&1)==0){ae=1;break}Z=c[191244]|0;ad=(Z|0)!=0?Z:c[q>>2]|0;eb(ad|0,47400,(E=i,i=i+8|0,c[E>>2]=$,E)|0)|0;i=E;ad=c[191244]|0;Z=(ad|0)!=0?ad:c[q>>2]|0;aZ(Z|0)|0;ae=1}else{ae=0}}while(0);a[766464]=ae;do{if((a[766263]&1)==0){ae=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,32)|0;ah=766424;if((c[ah>>2]&0|ae&1|0)==0&(c[ah+4>>2]&1|0)==0){ai=0;break}if((a[766472]&1)!=0){ai=1;break}ah=e|0;ae=c[175548]|0;if((ae|0)==0){aj=0}else{af=ae-1|0;c[175548]=af;aj=af}af=c[189113]|0;if((af|0)==0){ak=aj}else{ae=af+4|0;ag=c[ae>>2]|0;if(ag>>>0>1){Z=af|0;ad=1;ab=ag;while(1){ag=c[(c[Z>>2]|0)+(ad<<2)>>2]|0;if((ag|0)==0){al=ab}else{v_(c[ag+8>>2]|0);v_(c[(c[Z>>2]|0)+(ad<<2)>>2]|0);c[(c[Z>>2]|0)+(ad<<2)>>2]=0;al=c[ae>>2]|0}ag=ad+1|0;if(ag>>>0<al>>>0){ad=ag;ab=al}else{break}}}c[ae>>2]=1;ab=af+12|0;v_(c[ab>>2]|0);c[ab>>2]=0;ak=c[175548]|0}bN(ah|0,256,38928,(E=i,i=i+8|0,c[E>>2]=ak,E)|0)|0;i=E;ab=c[189113]|0;L1330:do{if((ab|0)!=0){ad=ab+4|0;if((c[ad>>2]|0)>>>0>=(c[ab+8>>2]|0)>>>0){break}Z=vZ(12)|0;do{if((Z|0)!=0){if((c[Z-4>>2]&3|0)==0){break}v3(Z|0,0,12)}}while(0);c[Z+4>>2]=1;c[Z>>2]=180;$=dn(ah|0)|0;ag=c[ad>>2]|0;c[Z+8>>2]=$;$=ab|0;c[(c[$>>2]|0)+(ag<<2)>>2]=Z;ag=c[ad>>2]|0;c[ad>>2]=ag+1;if(ag>>>0>1){am=ag}else{break}while(1){ag=am>>>1;ac=c[$>>2]|0;_=ac+(ag<<2)|0;aa=c[_>>2]|0;Y=c[ac+(am<<2)>>2]|0;if((c[Y+4>>2]|0)>>>0<=(c[aa+4>>2]|0)>>>0){break L1330}c[_>>2]=Y;c[(c[$>>2]|0)+(am<<2)>>2]=aa;if(am>>>0>3){am=ag}else{break}}}}while(0);if((a[607928]&1)==0){ai=1;break}ab=c[191244]|0;af=(ab|0)!=0?ab:c[q>>2]|0;eb(af|0,47400,(E=i,i=i+8|0,c[E>>2]=ah,E)|0)|0;i=E;af=c[191244]|0;ab=(af|0)!=0?af:c[q>>2]|0;aZ(ab|0)|0;ai=1}else{ai=0}}while(0);a[766472]=ai;ai=(c[189119]|0)==0;do{if((a[766263]&1)==0){am=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,28)|0;ak=766424;if((c[ak>>2]&268435456|am&1|0)==0&(c[ak+4>>2]&0|0)==0){an=0;break}if((a[766504]&1)!=0){an=1;break}f0();an=1}else{an=0}}while(0);a[766504]=an&1;if(ai){do{if((a[766263]&1)==0){ai=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,27)|0;ak=766424;am=(c[ak>>2]&134217728|ai&1|0)!=0|(c[ak+4>>2]&0|0)!=0;if(an|am^1){ao=am;break}if((a[766512]&1)!=0){ao=am;break}f_();ao=am}else{ao=0}}while(0);a[766512]=ao&1}if((a[756472]&1)!=0){ao=c[176768]|0;if(fX((c[176767]|0)+(ao<<1)|0,(c[176769]|0)-ao|0)|0){ap=a[607929]&1}else{ap=0}a[607929]=ap}a[756472]=0;do{if(a[9712]|0){if((c[189115]|0)==0){break}L1366:do{if((a[766263]&1)==0){ap=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,33)|0;ao=766424;if((c[ao>>2]&0|ap&1|0)==0&(c[ao+4>>2]&2|0)==0){n=1027;break}ao=c[189113]|0;ap=ao+4|0;an=c[ap>>2]|0;if(an>>>0>1){am=ao|0;ak=1;ai=an;while(1){an=c[(c[am>>2]|0)+(ak<<2)>>2]|0;if((an|0)==0){aq=ai}else{v_(c[an+8>>2]|0);v_(c[(c[am>>2]|0)+(ak<<2)>>2]|0);c[(c[am>>2]|0)+(ak<<2)>>2]=0;aq=c[ap>>2]|0}an=ak+1|0;if(an>>>0<aq>>>0){ak=an;ai=aq}else{break}}}c[ap>>2]=1;ai=ao+12|0;v_(c[ai>>2]|0);c[ai>>2]=0;ai=c[189115]|0;ak=ai+12|0;am=c[ak>>2]|0;an=am;al=ai+28|0;do{if((a[al]&1)==0){aj=ai+16|0;e=ai+8|0;ab=c[e>>2]|0;af=(c[aj>>2]|0)-1&ab;c[aj>>2]=af;ae=ai+20|0;$=c[ae>>2]|0;if((af|0)==($|0)){c[aj>>2]=af+1&ab;ad=c[189113]|0;Z=ad+4|0;if((c[Z>>2]|0)>>>0>=(c[ad+8>>2]|0)>>>0){break L1366}ag=vZ(12)|0;do{if((ag|0)!=0){if((c[ag-4>>2]&3|0)==0){break}v3(ag|0,0,12)}}while(0);c[ag+4>>2]=0;c[ag>>2]=30;aa=dn(14240)|0;Y=c[Z>>2]|0;c[ag+8>>2]=aa;aa=ad|0;c[(c[aa>>2]|0)+(Y<<2)>>2]=ag;Y=c[Z>>2]|0;c[Z>>2]=Y+1;if(Y>>>0>1){ar=Y}else{break L1366}while(1){Y=ar>>>1;_=c[aa>>2]|0;ac=_+(Y<<2)|0;V=c[ac>>2]|0;R=c[_+(ar<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[V+4>>2]|0)>>>0){break L1366}c[ac>>2]=R;c[(c[aa>>2]|0)+(ar<<2)>>2]=V;if(ar>>>0>3){ar=Y}else{break L1366}}}else{aa=ai|0;Z=(c[aa>>2]|0)+(af<<3)|0;ag=c[Z>>2]|0;ad=c[Z+4>>2]|0;if((ag|0)==0&(ad|0)==0){as=af;at=$;au=ab}else{Z=ad;ad=ag;ag=am;while(1){Y=ag+(Z<<2)|0;c[Y>>2]=c[Y>>2]^ad;av=c[e>>2]|0;aw=(c[aj>>2]|0)-1&av;c[aj>>2]=aw;Y=(c[aa>>2]|0)+(aw<<3)|0;V=c[Y>>2]|0;R=c[Y+4>>2]|0;if((V|0)==0&(R|0)==0){break}Z=R;ad=V;ag=c[ak>>2]|0}as=aw;at=c[ae>>2]|0;au=av}if((as|0)!=(at|0)){break}c[aj>>2]=at+1&au;break}}else{a[al]=0}}while(0);a[756472]=1;al=c[176769]|0;c[176768]=al;L1400:do{if((c[176757]|0)!=0){ak=0;am=al;while(1){ai=b[(c[176766]|0)+((ak|1)<<1)>>1]|0;ao=am-1|0;c[176768]=ao;b[(c[176767]|0)+(ao<<1)>>1]=ai;ai=b[(c[176766]|0)+(ak<<1)>>1]|0;ao=(c[176768]|0)-1|0;c[176768]=ao;b[(c[176767]|0)+(ao<<1)>>1]=ai;ai=ak+2|0;if(ai>>>0>=(c[176757]|0)>>>0){break L1400}ak=ai;am=c[176768]|0}}}while(0);c[176757]=0;al=c[189113]|0;am=al+4|0;L1405:do{if((c[am>>2]|0)>>>0<(c[al+8>>2]|0)>>>0){ak=(a[764679]&1)!=0?1:30;aj=vZ(12)|0;do{if((aj|0)!=0){if((c[aj-4>>2]&3|0)==0){break}v3(aj|0,0,12)}}while(0);c[aj+4>>2]=0;c[aj>>2]=ak;ae=dn(14336)|0;ai=c[am>>2]|0;c[aj+8>>2]=ae;ae=al|0;c[(c[ae>>2]|0)+(ai<<2)>>2]=aj;ai=c[am>>2]|0;c[am>>2]=ai+1;if(ai>>>0>1){ax=ai}else{break}while(1){ai=ax>>>1;ao=c[ae>>2]|0;ap=ao+(ai<<2)|0;ag=c[ap>>2]|0;ad=c[ao+(ax<<2)>>2]|0;if((c[ad+4>>2]|0)>>>0<=(c[ag+4>>2]|0)>>>0){break L1405}c[ap>>2]=ad;c[(c[ae>>2]|0)+(ax<<2)>>2]=ag;if(ax>>>0>3){ax=ai}else{break}}}}while(0);am=c[37186]|0;al=c[189117]|0;fr[am&63](an,al)|0;al=c[189119]|0;if((al|0)==0){break}a[al+33|0]=1;am=al+20|0;ae=c[am>>2]|0;aj=c[al+12>>2]|0;do{if(ae>>>0<2){ak=c[aj>>2]|0;ai=al+28|0;if((ak|0)!=(c[ai>>2]|0)){ay=ai;n=1015;break}c[am>>2]=0;ag=c[al>>2]|0;eo(ag|0,ak|0,0)|0;az=ai}else{ay=al+28|0;n=1015}}while(0);if((n|0)==1015){an=ae-((a[al+32|0]&1)!=0?1:2)&c[al+16>>2];c[am>>2]=an;ai=c[al>>2]|0;ak=c[aj+(an<<2)>>2]|0;eo(ai|0,ak|0,0)|0;az=ay}ak=al|0;ai=cb(c[ak>>2]|0)|0;an=c[az>>2]|0;if((ai|0)>(an|0)){break}ai=c[ak>>2]|0;if((a[al+24|0]&1)==0){eo(ai|0,16,0)|0;ag=c[37206]|0;ad=al+4|0;ap=c[ad>>2]|0;ao=al+8|0;Z=c[ao>>2]|0;fr[ag&63](ap,Z)|0;Z=c[ad>>2]|0;ad=c[ao>>2]|0;ao=c[ak>>2]|0;a3(Z|0,1,ad|0,ao|0)|0;break}else{eo(ai|0,an|0,0)|0;break}}else{n=1027}}while(0);do{if((n|0)==1027){ah=c[150945]|0;an=(((c[191630]|0)+1|0)>>>0)%(((ah|0)!=0?ah:1)>>>0)|0;c[191630]=an;if(!((an|0)==0|(c[189119]|0)!=0)){break}an=c[37206]|0;ah=c[189116]|0;ai=c[189117]|0;fr[an&63](ah,ai)|0;ai=c[189115]|0;ah=c[189116]|0;an=ai+12|0;ao=c[an>>2]|0;ad=ah;Z=ai+16|0;ak=c[Z>>2]|0;c[Z>>2]=ak+1;ap=ai|0;ag=(c[ap>>2]|0)+(ak<<3)|0;c[ag>>2]=0;c[ag+4>>2]=0;ag=ai+8|0;ak=c[ag>>2]|0;aa=c[Z>>2]&ak;c[Z>>2]=aa;e=ai+20|0;ab=(aa|0)==(c[e>>2]|0);$=ai+24|0;af=c[$>>2]|0;if((af|0)==0){aA=ab;aB=aa;aC=ak;aD=0}else{V=0;R=0;Y=ab;ab=aa;aa=ak;ak=af;while(1){af=R;ac=c[ao+(af<<2)>>2]|0;_=c[ad+(af<<2)>>2]|0;if((ac|0)==(_|0)){aE=Y;aF=ab;aG=aa;aH=ak}else{af=(c[ap>>2]|0)+(ab<<3)|0;c[af>>2]=_^ac;c[af+4>>2]=R;af=c[ag>>2]|0;ac=(c[Z>>2]|0)+1&af;c[Z>>2]=ac;aE=(ac|0)==(c[e>>2]|0)|Y;aF=ac;aG=af;aH=c[$>>2]|0}af=wc(R,V,1,0)|0;ac=G;_=0;if(ac>>>0<_>>>0|ac>>>0==_>>>0&af>>>0<aH>>>0){V=ac;R=af;Y=aE;ab=aF;aa=aG;ak=aH}else{aA=aE;aB=aF;aC=aG;aD=aH;break}}}do{if(aA){ak=aB+1&aC;c[e>>2]=ak;aa=c[ap>>2]|0;ab=aa+(ak<<3)|0;if((c[ab>>2]|0)==0&(c[ab+4>>2]|0)==0){break}else{aI=ak}do{aI=aI+1&aC;c[e>>2]=aI;ak=aa+(aI<<3)|0;}while(!((c[ak>>2]|0)==0&(c[ak+4>>2]|0)==0))}}while(0);e=c[an>>2]|0;ap=aD<<2;v6(e|0,ah|0,ap)|0;a[ai+28|0]=1}}while(0);e9[c[37202]&2047]((a[756472]&1)!=0?92:86);e9[c[37200]&2047]((a[756472]&1)!=0?38:22)}else{a[9712]=1}}while(0);L1444:do{if((a[766263]&1)==0){aD=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,47)|0;aI=766424;aC=(c[aI>>2]&0|aD&1|0)!=0|(c[aI+4>>2]&32768|0)!=0;a[764681]=aC&1;if(!aC){break}aC=c[189113]|0;aI=aC+4|0;aD=c[aI>>2]|0;if(aD>>>0>1){aB=aC|0;aA=1;aH=aD;while(1){aD=c[(c[aB>>2]|0)+(aA<<2)>>2]|0;if((aD|0)==0){aJ=aH}else{v_(c[aD+8>>2]|0);v_(c[(c[aB>>2]|0)+(aA<<2)>>2]|0);c[(c[aB>>2]|0)+(aA<<2)>>2]=0;aJ=c[aI>>2]|0}aD=aA+1|0;if(aD>>>0<aJ>>>0){aA=aD;aH=aJ}else{break}}}c[aI>>2]=1;aH=aC+12|0;v_(c[aH>>2]|0);c[aH>>2]=0;aH=c[189113]|0;aA=aH+4|0;if((c[aA>>2]|0)>>>0>=(c[aH+8>>2]|0)>>>0){break}aB=(a[756472]&1)!=0?14624:14488;aD=vZ(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}v3(aD|0,0,12)}}while(0);c[aD+4>>2]=0;c[aD>>2]=30;aC=dn(aB|0)|0;aI=c[aA>>2]|0;c[aD+8>>2]=aC;aC=aH|0;c[(c[aC>>2]|0)+(aI<<2)>>2]=aD;aI=c[aA>>2]|0;c[aA>>2]=aI+1;if(aI>>>0>1){aK=aI}else{break}while(1){aI=aK>>>1;aG=c[aC>>2]|0;aF=aG+(aI<<2)|0;aE=c[aF>>2]|0;az=c[aG+(aK<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[aE+4>>2]|0)>>>0){break L1444}c[aF>>2]=az;c[(c[aC>>2]|0)+(aK<<2)>>2]=aE;if(aK>>>0>3){aK=aI}else{break}}}else{a[764681]=0}}while(0);do{if((a[766263]&1)==0){aK=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,34)|0;aJ=766424;if((c[aJ>>2]&0|aK&1|0)==0&(c[aJ+4>>2]&4|0)==0){aL=0;aM=0;break}aL=(a[766568]&1)==0;aM=1}else{aL=0;aM=0}}while(0);do{if((a[760576]&1)==0){if(!aL){break}aJ=j|0;aK=k|0;if((c[189119]|0)==0){c[150945]=1;aC=c[175548]|0;if((aC|0)==0){bN(aJ|0,4096,16352,(E=i,i=i+8|0,c[E>>2]=756480,E)|0)|0;i=E}else{bN(aJ|0,4096,16432,(E=i,i=i+16|0,c[E>>2]=756480,c[E+8>>2]=aC,E)|0)|0;i=E}bN(aK|0,4096,16168,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;c[189119]=hc(aJ,1)|0;aC=c[189113]|0;aA=aC+4|0;aD=c[aA>>2]|0;if(aD>>>0>1){aH=aC|0;aB=1;aI=aD;while(1){aD=c[(c[aH>>2]|0)+(aB<<2)>>2]|0;if((aD|0)==0){aN=aI}else{v_(c[aD+8>>2]|0);v_(c[(c[aH>>2]|0)+(aB<<2)>>2]|0);c[(c[aH>>2]|0)+(aB<<2)>>2]=0;aN=c[aA>>2]|0}aD=aB+1|0;if(aD>>>0<aN>>>0){aB=aD;aI=aN}else{break}}}c[aA>>2]=1;aI=aC+12|0;v_(c[aI>>2]|0);c[aI>>2]=0;aI=c[189113]|0;aB=aI+4|0;L1535:do{if((c[aB>>2]|0)>>>0<(c[aI+8>>2]|0)>>>0){aH=(c[189119]|0)!=0?aK:15992;aD=vZ(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}v3(aD|0,0,12)}}while(0);c[aD+4>>2]=1;c[aD>>2]=180;ai=dn(aH|0)|0;ah=c[aB>>2]|0;c[aD+8>>2]=ai;ai=aI|0;c[(c[ai>>2]|0)+(ah<<2)>>2]=aD;ah=c[aB>>2]|0;c[aB>>2]=ah+1;if(ah>>>0>1){aO=ah}else{break}while(1){ah=aO>>>1;an=c[ai>>2]|0;aE=an+(ah<<2)|0;az=c[aE>>2]|0;aF=c[an+(aO<<2)>>2]|0;if((c[aF+4>>2]|0)>>>0<=(c[az+4>>2]|0)>>>0){break L1535}c[aE>>2]=aF;c[(c[ai>>2]|0)+(aO<<2)>>2]=az;if(aO>>>0>3){aO=ah}else{break}}}}while(0);if((c[189119]|0)==0){aB=c[191244]|0;aI=(aB|0)!=0?aB:c[q>>2]|0;a3(15320,51,1,aI|0)|0;aI=c[191244]|0;aB=(aI|0)!=0?aI:c[q>>2]|0;aZ(aB|0)|0;break}if((a[607928]&1)==0){break}aB=c[191244]|0;aI=(aB|0)!=0?aB:c[q>>2]|0;eb(aI|0,15856,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;aI=c[191244]|0;aB=(aI|0)!=0?aI:c[q>>2]|0;aZ(aB|0)|0;break}else{aB=c[189113]|0;aI=aB+4|0;aK=c[aI>>2]|0;if(aK>>>0>1){aC=aB|0;aA=1;ai=aK;while(1){aK=c[(c[aC>>2]|0)+(aA<<2)>>2]|0;if((aK|0)==0){aP=ai}else{v_(c[aK+8>>2]|0);v_(c[(c[aC>>2]|0)+(aA<<2)>>2]|0);c[(c[aC>>2]|0)+(aA<<2)>>2]=0;aP=c[aI>>2]|0}aK=aA+1|0;if(aK>>>0<aP>>>0){aA=aK;ai=aP}else{break}}}c[aI>>2]=1;ai=aB+12|0;v_(c[ai>>2]|0);c[ai>>2]=0;ai=c[189113]|0;aA=ai+4|0;L1503:do{if((c[aA>>2]|0)>>>0<(c[ai+8>>2]|0)>>>0){aC=vZ(12)|0;do{if((aC|0)!=0){if((c[aC-4>>2]&3|0)==0){break}v3(aC|0,0,12)}}while(0);c[aC+4>>2]=2;c[aC>>2]=180;aJ=dn(16672)|0;aK=c[aA>>2]|0;c[aC+8>>2]=aJ;aJ=ai|0;c[(c[aJ>>2]|0)+(aK<<2)>>2]=aC;aK=c[aA>>2]|0;c[aA>>2]=aK+1;if(aK>>>0>1){aQ=aK}else{break}while(1){aK=aQ>>>1;aD=c[aJ>>2]|0;aH=aD+(aK<<2)|0;ah=c[aH>>2]|0;az=c[aD+(aQ<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1503}c[aH>>2]=az;c[(c[aJ>>2]|0)+(aQ<<2)>>2]=ah;if(aQ>>>0>3){aQ=aK}else{break}}}}while(0);if((a[607928]&1)!=0){aA=c[191244]|0;ai=(aA|0)!=0?aA:c[q>>2]|0;a3(16560,34,1,ai|0)|0;ai=c[191244]|0;aA=(ai|0)!=0?ai:c[q>>2]|0;aZ(aA|0)|0}aA=c[189119]|0;if((aA|0)!=0){ai=c[aA>>2]|0;if((ai|0)!=0){aR(ai|0)|0}v_(c[aA+4>>2]|0);v_(c[aA+12>>2]|0);v_(aA)}c[189119]=0;break}}else{if(!((a[764675]&1)!=0|aL)){break}aA=c[189113]|0;ai=aA+4|0;L1472:do{if((c[ai>>2]|0)>>>0<(c[aA+8>>2]|0)>>>0){aB=vZ(12)|0;do{if((aB|0)!=0){if((c[aB-4>>2]&3|0)==0){break}v3(aB|0,0,12)}}while(0);c[aB+4>>2]=1;c[aB>>2]=180;aI=dn(15104)|0;aJ=c[ai>>2]|0;c[aB+8>>2]=aI;aI=aA|0;c[(c[aI>>2]|0)+(aJ<<2)>>2]=aB;aJ=c[ai>>2]|0;c[ai>>2]=aJ+1;if(aJ>>>0>1){aS=aJ}else{break}while(1){aJ=aS>>>1;aC=c[aI>>2]|0;aK=aC+(aJ<<2)|0;ah=c[aK>>2]|0;az=c[aC+(aS<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1472}c[aK>>2]=az;c[(c[aI>>2]|0)+(aS<<2)>>2]=ah;if(aS>>>0>3){aS=aJ}else{break}}}}while(0);if((a[607928]&1)!=0){ai=c[191244]|0;aA=(ai|0)!=0?ai:c[q>>2]|0;a3(14800,33,1,aA|0)|0;aA=c[191244]|0;ai=(aA|0)!=0?aA:c[q>>2]|0;aZ(ai|0)|0}ai=c[189119]|0;if((ai|0)!=0){aA=c[ai>>2]|0;if((aA|0)!=0){aR(aA|0)|0}v_(c[ai+4>>2]|0);v_(c[ai+12>>2]|0);v_(ai)}c[189119]=0;a[764675]=0;a[760576]=0}}while(0);a[766568]=aM;aM=f|0;L1550:do{if((c[191201]|0)!=0){if((c[(c[191559]|0)+20>>2]|0)==0){break}f=a[766263]|0;if((f&1)==0){aS=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,38)|0;aL=766424;aT=(c[aL>>2]&0|aS&1|0)!=0|(c[aL+4>>2]&64|0)!=0;aU=a[766263]|0}else{aT=0;aU=f}if((aU&1)==0){f=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,39)|0;aL=766424;aV=(c[aL>>2]&0|f&1|0)!=0|(c[aL+4>>2]&128|0)!=0}else{aV=0}do{if(aT){if((a[766488]&1)!=0){n=1120;break}aL=c[191201]|0;f=(((c[191202]|0)+1|0)>>>0)%((c[aL+4>>2]|0)>>>0)|0;c[191202]=f;aW=f;aX=aL;n=1125}else{n=1120}}while(0);do{if((n|0)==1120){if(!aV){break}if((a[766480]&1)!=0){break}aL=c[191202]|0;if((aL|0)==0){f=c[191201]|0;aS=(c[f+4>>2]|0)-1|0;c[191202]=aS;aW=aS;aX=f;n=1125;break}else{f=aL-1|0;c[191202]=f;aW=f;aX=c[191201]|0;n=1125;break}}}while(0);do{if((n|0)==1125){f=c[(c[aX>>2]|0)+(aW<<3)>>2]|0;aL=cf(f|0,46)|0;if((aL|0)==0){break L1550}do{if((cJ(aL|0,18096)|0)==0){aY=2}else{if((cJ(aL|0,17920)|0)==0){aY=0;break}if((cJ(aL|0,17792)|0)==0){aY=0}else{break L1550}}}while(0);aL=c[189113]|0;aS=aL+4|0;aQ=c[aS>>2]|0;if(aQ>>>0>1){aP=aL|0;aO=1;aN=aQ;while(1){aQ=c[(c[aP>>2]|0)+(aO<<2)>>2]|0;if((aQ|0)==0){a_=aN}else{v_(c[aQ+8>>2]|0);v_(c[(c[aP>>2]|0)+(aO<<2)>>2]|0);c[(c[aP>>2]|0)+(aO<<2)>>2]=0;a_=c[aS>>2]|0}aQ=aO+1|0;if(aQ>>>0<a_>>>0){aO=aQ;aN=a_}else{break}}}c[aS>>2]=1;aN=aL+12|0;v_(c[aN>>2]|0);c[aN>>2]=0;aN=c[191202]|0;bN(aM|0,512,17368,(E=i,i=i+16|0,c[E>>2]=aN,c[E+8>>2]=f,E)|0)|0;i=E;aN=c[189113]|0;aO=aN+4|0;L1584:do{if((c[aO>>2]|0)>>>0<(c[aN+8>>2]|0)>>>0){aP=vZ(12)|0;do{if((aP|0)!=0){if((c[aP-4>>2]&3|0)==0){break}v3(aP|0,0,12)}}while(0);c[aP+4>>2]=1;c[aP>>2]=120;aQ=dn(aM|0)|0;k=c[aO>>2]|0;c[aP+8>>2]=aQ;aQ=aN|0;c[(c[aQ>>2]|0)+(k<<2)>>2]=aP;k=c[aO>>2]|0;c[aO>>2]=k+1;if(k>>>0>1){a$=k}else{break}while(1){k=a$>>>1;j=c[aQ>>2]|0;ai=j+(k<<2)|0;aA=c[ai>>2]|0;aI=c[j+(a$<<2)>>2]|0;if((c[aI+4>>2]|0)>>>0<=(c[aA+4>>2]|0)>>>0){break L1584}c[ai>>2]=aI;c[(c[aQ>>2]|0)+(a$<<2)>>2]=aA;if(a$>>>0>3){a$=k}else{break}}}}while(0);if((a[607928]&1)!=0){aO=c[191244]|0;aN=(aO|0)!=0?aO:c[q>>2]|0;eb(aN|0,17144,(E=i,i=i+8|0,c[E>>2]=f,E)|0)|0;i=E;aN=c[191244]|0;aO=(aN|0)!=0?aN:c[q>>2]|0;aZ(aO|0)|0}if(fg[c[(c[191559]|0)+20>>2]&63](c[191562]|0,aY,f)|0){break}aO=c[191244]|0;aN=(aO|0)!=0?aO:c[q>>2]|0;a3(16888,44,1,aN|0)|0;aN=c[191244]|0;aO=(aN|0)!=0?aN:c[q>>2]|0;aZ(aO|0)|0}}while(0);a[766488]=aT&1;a[766480]=aV&1}}while(0);if((c[191220]|0)!=0){aV=a[766263]|0;if((aV&1)==0){aT=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,40)|0;aY=766424;a0=(c[aY>>2]&0|aT&1|0)!=0|(c[aY+4>>2]&256|0)!=0;a1=a[766263]|0}else{a0=0;a1=aV}if((a1&1)==0){aV=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,41)|0;aY=766424;a2=(c[aY>>2]&0|aV&1|0)!=0|(c[aY+4>>2]&512|0)!=0;a4=a[766263]|0}else{a2=0;a4=a1}if((a4&1)==0){a4=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,42)|0;a1=766424;a5=(c[a1>>2]&0|a4&1|0)!=0|(c[a1+4>>2]&1024|0)!=0}else{a5=0}do{if(a0){if((a[766648]&1)!=0){n=1156;break}a1=c[191220]|0;a4=a1+4|0;c[a4>>2]=(((c[a4>>2]|0)+1|0)>>>0)%((c[a1+8>>2]|0)>>>0)|0;hx(a1)}else{n=1156}}while(0);L1614:do{if((n|0)==1156){do{if(a2){if((a[766640]&1)!=0){break}a1=c[191220]|0;a4=a1+4|0;aY=c[a4>>2]|0;if((aY|0)==0){a6=c[a1+8>>2]|0}else{a6=aY}c[a4>>2]=a6-1;hx(a1);break L1614}}while(0);if(!a5){break}if((a[766632]&1)!=0){break}a1=c[191220]|0;a4=a1|0;aY=(c[a4>>2]|0)+((c[a1+4>>2]|0)*12|0)+4|0;a[aY]=a[aY]&1^1;fx[c[37232]&127]();aY=a1+8|0;aV=c[aY>>2]|0;if((aV|0)!=0){aT=0;E=0;a$=aV;while(1){aV=c[a4>>2]|0;if((a[aV+(E*12|0)+4|0]&1)==0){a7=aT;a8=a$}else{fw[c[37230]&127](aT,1,c[aV+(E*12|0)+8>>2]|0);a7=aT+1|0;a8=c[aY>>2]|0}aV=E+1|0;if(aV>>>0<a8>>>0){aT=a7;E=aV;a$=a8}else{break}}}hx(a1)}}while(0);a[766640]=a2&1;a[766648]=a0&1;a[766632]=a5&1}if((c[176732]|0)!=0){a5=a[766263]|0;if((a5&1)==0){a0=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,52)|0;a2=766424;a9=(c[a2>>2]&0|a0&1|0)!=0|(c[a2+4>>2]&1048576|0)!=0;ba=a[766263]|0}else{a9=0;ba=a5}if((ba&1)==0){ba=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,53)|0;a5=766424;bb=(c[a5>>2]&0|ba&1|0)!=0|(c[a5+4>>2]&2097152|0)!=0}else{bb=0}do{if(a9){if((a[766624]&1)!=0){n=1177;break}f4((fu[c[176729]&31]()|0)^1,1)}else{n=1177}}while(0);do{if((n|0)==1177){if(!bb){break}if((a[766616]&1)!=0){break}a5=fu[c[176732]&31]()|0;ba=fu[c[176730]&31]()|0;if((a5|0)==(-1|0)|(a5|0)==0){a2=c[191244]|0;a0=(a2|0)!=0?a2:c[q>>2]|0;a3(18320,59,1,a0|0)|0;a0=c[191244]|0;a2=(a0|0)!=0?a0:c[q>>2]|0;aZ(a2|0)|0;break}if(ba>>>0<a5>>>0){bc=((ba+1|0)>>>0)%((a5+1|0)>>>0)|0}else{bc=0}f5(bc)}}while(0);a[766624]=a9&1;a[766616]=bb&1}do{if((a[766263]&1)==0){bb=fr[c[(c[191560]|0)+12>>2]&63](c[191563]|0,37)|0;a9=766424;if((c[a9>>2]&0|bb&1|0)==0&(c[a9+4>>2]&32|0)==0){bd=0;break}if((a[766528]&1)!=0){bd=1;break}f2();bd=1}else{bd=0}}while(0);a[766528]=bd;i=d;return}function ga(a,d){a=a|0;d=d|0;var e=0;e=(c[176768]|0)-1|0;c[176768]=e;b[(c[176767]|0)+(e<<1)>>1]=d;d=(c[176768]|0)-1|0;c[176768]=d;b[(c[176767]|0)+(d<<1)>>1]=a;return}function gb(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0;b=i;i=i+4096|0;d=b|0;L1665:do{if((a[764678]&1)!=0){switch(c[153016]|0){case 0:{e=a[607928]|0;if((e&1)==0){f=e}else{e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;a3(20120,32,1,g|0)|0;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0;f=a[607928]|0}if((f&1)==0){h=f}else{e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;eb(g|0,19968,(j=i,i=i+8|0,c[j>>2]=648938,j)|0)|0;i=j;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0;h=a[607928]|0}if((h&1)!=0){e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;eb(g|0,19872,(j=i,i=i+8|0,c[j>>2]=653034,j)|0)|0;i=j;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0}gj(648938,0);gj(653034,1);break L1665;break};case 4:{e=a[607928]|0;if((e&1)==0){k=e}else{e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;a3(18720,40,1,g|0)|0;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0;k=a[607928]|0}if((k&1)==0){l=k}else{e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;eb(g|0,18624,(j=i,i=i+8|0,c[j>>2]=661226,j)|0)|0;i=j;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0;l=a[607928]|0}if((l&1)!=0){e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;eb(g|0,18472,(j=i,i=i+8|0,c[j>>2]=665322,j)|0)|0;i=j;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0}gj(661226,768);gj(665322,1024);break L1665;break};case 1:{e=a[607928]|0;if((e&1)==0){m=e}else{e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;a3(19752,32,1,g|0)|0;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0;m=a[607928]|0}if((m&1)==0){n=m}else{e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;eb(g|0,19968,(j=i,i=i+8|0,c[j>>2]=648938,j)|0)|0;i=j;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0;n=a[607928]|0}if((n&1)!=0){e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;eb(g|0,19872,(j=i,i=i+8|0,c[j>>2]=653034,j)|0)|0;i=j;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0}gj(648938,1280);gj(653034,1537);break L1665;break};case 2:case 3:{e=a[607928]|0;if((e&1)==0){o=e}else{e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;a3(19296,30,1,g|0)|0;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0;o=a[607928]|0}if((o&1)==0){p=o}else{e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;eb(g|0,19136,(j=i,i=i+8|0,c[j>>2]=648938,j)|0)|0;i=j;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0;p=a[607928]|0}if((p&1)!=0){e=c[191244]|0;g=(e|0)!=0?e:c[q>>2]|0;eb(g|0,18912,(j=i,i=i+8|0,c[j>>2]=657130,j)|0)|0;i=j;g=c[191244]|0;e=(g|0)!=0?g:c[q>>2]|0;aZ(e|0)|0}gj(648938,256);gj(657130,512);break L1665;break};default:{break L1665}}}}while(0);p=c[189115]|0;if((p|0)!=0){v_(c[p>>2]|0);v_(c[p+12>>2]|0);v_(p)}c[189115]=0;v_(c[189116]|0);c[189116]=0;p=c[191220]|0;if((p|0)!=0){hw(p)}p=c[189119]|0;if((p|0)!=0){o=c[p>>2]|0;if((o|0)!=0){aR(o|0)|0}v_(c[p+4>>2]|0);v_(c[p+12>>2]|0);v_(p)}do{if((a[766053]&1)==0){if((a[766052]&1)!=0){break}p=d|0;if((a[603802]&1)==0){break}gs(p,669418,20528);o=gh(p)|0;if((a[607928]&1)==0){break}n=c[191244]|0;m=(n|0)!=0?n:c[q>>2]|0;n=o?20296:20232;eb(m|0,20360,(j=i,i=i+16|0,c[j>>2]=p,c[j+8>>2]=n,j)|0)|0;i=j;n=c[191244]|0;p=(n|0)!=0?n:c[q>>2]|0;aZ(p|0)|0}}while(0);gC();d=c[176743]|0;do{if((d|0)!=0){if((a[766257]&1)!=0){break}fx[d&127]()}}while(0);gD();if((a[766259]&1)!=0){c[191562]=0}if((a[766260]&1)!=0){c[191561]=0}if((a[766261]&1)!=0){c[191563]=0}a[766259]=0;a[766260]=0;a[766261]=0;fx[c[37188]&127]();fx[c[37228]&127]();d=c[176752]|0;if((d|0)!=0){p=d+4104|0;if((c[p>>2]|0)==0){r=d|0}else{n=d+4100|0;m=d|0;o=0;while(1){l=c[n>>2]|0;gJ(c[m>>2]|0,c[l+(o<<4)+4>>2]|0,c[(c[c[l+(o<<4)+8>>2]>>2]|0)+(c[l+(o<<4)+12>>2]<<3)>>2]|0);l=o+1|0;if(l>>>0<(c[p>>2]|0)>>>0){o=l}else{r=m;break}}}m=c[r>>2]|0;r=d+4|0;gK(m,r)|0;hm(c[176752]|0)}v3(702216,0,4800);if((a[607964]&1)==0){a[764980]=0;i=b;return}if((a[607928]&1)!=0){r=c[191244]|0;m=(r|0)!=0?r:c[q>>2]|0;eb(m|0,23888,(j=i,i=i+8|0,c[j>>2]=607965,j)|0)|0;i=j;m=c[191244]|0;r=(m|0)!=0?m:c[q>>2]|0;aZ(r|0)|0}if((bz(607965)|0)<0){r=c[191244]|0;m=(r|0)!=0?r:c[q>>2]|0;eb(m|0,23608,(j=i,i=i+8|0,c[j>>2]=607965,j)|0)|0;i=j;j=c[191244]|0;m=(j|0)!=0?j:c[q>>2]|0;aZ(m|0)|0}a[607964]=0;a[764980]=0;i=b;return}function gc(d,e){d=d|0;e=e|0;var f=0,g=0;f=c[176757]|0;c[176757]=f+1;b[(c[176766]|0)+(f<<1)>>1]=d;d=c[176757]|0;c[176757]=d+1;b[(c[176766]|0)+(d<<1)>>1]=e;e=c[176757]|0;if(e>>>0<(c[176758]|0)>>>0){return}if(fX(c[176766]|0,e)|0){g=a[607929]&1}else{g=0}a[607929]=g;c[176757]=0;return}function gd(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=f&255;f=c[189119]|0;do{if((f|0)!=0){if((a[760576]&1)==0){break}if((d5(l|0,2,1,c[f>>2]|0)|0)!=1){a[764675]=1;break}n=b[l>>1]|0;i=j;return n|0}}while(0);if(h>>>0<25|(m|0)==3){o=fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,7320,d,m,g,h)|0}else{o=0}l=(m|0)==1;f=(d|0)==0;do{if(l&f){p=766424;q=c[p>>2]|0;r=c[p+4>>2]|0;p=we(1,0,h|0)|0;s=G;t=((q&p|0)!=0|(r&s|0)!=0)&1|o}else{if(!((m|0)==5&f)){t=o;break}t=(b[766432+(((h|0)==1|((g|0)==1?2:0))<<1)>>1]|0)+o&65535}}while(0);do{if(l){if((h-4|0)>>>0<=3){u=t;break}o=t<<16>>16!=0;do{if(o){if((a[764682+d|0]&1)==0){v=b[764690+(d<<1)>>1]|0;w=1<<h;break}else{g=1<<h;f=764690+(d<<1)|0;m=(e[f>>1]|0|g)&65535;b[f>>1]=m;v=m;w=g;break}}else{g=1<<h;m=764690+(d<<1)|0;f=(e[m>>1]|0)&(g^65535)&65535;b[m>>1]=f;v=f;w=g}}while(0);if((v&65535&w|0)==0){x=o}else{x=(((c[191177]|0)>>>0)%((c[141722]|0)>>>0)|0)>>>0<(c[141723]|0)>>>0&o}u=x&1}else{u=t}}while(0);t=c[189119]|0;if((t|0)==0){n=u;i=j;return n|0}if((a[760576]&1)!=0){n=u;i=j;return n|0}b[k>>1]=u;a3(k|0,2,1,c[t>>2]|0)|0;n=u;i=j;return n|0}function ge(){var a=0,b=0,d=0;a=i;da(37240|0)|0;da(37160|0)|0;b=c[o>>2]|0;a3(49360|0,11,1,b|0)|0;eb(b|0,49112|0,(d=i,i=i+16|0,c[d>>2]=48520,c[d+8>>2]=32,d)|0)|0;i=d;eb(b|0,48280|0,(d=i,i=i+8|0,c[d>>2]=48144,d)|0)|0;i=d;da(37240|0)|0;da(37112|0)|0;da(37056|0)|0;da(36936|0)|0;da(36800|0)|0;da(36344|0)|0;da(36216|0)|0;da(36136|0)|0;da(35816|0)|0;da(35632|0)|0;da(35480|0)|0;da(35296|0)|0;da(35152|0)|0;da(35080|0)|0;da(35e3|0)|0;da(34728|0)|0;da(34592|0)|0;c$(34384|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;c$(34272|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;c$(34200|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;da(34064|0)|0;da(33976|0)|0;da(33848|0)|0;da(33752|0)|0;da(33696|0)|0;da(33408|0)|0;da(33264|0)|0;da(33144|0)|0;da(33024|0)|0;da(32992|0)|0;da(32904|0)|0;da(32832|0)|0;da(32760|0)|0;da(32680|0)|0;da(32632|0)|0;da(32336|0)|0;i=a;return}function gf(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c2(b|0,34720|0)|0;do{if((e|0)!=0){eo(e|0,0,2)|0;b=cb(e|0)|0;ew(e|0);f=vZ(b+1|0)|0;if((f|0)==0){g=c[191244]|0;h=(g|0)!=0?g:c[q>>2]|0;a3(34152|0,47,1,h|0)|0;h=c[191244]|0;g=(h|0)!=0?h:c[q>>2]|0;aZ(g|0)|0;aR(e|0)|0;break}g=d5(f|0,1,b|0,e|0)|0;if((g|0)<(b|0)){h=c[191244]|0;i=(h|0)!=0?h:c[q>>2]|0;a3(28176|0,44,1,i|0)|0;i=c[191244]|0;h=(i|0)!=0?i:c[q>>2]|0;aZ(h|0)|0}c[d>>2]=f;a[f+b|0]=0;aR(e|0)|0;j=g;return j|0}}while(0);c[d>>2]=0;j=-1;return j|0}function gg(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[764981]&1)==0){d=c[191244]|0;e=(d|0)!=0?d:c[q>>2]|0;eb(e|0,33568,(e=i,i=i+16|0,c[e>>2]=43208,c[e+8>>2]=832,e)|0)|0;i=e;e=c[191244]|0;d=(e|0)!=0?e:c[q>>2]|0;aZ(d|0)|0;cd(2)}else{f=1024;g=764983;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=1317;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==1317){eC(766008,1)}a[g]=0;if((a[h]|0)==0){eC(766008,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);eC(766008,1)}function gh(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((a[607928]&1)!=0){e=c[191244]|0;f=(e|0)!=0?e:c[q>>2]|0;eb(f|0,21064,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;f=c[191244]|0;e=(f|0)!=0?f:c[q>>2]|0;aZ(e|0)|0}e=fu[c[37204]&31]()|0;if((e|0)==0){h=0;i=d;return h|0}f=vZ(e)|0;if((f|0)==0){j=c[191244]|0;k=(j|0)!=0?j:c[q>>2]|0;a3(19160,70,1,k|0)|0;k=c[191244]|0;j=(k|0)!=0?k:c[q>>2]|0;aZ(j|0)|0;h=0;i=d;return h|0}if((a[607928]&1)!=0){j=c[191244]|0;k=(j|0)!=0?j:c[q>>2]|0;eb(k|0,17200,(g=i,i=i+8|0,c[g>>2]=e,g)|0)|0;i=g;k=c[191244]|0;j=(k|0)!=0?k:c[q>>2]|0;aZ(j|0)|0}do{if(fr[c[37206]&63](f,e)|0){j=c2(b|0,37672)|0;if((j|0)==0){l=1328;break}k=(a3(f|0,1,e|0,j|0)|0)==(e|0);aR(j|0)|0;if(k){m=1}else{l=1328}}else{l=1328}}while(0);if((l|0)==1328){l=c[191244]|0;e=(l|0)!=0?l:c[q>>2]|0;eb(e|0,15144,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;g=c[191244]|0;b=(g|0)!=0?g:c[q>>2]|0;aZ(b|0)|0;m=0}v_(f);h=m;i=d;return h|0}function gi(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+16|0;e=d|0;f=d+8|0;if((a[607928]&1)!=0){g=c[191244]|0;h=(g|0)!=0?g:c[q>>2]|0;eb(h|0,13080,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;h=c[191244]|0;g=(h|0)!=0?h:c[q>>2]|0;aZ(g|0)|0}c[e>>2]=0;g=gf(b,e)|0;if((g|0)<0){h=c[191244]|0;k=(h|0)!=0?h:c[q>>2]|0;eb(k|0,50648,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;b=c[191244]|0;k=(b|0)!=0?b:c[q>>2]|0;aZ(k|0)|0;l=0;i=d;return l|0}if((a[607928]&1)!=0){k=c[191244]|0;b=(k|0)!=0?k:c[q>>2]|0;eb(b|0,48408,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;j=c[191244]|0;b=(j|0)!=0?j:c[q>>2]|0;aZ(b|0)|0}c[f>>2]=0;L1864:do{if((a[603800]&1)==0){m=1351}else{if((a[607928]&1)!=0){b=c[191244]|0;j=(b|0)!=0?b:c[q>>2]|0;a3(46488,36,1,j|0)|0;j=c[191244]|0;b=(j|0)!=0?j:c[q>>2]|0;aZ(b|0)|0}switch(c[153016]|0){case 0:{n=0;o=1;break};case 1:{n=1280;o=1537;break};case 2:case 3:{n=256;o=512;break};case 4:{n=768;o=1024;break};default:{m=1351;break L1864}}b=fc[c[37224]&127](n)|0;j=fc[c[37224]&127](o)|0;if((b|0)==0){p=0;r=0}else{p=vZ(b)|0;r=b}if((j|0)==0){s=0;t=0}else{b=vZ(j)|0;c[f>>2]=b;s=b;t=j}do{if((p|0)!=0){j=fc[c[37226]&127](n)|0;if((j|0)==0){break}v6(p|0,j|0,r)|0}}while(0);j=f;if((s|0)==0){u=0;v=t;w=n;x=o;y=r;z=p;A=j;break}b=fc[c[37226]&127](o)|0;if((b|0)==0){u=s;v=t;w=n;x=o;y=r;z=p;A=j;break}v6(s|0,b|0,t)|0;u=s;v=t;w=n;x=o;y=r;z=p;A=j}}while(0);if((m|0)==1351){u=0;v=0;w=-1;x=-1;y=0;z=0;A=f}f=c[e>>2]|0;e=fr[c[37186]&63](f,g)|0;do{if(e){do{if((z|0)!=0){g=fc[c[37226]&127](w)|0;if((g|0)==0){break}v6(g|0,z|0,y)|0}}while(0);if((u|0)==0){break}g=fc[c[37226]&127](x)|0;if((g|0)==0){break}v6(g|0,u|0,v)|0}}while(0);if((z|0)==0){B=u}else{v_(z);B=c[A>>2]|0}if((B|0)!=0){v_(B)}v_(f);l=e;i=d;return l|0}function gj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+8200|0;f=e|0;g=e+4096|0;h=e+8192|0;j=fc[c[37224]&127](d)|0;k=fc[c[37226]&127](d)|0;if((k|0)==0|(j|0)==0){i=e;return}l=c2(b|0,37672)|0;do{if((l|0)!=0){m=(a3(k|0,1,j|0,l|0)|0)==(j|0);aR(l|0)|0;if(!m){break}if((a[607928]&1)==0){i=e;return}m=c[191244]|0;n=(m|0)!=0?m:c[q>>2]|0;eb(n|0,42776,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;n=c[191244]|0;m=(n|0)!=0?n:c[q>>2]|0;aZ(m|0)|0;i=e;return}}while(0);b=c[191244]|0;a3(45072,42,1,((b|0)!=0?b:c[q>>2]|0)|0)|0;b=c[191244]|0;aZ(((b|0)!=0?b:c[q>>2]|0)|0)|0;b=c[191244]|0;a3(44144,46,1,((b|0)!=0?b:c[q>>2]|0)|0)|0;b=c[191244]|0;aZ(((b|0)!=0?b:c[q>>2]|0)|0)|0;b=f|0;l=g|0;g=dC(44720)|0;do{if((g|0)!=0){bN(b|0,4096,26200,(o=i,i=i+8|0,c[o>>2]=g,o)|0)|0;i=o;eF(h|0)|0;m=be(h|0)|0;cR(l|0,4096,25912,m|0)|0;m=v2(b|0)|0;n=m>>>0>4096?0:4096-m|0;L1919:do{if((n|0)==0){p=l;r=1382}else{s=n;t=f+m|0;u=l;while(1){v=s-1|0;if((v|0)==0){break}w=a[u]|0;a[t]=w;if(w<<24>>24==0){break L1919}else{s=v;t=t+1|0;u=u+1|0}}a[t]=0;p=u;r=1382}}while(0);do{if((r|0)==1382){if((a[p]|0)==0){break}else{x=p}do{x=x+1|0;}while((a[x]|0)!=0)}}while(0);switch(d|0){case 1:case 1537:{y=23984;break};case 512:{y=23784;break};case 768:{y=23488;break};case 1024:{y=23224;break};case 0:case 1280:case 256:{y=50408;break};default:{y=766672}}u=v2(b|0)|0;t=u>>>0>4096?0:4096-u|0;L1937:do{if((t|0)==0){z=y;r=1395}else{m=t;n=f+u|0;s=y;while(1){v=m-1|0;if((v|0)==0){break}w=a[s]|0;a[n]=w;if(w<<24>>24==0){break L1937}else{m=v;n=n+1|0;s=s+1|0}}a[n]=0;z=s;r=1395}}while(0);do{if((r|0)==1395){if((a[z]|0)==0){break}else{A=z}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);s=c2(b|0,37672)|0;if((s|0)==0){break}n=(a3(k|0,1,j|0,s|0)|0)==(j|0);aR(s|0)|0;if(!n){break}n=c[191244]|0;s=(n|0)!=0?n:c[q>>2]|0;eb(s|0,25440,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;s=c[191244]|0;n=(s|0)!=0?s:c[q>>2]|0;aZ(n|0)|0;i=e;return}}while(0);o=c[191244]|0;a3(24840,57,1,((o|0)!=0?o:c[q>>2]|0)|0)|0;o=c[191244]|0;aZ(((o|0)!=0?o:c[q>>2]|0)|0)|0;i=e;return}function gk(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;e=i;i=i+8280|0;f=e|0;g=e+48|0;h=e+56|0;j=e+4152|0;k=e+8248|0;l=e+8264|0;m=e+8272|0;L1954:do{if((a[644842]|0)!=0){if((a[702292]&1)!=0){break}n=cf(644842,46)|0;o=(n|0)==0?766672:n+1|0;if((o|0)==0){break}if((v9(o|0,41536)|0)!=0){break}a[607964]=1;o=h|0;n=j|0;p=go(702808,47200)|0;do{if((p|0)!=0){c[g>>2]=0;r=gf(644842,g)|0;if((r|0)<22){s=c[191244]|0;t=(s|0)!=0?s:c[q>>2]|0;eb(t|0,35232,(u=i,i=i+8|0,c[u>>2]=107,u)|0)|0;i=u;t=c[191244]|0;s=(t|0)!=0?t:c[q>>2]|0;aZ(s|0)|0;v_(c[g>>2]|0);v=0}else{s=r-22|0;L1964:do{if((s|0)>22){t=c[g>>2]|0;w=t+r|0;x=t+22|0;y=t+s|0;while(1){if((d[y+1|0]<<8|d[y]|d[y+2|0]<<16|d[y+3|0]<<24|0)==101010256){if((y+((d[y+21|0]<<8|d[y+20|0])+22)|0)==(w|0)){break}}z=y-1|0;if(z>>>0>x>>>0){y=z}else{A=1419;break L1964}}x=d[y+17|0]<<8|d[y+16|0]|d[y+18|0]<<16|d[y+19|0]<<24;w=t+x|0;L1972:do{if((d[t+(x+1)|0]<<8|d[w]|d[t+(x+2)|0]<<16|d[t+(x+3)|0]<<24|0)==33639248){z=p|0;B=p+4|0;C=w;L1974:while(1){D=a[C+10|0]|0;E=a[C+11|0]|0;F=a[C+16|0]|0;G=a[C+17|0]|0;H=a[C+18|0]|0;I=a[C+19|0]|0;J=d[C+21|0]<<8|d[C+20|0]|d[C+22|0]<<16|d[C+23|0]<<24;K=d[C+25|0]<<8|d[C+24|0]|d[C+26|0]<<16|d[C+27|0]<<24;L=d[C+29|0]<<8|d[C+28|0];M=d[C+33|0]<<8|d[C+32|0];N=d[C+31|0]<<8|d[C+30|0];v3(o|0,0,4096);if(L>>>0>4095){A=1425;break}O=C+46|0;v6(o|0,O|0,L)|0;O=d[C+43|0]<<8|d[C+42|0]|d[C+44|0]<<16|d[C+45|0]<<24;P=O+30+(d[t+(O+27)|0]<<8|d[t+(O+26)|0])+(d[t+(O+29)|0]<<8|d[t+(O+28)|0])|0;if((a[607928]&1)!=0){O=c[191244]|0;Q=(O|0)!=0?O:c[q>>2]|0;eb(Q|0,28488,(u=i,i=i+24|0,c[u>>2]=P,c[u+8>>2]=J,c[u+16>>2]=K,u)|0)|0;i=u;Q=c[191244]|0;O=(Q|0)!=0?Q:c[q>>2]|0;aZ(O|0)|0}O=cf(o|0,46)|0;Q=(O|0)==0?766672:O+1|0;L1980:do{if((Q|0)!=0){O=c[B>>2]|0;R=0;while(1){if(R>>>0>=O>>>0){break L1980}if((v9(c[(c[z>>2]|0)+(R<<3)>>2]|0,Q|0)|0)==0){break L1974}else{R=R+1|0}}}}while(0);Q=L+46+N+M|0;R=C+Q|0;if((d[C+(Q+1)|0]<<8|d[R]|d[C+(Q+2)|0]<<16|d[C+(Q+3)|0]<<24|0)==33639248){C=R}else{break L1972}}if((A|0)==1425){C=c[191244]|0;z=(C|0)!=0?C:c[q>>2]|0;eb(z|0,35232,(u=i,i=i+8|0,c[u>>2]=141,u)|0)|0;i=u;z=c[191244]|0;C=(z|0)!=0?z:c[q>>2]|0;aZ(C|0)|0;S=0;break L1964}C=(G&255)<<8|F&255|(H&255)<<16|(I&255)<<24;z=(E&255)<<8|D&255;B=t+P|0;R=cf(o|0,47)|0;gA(n,644842,(R|0)==0?o:R+1|0);if((z|0)==8){R=vZ(K)|0;if((R|0)!=0){v3(f|0,0,48);Q=vZ(43784)|0;do{if((Q|0)==0){O=c[191244]|0;T=(O|0)!=0?O:c[q>>2]|0;eb(T|0,35232,(u=i,i=i+8|0,c[u>>2]=61,u)|0)|0;i=u;T=c[191244]|0;O=(T|0)!=0?T:c[q>>2]|0;aZ(O|0)|0}else{O=f+28|0;c[O>>2]=Q;c[Q>>2]=0;c[Q+10992>>2]=0;c[Q+10996>>2]=0;c[Q+43780>>2]=1;c[Q+11e3>>2]=1;c[Q+11004>>2]=0;c[Q+11008>>2]=-15;c[f>>2]=B;c[f+4>>2]=J;c[f+12>>2]=R;c[f+16>>2]=K;T=(jz(f)|0)==1;U=c[O>>2]|0;if((U|0)!=0){v_(U);c[O>>2]=0}if(!T){T=c[191244]|0;O=(T|0)!=0?T:c[q>>2]|0;eb(O|0,35232,(u=i,i=i+8|0,c[u>>2]=71,u)|0)|0;i=u;O=c[191244]|0;T=(O|0)!=0?O:c[q>>2]|0;aZ(T|0)|0;break}if((K|0)==0){V=0}else{T=K;O=R;U=-1;while(1){W=T-1|0;X=d[O]|0;Y=c[9512+(((X^U)&15)<<2)>>2]^U>>>4;Z=Y>>>4^c[9512+((Y&15^X>>>4)<<2)>>2];if((W|0)==0){break}else{T=W;O=O+1|0;U=Z}}V=~Z}if((V|0)!=(C|0)){U=c[191244]|0;O=(U|0)!=0?U:c[q>>2]|0;eb(O|0,21408,(u=i,i=i+16|0,c[u>>2]=V,c[u+8>>2]=C,u)|0)|0;i=u;O=c[191244]|0;U=(O|0)!=0?O:c[q>>2]|0;aZ(U|0)|0}U=c2(n|0,37672)|0;do{if((U|0)!=0){O=(a3(R|0,1,K|0,U|0)|0)==(K|0);aR(U|0)|0;if(!O){break}v_(R);O=4096;T=644842;M=n;while(1){N=O-1|0;if((N|0)==0){break}L=a[M]|0;a[T]=L;if(L<<24>>24==0){S=1;break L1964}else{O=N;T=T+1|0;M=M+1|0}}a[T]=0;if((a[M]|0)==0){S=1;break L1964}else{_=M}while(1){O=_+1|0;if((a[O]|0)==0){S=1;break L1964}else{_=O}}}}while(0);U=c[191244]|0;M=(U|0)!=0?U:c[q>>2]|0;eb(M|0,35232,(u=i,i=i+8|0,c[u>>2]=81,u)|0)|0;i=u;M=c[191244]|0;U=(M|0)!=0?M:c[q>>2]|0;aZ(U|0)|0}}while(0);v_(R)}C=c[191244]|0;Q=(C|0)!=0?C:c[q>>2]|0;eb(Q|0,35232,(u=i,i=i+8|0,c[u>>2]=175,u)|0)|0;i=u;Q=c[191244]|0;C=(Q|0)!=0?Q:c[q>>2]|0;aZ(C|0)|0;S=0;break L1964}else if((z|0)==0){C=c2(n|0,37672)|0;if((C|0)!=0){Q=(a3(B|0,1,K|0,C|0)|0)==(K|0);aR(C|0)|0;if(Q){S=1;break L1964}}Q=c[191244]|0;eb(((Q|0)!=0?Q:c[q>>2]|0)|0,35232,(u=i,i=i+8|0,c[u>>2]=165,u)|0)|0;i=u;Q=c[191244]|0;aZ(((Q|0)!=0?Q:c[q>>2]|0)|0)|0;S=0;break L1964}else{Q=c[191244]|0;eb(((Q|0)!=0?Q:c[q>>2]|0)|0,35232,(u=i,i=i+8|0,c[u>>2]=178,u)|0)|0;i=u;Q=c[191244]|0;aZ(((Q|0)!=0?Q:c[q>>2]|0)|0)|0;S=0;break L1964}}}while(0);t=c[191244]|0;a3(24328,101,1,((t|0)!=0?t:c[q>>2]|0)|0)|0;t=c[191244]|0;aZ(((t|0)!=0?t:c[q>>2]|0)|0)|0;t=c[191244]|0;eb(((t|0)!=0?t:c[q>>2]|0)|0,35232,(u=i,i=i+8|0,c[u>>2]=186,u)|0)|0;i=u;t=c[191244]|0;aZ(((t|0)!=0?t:c[q>>2]|0)|0)|0;S=0}else{A=1419}}while(0);if((A|0)==1419){s=c[191244]|0;r=(s|0)!=0?s:c[q>>2]|0;eb(r|0,35232,(u=i,i=i+8|0,c[u>>2]=113,u)|0)|0;i=u;r=c[191244]|0;s=(r|0)!=0?r:c[q>>2]|0;aZ(s|0)|0;S=0}v_(c[g>>2]|0);v=S}s=p+4|0;r=p|0;t=c[r>>2]|0;if((c[s>>2]|0)==0){$=t}else{w=0;x=t;while(1){v_(c[x+(w<<3)>>2]|0);t=w+1|0;y=c[r>>2]|0;if(t>>>0<(c[s>>2]|0)>>>0){w=t;x=y}else{$=y;break}}}v_($);v_(p);if(v){aa=4096;ab=607965;ac=644842}else{break}while(1){x=aa-1|0;if((x|0)==0){break}w=a[ac]|0;a[ab]=w;if(w<<24>>24==0){break L1954}else{aa=x;ab=ab+1|0;ac=ac+1|0}}a[ab]=0;if((a[ac]|0)==0){break L1954}else{ad=ac}while(1){ad=ad+1|0;if((a[ad]|0)==0){break L1954}}}}while(0);p=c[191244]|0;n=(p|0)!=0?p:c[q>>2]|0;eb(n|0,40456,(u=i,i=i+8|0,c[u>>2]=644842,u)|0)|0;i=u;n=c[191244]|0;p=(n|0)!=0?n:c[q>>2]|0;aZ(p|0)|0;a[607964]=0;ae=0;i=e;return ae|0}}while(0);L2045:do{switch(b|0){case 1:{u=m|0;c[u>>2]=(a[644842]|0)!=0?644842:0;c[m+4>>2]=612072;if(gl(260,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 0:{if((a[766052]&1)==0){c[l>>2]=644842;if(gl(0,l,1)|0){break L2045}else{ae=0}i=e;return ae|0}if((a[702294]&1)==0){u=c[191244]|0;ad=(u|0)!=0?u:c[q>>2]|0;a3(26856,78,1,ad|0)|0;ad=c[191244]|0;u=(ad|0)!=0?ad:c[q>>2]|0;aZ(u|0)|0;ae=0;i=e;return ae|0}else{if(fc[c[37214]&127](0)|0){break L2045}else{ae=0}i=e;return ae|0}break};case 2:{u=m|0;c[u>>2]=(a[644842]|0)!=0?644842:0;c[m+4>>2]=616168;if(gl(257,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 3:{u=m|0;c[u>>2]=(a[644842]|0)!=0?644842:0;c[m+4>>2]=616168;if(gl(258,u,2)|0){break L2045}else{ae=0}i=e;return ae|0};case 4:{u=k|0;c[u>>2]=(a[644842]|0)!=0?644842:0;c[k+4>>2]=(a[620264]|0)!=0?620264:0;c[k+8>>2]=(a[624360]|0)!=0?624360:0;if(gl(259,u,3)|0){break L2045}else{ae=0}i=e;return ae|0};default:{u=c[191244]|0;a3(39456,39,1,((u|0)!=0?u:c[q>>2]|0)|0)|0;u=c[191244]|0;aZ(((u|0)!=0?u:c[q>>2]|0)|0)|0;ae=0;i=e;return ae|0}}}while(0);ae=1;i=e;return ae|0}function gl(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;g=i;i=i+520|0;h=g|0;j=g+368|0;k=g+400|0;l=g+408|0;m=g+416|0;n=g+424|0;o=g+440|0;p=g+456|0;if((f|0)==0|f>>>0>4){r=0;i=g;return r|0}v3(n|0,0,16);v3(o|0,0,16);v3(p|0,0,64);do{if((a[673514]|0)==0){s=0}else{t=c2(673514,41400)|0;if((t|0)==0){s=0;break}eo(t|0,0,2)|0;u=(cb(t|0)|0)+2|0;ew(t|0);v=(u|0)==0?0:u;w=vZ(v)|0;if((w|0)==0){aR(t|0)|0;s=0;break}if((c[w-4>>2]&3|0)!=0){v3(w|0,0,v|0)}v=w;x=w;while(1){if((eg(t|0)|0)!=0){y=x;break}bX(x|0,u-x+v|0,t|0)|0;z=x+(v2(x|0)|0)|0;if((z|0)==0){y=0;break}else{x=z}}x=b1(y|0,-1|0)|0;if((x|0)!=0){a[x]=0}aR(t|0)|0;if((a[607928]&1)==0){s=w;break}x=c[191244]|0;eb(((x|0)!=0?x:c[q>>2]|0)|0,27232,(A=i,i=i+8|0,c[A>>2]=673514,A)|0)|0;i=A;x=c[191244]|0;aZ(((x|0)!=0?x:c[q>>2]|0)|0)|0;s=w}}while(0);y=(a[607928]&1)!=0;do{if((a[702228]&1)==0){if(y){x=c[191244]|0;v=(x|0)!=0?x:c[q>>2]|0;x=c[e>>2]|0;eb(v|0,38544,(A=i,i=i+8|0,c[A>>2]=x,A)|0)|0;i=A;x=c[191244]|0;v=(x|0)!=0?x:c[q>>2]|0;aZ(v|0)|0}v=c[e>>2]|0;x=n|0;c[m>>2]=0;u=gf(v,m)|0;if((u|0)<1){B=u;C=0}else{L2097:do{if((a[689898]&1)==0){v=c[m>>2]|0;c[k>>2]=0;z=a[689899]|0;D=a[689900]|0;E=a[689901]|0;if(((D&1)+(z&1)+(E&1)|0)>1){F=c[191244]|0;G=(F|0)!=0?F:c[q>>2]|0;a3(31040,77,1,G|0)|0;G=c[191244]|0;F=(G|0)!=0?G:c[q>>2]|0;aZ(F|0)|0;H=u;I=v;break}F=(E|z)&1;G=((D|z)&1)!=0;if(((E|D)&1)!=0|(a[689902]|0)==0){J=1517}else{D=gf(689902,k)|0;if((D|0)>-1){K=30536;L=689902;M=4;N=D}else{J=1517}}do{if((J|0)==1517){if(!(F<<24>>24!=0|(a[693998]|0)==0)){D=gf(693998,k)|0;if((D|0)>-1){K=30168;L=693998;M=6;N=D;break}}if(!(G|(a[698094]|0)==0)){D=gf(698094,k)|0;if((D|0)>-1){K=29816;L=698094;M=8;N=D;break}}if((a[607928]&1)==0){H=u;I=v;break L2097}D=c[191244]|0;E=(D|0)!=0?D:c[q>>2]|0;a3(29456,43,1,E|0)|0;E=c[191244]|0;D=(E|0)!=0?E:c[q>>2]|0;aZ(D|0)|0;H=u;I=v;break L2097}}while(0);if((a[607928]&1)!=0){G=c[191244]|0;F=(G|0)!=0?G:c[q>>2]|0;eb(F|0,28912,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=L,A)|0)|0;i=A;F=c[191244]|0;G=(F|0)!=0?F:c[q>>2]|0;aZ(G|0)|0}G=u<<2;c[l>>2]=G;F=vZ(G)|0;if((F|0)==0){G=c[191244]|0;D=(G|0)!=0?G:c[q>>2]|0;a3(28256,67,1,D|0)|0;D=c[191244]|0;G=(D|0)!=0?D:c[q>>2]|0;aZ(G|0)|0;c[m>>2]=v;v_(c[k>>2]|0);H=u;I=v;break}G=c[k>>2]|0;D=fb[M&15](G,N,v,u,F,l)|0;if((D|0)==1){if((a[607928]&1)!=0){E=c[191244]|0;z=(E|0)!=0?E:c[q>>2]|0;eb(z|0,27872,(A=i,i=i+8|0,c[A>>2]=K,A)|0)|0;i=A;z=c[191244]|0;E=(z|0)!=0?z:c[q>>2]|0;aZ(E|0)|0}v_(v);c[m>>2]=F;O=c[l>>2]|0;P=F}else{F=c[191244]|0;E=(F|0)!=0?F:c[q>>2]|0;eb(E|0,27552,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=D,A)|0)|0;i=A;D=c[191244]|0;E=(D|0)!=0?D:c[q>>2]|0;aZ(E|0)|0;O=u;P=v}v_(G);H=O;I=P}else{H=u;I=c[m>>2]|0}}while(0);u=(H|0)==0;if((I|0)==0|u){Q=0}else{w=H;t=I;G=-1;while(1){E=w-1|0;D=d[t]|0;F=c[9512+(((D^G)&15)<<2)>>2]^G>>>4;R=F>>>4^c[9512+((F&15^D>>>4)<<2)>>2];if((E|0)==0){break}else{w=E;t=t+1|0;G=R}}Q=~R}c[153017]=Q;G=h;v3(G|0,0,360);t=h+324|0;v6(t|0,147360,32)|0;t=h+360|0;c[t>>2]=H;c[t+4>>2]=0;w=h+64|0;if(u){S=0}else{E=H;D=I;F=0;while(1){z=64-F|0;T=E>>>0<z>>>0?E:z;z=G+F|0;v6(z|0,D|0,T)|0;z=T+(c[w>>2]|0)|0;c[w>>2]=z;if((z|0)==64){gM(h);U=c[w>>2]|0}else{U=z}if((E|0)==(T|0)){S=U;break}else{E=E-T|0;D=D+T|0;F=U}}}c[w>>2]=S+1;a[h+S|0]=-128;F=c[w>>2]|0;if(F>>>0>56){v3(G+F|0,0,64-F|0);gM(h);V=c[w>>2]|0}else{V=F}v3(G+V|0,0,56-V|0);F=c[t>>2]|0;c[h+56>>2]=dW(F>>>29|c[t+4>>2]<<3|0)|0;c[h+60>>2]=dW(F<<3|0>>>29|0)|0;gM(h);c[j>>2]=dW(c[h+324>>2]|0)|0;c[j+4>>2]=dW(c[h+328>>2]|0)|0;c[j+8>>2]=dW(c[h+332>>2]|0)|0;c[j+12>>2]=dW(c[h+336>>2]|0)|0;c[j+16>>2]=dW(c[h+340>>2]|0)|0;c[j+20>>2]=dW(c[h+344>>2]|0)|0;c[j+24>>2]=dW(c[h+348>>2]|0)|0;c[j+28>>2]=dW(c[h+352>>2]|0)|0;F=j;D=0;do{bN(764812+(D<<1)|0,3,18808,(A=i,i=i+8|0,c[A>>2]=d[F+D|0]|0,A)|0)|0;i=A;D=D+1|0;}while(D>>>0<32);if((a[607928]&1)!=0){D=c[191244]|0;F=(D|0)!=0?D:c[q>>2]|0;D=c[153017]|0;eb(F|0,31832,(A=i,i=i+16|0,c[A>>2]=D,c[A+8>>2]=764812,A)|0)|0;i=A;D=c[191244]|0;F=(D|0)!=0?D:c[q>>2]|0;aZ(F|0)|0}c[x>>2]=I;B=H;C=I}c[o>>2]=B;if((B|0)==-1){F=c[191244]|0;D=(F|0)!=0?F:c[q>>2]|0;a3(37600,46,1,D|0)|0;D=c[191244]|0;F=(D|0)!=0?D:c[q>>2]|0;aZ(F|0)|0;W=0;break}if((a[607928]&1)==0){X=C;Y=B;J=1553;break}F=c[191244]|0;D=(F|0)!=0?F:c[q>>2]|0;eb(D|0,36256,(A=i,i=i+8|0,c[A>>2]=B,A)|0)|0;i=A;D=c[191244]|0;F=(D|0)!=0?D:c[q>>2]|0;aZ(F|0)|0;X=C;Y=B;J=1553}else{if(!y){X=0;Y=0;J=1553;break}F=c[191244]|0;D=(F|0)!=0?F:c[q>>2]|0;a3(34640,72,1,D|0)|0;D=c[191244]|0;F=(D|0)!=0?D:c[q>>2]|0;aZ(F|0)|0;X=0;Y=0;J=1553}}while(0);L2157:do{if((J|0)==1553){y=p|0;c[p>>2]=c[e>>2];c[p+4>>2]=X;c[p+8>>2]=Y;c[p+12>>2]=s;L2159:do{if(f>>>0>1){B=1;L2160:while(1){Z=e+(B<<2)|0;C=c[Z>>2]|0;do{if((C|0)==0){_=0}else{if((a[702228]&1)!=0){_=C;break}I=gf(C,n+(B<<2)|0)|0;c[o+(B<<2)>>2]=I;if((I|0)==-1){break L2160}_=c[Z>>2]|0}}while(0);c[p+(B<<4)>>2]=_;c[p+(B<<4)+4>>2]=c[n+(B<<2)>>2];c[p+(B<<4)+8>>2]=c[o+(B<<2)>>2];B=B+1|0;if(B>>>0>=f>>>0){break L2159}}B=c[191244]|0;eb(((B|0)!=0?B:c[q>>2]|0)|0,33352,(A=i,i=i+8|0,c[A>>2]=c[Z>>2],A)|0)|0;i=A;B=c[191244]|0;aZ(((B|0)!=0?B:c[q>>2]|0)|0)|0;W=0;break L2157}}while(0);if((b|0)==0){if(fc[c[37214]&127](y)|0){W=1;break}}else{if(fg[c[37212]&63](b,y,f)|0){W=1;break}}x=c[191244]|0;B=(x|0)!=0?x:c[q>>2]|0;a3(32288,42,1,B|0)|0;B=c[191244]|0;x=(B|0)!=0?B:c[q>>2]|0;aZ(x|0)|0;W=0}}while(0);v_(c[n>>2]|0);v_(c[n+4>>2]|0);v_(c[n+8>>2]|0);v_(c[n+12>>2]|0);v_(s);r=W;i=g;return r|0}function gm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=a[b+4|0]&1;f=a[d+4|0]&1;if(e<<24>>24==f<<24>>24){g=v9(c[b>>2]|0,c[d>>2]|0)|0;return g|0}else{g=(f&255)-(e&255)|0;return g|0}return 0}function gn(a,b){a=a|0;b=b|0;return v9(c[a>>2]|0,c[b>>2]|0)|0}function go(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;i=i+8|0;e=d|0;f=vZ(12)|0;do{if((f|0)==0){g=0}else{do{if((c[f-4>>2]&3|0)==0){h=f+4|0;j=c[h>>2]|0;if(j>>>0<32){k=h;l=j;m=f;break}j=c[191244]|0;h=(j|0)!=0?j:c[q>>2]|0;eb(h|0,33568,(n=i,i=i+16|0,c[n>>2]=15e3,c[n+8>>2]=69,n)|0)|0;i=n;h=c[191244]|0;j=(h|0)!=0?h:c[q>>2]|0;aZ(j|0)|0;cd(2);return 0}else{v3(f|0,0,12);k=f+4|0;l=0;m=f}}while(0);j=f;h=c[j>>2]|0;o=h;p=v$(o,256)|0;if((p|0)==0){if((l|0)!=0){r=0;do{v_(c[h+(r<<3)>>2]|0);r=r+1|0;}while(r>>>0<l>>>0)}v_(o);v_(f);g=0;break}r=p;c[j>>2]=r;h=f+8|0;c[h>>2]=32;s=dn(a|0)|0;L2197:do{if((s|0)==0){t=0;u=l;v=r}else{w=d7(s|0,b|0,e|0)|0;L2199:do{if((w|0)!=0){x=w;y=r;z=l;A=32;while(1){if(z>>>0<A>>>0){B=y;C=A}else{D=A<<1;if(z>>>0>=D>>>0){break}E=v$(y,A<<4)|0;if((E|0)==0){t=s;u=z;v=y;break L2197}F=E;c[j>>2]=F;c[h>>2]=D;B=F;C=D}D=dn(x|0)|0;if((D|0)==0){t=s;u=z;v=B;break L2197}c[B+(z<<3)>>2]=D;D=c[k>>2]|0;F=c[j>>2]|0;c[F+(D<<3)+4>>2]=0;E=D+1|0;c[k>>2]=E;D=d7(0,b|0,e|0)|0;if((D|0)==0){break L2199}else{x=D;y=F;z=E;A=C}}A=c[191244]|0;eb(((A|0)!=0?A:c[q>>2]|0)|0,33568,(n=i,i=i+16|0,c[n>>2]=15e3,c[n+8>>2]=69,n)|0)|0;i=n;A=c[191244]|0;aZ(((A|0)!=0?A:c[q>>2]|0)|0)|0;cd(2);return 0}}while(0);v_(s);G=m;i=d;return G|0}}while(0);if((u|0)!=0){s=0;do{v_(c[v+(s<<3)>>2]|0);s=s+1|0;}while(s>>>0<u>>>0)}v_(v);v_(f);g=t}}while(0);v_(g);G=0;i=d;return G|0}function gp(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=i;i=i+8264|0;g=f|0;h=f+4096|0;j=f+4168|0;k=vZ(12)|0;if((k|0)==0){l=0;i=f;return l|0}do{if((c[k-4>>2]&3|0)==0){m=k+4|0;n=c[m>>2]|0;if(n>>>0<32){o=m;p=n;r=k;break}n=c[191244]|0;m=(n|0)!=0?n:c[q>>2]|0;eb(m|0,33568,(s=i,i=i+16|0,c[s>>2]=15e3,c[s+8>>2]=69,s)|0)|0;i=s;m=c[191244]|0;n=(m|0)!=0?m:c[q>>2]|0;aZ(n|0)|0;cd(2);return 0}else{v3(k|0,0,12);o=k+4|0;p=0;r=k}}while(0);n=k;m=c[n>>2]|0;t=m;u=v$(t,256)|0;if((u|0)==0){if((p|0)!=0){v=0;do{v_(c[m+(v<<3)>>2]|0);v=v+1|0;}while(v>>>0<p>>>0)}v_(t);v_(k);l=0;i=f;return l|0}t=u;c[n>>2]=t;u=k+8|0;c[u>>2]=32;if((d|0)==0){w=0}else{w=go(d,47200)|0}d=bC(b|0)|0;L2238:do{if((d|0)==0){v=c[191244]|0;m=(v|0)!=0?v:c[q>>2]|0;eb(m|0,20720,(s=i,i=i+8|0,c[s>>2]=b,s)|0)|0;i=s;m=c[191244]|0;v=(m|0)!=0?m:c[q>>2]|0;aZ(v|0)|0;x=p;y=t}else{v=bS(d|0)|0;L2240:do{if((v|0)!=0){m=j|0;z=(w|0)==0;A=g|0;B=w|0;C=w+4|0;D=h+8|0;E=v;F=t;G=p;H=32;L2242:while(1){I=E+4|0;J=cf(I|0,46)|0;K=(J|0)==0?766672:J+1|0;gq(m,b,I);J=a[E+1036|0]|0;do{if((J<<24>>24|0)==0|(J<<24>>24|0)==10){if((eB(m|0,h|0)|0)<0){L=0;M=1619;break}N=(c[D>>2]&61440|0)==16384;M=1618}else if((J<<24>>24|0)==4){N=1;M=1618}else{L=0;M=1619}}while(0);if((M|0)==1618){M=0;if(e|N^1){L=N;M=1619}else{O=F;P=G;Q=H}}L2249:do{if((M|0)==1619){M=0;if((cJ(I|0,27920)|0)==0){O=F;P=G;Q=H;break}if((cJ(I|0,23992)|0)==0){O=F;P=G;Q=H;break}L2253:do{if(!(L|z)){bN(A|0,4096,30560,(s=i,i=i+16|0,c[s>>2]=27920,c[s+8>>2]=K,s)|0)|0;i=s;J=c[C>>2]|0;R=0;while(1){if(R>>>0>=J>>>0){O=F;P=G;Q=H;break L2249}S=c[(c[B>>2]|0)+(R<<3)>>2]|0;if((v9(S|0,K|0)|0)==0){break L2253}if((v9(S|0,A|0)|0)==0){break}else{R=R+1|0}}}}while(0);R=L&1;if(G>>>0<H>>>0){T=F;U=H}else{J=H<<1;if(G>>>0>=J>>>0){M=1629;break L2242}S=v$(F,H<<4)|0;if((S|0)==0){V=F;M=1638;break L2242}W=S;c[n>>2]=W;c[u>>2]=J;T=W;U=J}J=dn(m|0)|0;if((J|0)==0){V=T;M=1638;break L2242}c[T+(G<<3)>>2]=J;J=c[o>>2]|0;W=c[n>>2]|0;c[W+(J<<3)+4>>2]=R;R=J+1|0;c[o>>2]=R;O=W;P=R;Q=U}}while(0);K=bS(d|0)|0;if((K|0)==0){break L2240}else{E=K;F=O;G=P;H=Q}}if((M|0)==1629){H=c[191244]|0;F=(H|0)!=0?H:c[q>>2]|0;eb(F|0,33568,(s=i,i=i+16|0,c[s>>2]=15e3,c[s+8>>2]=69,s)|0)|0;i=s;F=c[191244]|0;H=(F|0)!=0?F:c[q>>2]|0;aZ(H|0)|0;cd(2);return 0}else if((M|0)==1638){H=c[191244]|0;eb(((H|0)!=0?H:c[q>>2]|0)|0,20720,(s=i,i=i+8|0,c[s>>2]=b,s)|0)|0;i=s;H=c[191244]|0;aZ(((H|0)!=0?H:c[q>>2]|0)|0)|0;eH(d|0)|0;x=G;y=V;break L2238}}}while(0);eH(d|0)|0;if((w|0)==0){l=r;i=f;return l|0}v=w+4|0;H=w|0;F=c[H>>2]|0;if((c[v>>2]|0)==0){X=F}else{E=0;m=F;while(1){v_(c[m+(E<<3)>>2]|0);F=E+1|0;A=c[H>>2]|0;if(F>>>0<(c[v>>2]|0)>>>0){E=F;m=A}else{X=A;break}}}v_(X);v_(w);l=r;i=f;return l|0}}while(0);if((x|0)!=0){r=0;do{v_(c[y+(r<<3)>>2]|0);r=r+1|0;}while(r>>>0<x>>>0)}v_(y);v_(k);if((w|0)==0){l=0;i=f;return l|0}k=w+4|0;y=w|0;x=c[y>>2]|0;if((c[k>>2]|0)==0){Y=x}else{r=0;X=x;while(1){v_(c[X+(r<<3)>>2]|0);x=r+1|0;d=c[y>>2]|0;if(x>>>0<(c[k>>2]|0)>>>0){r=x;X=d}else{Y=d;break}}}v_(Y);v_(w);l=0;i=f;return l|0}function gq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1656;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1656){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;p=h}while(1){g=o+1|0;d=p+1|0;if((a[g]|0)==0){n=d;break}else{o=g;p=d}}}}while(0);if(n>>>0>=4096){n=c[191244]|0;p=(n|0)!=0?n:c[q>>2]|0;eb(p|0,33568,(r=i,i=i+16|0,c[r>>2]=15e3,c[r+8>>2]=573,r)|0)|0;i=r;p=c[191244]|0;n=(p|0)!=0?p:c[q>>2]|0;aZ(n|0)|0;cd(2)}if((a[b]|0)!=0){gx(b)}n=v2(b|0)|0;p=n>>>0>4096?0:4096-n|0;L2308:do{if((p|0)==0){s=0;t=e;l=1667}else{o=p;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){u=h;break L2308}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;s=h;t=j;l=1667}}while(0);do{if((l|0)==1667){if((a[t]|0)==0){u=s;break}else{v=t;w=s}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){u=b;break}else{v=e;w=b}}}}while(0);if((u+n|0)>>>0<4096){i=f;return}else{f=c[191244]|0;n=(f|0)!=0?f:c[q>>2]|0;eb(n|0,33568,(r=i,i=i+16|0,c[r>>2]=15e3,c[r+8>>2]=578,r)|0)|0;i=r;r=c[191244]|0;n=(r|0)!=0?r:c[q>>2]|0;aZ(n|0)|0;cd(2)}}function gr(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+4096|0;g=f|0;h=4096;j=0;k=g;l=d;while(1){d=h-1|0;if((d|0)==0){m=1675;break}n=a[l]|0;a[k]=n;if(n<<24>>24==0){o=j;break}else{h=d;j=j+1|0;k=k+1|0;l=l+1|0}}do{if((m|0)==1675){a[k]=0;if((a[l]|0)==0){o=j;break}else{p=l;r=j}while(1){h=p+1|0;d=r+1|0;if((a[h]|0)==0){o=d;break}else{p=h;r=d}}}}while(0);if(o>>>0>=4096){o=c[191244]|0;r=(o|0)!=0?o:c[q>>2]|0;eb(r|0,33568,(s=i,i=i+16|0,c[s>>2]=15e3,c[s+8>>2]=409,s)|0)|0;i=s;r=c[191244]|0;o=(r|0)!=0?r:c[q>>2]|0;aZ(o|0)|0;cd(2)}o=cf(g|0,46)|0;if((o|0)==0){t=4096;u=0;v=b;w=g}else{a[o]=0;t=4096;u=0;v=b;w=g}while(1){g=t-1|0;if((g|0)==0){m=1683;break}o=a[w]|0;a[v]=o;if(o<<24>>24==0){x=u;break}else{t=g;u=u+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1683){a[v]=0;if((a[w]|0)==0){x=u;break}else{y=w;z=u}while(1){t=y+1|0;g=z+1|0;if((a[t]|0)==0){x=g;break}else{y=t;z=g}}}}while(0);if(x>>>0>=4096){x=c[191244]|0;z=(x|0)!=0?x:c[q>>2]|0;eb(z|0,33568,(s=i,i=i+16|0,c[s>>2]=15e3,c[s+8>>2]=414,s)|0)|0;i=s;z=c[191244]|0;x=(z|0)!=0?z:c[q>>2]|0;aZ(x|0)|0;cd(2)}x=v2(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2347:do{if((z|0)==0){A=0;B=e;m=1692}else{y=z;u=0;w=b+x|0;v=e;while(1){g=y-1|0;if((g|0)==0){break}t=a[v]|0;a[w]=t;if(t<<24>>24==0){C=u;break L2347}else{y=g;u=u+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=u;B=v;m=1692}}while(0);do{if((m|0)==1692){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[191244]|0;x=(f|0)!=0?f:c[q>>2]|0;eb(x|0,33568,(s=i,i=i+16|0,c[s>>2]=15e3,c[s+8>>2]=415,s)|0)|0;i=s;s=c[191244]|0;x=(s|0)!=0?s:c[q>>2]|0;aZ(x|0)|0;cd(2)}}function gs(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1700;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1700){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;p=h}while(1){g=o+1|0;d=p+1|0;if((a[g]|0)==0){n=d;break}else{o=g;p=d}}}}while(0);if(n>>>0>=4096){n=c[191244]|0;p=(n|0)!=0?n:c[q>>2]|0;eb(p|0,33568,(r=i,i=i+16|0,c[r>>2]=15e3,c[r+8>>2]=420,r)|0)|0;i=r;p=c[191244]|0;n=(p|0)!=0?p:c[q>>2]|0;aZ(n|0)|0;cd(2)}n=v2(b|0)|0;p=n>>>0>4096?0:4096-n|0;L2373:do{if((p|0)==0){s=0;t=e;l=1709}else{o=p;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){u=h;break L2373}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;s=h;t=j;l=1709}}while(0);do{if((l|0)==1709){if((a[t]|0)==0){u=s;break}else{v=t;w=s}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){u=b;break}else{v=e;w=b}}}}while(0);if((u+n|0)>>>0<4096){i=f;return}else{f=c[191244]|0;n=(f|0)!=0?f:c[q>>2]|0;eb(n|0,33568,(r=i,i=i+16|0,c[r>>2]=15e3,c[r+8>>2]=421,r)|0)|0;i=r;r=c[191244]|0;n=(r|0)!=0?r:c[q>>2]|0;aZ(n|0)|0;cd(2)}}function gt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;gx(b);f=cf(640746,47)|0;g=(f|0)==0?640746:f+1|0;f=v2(b|0)|0;h=f>>>0>4096?0:4096-f|0;L2388:do{if((h|0)==0){j=0;k=g;l=1719}else{m=h;n=0;o=b+f|0;p=g;while(1){r=m-1|0;if((r|0)==0){break}s=a[p]|0;a[o]=s;if(s<<24>>24==0){t=n;break L2388}else{m=r;n=n+1|0;o=o+1|0;p=p+1|0}}a[o]=0;j=n;k=p;l=1719}}while(0);do{if((l|0)==1719){if((a[k]|0)==0){t=j;break}else{u=k;v=j}while(1){g=u+1|0;h=v+1|0;if((a[g]|0)==0){t=h;break}else{u=g;v=h}}}}while(0);if((t+f|0)>>>0>=4096){f=c[191244]|0;t=(f|0)!=0?f:c[q>>2]|0;eb(t|0,33568,(w=i,i=i+16|0,c[w>>2]=15e3,c[w+8>>2]=457,w)|0)|0;i=w;t=c[191244]|0;f=(t|0)!=0?t:c[q>>2]|0;aZ(f|0)|0;cd(2)}f=v2(b|0)|0;t=f>>>0>4096?0:4096-f|0;L2402:do{if((t|0)==0){x=0;y=d;l=1728}else{v=t;u=0;j=b+f|0;k=d;while(1){p=v-1|0;if((p|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=u;break L2402}else{v=p;u=u+1|0;j=j+1|0;k=k+1|0}}a[j]=0;x=u;y=k;l=1728}}while(0);do{if((l|0)==1728){if((a[y]|0)==0){z=x;break}else{A=y;B=x}while(1){d=A+1|0;b=B+1|0;if((a[d]|0)==0){z=b;break}else{A=d;B=b}}}}while(0);if((z+f|0)>>>0<4096){i=e;return}else{e=c[191244]|0;f=(e|0)!=0?e:c[q>>2]|0;eb(f|0,33568,(w=i,i=i+16|0,c[w>>2]=15e3,c[w+8>>2]=458,w)|0)|0;i=w;w=c[191244]|0;f=(w|0)!=0?w:c[q>>2]|0;aZ(f|0)|0;cd(2)}}function gu(){var b=0,d=0.0,e=0.0,f=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0,p=0.0;b=i;a[702293]=0;d=+h[87782];if(d<=0.0){i=b;return}e=+h[87783];if(e<=0.0){i=b;return}f=+g[128458];j=f;if(+R(+(1.0-d/j))>.05000000074505806){if((a[607928]&1)==0){k=d;l=f}else{m=c[191244]|0;n=(m|0)!=0?m:c[q>>2]|0;f=d;eb(n|0,30440,(o=i,i=i+16|0,h[o>>3]=j,h[o+8>>3]=f,o)|0)|0;i=o;n=c[191244]|0;m=(n|0)!=0?n:c[q>>2]|0;aZ(m|0)|0;k=+h[87782];l=+g[128458]}do{if(k>l){a[702293]=1;if((a[607928]&1)==0){break}m=c[191244]|0;n=(m|0)!=0?m:c[q>>2]|0;a3(30104,57,1,n|0)|0;n=c[191244]|0;m=(n|0)!=0?n:c[q>>2]|0;aZ(m|0)|0}}while(0);p=+h[87783]}else{p=e*(j/d)}d=p;g[130528]=d;if((a[607928]&1)!=0){m=c[191244]|0;n=(m|0)!=0?m:c[q>>2]|0;p=d;eb(n|0,29768,(o=i,i=i+8|0,h[o>>3]=p,o)|0)|0;i=o;o=c[191244]|0;n=(o|0)!=0?o:c[q>>2]|0;aZ(n|0)|0}n=c[191562]|0;if((n|0)==0){i=b;return}if((a[702293]&1)!=0){fa[c[(c[191559]|0)+8>>2]&127](n,1);i=b;return}o=(a[766264]&1)!=0;if((a[607930]&1)!=0){fa[c[(c[191559]|0)+8>>2]&127](n,(a[505608]&1)==0|o)}n=c[191561]|0;if((a[607929]&1)!=0&(n|0)!=0){fa[c[(c[191558]|0)+16>>2]&127](n,(a[526216]&1)==0|o)}c[176758]=o?c[176759]|0:c[176760]|0;i=b;return}function gv(){var a=0,b=0,d=0;a=c[191610]|0;if((a|0)==0){b=0;return b|0}d=c[a+4>>2]|0;if((d|0)==0){b=0;return b|0}b=fc[d&127](c[191562]|0)|0;return b|0}function gw(a){a=a|0;var b=0,d=0,e=0;b=c[191610]|0;if((b|0)==0){d=0;return d|0}e=c[b+8>>2]|0;if((e|0)==0){d=0;return d|0}d=fr[e&63](c[191562]|0,a)|0;return d|0}function gx(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=cf(b|0,47)|0;g=v2(b|0)|0;if((f|0)==0){h=g>>>0>4096?0:4096-g|0;L2470:do{if((h|0)==0){j=0;k=19832;l=1788}else{m=b+g|0;do{if((h|0)==1){n=19832;o=m;p=0}else{r=b+(g+1)|0;a[m]=47;if((h|0)==2){n=19833;o=r;p=1;break}a[r]=0;s=1;break L2470}}while(0);a[o]=0;j=p;k=n;l=1788}}while(0);do{if((l|0)==1788){if((a[k]|0)==0){s=j;break}else{t=k;u=j}while(1){n=t+1|0;p=u+1|0;if((a[n]|0)==0){s=p;break}else{t=n;u=p}}}}while(0);if((s+g|0)>>>0<4096){i=d;return}else{s=c[191244]|0;u=(s|0)!=0?s:c[q>>2]|0;eb(u|0,33568,(v=i,i=i+16|0,c[v>>2]=15e3,c[v+8>>2]=450,v)|0)|0;i=v;u=c[191244]|0;s=(u|0)!=0?u:c[q>>2]|0;aZ(s|0)|0;cd(2)}}if((f|0)==(b+(g-1)|0)){i=d;return}g=e|0;s=a[f]|0;a[g]=s;a[e+1|0]=0;e=v2(b|0)|0;f=e>>>0>4096?0:4096-e|0;L2488:do{if((f|0)==0){w=0;x=g;y=s;l=1780}else{u=f;t=0;j=b+e|0;k=g;while(1){p=u-1|0;if((p|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=t;break L2488}else{u=p;t=t+1|0;j=j+1|0;k=k+1|0}}a[j]=0;w=t;x=k;y=a[k]|0;l=1780}}while(0);do{if((l|0)==1780){if(y<<24>>24==0){z=w;break}else{A=x;B=w}while(1){g=A+1|0;b=B+1|0;if((a[g]|0)==0){z=b;break}else{A=g;B=b}}}}while(0);if((z+e|0)>>>0<4096){i=d;return}else{d=c[191244]|0;e=(d|0)!=0?d:c[q>>2]|0;eb(e|0,33568,(v=i,i=i+16|0,c[v>>2]=15e3,c[v+8>>2]=447,v)|0)|0;i=v;v=c[191244]|0;e=(v|0)!=0?v:c[q>>2]|0;aZ(e|0)|0;cd(2)}}function gy(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0;f=i;g=cf(d|0,47)|0;h=(g|0)==0?d:g+1|0;L2503:do{if((e|0)==0){j=0;k=h;l=1801}else{g=e;d=0;m=b;n=h;while(1){o=g-1|0;if((o|0)==0){break}p=a[n]|0;a[m]=p;if(p<<24>>24==0){r=d;break L2503}else{g=o;d=d+1|0;m=m+1|0;n=n+1|0}}a[m]=0;j=d;k=n;l=1801}}while(0);do{if((l|0)==1801){if((a[k]|0)==0){r=j;break}else{s=k;t=j}while(1){h=s+1|0;b=t+1|0;if((a[h]|0)==0){r=b;break}else{s=h;t=b}}}}while(0);if(r>>>0<e>>>0){i=f;return}else{f=c[191244]|0;e=(f|0)!=0?f:c[q>>2]|0;eb(e|0,33568,(e=i,i=i+16|0,c[e>>2]=15e3,c[e+8>>2]=470,e)|0)|0;i=e;e=c[191244]|0;f=(e|0)!=0?e:c[q>>2]|0;aZ(f|0)|0;cd(2)}}function gz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=4096;g=0;h=b;j=d;while(1){d=f-1|0;if((d|0)==0){k=1809;break}l=a[j]|0;a[h]=l;if(l<<24>>24==0){m=g;break}else{f=d;g=g+1|0;h=h+1|0;j=j+1|0}}do{if((k|0)==1809){a[h]=0;if((a[j]|0)==0){m=g;break}else{n=j;o=g}while(1){f=n+1|0;d=o+1|0;if((a[f]|0)==0){m=d;break}else{n=f;o=d}}}}while(0);if(m>>>0>=4096){m=c[191244]|0;o=(m|0)!=0?m:c[q>>2]|0;eb(o|0,33568,(p=i,i=i+16|0,c[p>>2]=15e3,c[p+8>>2]=475,p)|0)|0;i=p;o=c[191244]|0;m=(o|0)!=0?o:c[q>>2]|0;aZ(m|0)|0;cd(2)}if((v2(b|0)|0)>>>0<2){i=e;return}m=cf(b|0,47)|0;if((m|0)==0){bN(b|0,3,50584,(p=i,i=i+8|0,c[p>>2]=19832,p)|0)|0;i=p;i=e;return}else{a[m+1|0]=0;i=e;return}}function gA(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;if((a[e]|0)==47){g=4096;h=0;j=b;k=e;while(1){l=g-1|0;if((l|0)==0){m=1824;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=h;break}else{g=l;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((m|0)==1824){a[j]=0;if((a[k]|0)==0){o=h;break}else{p=k;r=h}while(1){g=p+1|0;l=r+1|0;if((a[g]|0)==0){o=l;break}else{p=g;r=l}}}}while(0);if(o>>>0<4096){i=f;return}else{o=c[191244]|0;r=(o|0)!=0?o:c[q>>2]|0;eb(r|0,33568,(s=i,i=i+16|0,c[s>>2]=15e3,c[s+8>>2]=562,s)|0)|0;i=s;r=c[191244]|0;o=(r|0)!=0?r:c[q>>2]|0;aZ(o|0)|0;cd(2)}}else{t=4096;u=0;v=b;w=d}while(1){d=t-1|0;if((d|0)==0){m=1830;break}o=a[w]|0;a[v]=o;if(o<<24>>24==0){x=u;break}else{t=d;u=u+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1830){a[v]=0;if((a[w]|0)==0){x=u;break}else{y=w;z=u}while(1){t=y+1|0;d=z+1|0;if((a[t]|0)==0){x=d;break}else{y=t;z=d}}}}while(0);if(x>>>0>=4096){x=c[191244]|0;z=(x|0)!=0?x:c[q>>2]|0;eb(z|0,33568,(s=i,i=i+16|0,c[s>>2]=15e3,c[s+8>>2]=565,s)|0)|0;i=s;z=c[191244]|0;x=(z|0)!=0?z:c[q>>2]|0;aZ(x|0)|0;cd(2)}do{if((v2(b|0)|0)>>>0>=2){x=cf(b|0,47)|0;if((x|0)==0){bN(b|0,3,50584,(s=i,i=i+8|0,c[s>>2]=19832,s)|0)|0;i=s;break}else{a[x+1|0]=0;break}}}while(0);x=v2(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2566:do{if((z|0)==0){A=0;B=e;m=1843}else{y=z;u=0;w=b+x|0;v=e;while(1){d=y-1|0;if((d|0)==0){break}t=a[v]|0;a[w]=t;if(t<<24>>24==0){C=u;break L2566}else{y=d;u=u+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=u;B=v;m=1843}}while(0);do{if((m|0)==1843){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[191244]|0;x=(f|0)!=0?f:c[q>>2]|0;eb(x|0,33568,(s=i,i=i+16|0,c[s>>2]=15e3,c[s+8>>2]=567,s)|0)|0;i=s;s=c[191244]|0;x=(s|0)!=0?s:c[q>>2]|0;aZ(x|0)|0;cd(2)}}function gB(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,r=0.0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+24|0;d=b|0;a[766259]=(c[191562]|0)==0|0;a[766260]=(c[191561]|0)==0|0;a[766261]=(c[191563]|0)==0|0;gu();c[191184]=0;e=d;L2581:do{if((a[513837]|0)!=0){f=gp(513837,33232,0)|0;c[191201]=f;do{if((f|0)!=0){j=f+4|0;if((c[j>>2]|0)==0){v_(c[f>>2]|0);v_(f);break}c[191202]=0;df(c[f>>2]|0,c[j>>2]|0,8,48);j=c[191201]|0;if((c[j+4>>2]|0)==0){break L2581}else{k=0;l=j}while(1){if((a[607928]&1)==0){m=l}else{j=c[191244]|0;n=(j|0)!=0?j:c[q>>2]|0;j=c[(c[l>>2]|0)+(k<<3)>>2]|0;eb(n|0,32256,(o=i,i=i+8|0,c[o>>2]=j,o)|0)|0;i=o;j=c[191244]|0;n=(j|0)!=0?j:c[q>>2]|0;aZ(n|0)|0;m=c[191201]|0}n=k+1|0;if(n>>>0<(c[m+4>>2]|0)>>>0){k=n;l=m}else{break L2581}}}}while(0);c[191201]=0;c[191202]=0}}while(0);m=c[175560]|0;l=c[175561]|0;k=(m>>>0>l>>>0?m:l)-1|0;l=k>>>1|k;k=l>>>2|l;l=k>>>4|k;k=l>>>8|l;l=((k>>>16|k)+1|0)>>>8;k=(a[756288]&1)==0?l>>>0>1?l:1:c[189077]|0;p=+g[126406];g[175568]=p;do{if(p<0.0){r=+g[175562];if(r>0.0){if((a[505628]&1)==0){s=1862}else{t=r}}else{s=1862}if((s|0)==1862){t=+((c[175558]|0)>>>0>>>0)/+((c[175559]|0)>>>0>>>0)}g[175568]=t;if((a[607928]&1)==0){break}l=c[191244]|0;m=(l|0)!=0?l:c[q>>2]|0;r=t;eb(m|0,12888,(o=i,i=i+8|0,h[o>>3]=r,o)|0)|0;i=o;m=c[191244]|0;l=(m|0)!=0?m:c[q>>2]|0;aZ(l|0)|0}}while(0);do{if((a[505592]&1)==0){if((a[505621]&1)==0){s=~~+bH(+(+((c[175558]|0)>>>0>>>0)*+g[126396]));u=s;v=~~+bH(+(+((c[175559]|0)>>>0>>>0)*+g[126397]));break}else{t=+((c[175559]|0)>>>0>>>0);p=+(~~+bH(+(t*+g[175568]))>>>0>>>0);s=~~+bH(+(+g[126396]*p));u=s;v=~~+bH(+(t*+g[126397]));break}}else{u=c[126400]|0;v=c[126401]|0}}while(0);s=(a[607928]&1)==0;do{if((u|0)==0|(v|0)==0){if(s){break}l=c[191244]|0;m=(l|0)!=0?l:c[q>>2]|0;a3(48168,30,1,m|0)|0;m=c[191244]|0;l=(m|0)!=0?m:c[q>>2]|0;aZ(l|0)|0}else{if(s){break}l=c[191244]|0;m=(l|0)!=0?l:c[q>>2]|0;eb(m|0,50528,(o=i,i=i+16|0,c[o>>2]=u,c[o+8>>2]=v,o)|0)|0;i=o;m=c[191244]|0;l=(m|0)!=0?m:c[q>>2]|0;aZ(l|0)|0}}while(0);c[191569]=0;c[191567]=0;c[191568]=0;s=k<<8;v_(c[191586]|0);v_(c[191589]|0);v_(c[191590]|0);v_(c[191593]|0);v_(c[191596]|0);v_(c[191594]|0);v_(c[191600]|0);v3(766280,0,128);v_(c[191602]|0);c[191602]=0;if((c[175572]|0)==0){l=c[191244]|0;m=(l|0)!=0?l:c[q>>2]|0;a3(34464,120,1,m|0)|0;m=c[191244]|0;l=(m|0)!=0?m:c[q>>2]|0;aZ(l|0)|0;c[191578]=1;c[191576]=2;c[191577]=3;if(!(hI(766280)|0)){l=c[191244]|0;m=(l|0)!=0?l:c[q>>2]|0;a3(46120,53,1,m|0)|0;m=c[191244]|0;l=(m|0)!=0?m:c[q>>2]|0;aZ(l|0)|0;gF(45008)}l=ac(s,s)|0;s=l<<1;if(l>>>0>65535){w=(l&2147418112|0)==(l|0)?s:-1}else{w=s}s=vZ(w)|0;do{if((s|0)!=0){if((c[s-4>>2]&3|0)==0){break}v3(s|0,0,w|0)}}while(0);c[191602]=s}c[e>>2]=c[2272];c[e+4>>2]=c[2273];c[e+8>>2]=c[2274];c[e+12>>2]=c[2275];c[e+16>>2]=c[2276];c[d>>2]=u;c[d+4>>2]=v;a[d+8|0]=a[505592]&1;if((a[505608]&1)==0){x=0}else{x=a[702293]&1^1}a[d+9|0]=x;a[d+10|0]=a[505621]&1;a[d+11|0]=a[505620]&1;c[d+12>>2]=k;if((a[756288]&1)==0){y=(c[175572]|0)==1|0}else{y=1}a[d+16|0]=y;y=c[191560]|0;k=fg[c[c[191559]>>2]&63](d,766240,766252)|0;c[191562]=k;if((k|0)==0){d=c[191244]|0;x=(d|0)!=0?d:c[q>>2]|0;a3(44008,62,1,x|0)|0;x=c[191244]|0;d=(x|0)!=0?x:c[q>>2]|0;aZ(d|0)|0;gF(45008)}c[191610]=0;d=c[191559]|0;x=c[d+56>>2]|0;if((x|0)==0){z=d}else{fa[x&127](k,766440);z=c[191559]|0}k=c[z+40>>2]|0;z=c[175569]|0;if((k|0)!=0&(z|0)!=0){fa[k&127](c[191562]|0,z)}z=c[191610]|0;do{if((z|0)!=0){k=c[z+12>>2]|0;x=c[126408]|0;if(!((k|0)!=0&(x|0)!=4)){break}fa[k&127](c[191562]|0,x)}}while(0);do{if((c[191560]|0)==0){if((a[607928]&1)!=0){z=c[191244]|0;x=(z|0)!=0?z:c[q>>2]|0;a3(42528,101,1,x|0)|0;x=c[191244]|0;z=(x|0)!=0?x:c[q>>2]|0;aZ(z|0)|0}c[191560]=y;if((y|0)==0){z=c[191244]|0;x=(z|0)!=0?z:c[q>>2]|0;a3(40328,59,1,x|0)|0;x=c[191244]|0;z=(x|0)!=0?x:c[q>>2]|0;aZ(z|0)|0;gF(45008)}z=fu[c[y>>2]&31]()|0;c[191563]=z;if((z|0)!=0){break}z=c[191244]|0;x=(z|0)!=0?z:c[q>>2]|0;a3(41416,59,1,x|0)|0;x=c[191244]|0;z=(x|0)!=0?x:c[q>>2]|0;aZ(z|0)|0;gF(45008)}}while(0);y=c[191604]|0;if((y|0)!=0){z=y+24|0;x=y+12|0;k=c[x>>2]|0;if((c[z>>2]|0)==0){A=k}else{d=0;v=k;while(1){v_(c[v+(d*136|0)>>2]|0);v_(c[v+(d*136|0)+8>>2]|0);k=d+1|0;u=c[x>>2]|0;if(k>>>0<(c[z>>2]|0)>>>0){d=k;v=u}else{A=u;break}}}v_(A);A=c[y+4>>2]|0;if((A|0)!=0){fa[c[A>>2]&127](c[y>>2]|0,0)}v_(y);c[191604]=0}do{if((a[566896]|0)!=0){y=hH()|0;c[191604]=y;if((y|0)!=0){break}y=c[191244]|0;A=(y|0)!=0?y:c[q>>2]|0;a3(35904,45,1,A|0)|0;A=c[191244]|0;y=(A|0)!=0?A:c[q>>2]|0;aZ(y|0)|0}}while(0);y=756280;c[y>>2]=0;c[y+4>>2]=0;y=c[176736]|0;if((a[766258]&1)==0&(y|0)!=0){fx[y&127]()}a[766258]=0;do{if((c[191561]|0)==0){y=~~(+g[150946]*65536.0);A=vZ(y<<1)|0;c[176766]=A;if((A|0)==0){A=c[191244]|0;v=(A|0)!=0?A:c[q>>2]|0;eb(v|0,33568,(o=i,i=i+16|0,c[o>>2]=23944,c[o+8>>2]=497,o)|0)|0;i=o;v=c[191244]|0;A=(v|0)!=0?v:c[q>>2]|0;aZ(A|0)|0;cd(2)}c[176760]=512;c[176759]=2048;c[176758]=512;A=vZ(8192)|0;c[176767]=A;if((A|0)==0){A=c[191244]|0;v=(A|0)!=0?A:c[q>>2]|0;eb(v|0,33568,(o=i,i=i+16|0,c[o>>2]=23944,c[o+8>>2]=504,o)|0)|0;i=o;v=c[191244]|0;A=(v|0)!=0?v:c[q>>2]|0;aZ(A|0)|0;cd(2)}c[176769]=4096;if((a[522100]&1)==0){a[607929]=0;break}A=fg[c[c[191558]>>2]&63]((a[522116]|0)!=0?522116:0,c[130526]|0,c[131553]|0)|0;c[191561]=A;do{if((A|0)==0){v=c[191244]|0;d=(v|0)!=0?v:c[q>>2]|0;a3(20536,85,1,d|0)|0;d=c[191244]|0;v=(d|0)!=0?d:c[q>>2]|0;aZ(v|0)|0;a[607929]=0}else{if((a[607929]&1)==0){break}v=c[(c[191558]|0)+24>>2]|0;if((v|0)==0){break}if(!(fc[v&127](A)|0)){break}a[707056]=1}}while(0);do{if((a[526216]&1)==0){if((a[607929]&1)==0){break}fa[c[(c[191558]|0)+16>>2]&127](c[191561]|0,1);c[176758]=c[176759]}}while(0);t=+((c[130526]|0)>>>0>>>0)/+g[130528];h[88381]=t;h[88387]=t;A=a[530324]|0;v=c[176754]|0;do{if((v|0)!=0){d=c[176755]|0;if((d|0)==0){break}e9[c[d+8>>2]&2047](v)}}while(0);c[176755]=1816;v=ih(t)|0;c[176754]=v;if((v|0)==0){c[176755]=0;v=c[191244]|0;d=(v|0)!=0?v:c[q>>2]|0;v=A<<24>>24!=0?530324:16936;eb(d|0,18936,(o=i,i=i+8|0,c[o>>2]=v,o)|0)|0;i=o;v=c[191244]|0;d=(v|0)!=0?v:c[q>>2]|0;aZ(d|0)|0;a[607929]=0}d=vZ(16384)|0;c[176756]=d;if((d|0)==0){d=c[191244]|0;v=(d|0)!=0?d:c[q>>2]|0;eb(v|0,33568,(o=i,i=i+16|0,c[o>>2]=23944,c[o+8>>2]=561,o)|0)|0;i=o;v=c[191244]|0;d=(v|0)!=0?v:c[q>>2]|0;aZ(d|0)|0;cd(2)}c[176757]=0;if(+((c[130526]|0)>>>0>>>0)>=+g[130528]*16.0){d=c[191244]|0;v=(d|0)!=0?d:c[q>>2]|0;eb(v|0,33568,(o=i,i=i+16|0,c[o>>2]=23944,c[o+8>>2]=565,o)|0)|0;i=o;v=c[191244]|0;d=(v|0)!=0?v:c[q>>2]|0;aZ(d|0)|0;cd(2)}d=vZ(y<<2)|0;c[176765]=d;if((d|0)==0){d=c[191244]|0;v=(d|0)!=0?d:c[q>>2]|0;eb(v|0,33568,(o=i,i=i+16|0,c[o>>2]=23944,c[o+8>>2]=566,o)|0)|0;i=o;v=c[191244]|0;d=(v|0)!=0?v:c[q>>2]|0;aZ(d|0)|0;cd(2)}a[707092]=0;L2714:do{if((c[176727]|0)==0){if((a[607929]&1)==0){break}if((a[530313]&1)==0){break}d=c[191558]|0;v=c[d+36>>2]|0;do{if((v|0)!=0){if((c[d+32>>2]|0)==0){break}c[176776]=fc[v&127](c[191561]|0)|0;a[707092]=1;break L2714}}while(0);v=c[191244]|0;d=(v|0)!=0?v:c[q>>2]|0;a3(14872,97,1,d|0)|0;d=c[191244]|0;v=(d|0)!=0?d:c[q>>2]|0;aZ(v|0)|0}}while(0);t=+g[132580];g[176777]=t;g[176778]=+T(10.0,+(t/20.0));y=739888;c[y>>2]=0;c[y+4>>2]=0;if((a[607929]&1)==0){break}if(!((a[707057]&1)==0&(c[176727]|0)!=0)){break}y=c[(c[191558]|0)+12>>2]|0;A=c[191561]|0;fc[y&127](A)|0}}while(0);if((a[766264]&1)==0){B=707e3;C=0;D=0;E=B|0;c[E>>2]=C;F=B+4|0;c[F>>2]=D;i=b;return}o=c[191562]|0;if((a[607930]&1)!=0&(o|0)!=0){fa[c[(c[191559]|0)+8>>2]&127](o,1)}o=c[191561]|0;if((a[607929]&1)!=0&(o|0)!=0){fa[c[(c[191558]|0)+16>>2]&127](o,1)}c[176758]=c[176759];B=707e3;C=0;D=0;E=B|0;c[E>>2]=C;F=B+4|0;c[F>>2]=D;i=b;return}function gC(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0,r=0,s=0,t=0,u=0.0,v=0;b=i;d=c[191561]|0;e=c[191558]|0;if((d|0)!=0&(e|0)!=0){e9[c[e+20>>2]&2047](d)}v_(c[176766]|0);c[176766]=0;c[176757]=0;v_(c[176767]|0);c[176767]=0;if((a[522100]&1)==0){a[607929]=0;i=b;return}d=c[176755]|0;e=c[176754]|0;if((d|0)!=0&(e|0)!=0){e9[c[d+8>>2]&2047](e)}c[176755]=0;c[176754]=0;v_(c[176756]|0);c[176756]=0;v_(c[176765]|0);c[176765]=0;e=739888;d=c[e>>2]|0;f=c[e+4>>2]|0;e=0;g=f>>>0<e>>>0|f>>>0==e>>>0&d>>>0<8192>>>0?d:8192;if(g>>>0<3){i=b;return}else{j=1;k=0;l=0}do{l=wc(c[707120+(j<<2)>>2]|0,0,l,k)|0;k=G;j=j+1|0;}while(j>>>0<g>>>0);j=g-1|0;d=wn(l,k,j,0)|0;k=d;d=1;l=0;e=0;do{f=k-(c[707120+(d<<2)>>2]|0)|0;e=wc(ac(f,f)|0,0,e,l)|0;l=G;d=d+1|0;}while(d>>>0<g>>>0);m=+S(+((+(e>>>0)+ +(l>>>0)*4294967296.0)/+((g-2|0)>>>0>>>0)));l=c[176776]|0;n=+(l>>>0>>>0);o=+(k|0)/n;k=(l*3|0)>>>2;e=l>>>2;l=0;d=0;f=1;while(1){p=c[707120+(f<<2)>>2]|0;if(p>>>0<k>>>0){r=(p>>>0<=e>>>0)+d|0;s=l}else{r=d;s=l+1|0}p=f+1|0;if(p>>>0<g>>>0){l=s;d=r;f=p}else{break}}f=a[607928]|0;if((f&1)==0){t=f}else{f=c[191244]|0;d=(f|0)!=0?f:c[q>>2]|0;u=(1.0-o)*100.0;o=+(~~m>>>0>>>0)/n*100.0;eb(d|0,31680,(v=i,i=i+16|0,h[v>>3]=u,h[v+8>>3]=o,v)|0)|0;i=v;d=c[191244]|0;f=(d|0)!=0?d:c[q>>2]|0;aZ(f|0)|0;t=a[607928]|0}if((t&1)==0){i=b;return}t=c[191244]|0;o=+(j>>>0>>>0);eb(((t|0)!=0?t:c[q>>2]|0)|0,30896,(v=i,i=i+16|0,h[v>>3]=+(s>>>0>>>0)*100.0/o,h[v+8>>3]=+(r>>>0>>>0)*100.0/o,v)|0)|0;i=v;v=c[191244]|0;aZ(((v|0)!=0?v:c[q>>2]|0)|0)|0;i=b;return}function gD(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0.0,v=0.0;b=i;d=c[191604]|0;if((d|0)!=0){e=d+24|0;f=d+12|0;g=c[f>>2]|0;if((c[e>>2]|0)==0){j=g}else{k=0;l=g;while(1){v_(c[l+(k*136|0)>>2]|0);v_(c[l+(k*136|0)+8>>2]|0);g=k+1|0;m=c[f>>2]|0;if(g>>>0<(c[e>>2]|0)>>>0){k=g;l=m}else{j=m;break}}}v_(j);j=c[d+4>>2]|0;if((j|0)!=0){fa[c[j>>2]&127](c[d>>2]|0,0)}v_(d);c[191604]=0;v3(766424,0,16)}d=c[191563]|0;j=c[191562]|0;l=c[191560]|0;if((d|0)!=(j|0)&(l|0)!=0){e9[c[l+16>>2]&2047](d);n=c[191562]|0}else{n=j}j=c[191559]|0;if((n|0)!=0&(j|0)!=0){e9[c[j+24>>2]&2047](n)}v_(c[191586]|0);v_(c[191589]|0);v_(c[191590]|0);v_(c[191593]|0);v_(c[191596]|0);v_(c[191594]|0);v_(c[191600]|0);v3(766280,0,128);v_(c[191602]|0);c[191602]=0;n=c[191201]|0;if((n|0)!=0){j=n+4|0;d=n|0;l=c[d>>2]|0;if((c[j>>2]|0)==0){o=l}else{k=0;e=l;while(1){v_(c[e+(k<<3)>>2]|0);l=k+1|0;f=c[d>>2]|0;if(l>>>0<(c[j>>2]|0)>>>0){k=l;e=f}else{o=f;break}}}v_(o);v_(n)}c[191201]=0;c[191202]=0;if((a[513836]&1)!=0){if((a[607928]&1)==0){i=b;return}n=c[191244]|0;o=(n|0)!=0?n:c[q>>2]|0;a3(39352,66,1,o|0)|0;o=c[191244]|0;n=(o|0)!=0?o:c[q>>2]|0;aZ(n|0)|0;i=b;return}n=756280;o=c[n+4>>2]|0;e=0;if(o>>>0<e>>>0|o>>>0==e>>>0&(c[n>>2]|0)>>>0<4096>>>0){if((a[607928]&1)==0){i=b;return}n=c[191244]|0;e=(n|0)!=0?n:c[q>>2]|0;eb(e|0,38368,(p=i,i=i+8|0,c[p>>2]=4096,p)|0)|0;i=p;e=c[191244]|0;n=(e|0)!=0?e:c[q>>2]|0;aZ(n|0)|0;i=b;return}else{r=0;s=0;t=0}do{n=739896+(r<<3)|0;t=wc(c[n>>2]|0,c[n+4>>2]|0,t,s)|0;s=G;r=r+1|0;}while(r>>>0<2048);r=wk(t,s,2048,0)|0;s=G;t=0;n=0;e=0;do{o=739896+(e<<3)|0;k=wd(c[o>>2]|0,c[o+4>>2]|0,r,s)|0;o=G;j=wm(k,o,k,o)|0;n=wc(j,G,n,t)|0;t=G;e=e+1|0;}while(e>>>0<2048);u=+(r>>>0)+ +(s|0)*4294967296.0;if((a[607928]&1)==0){i=b;return}v=+S(+((+(n>>>0)+ +(t|0)*4294967296.0)/2047.0))/u;t=c[191244]|0;eb(((t|0)!=0?t:c[q>>2]|0)|0,37400,(p=i,i=i+24|0,h[p>>3]=1.0e6/u,h[p+8>>3]=v*100.0,c[p+16>>2]=2048,p)|0)|0;i=p;p=c[191244]|0;aZ(((p|0)!=0?p:c[q>>2]|0)|0)|0;i=b;return}function gE(a){a=a|0;var b=0,d=0;if((a|0)==0){return}b=c[a+4>>2]|0;if((b|0)!=0){d=b;while(1){v_(c[d+4>>2]|0);v_(c[d+8>>2]|0);b=c[d+12>>2]|0;v_(d|0);if((b|0)==0){break}else{d=b}}}d=c[a+16>>2]|0;if((d|0)!=0){b=d;while(1){v_(c[b>>2]|0);d=c[b+4>>2]|0;v_(b);if((d|0)==0){break}else{b=d}}}v_(c[a>>2]|0);v_(a);return}function gF(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[764981]&1)==0){d=c[191244]|0;e=(d|0)!=0?d:c[q>>2]|0;eb(e|0,33568,(e=i,i=i+16|0,c[e>>2]=43208,c[e+8>>2]=832,e)|0)|0;i=e;e=c[191244]|0;d=(e|0)!=0?e:c[q>>2]|0;aZ(d|0)|0;cd(2)}else{f=1024;g=764983;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=2033;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==2033){eC(766008,1)}a[g]=0;if((a[h]|0)==0){eC(766008,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);eC(766008,1)}function gG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+4112|0;f=e|0;g=e+8|0;h=e+4104|0;j=vZ(20)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){v3(j|0,0,20)}l=j;if((b|0)==0){k=l;i=e;return k|0}m=dn(b|0)|0;n=j;c[n>>2]=m;if((m|0)==0){v_(j);k=0;i=e;return k|0}o=j+12|0;c[o>>2]=d;d=c2(b|0,41400)|0;if((d|0)==0){v_(m);v_(j);k=0;i=e;return k|0}if((eg(d|0)|0)==0){m=j+8|0;b=j+4|0;p=g|0;r=j+16|0;do{j=vZ(16)|0;do{if((j|0)!=0){if((c[j-4>>2]&3|0)==0){break}v3(j|0,0,16)}}while(0);s=j;t=vZ(9)|0;u=bP(d|0)|0;v=0;w=8;x=t;while(1){if((u|0)==(-1|0)|(u|0)==10){break}if((v|0)==(w|0)){t=w<<1;z=t;A=v$(x,t|1)|0}else{z=w;A=x}a[A+v|0]=u&255;u=bP(d|0)|0;v=v+1|0;w=z;x=A}a[x+v|0]=0;if((x|0)!=0){w=b1(x|0,35)|0;if((w|0)!=0){a[w]=0}u=c[o>>2]|0;do{if((w|0)==(x|0)){if(u>>>0>=16){B=2105;break}if((bJ(x+1|0,37376,8)|0)!=0){C=x;B=2106;break}t=x+9|0;while(1){D=t+1|0;if((bd(a[t]|0)|0)==0){break}else{t=D}}E=a[t]|0;if((E<<24>>24|0)==0){break}else if((E<<24>>24|0)==34){E=d7(D|0,34376,f|0)|0;if((E|0)==0){break}F=dn(E|0)|0}else{E=d7(t|0,33136,f|0)|0;if((E|0)==0){break}F=dn(E|0)|0}if((F|0)==0){break}E=c[r>>2]|0;G=vZ(8)|0;do{if((G|0)!=0){if((c[G-4>>2]&3|0)==0){break}H=G;I=H|0;y=0;a[I]=y&255;y=y>>8;a[I+1|0]=y&255;y=y>>8;a[I+2|0]=y&255;y=y>>8;a[I+3|0]=y&255;I=H+4|0;y=0;a[I]=y&255;y=y>>8;a[I+1|0]=y&255;y=y>>8;a[I+2|0]=y&255;y=y>>8;a[I+3|0]=y&255}}while(0);t=G;c[G>>2]=dn(F|0)|0;if((E|0)==0){c[r>>2]=t}else{I=E;do{J=I+4|0;I=c[J>>2]|0;}while((I|0)!=0);c[J>>2]=t}L2905:do{if((a[F]|0)==126){I=dC(44720)|0;E=4096;G=p;H=(I|0)!=0?I:766672;while(1){I=E-1|0;if((I|0)==0){B=2079;break}K=a[H]|0;a[G]=K;if(K<<24>>24==0){break}else{E=I;G=G+1|0;H=H+1|0}}do{if((B|0)==2079){B=0;a[G]=0;if((a[H]|0)==0){break}else{L=H}do{L=L+1|0;}while((a[L]|0)!=0)}}while(0);H=F+1|0;G=v2(p|0)|0;E=G>>>0>4096?0:4096-G|0;if((E|0)==0){M=H}else{I=E;E=g+G|0;G=H;while(1){H=I-1|0;if((H|0)==0){break}K=a[G]|0;a[E]=K;if(K<<24>>24==0){break L2905}else{I=H;E=E+1|0;G=G+1|0}}a[E]=0;M=G}if((a[M]|0)==0){break}else{N=M}do{N=N+1|0;}while((a[N]|0)!=0)}else{gA(p,c[n>>2]|0,F)}}while(0);t=gG(p,(c[o>>2]|0)+1|0)|0;if((t|0)==0){v_(F);break}G=c[b>>2]|0;if((G|0)==0){E=t+4|0;I=c[E>>2]|0;if((I|0)==0){O=0}else{H=I;do{a[H|0]=1;H=c[H+12>>2]|0;}while((H|0)!=0);O=c[E>>2]|0}c[b>>2]=O;P=O}else{H=G;do{Q=H+12|0;H=c[Q>>2]|0;}while((H|0)!=0);H=t+4|0;G=c[H>>2]|0;if((G|0)==0){R=0}else{E=G;do{a[E|0]=1;E=c[E+12>>2]|0;}while((E|0)!=0);R=c[H>>2]|0}c[Q>>2]=R;P=c[b>>2]|0}c[t+4>>2]=0;if((P|0)==0){S=0}else{E=P;while(1){G=c[E+12>>2]|0;if((G|0)==0){S=E;break}else{E=G}}}c[m>>2]=S;gE(t);v_(F)}else{if(u>>>0>15){B=2105}else{C=x;B=2106}}}while(0);if((B|0)==2105){B=0;u=c[q>>2]|0;a3(36032,58,1,u|0)|0;C=x;B=2106}L2952:do{if((B|0)==2106){while(1){B=0;if((bd(a[C]|0)|0)==0){break}else{C=C+1|0;B=2106}}t=vZ(9)|0;if((eI(a[C]|0)|0)==0){T=C;U=t;V=0}else{u=C;w=t;t=8;v=0;while(1){if((v|0)==(t|0)){E=v<<1;W=E;X=v$(w,E|1)|0}else{W=t;X=w}E=u+1|0;H=v+1|0;a[X+v|0]=a[u]|0;if((eI(a[E]|0)|0)==0){T=E;U=X;V=H;break}else{u=E;w=X;t=W;v=H}}}a[U+V|0]=0;v=j+4|0;c[v>>2]=U;t=T;while(1){Y=t+1|0;if((bd(a[t]|0)|0)==0){break}else{t=Y}}do{if((a[t]|0)==61){w=Y;while(1){Z=w+1|0;if((bd(a[w]|0)|0)==0){break}else{w=Z}}u=a[w]|0;if((u<<24>>24|0)==34){H=d7(Z|0,34376,h|0)|0;if((H|0)==0){B=2120;break}_=dn(H|0)|0}else if((u<<24>>24|0)==0){B=2120;break}else{u=d7(w|0,33136,h|0)|0;if((u|0)==0){B=2120;break}_=dn(u|0)|0}c[j+8>>2]=_;if((_|0)==0){break}if((c[b>>2]|0)==0){c[b>>2]=s;c[m>>2]=s;break L2952}else{c[(c[m>>2]|0)+12>>2]=s;c[m>>2]=s;break L2952}}else{B=2120}}while(0);if((B|0)==2120){B=0;c[j+8>>2]=0}c[v>>2]=0;v_(U)}}while(0);v_(x)}if((s|0)!=(c[m>>2]|0)){v_(j)}}while((eg(d|0)|0)==0)}aR(d|0)|0;k=l;i=e;return k|0}function gH(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+8192|0;g=f|0;h=f+4096|0;j=b+4|0;while(1){k=c[j>>2]|0;if((k|0)==0){l=0;m=2176;break}if((cJ(d|0,c[k+4>>2]|0)|0)==0){break}else{j=k+12|0}}if((m|0)==2176){i=f;return l|0}j=c[k+8>>2]|0;k=a[j]|0;do{if((k<<24>>24|0)==58){if((a[j+1|0]|0)!=47){n=e;o=j;p=4096;m=2167;break}d=h|0;b=g|0;a[d]=0;r=bZ()|0;s=0;while(1){if(s>>>0>=3){m=2153;break}t=c[9408+(s<<2)>>2]|0;bN(b|0,4096,44088,(u=i,i=i+16|0,c[u>>2]=r,c[u+8>>2]=t,u)|0)|0;i=u;v=eJ(b|0,d|0,4095)|0;if((v|0)>-1){m=2152;break}else{s=s+1|0}}if((m|0)==2152){a[h+v|0]=0}else if((m|0)==2153){s=c[191244]|0;a3(42656,78,1,((s|0)!=0?s:c[q>>2]|0)|0)|0;s=c[191244]|0;aZ(((s|0)!=0?s:c[q>>2]|0)|0)|0}if((a[607928]&1)!=0){s=c[191244]|0;b=(s|0)!=0?s:c[q>>2]|0;eb(b|0,32560,(u=i,i=i+8|0,c[u>>2]=d,u)|0)|0;i=u;b=c[191244]|0;s=(b|0)!=0?b:c[q>>2]|0;aZ(s|0)|0}do{if((v2(d|0)|0)>>>0<2){w=4096;x=0;y=e;z=d}else{s=cf(d|0,47)|0;if((s|0)==0){bN(d|0,3,50584,(u=i,i=i+8|0,c[u>>2]=19832,u)|0)|0;i=u;w=4096;x=0;y=e;z=d;break}else{a[s+1|0]=0;w=4096;x=0;y=e;z=d;break}}}while(0);while(1){d=w-1|0;if((d|0)==0){m=2162;break}s=a[z]|0;a[y]=s;if(s<<24>>24==0){A=x;break}else{w=d;x=x+1|0;y=y+1|0;z=z+1|0}}do{if((m|0)==2162){a[y]=0;if((a[z]|0)==0){A=x;break}else{B=z;C=x}while(1){d=B+1|0;s=C+1|0;if((a[d]|0)==0){A=s;break}else{B=d;C=s}}}}while(0);if(A>>>0<4096){D=A;E=j+2|0;m=2166;break}else{l=0;i=f;return l|0}}else if((k<<24>>24|0)==126){s=dC(44720)|0;if((s|0)==0){n=e;o=j;p=4096;m=2167;break}else{F=4096;G=0;H=e;I=s}while(1){s=F-1|0;if((s|0)==0){m=2144;break}d=a[I]|0;a[H]=d;if(d<<24>>24==0){J=G;break}else{F=s;G=G+1|0;H=H+1|0;I=I+1|0}}do{if((m|0)==2144){a[H]=0;if((a[I]|0)==0){J=G;break}else{K=I;L=G}while(1){s=K+1|0;d=L+1|0;if((a[s]|0)==0){J=d;break}else{K=s;L=d}}}}while(0);if(J>>>0<4096){D=J;E=j+1|0;m=2166;break}else{l=0;i=f;return l|0}}else{n=e;o=j;p=4096;m=2167}}while(0);if((m|0)==2166){if((D|0)==4096){M=0;N=E;O=0;m=2171}else{n=e+D|0;o=E;p=4096-D|0;m=2167}}L3040:do{if((m|0)==2167){D=p;E=0;e=n;j=o;while(1){J=D-1|0;if((J|0)==0){break}L=a[j]|0;a[e]=L;if(L<<24>>24==0){P=E;Q=p;break L3040}else{D=J;E=E+1|0;e=e+1|0;j=j+1|0}}a[e]=0;M=E;N=j;O=p;m=2171}}while(0);do{if((m|0)==2171){if((a[N]|0)==0){P=M;Q=O;break}else{R=N;S=M}while(1){p=R+1|0;o=S+1|0;if((a[p]|0)==0){P=o;Q=O;break}else{R=p;S=o}}}}while(0);l=P>>>0<Q>>>0;i=f;return l|0}function gI(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;while(1){g=c[f>>2]|0;if((g|0)==0){h=0;i=2195;break}if((cJ(d|0,c[g+4>>2]|0)|0)==0){break}else{f=g+12|0}}if((i|0)==2195){return h|0}i=c[g+8>>2]|0;if((v9(i|0,49992)|0)==0){a[e]=1;h=1;return h|0}if((v9(i|0,23872)|0)==0){a[e]=1;h=1;return h|0}if((v9(i|0,20464)|0)==0){a[e]=0;h=1;return h|0}if((v9(i|0,18856)|0)!=0){h=0;return h|0}a[e]=0;h=1;return h|0}function gJ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;b=c[f>>2]|0;L3076:do{if((b|0)==0){g=0}else{h=b;while(1){if((a[h|0]&1)==0){if((cJ(d|0,c[h+4>>2]|0)|0)==0){break}}i=c[h+12>>2]|0;if((i|0)==0){g=h;break L3076}else{h=i}}i=h+8|0;v_(c[i>>2]|0);c[i>>2]=dn(e|0)|0;return}}while(0);b=vZ(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)==0){break}v3(b|0,0,16)}}while(0);i=b;c[b+4>>2]=dn(d|0)|0;c[b+8>>2]=dn(e|0)|0;if((g|0)==0){c[f>>2]=i;return}else{c[g+12>>2]=i;return}}function gK(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=(d|0)!=0;do{if(f){g=c2(d|0,47696)|0;if((g|0)==0){h=0}else{j=g;break}i=e;return h|0}else{j=c[o>>2]|0}}while(0);d=c[b+16>>2]|0;if((d|0)!=0){g=d;do{eb(j|0,43952,(k=i,i=i+8|0,c[k>>2]=c[g>>2],k)|0)|0;i=k;g=c[g+4>>2]|0;}while((g|0)!=0)}g=c[b+4>>2]|0;if((g|0)!=0){b=g;do{if((a[b|0]&1)==0){g=c[b+4>>2]|0;d=c[b+8>>2]|0;eb(j|0,42440,(k=i,i=i+16|0,c[k>>2]=g,c[k+8>>2]=d,k)|0)|0;i=k}b=c[b+12>>2]|0;}while((b|0)!=0)}if(!f){h=1;i=e;return h|0}aR(j|0)|0;h=1;i=e;return h|0}function gL(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aX=0,aY=0,a_=0,a$=0,a1=0,a2=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0.0,bI=0.0,bJ=0,bK=0,bL=0,bM=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0;e=i;i=i+12848|0;f=e|0;h=e+72|0;j=e+144|0;k=e+4312|0;l=e+4320|0;m=e+8416|0;n=e+12512|0;o=e+12520|0;p=e+12528|0;r=e+12536|0;s=e+12544|0;t=e+12552|0;u=e+12560|0;v=e+12568|0;w=e+12576|0;x=e+12584|0;y=e+12592|0;z=e+12600|0;A=e+12608|0;B=e+12616|0;C=e+12624|0;D=e+12632|0;E=e+12640|0;F=e+12648|0;G=e+12656|0;H=e+12664|0;I=e+12672|0;J=e+12736|0;K=e+12744|0;L=e+12752|0;M=e+12760|0;N=e+12768|0;O=e+12776|0;P=e+12784|0;Q=e+12792|0;R=e+12800|0;S=e+12808|0;T=e+12816|0;U=e+12824|0;V=e+12832|0;W=e+12840|0;do{if((d|0)==0){X=e+216|0;Y=dC(44768)|0;Z=dC(44720)|0;do{if((Y|0)==0){if((Z|0)==0){_=2240;break}bN(X|0,4096,44584,($=i,i=i+8|0,c[$>>2]=Z,$)|0)|0;i=$;_=2233}else{bN(X|0,4096,44656,($=i,i=i+8|0,c[$>>2]=Y,$)|0)|0;i=$;_=2233}}while(0);if((_|0)==2233){if((a[607928]&1)!=0){Y=c[191244]|0;aa=(Y|0)!=0?Y:c[q>>2]|0;eb(aa|0,44328,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[191244]|0;Y=(aa|0)!=0?aa:c[q>>2]|0;aZ(Y|0)|0}Y=gG(X,0)|0;if((Y|0)!=0|(Z|0)==0){ab=Y}else{bN(X|0,4096,44192,($=i,i=i+8|0,c[$>>2]=Z,$)|0)|0;i=$;if((a[607928]&1)!=0){Y=c[191244]|0;aa=(Y|0)!=0?Y:c[q>>2]|0;eb(aa|0,44328,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[191244]|0;Y=(aa|0)!=0?aa:c[q>>2]|0;aZ(Y|0)|0}ab=gG(X,0)|0}if((ab|0)==0){_=2240}else{ac=ab}}do{if((_|0)==2240){gq(X,44072,43912);if((a[607928]&1)!=0){Y=c[191244]|0;aa=(Y|0)!=0?Y:c[q>>2]|0;eb(aa|0,44328,($=i,i=i+8|0,c[$>>2]=X,$)|0)|0;i=$;aa=c[191244]|0;Y=(aa|0)!=0?aa:c[q>>2]|0;aZ(Y|0)|0}Y=gG(X,0)|0;if((Y|0)==0){ad=1}else{ac=Y;break}i=e;return ad|0}}while(0);Z=4096;Y=628458;aa=X;while(1){ae=Z-1|0;if((ae|0)==0){_=2246;break}af=a[aa]|0;a[Y]=af;if(af<<24>>24==0){break}else{Z=ae;Y=Y+1|0;aa=aa+1|0}}do{if((_|0)==2246){a[Y]=0;if((a[aa]|0)==0){break}else{ag=aa}do{ag=ag+1|0;}while((a[ag]|0)!=0)}}while(0);if((ac|0)==0){ad=1}else{ah=ac;break}i=e;return ad|0}else{aa=gG(d,0)|0;if((aa|0)==0){ad=0}else{ah=aa;break}i=e;return ad|0}}while(0);d=l|0;l=4096;ac=d;ag=632554;while(1){ab=l-1|0;if((ab|0)==0){_=2252;break}aa=a[ag]|0;a[ac]=aa;if(aa<<24>>24==0){break}else{l=ab;ac=ac+1|0;ag=ag+1|0}}do{if((_|0)==2252){a[ac]=0;if((a[ag]|0)==0){break}else{ai=ag}do{ai=ai+1|0;}while((a[ai]|0)!=0)}}while(0);ai=d7(d|0,20456,k|0)|0;d=(a[607928]&1)!=0;if((ai|0)==0){aj=d}else{ag=ah+4|0;ac=ai;ai=d;while(1){if(ai){d=c[191244]|0;l=(d|0)!=0?d:c[q>>2]|0;eb(l|0,18816,($=i,i=i+8|0,c[$>>2]=ac,$)|0)|0;i=$;l=c[191244]|0;d=(l|0)!=0?l:c[q>>2]|0;aZ(d|0)|0}d=gG(ac,0)|0;if((d|0)==0){l=c[191244]|0;ab=(l|0)!=0?l:c[q>>2]|0;eb(ab|0,16736,($=i,i=i+8|0,c[$>>2]=ac,$)|0)|0;i=$;ab=c[191244]|0;l=(ab|0)!=0?ab:c[q>>2]|0;aZ(l|0)|0}else{l=c[d+8>>2]|0;if((l|0)!=0){c[l+12>>2]=c[ag>>2];l=d+4|0;c[ag>>2]=c[l>>2];c[l>>2]=0}gE(d)}d=d7(0,27720,k|0)|0;l=(a[607928]&1)!=0;if((d|0)==0){aj=l;break}else{ac=d;ai=l}}}do{if(aj){ai=c[191244]|0;ac=(ai|0)!=0?ai:c[q>>2]|0;a3(12800,15,1,ac|0)|0;ac=c[191244]|0;ai=(ac|0)!=0?ac:c[q>>2]|0;aZ(ai|0)|0;ai=c[q>>2]|0;ac=c[ah+16>>2]|0;if((ac|0)!=0){k=ac;do{eb(ai|0,43952,($=i,i=i+8|0,c[$>>2]=c[k>>2],$)|0)|0;i=$;k=c[k+4>>2]|0;}while((k|0)!=0)}k=ah+4|0;ac=c[k>>2]|0;if((ac|0)!=0){ag=ac;do{ac=c[ag+8>>2]|0;l=(a[ag|0]&1)!=0?40296:766672;eb(ai|0,41376,($=i,i=i+24|0,c[$>>2]=c[ag+4>>2],c[$+8>>2]=ac,c[$+16>>2]=l,$)|0)|0;i=$;ag=c[ag+12>>2]|0;}while((ag|0)!=0)}if((a[607928]&1)==0){ak=k;break}ag=c[191244]|0;ai=(ag|0)!=0?ag:c[q>>2]|0;a3(50416,19,1,ai|0)|0;ai=c[191244]|0;ag=(ai|0)!=0?ai:c[q>>2]|0;aZ(ag|0)|0;ak=k}else{ak=ah+4|0}}while(0);aj=ak;while(1){al=c[aj>>2]|0;if((al|0)==0){am=ak;break}if((cJ(47880,c[al+4>>2]|0)|0)==0){_=2276;break}aj=al+12|0}if((_|0)==2276){g[126396]=+v1(c[al+8>>2]|0);am=ak}while(1){an=c[am>>2]|0;if((an|0)==0){ao=ak;break}if((cJ(46008,c[an+4>>2]|0)|0)==0){_=2280;break}am=an+12|0}if((_|0)==2280){g[126397]=+v1(c[an+8>>2]|0);ao=ak}while(1){ap=c[ao>>2]|0;if((ap|0)==0){aq=ak;break}if((cJ(44960,c[ap+4>>2]|0)|0)==0){_=2284;break}ao=ap+12|0}do{if((_|0)==2284){c[(dR()|0)>>2]=0;ao=a0(c[ap+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){aq=ak;break}c[126400]=ao;aq=ak}}while(0);while(1){ar=c[aq>>2]|0;if((ar|0)==0){break}if((cJ(43928,c[ar+4>>2]|0)|0)==0){_=2289;break}aq=ar+12|0}do{if((_|0)==2289){c[(dR()|0)>>2]=0;aq=a0(c[ar+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[126401]=aq}}while(0);do{if((a[607931]&1)==0){a[n]=0;if(!(gI(ah,42416,n)|0)){break}a[505592]=a[n]&1}}while(0);a[o]=0;if(gI(ah,41344,o)|0){a[505593]=a[o]&1;as=ak}else{as=ak}while(1){at=c[as>>2]|0;if((at|0)==0){break}if((cJ(40272,c[at+4>>2]|0)|0)==0){_=2298;break}else{as=at+12|0}}do{if((_|0)==2298){c[(dR()|0)>>2]=0;as=a0(c[at+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[126399]=as}}while(0);a[p]=0;if(gI(ah,39280,p)|0){a[522060]=a[p]&1}a[r]=0;if(gI(ah,38344,r)|0){a[505608]=a[r]&1}a[s]=0;if(gI(ah,37360,s)|0){a[505609]=a[s]&1;au=ak}else{au=ak}while(1){av=c[au>>2]|0;if((av|0)==0){_=2310;break}if((cJ(35952,c[av+4>>2]|0)|0)==0){_=2308;break}else{au=av+12|0}}do{if((_|0)==2308){c[(dR()|0)>>2]=0;au=a0(c[av+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){_=2310;break}c[126404]=au;aw=au}}while(0);if((_|0)==2310){aw=c[126404]|0}if(aw>>>0>3){c[126404]=3}a[t]=0;if(gI(ah,34344,t)|0){a[505610]=a[t]&1;ax=ak}else{ax=ak}while(1){ay=c[ax>>2]|0;if((ay|0)==0){_=2318;break}if((cJ(33112,c[ay+4>>2]|0)|0)==0){_=2317;break}else{ax=ay+12|0}}do{if((_|0)==2317){c[(dR()|0)>>2]=0;ax=a0(c[ay+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){_=2318;break}c[126403]=ax;az=ax}}while(0);if((_|0)==2318){az=c[126403]|0}ay=az>>>0>1?az:1;c[126403]=ay>>>0<4?ay:4;a[u]=0;if(gI(ah,32232,u)|0){a[513836]=a[u]&1}a[v]=0;if(gI(ah,31656,v)|0){a[505620]=a[v]&1}a[w]=0;if(gI(ah,30784,w)|0){a[505621]=a[w]&1}a[x]=0;if(gI(ah,30416,x)|0){a[505629]=a[x]&1}a[y]=0;if(gI(ah,30048,y)|0){a[505622]=a[y]&1;aA=ak}else{aA=ak}while(1){aB=c[aA>>2]|0;if((aB|0)==0){aC=ak;break}if((cJ(29744,c[aB+4>>2]|0)|0)==0){_=2332;break}else{aA=aB+12|0}}if((_|0)==2332){g[126406]=+v1(c[aB+8>>2]|0);aC=ak}while(1){aD=c[aC>>2]|0;if((aD|0)==0){break}if((cJ(29368,c[aD+4>>2]|0)|0)==0){_=2335;break}else{aC=aD+12|0}}do{if((_|0)==2335){c[(dR()|0)>>2]=0;aC=a0(c[aD+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[126408]=aC}}while(0);a[z]=0;if(gI(ah,28800,z)|0){a[505628]=a[z]&1;aE=ak}else{aE=ak}while(1){aF=c[aE>>2]|0;if((aF|0)==0){break}if((cJ(28224,c[aF+4>>2]|0)|0)==0){_=2341;break}else{aE=aF+12|0}}if((_|0)==2341){g[128458]=+v1(c[aF+8>>2]|0)}gH(ah,27832,505636)|0;a[A]=0;if(gI(ah,27464,A)|0){a[509732]=a[A]&1}a[B]=0;if(gI(ah,27176,B)|0){a[522064]=a[B]&1}gH(ah,26816,517933)|0;B=ak;while(1){aG=c[B>>2]|0;if((aG|0)==0){break}if((cJ(26480,c[aG+4>>2]|0)|0)==0){_=2349;break}else{B=aG+12|0}}if((_|0)==2349){g[130508]=+v1(c[aG+8>>2]|0)}a[C]=0;if(gI(ah,26144,C)|0){a[522036]=a[C]&1}a[D]=0;if(gI(ah,25864,D)|0){a[522037]=a[D]&1;aH=ak}else{aH=ak}while(1){aI=c[aH>>2]|0;if((aI|0)==0){aJ=ak;break}if((cJ(25416,c[aI+4>>2]|0)|0)==0){_=2356;break}else{aH=aI+12|0}}if((_|0)==2356){g[130510]=+v1(c[aI+8>>2]|0);aJ=ak}while(1){aK=c[aJ>>2]|0;if((aK|0)==0){aL=ak;break}if((cJ(24752,c[aK+4>>2]|0)|0)==0){_=2359;break}else{aJ=aK+12|0}}if((_|0)==2359){g[130511]=+v1(c[aK+8>>2]|0);aL=ak}while(1){aM=c[aL>>2]|0;if((aM|0)==0){aN=ak;break}if((cJ(24192,c[aM+4>>2]|0)|0)==0){_=2362;break}else{aL=aM+12|0}}do{if((_|0)==2362){c[(dR()|0)>>2]=0;aL=a0(c[aM+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){aN=ak;break}c[191229]=aL;aN=ak}}while(0);while(1){aO=c[aN>>2]|0;if((aO|0)==0){aP=ak;break}if((cJ(23960,c[aO+4>>2]|0)|0)==0){_=2366;break}else{aN=aO+12|0}}do{if((_|0)==2366){c[(dR()|0)>>2]=0;aN=a0(c[aO+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){aP=ak;break}c[191230]=aN;aP=ak}}while(0);while(1){aQ=c[aP>>2]|0;if((aQ|0)==0){aR=ak;break}if((cJ(23744,c[aQ+4>>2]|0)|0)==0){_=2370;break}else{aP=aQ+12|0}}do{if((_|0)==2370){c[(dR()|0)>>2]=0;aP=a0(c[aQ+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){aR=ak;break}c[191231]=aP;aR=ak}}while(0);while(1){aS=c[aR>>2]|0;if((aS|0)==0){aT=ak;break}if((cJ(23464,c[aS+4>>2]|0)|0)==0){_=2374;break}else{aR=aS+12|0}}do{if((_|0)==2374){c[(dR()|0)>>2]=0;aR=a0(c[aS+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){aT=ak;break}c[191232]=aR;aT=ak}}while(0);while(1){aU=c[aT>>2]|0;if((aU|0)==0){break}if((cJ(23200,c[aU+4>>2]|0)|0)==0){_=2378;break}else{aT=aU+12|0}}do{if((_|0)==2378){c[(dR()|0)>>2]=0;aT=aW(c[aU+8>>2]|0,0,16)|0;if((c[(dR()|0)>>2]|0)!=0){break}g[130512]=+((aT>>>16&255)>>>0>>>0)/255.0;g[130513]=+((aT>>>8&255)>>>0>>>0)/255.0;g[130514]=+((aT&255)>>>0>>>0)/255.0}}while(0);a[E]=0;if(gI(ah,22952,E)|0){a[522061]=a[E]&1}a[F]=0;if(gI(ah,22672,F)|0){a[522062]=a[F]&1}a[G]=0;if(gI(ah,22472,G)|0){a[522063]=a[G]&1}gH(ah,22128,513837)|0;if((cJ(513837,21624)|0)==0){a[513837]=0;aV=ak}else{aV=ak}while(1){aX=c[aV>>2]|0;if((aX|0)==0){break}if((cJ(21096,c[aX+4>>2]|0)|0)==0){_=2390;break}else{aV=aX+12|0}}if((_|0)==2390){g[141568]=+v1(c[aX+8>>2]|0)}a[H]=0;if(gI(ah,20624,H)|0){a[566886]=a[H]&1}H=I|0;bN(H|0,64,20424,($=i,i=i+8|0,c[$>>2]=1,$)|0)|0;i=$;I=ak;while(1){aY=c[I>>2]|0;if((aY|0)==0){break}if((cJ(H|0,c[aY+4>>2]|0)|0)==0){_=2396;break}else{I=aY+12|0}}do{if((_|0)==2396){c[(dR()|0)>>2]=0;I=a0(c[aY+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[141569]=I}}while(0);bN(H|0,64,20424,($=i,i=i+8|0,c[$>>2]=2,$)|0)|0;i=$;aY=ak;while(1){a_=c[aY>>2]|0;if((a_|0)==0){break}if((cJ(H|0,c[a_+4>>2]|0)|0)==0){_=2401;break}else{aY=a_+12|0}}do{if((_|0)==2401){c[(dR()|0)>>2]=0;aY=a0(c[a_+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[141570]=aY}}while(0);bN(H|0,64,20424,($=i,i=i+8|0,c[$>>2]=3,$)|0)|0;i=$;a_=ak;while(1){a$=c[a_>>2]|0;if((a$|0)==0){break}if((cJ(H|0,c[a$+4>>2]|0)|0)==0){_=2606;break}else{a_=a$+12|0}}do{if((_|0)==2606){c[(dR()|0)>>2]=0;a_=a0(c[a$+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[141571]=a_}}while(0);bN(H|0,64,20424,($=i,i=i+8|0,c[$>>2]=4,$)|0)|0;i=$;a$=ak;while(1){a1=c[a$>>2]|0;if((a1|0)==0){break}if((cJ(H|0,c[a1+4>>2]|0)|0)==0){_=2611;break}else{a$=a1+12|0}}do{if((_|0)==2611){c[(dR()|0)>>2]=0;a$=a0(c[a1+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[141572]=a$}}while(0);bN(H|0,64,20424,($=i,i=i+8|0,c[$>>2]=5,$)|0)|0;i=$;a1=ak;while(1){a2=c[a1>>2]|0;if((a2|0)==0){break}if((cJ(H|0,c[a2+4>>2]|0)|0)==0){_=2616;break}else{a1=a2+12|0}}do{if((_|0)==2616){c[(dR()|0)>>2]=0;a1=a0(c[a2+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[141573]=a1}}while(0);bN(H|0,64,20424,($=i,i=i+8|0,c[$>>2]=6,$)|0)|0;i=$;a2=ak;while(1){a4=c[a2>>2]|0;if((a4|0)==0){break}if((cJ(H|0,c[a4+4>>2]|0)|0)==0){_=2621;break}else{a2=a4+12|0}}do{if((_|0)==2621){c[(dR()|0)>>2]=0;a2=a0(c[a4+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[141574]=a2}}while(0);bN(H|0,64,20424,($=i,i=i+8|0,c[$>>2]=7,$)|0)|0;i=$;a4=ak;while(1){a5=c[a4>>2]|0;if((a5|0)==0){break}if((cJ(H|0,c[a5+4>>2]|0)|0)==0){_=2626;break}else{a4=a5+12|0}}do{if((_|0)==2626){c[(dR()|0)>>2]=0;a4=a0(c[a5+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[141575]=a4}}while(0);bN(H|0,64,20424,($=i,i=i+8|0,c[$>>2]=8,$)|0)|0;i=$;a5=ak;while(1){a6=c[a5>>2]|0;if((a6|0)==0){break}if((cJ(H|0,c[a6+4>>2]|0)|0)==0){_=2631;break}else{a5=a6+12|0}}do{if((_|0)==2631){c[(dR()|0)>>2]=0;a5=a0(c[a6+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[141576]=a5}}while(0);a[J]=0;if(gI(ah,20312,J)|0){a[522100]=a[J]&1;a7=ak}else{a7=ak}while(1){a8=c[a7>>2]|0;if((a8|0)==0){a9=ak;break}if((cJ(20256,c[a8+4>>2]|0)|0)==0){_=2405;break}else{a7=a8+12|0}}do{if((_|0)==2405){c[(dR()|0)>>2]=0;a7=a0(c[a8+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){a9=ak;break}c[130526]=a7;a9=ak}}while(0);while(1){ba=c[a9>>2]|0;if((ba|0)==0){bb=ak;break}if((cJ(20160,c[ba+4>>2]|0)|0)==0){_=2409;break}else{a9=ba+12|0}}do{if((_|0)==2409){c[(dR()|0)>>2]=0;a9=a0(c[ba+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){bb=ak;break}c[130527]=a9;bb=ak}}while(0);while(1){bc=c[bb>>2]|0;if((bc|0)==0){bd=ak;break}if((cJ(20008,c[bc+4>>2]|0)|0)==0){_=2413;break}else{bb=bc+12|0}}L3444:do{if((_|0)==2413){bb=4096;ba=522116;a9=c[bc+8>>2]|0;while(1){a8=bb-1|0;if((a8|0)==0){break}a7=a[a9]|0;a[ba]=a7;if(a7<<24>>24==0){bd=ak;break L3444}else{bb=a8;ba=ba+1|0;a9=a9+1|0}}a[ba]=0;if((a[a9]|0)==0){bd=ak;break}else{be=a9}while(1){bb=be+1|0;if((a[bb]|0)==0){bd=ak;break}else{be=bb}}}}while(0);while(1){bf=c[bd>>2]|0;if((bf|0)==0){break}if((cJ(19912,c[bf+4>>2]|0)|0)==0){_=2420;break}else{bd=bf+12|0}}do{if((_|0)==2420){c[(dR()|0)>>2]=0;bd=a0(c[bf+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[131553]=bd}}while(0);a[K]=0;if(gI(ah,19816,K)|0){a[526216]=a[K]&1}a[L]=0;if(gI(ah,19472,L)|0){a[530313]=a[L]&1;bg=ak}else{bg=ak}while(1){bh=c[bg>>2]|0;if((bh|0)==0){bi=ak;break}if((cJ(19232,c[bh+4>>2]|0)|0)==0){_=2428;break}else{bg=bh+12|0}}if((_|0)==2428){g[132579]=+v1(c[bh+8>>2]|0);bi=ak}while(1){bj=c[bi>>2]|0;if((bj|0)==0){bk=ak;break}if((cJ(19e3,c[bj+4>>2]|0)|0)==0){_=2431;break}else{bi=bj+12|0}}if((_|0)==2431){g[132580]=+v1(c[bj+8>>2]|0);bk=ak}while(1){bl=c[bk>>2]|0;if((bl|0)==0){bm=ak;break}if((cJ(18792,c[bl+4>>2]|0)|0)==0){_=2434;break}else{bk=bl+12|0}}L3477:do{if((_|0)==2434){bk=32;bj=505520;bi=c[bl+8>>2]|0;while(1){bh=bk-1|0;if((bh|0)==0){break}bg=a[bi]|0;a[bj]=bg;if(bg<<24>>24==0){bm=ak;break L3477}else{bk=bh;bj=bj+1|0;bi=bi+1|0}}a[bj]=0;if((a[bi]|0)==0){bm=ak;break}else{bn=bi}while(1){bk=bn+1|0;if((a[bk]|0)==0){bm=ak;break}else{bn=bk}}}}while(0);while(1){bo=c[bm>>2]|0;if((bo|0)==0){bp=ak;break}if((cJ(18648,c[bo+4>>2]|0)|0)==0){_=2441;break}else{bm=bo+12|0}}L3488:do{if((_|0)==2441){bm=32;bn=505552;bl=c[bo+8>>2]|0;while(1){bi=bm-1|0;if((bi|0)==0){break}bj=a[bl]|0;a[bn]=bj;if(bj<<24>>24==0){bp=ak;break L3488}else{bm=bi;bn=bn+1|0;bl=bl+1|0}}a[bn]=0;if((a[bl]|0)==0){bp=ak;break}else{bq=bl}while(1){bm=bq+1|0;if((a[bm]|0)==0){bp=ak;break}else{bq=bm}}}}while(0);while(1){br=c[bp>>2]|0;if((br|0)==0){break}if((cJ(18560,c[br+4>>2]|0)|0)==0){_=2448;break}else{bp=br+12|0}}L3499:do{if((_|0)==2448){bp=32;bq=522068;bo=c[br+8>>2]|0;while(1){bl=bp-1|0;if((bl|0)==0){break}bn=a[bo]|0;a[bq]=bn;if(bn<<24>>24==0){break L3499}else{bp=bl;bq=bq+1|0;bo=bo+1|0}}a[bq]=0;if((a[bo]|0)==0){break}else{bs=bo}do{bs=bs+1|0;}while((a[bs]|0)!=0)}}while(0);gH(ah,18384,526217)|0;bs=ak;while(1){bt=c[bs>>2]|0;if((bt|0)==0){bu=ak;break}if((cJ(39512,c[bt+4>>2]|0)|0)==0){_=2456;break}else{bs=bt+12|0}}L3511:do{if((_|0)==2456){bs=32;br=530360;bo=c[bt+8>>2]|0;while(1){bq=bs-1|0;if((bq|0)==0){break}bp=a[bo]|0;a[br]=bp;if(bp<<24>>24==0){bu=ak;break L3511}else{bs=bq;br=br+1|0;bo=bo+1|0}}a[br]=0;if((a[bo]|0)==0){bu=ak;break}else{bv=bo}while(1){bs=bv+1|0;if((a[bs]|0)==0){bu=ak;break}else{bv=bs}}}}while(0);while(1){bw=c[bu>>2]|0;if((bw|0)==0){break}if((cJ(18008,c[bw+4>>2]|0)|0)==0){_=2463;break}else{bu=bw+12|0}}L3522:do{if((_|0)==2463){bu=32;bv=530392;bt=c[bw+8>>2]|0;while(1){bo=bu-1|0;if((bo|0)==0){break}br=a[bt]|0;a[bv]=br;if(br<<24>>24==0){break L3522}else{bu=bo;bv=bv+1|0;bt=bt+1|0}}a[bv]=0;if((a[bt]|0)==0){break}else{bx=bt}do{bx=bx+1|0;}while((a[bx]|0)!=0)}}while(0);if((a[583292]|0)==0){gH(ah,17824,583292)|0}gH(ah,17536,575096)|0;gH(ah,17240,595580)|0;do{if((a[595580]|0)!=0){if((eB(595580,j|0)|0)>=0){if((c[j+8>>2]&61440|0)==16384){break}}bx=c[191244]|0;bw=(bx|0)!=0?bx:c[q>>2]|0;a3(16952,84,1,bw|0)|0;bw=c[191244]|0;bx=(bw|0)!=0?bw:c[q>>2]|0;aZ(bx|0)|0;a[595580]=0}}while(0);gH(ah,16712,603809)|0;if((cJ(603809,21624)|0)==0){a[603809]=0}gH(ah,16600,685802)|0;if((cJ(685802,21624)|0)==0){a[685802]=0}gH(ah,16496,566896)|0;j=ak;while(1){by=c[j>>2]|0;if((by|0)==0){bz=ak;break}if((cJ(16360,c[by+4>>2]|0)|0)==0){_=2481;break}else{j=by+12|0}}if((_|0)==2481){g[142748]=+v1(c[by+8>>2]|0);bz=ak}while(1){bA=c[bz>>2]|0;if((bA|0)==0){break}if((cJ(16216,c[bA+4>>2]|0)|0)==0){_=2484;break}else{bz=bA+12|0}}if((_|0)==2484){g[142749]=+v1(c[bA+8>>2]|0)}a[M]=0;if(gI(ah,16112,M)|0){a[603772]=a[M]&1;bB=ak}else{bB=ak}while(1){bC=c[bB>>2]|0;if((bC|0)==0){bD=ak;break}if((cJ(15920,c[bC+4>>2]|0)|0)==0){_=2489;break}else{bB=bC+12|0}}do{if((_|0)==2489){c[(dR()|0)>>2]=0;bB=a0(c[bC+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){bD=ak;break}c[150944]=bB*1e6|0;bD=ak}}while(0);while(1){bE=c[bD>>2]|0;if((bE|0)==0){bF=ak;break}if((cJ(15648,c[bE+4>>2]|0)|0)==0){_=2493;break}else{bD=bE+12|0}}do{if((_|0)==2493){c[(dR()|0)>>2]=0;bD=a0(c[bE+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){bF=ak;break}c[150945]=bD;bF=ak}}while(0);while(1){bG=c[bF>>2]|0;if((bG|0)==0){_=2498;break}if((cJ(15200,c[bG+4>>2]|0)|0)==0){_=2497;break}else{bF=bG+12|0}}if((_|0)==2497){bH=+v1(c[bG+8>>2]|0);g[150946]=bH;bI=bH}else if((_|0)==2498){bI=+g[150946]}if(bI<1.0){g[150946]=1.0;bJ=ak}else{bJ=ak}while(1){bK=c[bJ>>2]|0;if((bK|0)==0){break}if((cJ(14976,c[bK+4>>2]|0)|0)==0){_=2503;break}else{bJ=bK+12|0}}if((_|0)==2503){g[150947]=+v1(c[bK+8>>2]|0)}a[N]=0;if(gI(ah,14664,N)|0){a[603792]=a[N]&1;bL=ak}else{bL=ak}while(1){bM=c[bL>>2]|0;if((bM|0)==0){break}if((cJ(14504,c[bM+4>>2]|0)|0)==0){_=2508;break}else{bL=bM+12|0}}do{if((_|0)==2508){c[(dR()|0)>>2]=0;bL=a0(c[bM+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[150949]=bL}}while(0);gH(ah,14408,587388)|0;gH(ah,14272,591484)|0;a[O]=0;if(gI(ah,14032,O)|0){a[603800]=a[O]&1}a[P]=0;if(gI(ah,13888,P)|0){a[603801]=a[P]&1}a[Q]=0;if(gI(ah,13736,Q)|0){a[603802]=a[Q]&1}a[R]=0;if(gI(ah,13544,R)|0){a[603803]=a[R]&1}a[S]=0;if(gI(ah,13120,S)|0){a[603804]=a[S]&1;bO=ak}else{bO=ak}while(1){bP=c[bO>>2]|0;if((bP|0)==0){break}if((cJ(12936,c[bP+4>>2]|0)|0)==0){_=2522;break}else{bO=bP+12|0}}do{if((_|0)==2522){c[(dR()|0)>>2]=0;bO=a0(c[bP+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}b[301903]=bO&65535}}while(0);a[T]=0;if(gI(ah,12776,T)|0){a[603808]=a[T]&1}gH(ah,12632,579192)|0;T=ak;while(1){bQ=c[T>>2]|0;if((bQ|0)==0){bR=ak;break}if((cJ(12560,c[bQ+4>>2]|0)|0)==0){_=2529;break}else{T=bQ+12|0}}do{if((_|0)==2529){c[(dR()|0)>>2]=0;T=a0(c[bQ+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){bR=ak;break}c[145822]=T;bR=ak}}while(0);while(1){bS=c[bR>>2]|0;if((bS|0)==0){bT=ak;break}if((cJ(12440,c[bS+4>>2]|0)|0)==0){_=2533;break}else{bR=bS+12|0}}do{if((_|0)==2533){c[(dR()|0)>>2]=0;bR=a0(c[bS+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){bT=ak;break}c[141722]=bR;bT=ak}}while(0);while(1){bU=c[bT>>2]|0;if((bU|0)==0){break}if((cJ(12336,c[bU+4>>2]|0)|0)==0){_=2537;break}else{bT=bU+12|0}}do{if((_|0)==2537){c[(dR()|0)>>2]=0;bT=a0(c[bU+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[141723]=bT}}while(0);a[U]=0;if(gI(ah,12216,U)|0){a[566884]=a[U]&1}a[V]=0;if(gI(ah,51392,V)|0){a[566885]=a[V]&1}gH(ah,51152,571e3)|0;a[W]=0;if(gI(ah,50704,W)|0){a[764982]=a[W]&1}L3647:do{if((a[628456]&1)==0){W=m|0;if(!(gH(ah,50560,W)|0)){break}if((cJ(W|0,21624)|0)==0){a[677610]=0;break}do{if((eB(W|0,h|0)|0)>=0){if((c[h+8>>2]&61440|0)==16384){bV=4096;bW=677610;bX=W}else{break}while(1){V=bV-1|0;if((V|0)==0){_=2553;break}U=a[bX]|0;a[bW]=U;if(U<<24>>24==0){bY=4096;bZ=648938;b_=W;break}else{bV=V;bW=bW+1|0;bX=bX+1|0}}do{if((_|0)==2553){a[bW]=0;if((a[bX]|0)==0){bY=4096;bZ=648938;b_=W;break}else{b$=bX}while(1){V=b$+1|0;if((a[V]|0)==0){bY=4096;bZ=648938;b_=W;break}else{b$=V}}}}while(0);while(1){V=bY-1|0;if((V|0)==0){_=2557;break}U=a[b_]|0;a[bZ]=U;if(U<<24>>24==0){break}else{bY=V;bZ=bZ+1|0;b_=b_+1|0}}do{if((_|0)==2557){a[bZ]=0;if((a[b_]|0)==0){break}else{b0=b_}do{b0=b0+1|0;}while((a[b0]|0)!=0)}}while(0);gt(648938,50408);break L3647}}while(0);W=c[191244]|0;V=(W|0)!=0?W:c[q>>2]|0;a3(50208,72,1,V|0)|0;V=c[191244]|0;W=(V|0)!=0?V:c[q>>2]|0;aZ(W|0)|0}}while(0);L3672:do{if((a[628457]&1)==0){b0=m|0;if(!(gH(ah,50096,b0)|0)){break}if((cJ(b0|0,21624)|0)==0){a[681706]=0;break}do{if((eB(b0|0,f|0)|0)>=0){if((c[f+8>>2]&61440|0)==16384){b1=4096;b2=681706;b3=b0}else{break}while(1){b_=b1-1|0;if((b_|0)==0){_=2569;break}bZ=a[b3]|0;a[b2]=bZ;if(bZ<<24>>24==0){b4=4096;b5=669418;b6=b0;break}else{b1=b_;b2=b2+1|0;b3=b3+1|0}}do{if((_|0)==2569){a[b2]=0;if((a[b3]|0)==0){b4=4096;b5=669418;b6=b0;break}else{b7=b3}while(1){b_=b7+1|0;if((a[b_]|0)==0){b4=4096;b5=669418;b6=b0;break}else{b7=b_}}}}while(0);while(1){b_=b4-1|0;if((b_|0)==0){_=2573;break}bZ=a[b6]|0;a[b5]=bZ;if(bZ<<24>>24==0){break}else{b4=b_;b5=b5+1|0;b6=b6+1|0}}do{if((_|0)==2573){a[b5]=0;if((a[b6]|0)==0){break}else{b8=b6}do{b8=b8+1|0;}while((a[b8]|0)!=0)}}while(0);gt(669418,49960);break L3672}}while(0);b0=c[191244]|0;b_=(b0|0)!=0?b0:c[q>>2]|0;a3(49752,73,1,b_|0)|0;b_=c[191244]|0;b0=(b_|0)!=0?b_:c[q>>2]|0;aZ(b0|0)|0}}while(0);if(!(gH(ah,49440,599676)|0)){b8=c[191244]|0;b6=(b8|0)!=0?b8:c[q>>2]|0;eb(b6|0,49176,($=i,i=i+8|0,c[$>>2]=599676,$)|0)|0;i=$;$=c[191244]|0;b6=($|0)!=0?$:c[q>>2]|0;aZ(b6|0)|0}if((cJ(599676,21624)|0)==0){a[599676]=0;b9=0}else{b9=0}do{b6=11552+(b9<<2)|0;L3704:do{if((b9|0)==0){$=0;b8=7928;while(1){b5=530424+($*40|0)|0;do{if((a[b5|0]&1)==0){_=2588}else{b4=c[7936+($*20|0)>>2]|0;if(($|0)==56){ca=57;break}b7=($-25|0)>>>0<31?40136:39160;hd(ah,b7,b4,b5);b3=a[b8]|0;if((b3&1)==0){cb=b3}else{he(ah,b7,b4,b5);cb=a[b8]|0}if((cb&1)==0){_=2588;break}hf(ah,b7,b4,b5);_=2588}}while(0);if((_|0)==2588){_=0;b5=$+1|0;if((b5|0)==56){break L3704}else{ca=b5}}$=ca;b8=7928+(ca*20|0)|0}}else{b8=0;$=7928;while(1){b5=530424+(b9*2240|0)+(b8*40|0)|0;do{if((a[b5|0]&1)==0){_=2597}else{b4=c[7936+(b8*20|0)>>2]|0;if((b8|0)==56){cc=57;break}if((b8-25|0)>>>0<31){_=2597;break}b7=c[b6>>2]|0;hd(ah,b7,b4,b5);b3=a[$]|0;if((b3&1)==0){cd=b3}else{he(ah,b7,b4,b5);cd=a[$]|0}if((cd&1)==0){_=2597;break}hf(ah,b7,b4,b5);_=2597}}while(0);if((_|0)==2597){_=0;b5=b8+1|0;if((b5|0)==56){break L3704}else{cc=b5}}b8=cc;$=7928+(cc*20|0)|0}}}while(0);b9=b9+1|0;}while(b9>>>0<8);gE(ah);ad=1;i=e;return ad|0}function gM(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=dW(c[a>>2]|0)|0;c[a+68>>2]=b;c[a+72>>2]=dW(c[a+4>>2]|0)|0;c[a+76>>2]=dW(c[a+8>>2]|0)|0;c[a+80>>2]=dW(c[a+12>>2]|0)|0;c[a+84>>2]=dW(c[a+16>>2]|0)|0;c[a+88>>2]=dW(c[a+20>>2]|0)|0;c[a+92>>2]=dW(c[a+24>>2]|0)|0;c[a+96>>2]=dW(c[a+28>>2]|0)|0;c[a+100>>2]=dW(c[a+32>>2]|0)|0;c[a+104>>2]=dW(c[a+36>>2]|0)|0;c[a+108>>2]=dW(c[a+40>>2]|0)|0;c[a+112>>2]=dW(c[a+44>>2]|0)|0;c[a+116>>2]=dW(c[a+48>>2]|0)|0;c[a+120>>2]=dW(c[a+52>>2]|0)|0;c[a+124>>2]=dW(c[a+56>>2]|0)|0;c[a+128>>2]=dW(c[a+60>>2]|0)|0;d=16;e=b;while(1){b=c[a+68+(d-15<<2)>>2]|0;f=c[a+68+(d-2<<2)>>2]|0;c[a+68+(d<<2)>>2]=(c[a+68+(d-7<<2)>>2]|0)+e+((b>>>18|b<<14)^b>>>3^(b>>>7|b<<25))+((f>>>19|f<<13)^f>>>10^(f>>>17|f<<15));f=d+1|0;if(f>>>0<64){d=f;e=b}else{break}}e=a+324|0;d=c[e>>2]|0;b=a+328|0;f=c[b>>2]|0;g=a+332|0;h=c[g>>2]|0;i=a+336|0;j=c[i>>2]|0;k=a+340|0;l=c[k>>2]|0;m=a+344|0;n=c[m>>2]|0;o=a+348|0;p=c[o>>2]|0;q=a+352|0;r=c[q>>2]|0;s=f;t=h;u=j;v=l;w=n;x=p;y=r;z=d;A=0;while(1){B=(x&~v^v&w)+y+((v>>>6|v<<26)^(v>>>11|v<<21)^(v>>>25|v<<7))+(c[147104+(A<<2)>>2]|0)+(c[a+68+(A<<2)>>2]|0)|0;C=B+u|0;D=((s^t)&z^s&t)+((z>>>2|z<<30)^(z>>>13|z<<19)^(z>>>22|z<<10))+B|0;B=A+1|0;if(B>>>0<64){u=t;t=s;s=z;y=x;x=w;w=v;v=C;z=D;A=B}else{break}}c[e>>2]=D+d;c[b>>2]=z+f;c[g>>2]=s+h;c[i>>2]=t+j;c[k>>2]=C+l;c[m>>2]=v+n;c[o>>2]=w+p;c[q>>2]=x+r;c[a+64>>2]=0;return}function gN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+4096|0;f=e|0;if((b|0)==15){if((a[607928]&1)!=0){g=c[191244]|0;h=(g|0)!=0?g:c[q>>2]|0;g=c[d>>2]|0;eb(h|0,26776,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;g=c[191244]|0;h=(g|0)!=0?g:c[q>>2]|0;aZ(h|0)|0}h=c[176752]|0;do{if((h|0)==0){c[d+4>>2]=0;k=0}else{a[h+4108|0]=0;g=c[h+4104>>2]|0;l=h+4100|0;m=d;n=0;while(1){if(n>>>0>=g>>>0){o=2655;break}p=c[l>>2]|0;if((cJ(c[p+(n<<4)+4>>2]|0,c[m>>2]|0)|0)==0){o=2654;break}else{n=n+1|0}}if((o|0)==2655){c[d+4>>2]=0;k=0;break}else if((o|0)==2654){m=c[(c[c[p+(n<<4)+8>>2]>>2]|0)+(c[p+(n<<4)+12>>2]<<3)>>2]|0;c[d+4>>2]=m;k=m;break}}}while(0);if((a[607928]&1)==0){r=1;i=e;return r|0}p=c[191244]|0;h=(p|0)!=0?p:c[q>>2]|0;p=(k|0)==0?17560:k;eb(h|0,23184,(j=i,i=i+8|0,c[j>>2]=p,j)|0)|0;i=j;p=c[191244]|0;h=(p|0)!=0?p:c[q>>2]|0;aZ(h|0)|0;r=1;i=e;return r|0}else if((b|0)==17){h=c[176752]|0;if((h|0)==0){s=0}else{s=a[h+4108|0]&1}a[d]=s;r=1;i=e;return r|0}else if((b|0)==3){a[d]=1;if((a[607928]&1)==0){r=1;i=e;return r|0}s=c[191244]|0;a3(30744,38,1,((s|0)!=0?s:c[q>>2]|0)|0)|0;s=c[191244]|0;aZ(((s|0)!=0?s:c[q>>2]|0)|0)|0;r=1;i=e;return r|0}else if((b|0)==2){a[d]=a[505622]&1^1;if((a[607928]&1)==0){r=1;i=e;return r|0}s=c[191244]|0;eb(((s|0)!=0?s:c[q>>2]|0)|0,41264,(j=i,i=i+8|0,c[j>>2]=(a[505622]&1^1)&255,j)|0)|0;i=j;s=c[191244]|0;aZ(((s|0)!=0?s:c[q>>2]|0)|0)|0;r=1;i=e;return r|0}else if((b|0)==16){if((a[607928]&1)!=0){s=c[191244]|0;h=(s|0)!=0?s:c[q>>2]|0;a3(18520,34,1,h|0)|0;h=c[191244]|0;s=(h|0)!=0?h:c[q>>2]|0;aZ(s|0)|0}s=c[176752]|0;if((s|0)!=0){h=s+4104|0;if((c[h>>2]|0)==0){t=s|0}else{p=s+4100|0;k=s|0;m=0;while(1){l=c[p>>2]|0;gJ(c[k>>2]|0,c[l+(m<<4)+4>>2]|0,c[(c[c[l+(m<<4)+8>>2]>>2]|0)+(c[l+(m<<4)+12>>2]<<3)>>2]|0);l=m+1|0;if(l>>>0<(c[h>>2]|0)>>>0){m=l}else{t=k;break}}}k=c[t>>2]|0;t=s+4|0;gK(k,t)|0;hm(c[176752]|0)}t=d;if((a[575096]|0)!=0|(a[628458]|0)==0){u=575096}else{k=f|0;gA(k,628458,16464);u=k}k=vZ(4112)|0;L3791:do{if((k|0)==0){v=0}else{if((c[k-4>>2]&3|0)!=0){v3(k|0,0,4112)}f=k;if((a[u]|0)==0){w=c[k>>2]|0}else{s=gG(u,0)|0;c[k>>2]=s;w=s}s=k;if((w|0)==0){m=vZ(20)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}v3(m|0,0,20)}}while(0);c[s>>2]=m}n=4096;h=k+4|0;p=u;while(1){l=n-1|0;if((l|0)==0){o=2686;break}g=a[p]|0;a[h]=g;if(g<<24>>24==0){break}else{n=l;h=h+1|0;p=p+1|0}}do{if((o|0)==2686){a[h]=0;if((a[p]|0)==0){break}else{x=p}do{x=x+1|0;}while((a[x]|0)!=0)}}while(0);do{if((c[s>>2]|0)!=0){p=d;h=c[p>>2]|0;n=(h|0)==0;do{if(n){y=0;z=0}else{m=0;l=t;while(1){if((c[l+4>>2]|0)==0){A=m;break}g=m+1|0;B=l+8|0;if((c[B>>2]|0)==0){A=g;break}else{m=g;l=B}}if((A|0)==0){y=0;z=0;break}l=A<<4;if(A>>>0<=65535){y=l;z=A;break}y=((l>>>0)/(A>>>0)|0|0)==16?l:-1;z=A}}while(0);l=vZ(y)|0;if((l|0)==0){c[k+4100>>2]=0;break}if((c[l-4>>2]&3|0)==0){m=k+4100|0;c[m>>2]=l;C=m}else{v3(l|0,0,y|0);m=k+4100|0;c[m>>2]=l;C=m}c[k+4104>>2]=z;if(n){v=f;break L3791}else{D=0;E=p;F=h}while(1){m=E+4|0;if((c[m>>2]|0)==0){v=f;break L3791}l=c[C>>2]|0;B=l+(D<<4)+4|0;c[B>>2]=dn(F|0)|0;G=dn(c[m>>2]|0)|0;m=bu(G|0,50328)|0;if((m|0)==0){o=2703;break}a[m]=0;g=l+(D<<4)|0;c[g>>2]=dn(G|0)|0;H=go(m+2|0,47200)|0;m=l+(D<<4)+8|0;c[m>>2]=H;if((H|0)==0){o=2705;break}H=c[B>>2]|0;I=(c[s>>2]|0)+4|0;while(1){J=c[I>>2]|0;if((J|0)==0){break}if((cJ(H|0,c[J+4>>2]|0)|0)==0){o=2709;break}else{I=J+12|0}}if((o|0)==2709){o=0;I=dn(c[J+8>>2]|0)|0;H=c[m>>2]|0;K=c[H+4>>2]|0;L=H|0;H=0;while(1){if(H>>>0>=K>>>0){break}if((cJ(c[(c[L>>2]|0)+(H<<3)>>2]|0,I|0)|0)==0){o=2712;break}else{H=H+1|0}}if((o|0)==2712){o=0;c[l+(D<<4)+12>>2]=H}v_(I)}v_(G);L=a[607928]|0;if((L&1)==0){M=L}else{L=c[191244]|0;K=(L|0)!=0?L:c[q>>2]|0;a3(36904,24,1,K|0)|0;K=c[191244]|0;L=(K|0)!=0?K:c[q>>2]|0;aZ(L|0)|0;M=a[607928]|0}if((M&1)==0){N=M}else{L=c[191244]|0;K=(L|0)!=0?L:c[q>>2]|0;L=c[g>>2]|0;eb(K|0,29272,(j=i,i=i+8|0,c[j>>2]=L,j)|0)|0;i=j;L=c[191244]|0;K=(L|0)!=0?L:c[q>>2]|0;aZ(K|0)|0;N=a[607928]|0}if((N&1)==0){O=N}else{K=c[191244]|0;L=(K|0)!=0?K:c[q>>2]|0;K=c[B>>2]|0;eb(L|0,25272,(j=i,i=i+8|0,c[j>>2]=K,j)|0)|0;i=j;K=c[191244]|0;L=(K|0)!=0?K:c[q>>2]|0;aZ(L|0)|0;O=a[607928]|0}if((O&1)==0){P=O}else{L=c[191244]|0;K=(L|0)!=0?L:c[q>>2]|0;L=c[C>>2]|0;Q=c[(c[c[L+(D<<4)+8>>2]>>2]|0)+(c[L+(D<<4)+12>>2]<<3)>>2]|0;eb(K|0,22064,(j=i,i=i+8|0,c[j>>2]=Q,j)|0)|0;i=j;Q=c[191244]|0;K=(Q|0)!=0?Q:c[q>>2]|0;aZ(K|0)|0;P=a[607928]|0}if((P&1)!=0){K=c[191244]|0;Q=(K|0)!=0?K:c[q>>2]|0;a3(19720,29,1,Q|0)|0;Q=c[191244]|0;K=(Q|0)!=0?Q:c[q>>2]|0;aZ(K|0)|0}K=c[m>>2]|0;if((c[K+4>>2]|0)!=0){Q=0;L=K;while(1){if((a[607928]&1)==0){R=L}else{K=c[191244]|0;S=(K|0)!=0?K:c[q>>2]|0;K=c[(c[L>>2]|0)+(Q<<3)>>2]|0;eb(S|0,17768,(j=i,i=i+8|0,c[j>>2]=K,j)|0)|0;i=j;K=c[191244]|0;S=(K|0)!=0?K:c[q>>2]|0;aZ(S|0)|0;R=c[m>>2]|0}S=Q+1|0;if(S>>>0<(c[R+4>>2]|0)>>>0){Q=S;L=R}else{break}}}L=E+8|0;Q=c[L>>2]|0;if((Q|0)==0){v=f;break L3791}else{D=D+1|0;E=L;F=Q}}if((o|0)==2703){v_(G);break}else if((o|0)==2705){v_(G);break}}}while(0);hm(f);v=0}}while(0);c[176752]=v;r=1;i=e;return r|0}else if((b|0)==6){if((a[607928]&1)!=0){v=c[191244]|0;G=(v|0)!=0?v:c[q>>2]|0;v=c[d>>2]|0;eb(G|0,14368,(j=i,i=i+8|0,c[j>>2]=v,j)|0)|0;i=j;v=c[191244]|0;G=(v|0)!=0?v:c[q>>2]|0;aZ(G|0)|0}G=c[189113]|0;if((G|0)==0){r=1;i=e;return r|0}v=G+4|0;F=c[v>>2]|0;if(F>>>0>1){E=G|0;D=1;R=F;while(1){F=c[(c[E>>2]|0)+(D<<2)>>2]|0;if((F|0)==0){T=R}else{v_(c[F+8>>2]|0);v_(c[(c[E>>2]|0)+(D<<2)>>2]|0);c[(c[E>>2]|0)+(D<<2)>>2]=0;T=c[v>>2]|0}F=D+1|0;if(F>>>0<T>>>0){D=F;R=T}else{break}}}c[v>>2]=1;v=G+12|0;v_(c[v>>2]|0);c[v>>2]=0;v=c[189113]|0;G=c[d>>2]|0;T=v+4|0;R=c[T>>2]|0;if(R>>>0>=(c[v+8>>2]|0)>>>0){r=1;i=e;return r|0}D=c[d+4>>2]|0;E=vZ(12)|0;do{if((E|0)!=0){if((c[E-4>>2]&3|0)==0){break}v3(E|0,0,12)}}while(0);c[E+4>>2]=1;c[E>>2]=D;if((G|0)==0){U=0;V=R}else{R=dn(G|0)|0;U=R;V=c[T>>2]|0}c[E+8>>2]=U;U=v|0;c[(c[U>>2]|0)+(V<<2)>>2]=E;E=c[T>>2]|0;c[T>>2]=E+1;if(E>>>0>1){W=E}else{r=1;i=e;return r|0}while(1){E=W>>>1;T=c[U>>2]|0;V=T+(E<<2)|0;v=c[V>>2]|0;R=c[T+(W<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[v+4>>2]|0)>>>0){r=1;o=2846;break}c[V>>2]=R;c[(c[U>>2]|0)+(W<<2)>>2]=v;if(W>>>0>3){W=E}else{r=1;o=2847;break}}if((o|0)==2846){i=e;return r|0}else if((o|0)==2847){i=e;return r|0}}else if((b|0)==1){W=c[d>>2]|0;if((a[607928]&1)!=0){U=c[191244]|0;E=(U|0)!=0?U:c[q>>2]|0;eb(E|0,12520,(j=i,i=i+8|0,c[j>>2]=W,j)|0)|0;i=j;E=c[191244]|0;U=(E|0)!=0?E:c[q>>2]|0;aZ(U|0)|0}if((a[522064]&1)==0){r=1;i=e;return r|0}c[175569]=W;U=c[191559]|0;if((U|0)==0){r=0;i=e;return r|0}E=c[U+40>>2]|0;if((E|0)==0){r=0;i=e;return r|0}U=c[191562]|0;if((U|0)==0){r=1;i=e;return r|0}fa[E&127](U,W);r=1;i=e;return r|0}else if((b|0)==7){if((a[607928]&1)!=0){W=c[191244]|0;U=(W|0)!=0?W:c[q>>2]|0;a3(50064,29,1,U|0)|0;U=c[191244]|0;W=(U|0)!=0?U:c[q>>2]|0;aZ(W|0)|0}a[702280]=1;r=1;i=e;return r|0}else if((b|0)==8){W=c[d>>2]|0;c[175571]=W;if((a[607928]&1)==0){r=1;i=e;return r|0}U=c[191244]|0;eb(((U|0)!=0?U:c[q>>2]|0)|0,47544,(j=i,i=i+8|0,c[j>>2]=W,j)|0)|0;i=j;W=c[191244]|0;aZ(((W|0)!=0?W:c[q>>2]|0)|0)|0;r=1;i=e;return r|0}else if((b|0)==9){c[d>>2]=(a[599676]|0)!=0?599676:0;if((a[607928]&1)==0){r=1;i=e;return r|0}W=c[191244]|0;eb(((W|0)!=0?W:c[q>>2]|0)|0,45792,(j=i,i=i+8|0,c[j>>2]=599676,j)|0)|0;i=j;W=c[191244]|0;aZ(((W|0)!=0?W:c[q>>2]|0)|0)|0;r=1;i=e;return r|0}else if((b|0)==10){W=c[d>>2]|0;do{if((W|0)==0){if((a[607928]&1)==0){break}U=c[191244]|0;E=(U|0)!=0?U:c[q>>2]|0;a3(44824,47,1,E|0)|0;E=c[191244]|0;U=(E|0)!=0?E:c[q>>2]|0;aZ(U|0)|0}else if((W|0)==2){if((a[607928]&1)==0){break}U=c[191244]|0;a3(43624,45,1,((U|0)!=0?U:c[q>>2]|0)|0)|0;U=c[191244]|0;aZ(((U|0)!=0?U:c[q>>2]|0)|0)|0}else if((W|0)==1){if((a[607928]&1)==0){break}U=c[191244]|0;a3(42160,47,1,((U|0)!=0?U:c[q>>2]|0)|0)|0;U=c[191244]|0;aZ(((U|0)!=0?U:c[q>>2]|0)|0)|0}else{r=0;i=e;return r|0}}while(0);c[175572]=W;r=1;i=e;return r|0}else if((b|0)==11){v3(702296,0,512);W=c[d+16>>2]|0;if((W|0)!=0){U=d;E=W;while(1){W=c[U>>2]|0;do{if(W>>>0<=7){if((c[U+4>>2]|0)!=1){break}v=c[U+12>>2]|0;if(v>>>0>15){break}c[702296+(W<<6)+(v<<2)>>2]=E}}while(0);W=c[U+36>>2]|0;if((W|0)==0){break}else{U=U+20|0;E=W}}}if((a[607928]&1)==0){X=0}else{E=c[191244]|0;U=(E|0)!=0?E:c[q>>2]|0;a3(28128,42,1,U|0)|0;U=c[191244]|0;E=(U|0)!=0?U:c[q>>2]|0;aZ(E|0)|0;X=0}while(1){E=X+1|0;U=0;do{W=c[702296+(X<<6)+(U<<2)>>2]|0;do{if((W|0)!=0){if((a[607928]&1)==0){break}f=c[191244]|0;v=(f|0)!=0?f:c[q>>2]|0;f=c[6296+(U<<2)>>2]|0;eb(v|0,27776,(j=i,i=i+24|0,c[j>>2]=E,c[j+8>>2]=f,c[j+16>>2]=W,j)|0)|0;i=j;f=c[191244]|0;v=(f|0)!=0?f:c[q>>2]|0;aZ(v|0)|0}}while(0);U=U+1|0;}while(U>>>0<16);if(E>>>0<8){X=E}else{r=1;break}}i=e;return r|0}else if((b|0)==12){if((a[607928]&1)!=0){X=c[191244]|0;U=(X|0)!=0?X:c[q>>2]|0;a3(27416,42,1,U|0)|0;U=c[191244]|0;X=(U|0)!=0?U:c[q>>2]|0;aZ(X|0)|0}c[176726]=c[d>>2];r=1;i=e;return r|0}else if((b|0)==13){if((a[607928]&1)!=0){X=c[191244]|0;U=(X|0)!=0?X:c[q>>2]|0;a3(27128,47,1,U|0)|0;U=c[191244]|0;X=(U|0)!=0?U:c[q>>2]|0;aZ(X|0)|0}c[176728]=c[d>>2];c[706916>>2]=c[d+4>>2];c[706920>>2]=c[d+8>>2];c[706924>>2]=c[d+12>>2];c[706928>>2]=c[d+16>>2];c[706932>>2]=c[d+20>>2];c[706936>>2]=c[d+24>>2];r=1;i=e;return r|0}else if((b|0)==14|(b|0)==65550){if((a[607928]&1)!=0){X=c[191244]|0;U=(X|0)!=0?X:c[q>>2]|0;a3(26736,34,1,U|0)|0;U=c[191244]|0;X=(U|0)!=0?U:c[q>>2]|0;aZ(X|0)|0}X=c[d>>2]|0;do{if((X|0)==0){if((a[607928]&1)==0){break}U=c[191244]|0;W=(U|0)!=0?U:c[q>>2]|0;a3(26440,37,1,W|0)|0;W=c[191244]|0;U=(W|0)!=0?W:c[q>>2]|0;aZ(U|0)|0}else if((X|0)==2){if((a[607928]&1)!=0){U=c[191244]|0;W=(U|0)!=0?U:c[q>>2]|0;a3(26096,41,1,W|0)|0;W=c[191244]|0;U=(W|0)!=0?W:c[q>>2]|0;aZ(U|0)|0}c[191559]=72}else if((X|0)==1|(X|0)==3){U=c[191244]|0;a3(25744,116,1,((U|0)!=0?U:c[q>>2]|0)|0)|0;U=c[191244]|0;aZ(((U|0)!=0?U:c[q>>2]|0)|0)|0;r=0;i=e;return r|0}else{if((a[607928]&1)==0){r=0;i=e;return r|0}U=c[191244]|0;a3(25376,39,1,((U|0)!=0?U:c[q>>2]|0)|0)|0;U=c[191244]|0;aZ(((U|0)!=0?U:c[q>>2]|0)|0)|0;r=0;i=e;return r|0}}while(0);c[d+8>>2]=26;c[d+12>>2]=26;if((b&65536|0)==0){v6(706940,d|0,40)|0;r=1;i=e;return r|0}else{c[176735]=c[d>>2];c[706944>>2]=c[d+4>>2];c[706948>>2]=c[d+8>>2];c[706952>>2]=c[d+12>>2];a[706956|0]=a[d+16|0]|0;r=1;i=e;return r|0}}else if((b|0)==18){X=a[d]|0;if((a[607928]&1)==0){Y=X&1}else{U=c[191244]|0;W=(U|0)!=0?U:c[q>>2]|0;U=X&1;X=U<<24>>24!=0?24184:23936;eb(W|0,24600,(j=i,i=i+8|0,c[j>>2]=X,j)|0)|0;i=j;X=c[191244]|0;W=(X|0)!=0?X:c[q>>2]|0;aZ(W|0)|0;Y=U}a[702294]=Y;r=1;i=e;return r|0}else if((b|0)==19){c[d>>2]=0;r=1;i=e;return r|0}else if((b|0)==21){if((a[607928]&1)!=0){Y=c[191244]|0;U=(Y|0)!=0?Y:c[q>>2]|0;a3(23696,44,1,U|0)|0;U=c[191244]|0;Y=(U|0)!=0?U:c[q>>2]|0;aZ(Y|0)|0}c[176746]=c[d>>2];c[706988>>2]=c[d+4>>2];c[706992>>2]=c[d+8>>2];c[706996>>2]=c[d+12>>2];r=1;i=e;return r|0}else if((b|0)==131072){if((a[607928]&1)!=0){Y=c[191244]|0;U=(Y|0)!=0?Y:c[q>>2]|0;a3(23408,48,1,U|0)|0;U=c[191244]|0;Y=(U|0)!=0?U:c[q>>2]|0;aZ(Y|0)|0}Y=c2(d|0,34720)|0;if((Y|0)==0){r=0;i=e;return r|0}aR(Y|0)|0;Y=4096;U=583292;W=d;while(1){X=Y-1|0;if((X|0)==0){break}v=a[W]|0;a[U]=v;if(v<<24>>24==0){r=1;o=2872;break}else{Y=X;U=U+1|0;W=W+1|0}}if((o|0)==2872){i=e;return r|0}a[U]=0;if((a[W]|0)==0){r=1;i=e;return r|0}else{Z=W}while(1){W=Z+1|0;if((a[W]|0)==0){r=1;break}else{Z=W}}i=e;return r|0}else if((b|0)==131073|(b|0)==131074){L4042:do{if((d|0)==0){a[644842]=0}else{Z=4096;W=644842;U=d;while(1){o=Z-1|0;if((o|0)==0){break}Y=a[U]|0;a[W]=Y;if(Y<<24>>24==0){break L4042}else{Z=o;W=W+1|0;U=U+1|0}}a[W]=0;if((a[U]|0)==0){break}else{_=U}do{_=_+1|0;}while((a[_]|0)!=0)}}while(0);_=(a[607928]&1)!=0;if((b|0)==131074){if(_){d=c[191244]|0;U=(d|0)!=0?d:c[q>>2]|0;a3(23136,42,1,U|0)|0;U=c[191244]|0;d=(U|0)!=0?U:c[q>>2]|0;aZ(d|0)|0}a[756456]=1;r=1;i=e;return r|0}else{if(!_){r=1;i=e;return r|0}_=c[191244]|0;d=(_|0)!=0?_:c[q>>2]|0;a3(22912,35,1,d|0)|0;d=c[191244]|0;_=(d|0)!=0?d:c[q>>2]|0;aZ(_|0)|0;r=1;i=e;return r|0}}else{if((a[607928]&1)==0){r=0;i=e;return r|0}_=c[191244]|0;eb(((_|0)!=0?_:c[q>>2]|0)|0,22632,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;j=c[191244]|0;aZ(((j|0)!=0?j:c[q>>2]|0)|0)|0;r=0;i=e;return r|0}return 0}function gO(){return 1}function gP(a,b){a=a|0;b=b|0;return}function gQ(a){a=a|0;c[191554]=a;return}function gR(a){a=a|0;c[191556]=a;return}function gS(a){a=a|0;c[191550]=a;return}function gT(a){a=a|0;c[191548]=a;return}function gU(a){a=a|0;c[191546]=a;return}function gV(){return}function gW(a){a=a|0;return 0}function gX(){return}function gY(){return 0}function gZ(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function g_(){return 0}function g$(a,b){a=a|0;b=b|0;return 0}function g0(a,b){a=a|0;b=b|0;return 0}function g1(a){a=a|0;return 0}function g2(a){a=a|0;return 0}function g3(){return}function g4(a,b,c){a=a|0;b=b|0;c=c|0;return}function g5(a){a=a|0;h[a+24>>3]=60.0;h[a+32>>3]=3.0e4;c[a>>2]=320;c[a+4>>2]=240;c[a+8>>2]=320;c[a+12>>2]=240;g[a+16>>2]=1.3333333730697632;return}function g6(){var a=0;a=vZ(153600)|0;do{if((a|0)!=0){if((c[a-4>>2]&3|0)==0){break}v3(a|0,0,153600)}}while(0);c[191522]=a;return}function g7(){v_(c[191522]|0);c[191522]=0;return}function g8(b){b=b|0;v3(b|0,0,16);c[b>>2]=37792;c[b+4>>2]=766672;a[b+12|0]=0;c[b+8>>2]=766672;return}function g9(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[191552]=a;c[d>>2]=2;fr[a&63](10,d)|0;i=b;return}function ha(){var a=0,d=0;fx[c[191550]&127]();a=c[191522]|0;d=0;do{b[a+(d<<1)>>1]=128;d=d+1|0;}while(d>>>0<76800);fy[c[191546]&63](a,320,240,640);return}function hb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+4|0;if((c[b>>2]|0)==1){d=0;return d|0}e=a|0;f=c[(c[e>>2]|0)+4>>2]|0;g=f|0;h=(c[g>>2]|0)-1|0;c[g>>2]=h;if((h|0)!=0){d=c[f+8>>2]|0;return d|0}h=a+12|0;v_(c[h>>2]|0);a=f+8|0;c[h>>2]=c[a>>2];c[a>>2]=0;a=c[e>>2]|0;f=a+4|0;g=c[f>>2]|0;i=(c[b>>2]|0)-1|0;c[b>>2]=i;c[f>>2]=c[a+(i<<2)>>2];v_(g);g=1;while(1){i=g<<1;a=c[b>>2]|0;if(i>>>0>a>>>0){j=0}else{f=c[e>>2]|0;j=(c[f+(g<<2)>>2]|0)>>>0<(c[f+(i<<2)>>2]|0)>>>0}f=i|1;if(f>>>0>a>>>0){k=0}else{a=c[e>>2]|0;k=(c[a+(g<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0}if(!(j|k)){break}do{if(k|j^1){if(!(j|k^1)){l=f;break}a=c[e>>2]|0;l=(c[a+(i<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0?f:i}else{l=i}}while(0);i=c[e>>2]|0;f=i+(g<<2)|0;a=c[f>>2]|0;c[f>>2]=c[i+(l<<2)>>2];c[(c[e>>2]|0)+(l<<2)>>2]=a;g=l}d=c[h>>2]|0;return d|0}function hc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+16|0;f=e|0;g=f|0;h=f;j=vZ(36)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){v3(j|0,0,36)}l=j;m=f;L4129:do{if((d|0)==0){a[j+24|0]=1;n=c2(b|0,34720)|0;c[j>>2]=n;if((n|0)==0){o=c[191244]|0;p=(o|0)!=0?o:c[q>>2]|0;eb(p|0,26224,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;p=c[191244]|0;o=(p|0)!=0?p:c[q>>2]|0;aZ(o|0)|0;break}v3(m|0,0,16);if((d5(m|0,4,4,n|0)|0)!=4){o=c[191244]|0;p=(o|0)!=0?o:c[q>>2]|0;a3(22712,49,1,p|0)|0;p=c[191244]|0;o=(p|0)!=0?p:c[q>>2]|0;aZ(o|0)|0;s=n;t=2960;break}o=c[f>>2]|0;if(!((o|0)==1112757809|(o|0)==827740994)){o=c[191244]|0;p=(o|0)!=0?o:c[q>>2]|0;a3(20024,58,1,p|0)|0;p=c[191244]|0;o=(p|0)!=0?p:c[q>>2]|0;aZ(o|0)|0;u=n;t=2959;break}if((c[f+8>>2]|0)!=(c[153017]|0)){o=c[191244]|0;p=(o|0)!=0?o:c[q>>2]|0;a3(18120,151,1,p|0)|0;p=c[191244]|0;o=(p|0)!=0?p:c[q>>2]|0;aZ(o|0)|0}o=c[h+12>>2]|0;do{if((o|0)!=0){p=vZ(o)|0;c[j+4>>2]=p;c[j+8>>2]=o;if((p|0)==0){u=n;t=2959;break L4129}if((d5(p|0,1,o|0,n|0)|0)!=(o|0)){v=c[191244]|0;w=(v|0)!=0?v:c[q>>2]|0;a3(16240,53,1,w|0)|0;w=c[191244]|0;v=(w|0)!=0?w:c[q>>2]|0;aZ(v|0)|0;u=n;t=2959;break L4129}if((fu[c[37204]&31]()|0)==(o|0)){v=c[37186]|0;fr[v&63](p,o)|0;break}else{p=c[191244]|0;v=(p|0)!=0?p:c[q>>2]|0;a3(14072,102,1,v|0)|0;v=c[191244]|0;p=(v|0)!=0?v:c[q>>2]|0;aZ(p|0)|0;break}}}while(0);p=o+16|0;c[j+28>>2]=p;x=n;y=p;t=2954}else{p=c2(b|0,37672)|0;c[j>>2]=p;if((p|0)==0){v=c[191244]|0;w=(v|0)!=0?v:c[q>>2]|0;eb(w|0,39608,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;w=c[191244]|0;v=(w|0)!=0?w:c[q>>2]|0;aZ(v|0)|0;break}c[g>>2]=0;c[g+4>>2]=0;c[f>>2]=827740994;c[f+8>>2]=c[153017];v=fu[c[37204]&31]()|0;c[h+12>>2]=v;a3(m|0,4,4,p|0)|0;w=v+16|0;c[j+28>>2]=w;c[j+8>>2]=v;if((v|0)==0){x=p;y=w;t=2954;break}z=vZ(v)|0;c[j+4>>2]=z;if((z|0)==0){u=p;t=2959;break}A=c[37206]|0;fr[A&63](z,v)|0;a3(z|0,1,v|0,p|0)|0;x=p;y=w;t=2954}}while(0);do{if((t|0)==2954){m=vZ(4194304)|0;if((m|0)==0){c[j+12>>2]=0;u=x;t=2959;break}if((c[m-4>>2]&3|0)!=0){v3(m|0,0,4194304)}h=m;c[j+12>>2]=h;c[h>>2]=y;c[j+16>>2]=1048575;k=l;i=e;return k|0}}while(0);if((t|0)==2959){if((u|0)!=0){s=u;t=2960}}if((t|0)==2960){aR(s|0)|0}v_(c[j+4>>2]|0);v_(c[j+12>>2]|0);v_(j);k=0;i=e;return k|0}function hd(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+128|0;h=g+64|0;bN(h|0,64,40184,(j=i,i=i+16|0,c[j>>2]=d,c[j+8>>2]=e,j)|0)|0;i=j;j=g|0;e=b+4|0;while(1){k=c[e>>2]|0;if((k|0)==0){l=2984;break}if((cJ(h|0,c[k+4>>2]|0)|0)==0){break}else{e=k+12|0}}if((l|0)==2984){i=g;return}e=64;h=0;b=j;d=c[k+8>>2]|0;while(1){k=e-1|0;if((k|0)==0){l=2972;break}m=a[d]|0;a[b]=m;if(m<<24>>24==0){n=h;break}else{e=k;h=h+1|0;b=b+1|0;d=d+1|0}}do{if((l|0)==2972){a[b]=0;if((a[d]|0)==0){n=h;break}else{o=d;p=h}while(1){e=o+1|0;k=p+1|0;if((a[e]|0)==0){n=k;break}else{o=e;p=k}}}}while(0);if(n>>>0>=64){i=g;return}do{if((v2(j|0)|0)==1){n=a[j]|0;if((di(n|0)|0)==0){q=0;l=2978;break}r=v7(n|0)|0}else{q=0;l=2978}}while(0);L4195:do{if((l|0)==2978){while(1){l=0;if((q|0)==67){r=0;break L4195}if((v9(c[7384+(q<<3)>>2]|0,j|0)|0)==0){break}else{q=q+1|0;l=2978}}r=c[7388+(q<<3)>>2]|0}}while(0);c[f+12>>2]=r;i=g;return}function he(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0;g=i;i=i+136|0;h=g|0;j=g+8|0;k=g+72|0;bN(k|0,64,40088,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;l=j|0;e=b+4|0;while(1){m=c[e>>2]|0;if((m|0)==0){n=3011;break}if((cJ(k|0,c[m+4>>2]|0)|0)==0){break}else{e=m+12|0}}if((n|0)==3011){i=g;return}e=64;k=0;b=l;d=c[m+8>>2]|0;while(1){m=e-1|0;if((m|0)==0){n=2992;break}o=a[d]|0;a[b]=o;if(o<<24>>24==0){p=k;break}else{e=m;k=k+1|0;b=b+1|0;d=d+1|0}}do{if((n|0)==2992){a[b]=0;if((a[d]|0)==0){p=k;break}else{r=d;s=k}while(1){e=r+1|0;m=s+1|0;if((a[e]|0)==0){p=m;break}else{r=e;s=m}}}}while(0);if(p>>>0>=64){i=g;return}if((cJ(l|0,40224)|0)==0){p=f+16|0;c[p>>2]=65535;c[p+4>>2]=0;i=g;return}if((a[l]|0)!=104){p=aX(l|0,0,0)|0;l=f+16|0;c[l>>2]=p;c[l+4>>2]=G;i=g;return}l=j+1|0;if(((a[l]|0)-48|0)>>>0>=10){i=g;return}c[h>>2]=0;j=aW(l|0,h|0,0)|0;l=c[h>>2]|0;if((l|0)==0){h=c[191244]|0;p=(h|0)!=0?h:c[q>>2]|0;a3(39216,49,1,p|0)|0;p=c[191244]|0;h=(p|0)!=0?p:c[q>>2]|0;aZ(h|0)|0;i=g;return}do{if((v9(l|0,27072)|0)==0){t=-32768}else{if((v9(l|0,26680)|0)==0){t=16384;break}if((v9(l|0,26424)|0)==0){t=8192;break}h=(v9(l|0,26008)|0)==0;if(h){t=h?4096:0;break}i=g;return}}while(0);l=f+16|0;c[l>>2]=t&65535|j&4095;c[l+4>>2]=0;i=g;return}function hf(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+128|0;h=g|0;j=g+64|0;bN(j|0,64,40024,(k=i,i=i+16|0,c[k>>2]=d,c[k+8>>2]=e,k)|0)|0;i=k;k=h|0;e=b+4|0;while(1){l=c[e>>2]|0;if((l|0)==0){m=3036;break}if((cJ(j|0,c[l+4>>2]|0)|0)==0){break}else{e=l+12|0}}if((m|0)==3036){i=g;return}e=64;j=0;b=k;d=c[l+8>>2]|0;while(1){l=e-1|0;if((l|0)==0){m=3022;break}n=a[d]|0;a[b]=n;if(n<<24>>24==0){o=j;break}else{e=l;j=j+1|0;b=b+1|0;d=d+1|0}}do{if((m|0)==3022){a[b]=0;if((a[d]|0)==0){o=j;break}else{p=d;q=j}while(1){e=p+1|0;l=q+1|0;if((a[e]|0)==0){o=l;break}else{p=e;q=l}}}}while(0);if(o>>>0>=64){i=g;return}if((cJ(k|0,40224)|0)==0){c[f+32>>2]=-1;i=g;return}if((v2(k|0)|0)>>>0<=1){i=g;return}o=a[k]|0;if(!((o<<24>>24|0)==43|(o<<24>>24|0)==45)){i=g;return}o=a0(h+1|0,0,0)|0;if((a[k]|0)==43){c[f+32>>2]=o|-65536;i=g;return}else{c[f+32>>2]=o<<16|65535;i=g;return}}function hg(){var a=0,b=0,d=0,e=0,f=0;a=vZ(48)|0;if((a|0)==0){b=0;return b|0}if((c[a-4>>2]&3|0)!=0){v3(a|0,0,48)}d=bm()|0;c[a+44>>2]=d;if((d|0)==0){v_(a);b=0;return b|0}v3(147440,0,1292);d=5616;e=276;while(1){c[147440+(e<<2)>>2]=c[d>>2];f=c[d+12>>2]|0;if((f|0)==0){b=a;break}else{d=d+8|0;e=f}}return b|0}function hh(a){a=a|0;var b=0;b=ch(c[a+44>>2]|0)|0;v6(a|0,b|0,44)|0;return}function hi(a,b){a=a|0;b=b|0;return}function hj(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;g=b;do{if((f|0)==2){if((h|0)==1){i=c[b+36>>2]&65535;break}else if((h|0)==2){i=a[b+40|0]|0;break}else if((h|0)==3){i=a[b+41|0]|0;break}else if((h|0)==0){i=c[b+32>>2]&65535;break}else{i=0;break}}else if((f|0)==1){j=c[d+(e<<2)>>2]|0;if(h>>>0>=56){i=0;break}if((a[j+(h*40|0)|0]&1)==0){i=0;break}k=c[j+(h*40|0)+12>>2]|0;if((k|0)>322){i=0;break}j=c[147440+(k<<2)>>2]|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else if((f|0)==3){if((h|0)>322){i=0;break}j=c[147440+(h<<2)>>2]|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else{i=0}}while(0);return i|0}function hk(b,d){b=b|0;d=d|0;var e=0,f=0;if(d>>>0>=56){e=0;return e|0}if((a[530424+(d*40|0)|0]&1)==0){e=0;return e|0}f=c[530436+(d*40|0)>>2]|0;if((f|0)>322){e=0;return e|0}d=c[147440+(f<<2)>>2]|0;e=(a[b+(d>>>3)|0]&1<<(d&7)|0)!=0;return e|0}function hl(a){a=a|0;aN(c[a+44>>2]|0);v_(a);return}function hm(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)==0){return}b=a+4104|0;if((c[b>>2]|0)!=0){d=a+4100|0;e=0;do{v_(c[(c[d>>2]|0)+(e<<4)>>2]|0);v_(c[(c[d>>2]|0)+(e<<4)+4>>2]|0);f=c[(c[d>>2]|0)+(e<<4)+8>>2]|0;if((f|0)!=0){g=f+4|0;h=f|0;i=c[h>>2]|0;if((c[g>>2]|0)==0){j=i}else{k=0;l=i;while(1){v_(c[l+(k<<3)>>2]|0);i=k+1|0;m=c[h>>2]|0;if(i>>>0<(c[g>>2]|0)>>>0){k=i;l=m}else{j=m;break}}}v_(j);v_(f)}e=e+1|0;}while(e>>>0<(c[b>>2]|0)>>>0)}b=c[a>>2]|0;if((b|0)!=0){gE(b)}v_(c[a+4100>>2]|0);v_(a);return}
function lP(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>27&1;e=d>>28;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lQ(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>28&1;e=d>>29;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lR(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>29&1;e=d>>30;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lS(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>30&1;e=d>>31;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lT(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194146]|0;f=e+d|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(f|0)==0|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d&f;g=b^1;a[768256]=(g&f|e|g&d)&255;a[768232]=(g&e|(d^1)&(f^1)&b)&255;return}function lU(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194147]|0;f=e+d|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(f|0)==0|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d&f;g=b^1;a[768256]=(g&f|e|g&d)&255;a[768232]=(g&e|(d^1)&(f^1)&b)&255;return}function lV(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194148]|0;f=e+d|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(f|0)==0|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d&f;g=b^1;a[768256]=(g&f|e|g&d)&255;a[768232]=(g&e|(d^1)&(f^1)&b)&255;return}function lW(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194149]|0;f=e+d|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(f|0)==0|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d&f;g=b^1;a[768256]=(g&f|e|g&d)&255;a[768232]=(g&e|(d^1)&(f^1)&b)&255;return}function lX(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194150]|0;f=e+d|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(f|0)==0|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d&f;g=b^1;a[768256]=(g&f|e|g&d)&255;a[768232]=(g&e|(d^1)&(f^1)&b)&255;return}function lY(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194151]|0;f=e+d|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(f|0)==0|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d&f;g=b^1;a[768256]=(g&f|e|g&d)&255;a[768232]=(g&e|(d^1)&(f^1)&b)&255;return}function lZ(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194152]|0;f=e+d|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(f|0)==0|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d&f;g=b^1;a[768256]=(g&f|e|g&d)&255;a[768232]=(g&e|(d^1)&(f^1)&b)&255;return}function l_(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194153]|0;f=e+d|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(f|0)==0|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d&f;g=b^1;a[768256]=(g&f|e|g&d)&255;a[768232]=(g&e|(d^1)&(f^1)&b)&255;return}function l$(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194146]|0;f=d-e|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(d|0)==(e|0)|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d^1;g=e&f;h=b^1;a[768256]=(h&f|g|h&e)&255;a[768232]=(g&h|(f^1)&d&b)&255;return}function l0(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194147]|0;f=d-e|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(d|0)==(e|0)|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d^1;g=e&f;h=b^1;a[768256]=(h&f|g|h&e)&255;a[768232]=(g&h|(f^1)&d&b)&255;return}function l1(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194148]|0;f=d-e|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(d|0)==(e|0)|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d^1;g=e&f;h=b^1;a[768256]=(h&f|g|h&e)&255;a[768232]=(g&h|(f^1)&d&b)&255;return}function l2(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194149]|0;f=d-e|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(d|0)==(e|0)|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d^1;g=e&f;h=b^1;a[768256]=(h&f|g|h&e)&255;a[768232]=(g&h|(f^1)&d&b)&255;return}function l3(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194150]|0;f=d-e|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(d|0)==(e|0)|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d^1;g=e&f;h=b^1;a[768256]=(h&f|g|h&e)&255;a[768232]=(g&h|(f^1)&d&b)&255;return}function l4(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194151]|0;f=d-e|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(d|0)==(e|0)|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d^1;g=e&f;h=b^1;a[768256]=(h&f|g|h&e)&255;a[768232]=(g&h|(f^1)&d&b)&255;return}function l5(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194152]|0;f=d-e|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(d|0)==(e|0)|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d^1;g=e&f;h=b^1;a[768256]=(h&f|g|h&e)&255;a[768232]=(g&h|(f^1)&d&b)&255;return}function l6(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[194153]|0;f=d-e|0;c[776584+((b&7)<<2)>>2]=f;a[768224]=(d|0)==(e|0)|0;b=f>>>31;a[768240]=b&255;f=d>>>31;d=e>>>31;e=d^1;g=e&f;h=b^1;a[768256]=(h&f|g|h&e)&255;a[768232]=(g&h|(f^1)&d&b)&255;return}function l7(b){b=b|0;var d=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;c[776584+((b&7)<<2)>>2]=d;a[768224]=(d|0)==0|0;a[768240]=d>>>31&255;a[768256]=0;a[768232]=0;return}function l8(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d+1|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;a[768256]=(-2-d&d)>>>31&255;a[768232]=(d>>>31^1)&b&255;return}function l9(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d+2|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;a[768256]=(-3-d&d)>>>31&255;a[768232]=(d>>>31^1)&b&255;return}function ma(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d+3|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;a[768256]=(-4-d&d)>>>31&255;a[768232]=(d>>>31^1)&b&255;return}function mb(b){b=b|0;var d=0;d=b&255;c[194146]=d;a[768240]=0;a[768224]=(d|0)==0|0;return}function mc(b){b=b|0;var d=0;d=b&255;c[194147]=d;a[768240]=0;a[768224]=(d|0)==0|0;return}function md(b){b=b|0;var d=0;d=b&255;c[194148]=d;a[768240]=0;a[768224]=(d|0)==0|0;return}function me(b){b=b|0;var d=0;d=b&255;c[194149]=d;a[768240]=0;a[768224]=(d|0)==0|0;return}function mf(b){b=b|0;var d=0;d=b&255;c[194150]=d;a[768240]=0;a[768224]=(d|0)==0|0;return}function mg(b){b=b|0;var d=0;d=b&255;c[194151]=d;a[768240]=0;a[768224]=(d|0)==0|0;return}function mh(b){b=b|0;var d=0;d=b&255;c[194152]=d;a[768240]=0;a[768224]=(d|0)==0|0;return}function mi(b){b=b|0;var d=0;d=b&255;c[194153]=d;a[768240]=0;a[768224]=(d|0)==0|0;return}function mj(b){b=b|0;var d=0,e=0;d=c[194146]|0;e=b&255;a[768224]=(d|0)==(e|0)|0;b=(d-e|0)>>>31;a[768240]=b&255;e=d>>>31;d=b^1;a[768256]=(d|e)&255;a[768232]=d&e&255;return}function mk(b){b=b|0;var d=0,e=0;d=c[194147]|0;e=b&255;a[768224]=(d|0)==(e|0)|0;b=(d-e|0)>>>31;a[768240]=b&255;e=d>>>31;d=b^1;a[768256]=(d|e)&255;a[768232]=d&e&255;return}function ml(b){b=b|0;var d=0,e=0;d=c[194148]|0;e=b&255;a[768224]=(d|0)==(e|0)|0;b=(d-e|0)>>>31;a[768240]=b&255;e=d>>>31;d=b^1;a[768256]=(d|e)&255;a[768232]=d&e&255;return}function mm(b){b=b|0;var d=0,e=0;d=c[194149]|0;e=b&255;a[768224]=(d|0)==(e|0)|0;b=(d-e|0)>>>31;a[768240]=b&255;e=d>>>31;d=b^1;a[768256]=(d|e)&255;a[768232]=d&e&255;return}function mn(b){b=b|0;var d=0,e=0;d=c[194150]|0;e=b&255;a[768224]=(d|0)==(e|0)|0;b=(d-e|0)>>>31;a[768240]=b&255;e=d>>>31;d=b^1;a[768256]=(d|e)&255;a[768232]=d&e&255;return}function mo(b){b=b|0;var d=0,e=0;d=c[194151]|0;e=b&255;a[768224]=(d|0)==(e|0)|0;b=(d-e|0)>>>31;a[768240]=b&255;e=d>>>31;d=b^1;a[768256]=(d|e)&255;a[768232]=d&e&255;return}function mp(b){b=b|0;var d=0,e=0;d=c[194152]|0;e=b&255;a[768224]=(d|0)==(e|0)|0;b=(d-e|0)>>>31;a[768240]=b&255;e=d>>>31;d=b^1;a[768256]=(d|e)&255;a[768232]=d&e&255;return}function mq(b){b=b|0;var d=0,e=0;d=c[194153]|0;e=b&255;a[768224]=(d|0)==(e|0)|0;b=(d-e|0)>>>31;a[768240]=b&255;e=d>>>31;d=b^1;a[768256]=(d|e)&255;a[768232]=d&e&255;return}function mr(b){b=b|0;var d=0,e=0;d=c[194146]|0;e=d+(b&255)|0;c[194146]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;e=d>>>31;a[768256]=(b^1)&e&255;a[768232]=(e^1)&b&255;return}function ms(b){b=b|0;var d=0,e=0;d=c[194147]|0;e=d+(b&255)|0;c[194147]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;e=d>>>31;a[768256]=(b^1)&e&255;a[768232]=(e^1)&b&255;return}function mt(b){b=b|0;var d=0,e=0;d=c[194148]|0;e=d+(b&255)|0;c[194148]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;e=d>>>31;a[768256]=(b^1)&e&255;a[768232]=(e^1)&b&255;return}function mu(b){b=b|0;var d=0,e=0;d=c[194149]|0;e=d+(b&255)|0;c[194149]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;e=d>>>31;a[768256]=(b^1)&e&255;a[768232]=(e^1)&b&255;return}function mv(b){b=b|0;var d=0,e=0;d=c[194150]|0;e=d+(b&255)|0;c[194150]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;e=d>>>31;a[768256]=(b^1)&e&255;a[768232]=(e^1)&b&255;return}function mw(b){b=b|0;var d=0,e=0;d=c[194151]|0;e=d+(b&255)|0;c[194151]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;e=d>>>31;a[768256]=(b^1)&e&255;a[768232]=(e^1)&b&255;return}function mx(b){b=b|0;var d=0,e=0;d=c[194152]|0;e=d+(b&255)|0;c[194152]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;e=d>>>31;a[768256]=(b^1)&e&255;a[768232]=(e^1)&b&255;return}function my(b){b=b|0;var d=0,e=0;d=c[194153]|0;e=d+(b&255)|0;c[194153]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;e=d>>>31;a[768256]=(b^1)&e&255;a[768232]=(e^1)&b&255;return}function mz(b){b=b|0;var d=0,e=0;d=c[194146]|0;e=b&255;b=d-e|0;c[194146]=b;a[768224]=(d|0)==(e|0)|0;e=b>>>31;a[768240]=e&255;b=d>>>31;d=e^1;a[768256]=(d|b)&255;a[768232]=d&b&255;return}function mA(b){b=b|0;var d=0,e=0;d=c[194147]|0;e=b&255;b=d-e|0;c[194147]=b;a[768224]=(d|0)==(e|0)|0;e=b>>>31;a[768240]=e&255;b=d>>>31;d=e^1;a[768256]=(d|b)&255;a[768232]=d&b&255;return}function mB(b){b=b|0;var d=0,e=0;d=c[194148]|0;e=b&255;b=d-e|0;c[194148]=b;a[768224]=(d|0)==(e|0)|0;e=b>>>31;a[768240]=e&255;b=d>>>31;d=e^1;a[768256]=(d|b)&255;a[768232]=d&b&255;return}function mC(b){b=b|0;var d=0,e=0;d=c[194149]|0;e=b&255;b=d-e|0;c[194149]=b;a[768224]=(d|0)==(e|0)|0;e=b>>>31;a[768240]=e&255;b=d>>>31;d=e^1;a[768256]=(d|b)&255;a[768232]=d&b&255;return}function mD(b){b=b|0;var d=0,e=0;d=c[194150]|0;e=b&255;b=d-e|0;c[194150]=b;a[768224]=(d|0)==(e|0)|0;e=b>>>31;a[768240]=e&255;b=d>>>31;d=e^1;a[768256]=(d|b)&255;a[768232]=d&b&255;return}function mE(b){b=b|0;var d=0,e=0;d=c[194151]|0;e=b&255;b=d-e|0;c[194151]=b;a[768224]=(d|0)==(e|0)|0;e=b>>>31;a[768240]=e&255;b=d>>>31;d=e^1;a[768256]=(d|b)&255;a[768232]=d&b&255;return}function mF(b){b=b|0;var d=0,e=0;d=c[194152]|0;e=b&255;b=d-e|0;c[194152]=b;a[768224]=(d|0)==(e|0)|0;e=b>>>31;a[768240]=e&255;b=d>>>31;d=e^1;a[768256]=(d|b)&255;a[768232]=d&b&255;return}function mG(b){b=b|0;var d=0,e=0;d=c[194153]|0;e=b&255;b=d-e|0;c[194153]=b;a[768224]=(d|0)==(e|0)|0;e=b>>>31;a[768240]=e&255;b=d>>>31;d=e^1;a[768256]=(d|b)&255;a[768232]=d&b&255;return}function mH(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d+4|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;a[768256]=(-5-d&d)>>>31&255;a[768232]=(d>>>31^1)&b&255;return}function mI(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d+5|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;a[768256]=(-6-d&d)>>>31&255;a[768232]=(d>>>31^1)&b&255;return}function mJ(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d+6|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;a[768256]=(-7-d&d)>>>31&255;a[768232]=(d>>>31^1)&b&255;return}function mK(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d+7|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;b=e>>>31;a[768240]=b&255;a[768256]=(-8-d&d)>>>31&255;a[768232]=(d>>>31^1)&b&255;return}function mL(b){b=b|0;var d=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;c[776584+((b&7)<<2)>>2]=d;a[768224]=(d|0)==0|0;a[768240]=d>>>31&255;a[768256]=1;a[768232]=0;return}function mM(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d-1|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;a[768240]=e>>>31&255;e=d>>>31;b=(-d|0)>>>31;a[768256]=(e|b)&255;a[768232]=e&b&255;return}function mN(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d-2|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;a[768240]=e>>>31&255;e=d>>>31;b=(1-d|0)>>>31;a[768256]=(b|e)&255;a[768232]=b&e&255;return}function mO(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d-3|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;a[768240]=e>>>31&255;e=d>>>31;b=(2-d|0)>>>31;a[768256]=(b|e)&255;a[768232]=b&e&255;return}function mP(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d-4|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;a[768240]=e>>>31&255;e=d>>>31;b=(3-d|0)>>>31;a[768256]=(b|e)&255;a[768232]=b&e&255;return}function mQ(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d-5|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;a[768240]=e>>>31&255;e=d>>>31;b=(4-d|0)>>>31;a[768256]=(b|e)&255;a[768232]=b&e&255;return}function mR(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d-6|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;a[768240]=e>>>31&255;e=d>>>31;b=(5-d|0)>>>31;a[768256]=(b|e)&255;a[768232]=b&e&255;return}function mS(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d-7|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(e|0)==0|0;a[768240]=e>>>31&255;e=d>>>31;b=(6-d|0)>>>31;a[768256]=(b|e)&255;a[768232]=b&e&255;return}function mT(b){b=b|0;var d=0,e=0;d=776584+((b&7)<<2)|0;e=c[776584+((b>>>3&7)<<2)>>2]&c[d>>2];a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;c[d>>2]=e;return}function mU(b){b=b|0;var d=0,e=0,f=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=776584+((b&7)<<2)|0;b=c[e>>2]|0;f=b^d;c[e>>2]=f;a[768240]=f>>>31&255;a[768224]=(b|0)==(d|0)|0;return}function mV(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b&7;f=a[776584+((b>>>3&7)<<2)|0]|0;b=f&255;do{if((f<<24>>24|0)==32){g=776584+(e<<2)|0;a[768256]=c[g>>2]&1;h=0;i=g;j=4241}else if((f<<24>>24|0)==0){k=c[776584+(e<<2)>>2]|0}else{if((f&255)<32){g=776584+(e<<2)|0;l=c[g>>2]|0;a[768256]=(l&1<<32-b|0)!=0|0;h=l<<b;i=g;j=4241;break}else{a[768256]=0;h=0;i=776584+(e<<2)|0;j=4241;break}}}while(0);if((j|0)==4241){c[i>>2]=h;k=h}a[768240]=k>>>31&255;a[768224]=(k|0)==0|0;k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;m=(d[130328+k|0]|0)-1|0;n=m+2|0;c[204526]=n;return}else{c[194192]=i>>>2|h&-256;m=0;n=m+2|0;c[204526]=n;return}}}while(0);c[194192]=0;m=d[147072+k|0]|0;n=m+2|0;c[204526]=n;return}function mW(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b&7;f=a[776584+((b>>>3&7)<<2)|0]|0;b=f&255;do{if((f<<24>>24|0)==0){g=c[776584+(e<<2)>>2]|0}else if((f<<24>>24|0)==32){h=776584+(e<<2)|0;a[768256]=(c[h>>2]|0)>>>31&255;i=0;j=h;k=4258}else{if((f&255)<32){h=776584+(e<<2)|0;l=c[h>>2]|0;a[768256]=(l&1<<b-1|0)!=0|0;i=l>>>(b>>>0);j=h;k=4258;break}else{a[768256]=0;i=0;j=776584+(e<<2)|0;k=4258;break}}}while(0);if((k|0)==4258){c[j>>2]=i;g=i}a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;m=(d[130328+g|0]|0)-1|0;n=m+2|0;c[204526]=n;return}else{c[194192]=j>>>2|i&-256;m=0;n=m+2|0;c[204526]=n;return}}}while(0);c[194192]=0;m=d[147072+g|0]|0;n=m+2|0;c[204526]=n;return}function mX(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b&7;f=a[776584+((b>>>3&7)<<2)|0]|0;b=f&255;do{if(f<<24>>24==0){g=c[776584+(e<<2)>>2]|0}else{h=776584+(e<<2)|0;i=c[h>>2]|0;if((f&255)<32){a[768256]=(i&1<<b-1|0)!=0|0;j=i>>b;c[h>>2]=j;g=j;break}if((i|0)<0){c[h>>2]=-1;a[768256]=1;g=-1;break}else{c[h>>2]=0;a[768256]=0;g=0;break}}}while(0);a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}f=b&255;if((b&2|0)==0){c[194192]=f>>>1|b&-256;k=(d[130328+g|0]|0)-1|0;l=k+2|0;c[204526]=l;return}else{c[194192]=f>>>2|b&-256;k=0;l=k+2|0;c[204526]=l;return}}}while(0);c[194192]=0;k=d[147072+g|0]|0;l=k+2|0;c[204526]=l;return}function mY(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=776584+((b&7)<<2)|0;b=c[e>>2]|0;f=b+d+(a[768256]&1)|0;c[e>>2]=f;a[768224]=(f|0)==0|0;e=f>>>31;a[768240]=e&255;f=b>>>31;b=d>>>31;d=f&b;g=e^1;a[768256]=(g&f|d|g&b)&255;a[768232]=(g&d|(f^1)&(b^1)&e)&255;return}function mZ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=776584+((b&7)<<2)|0;b=c[e>>2]|0;f=b-d|0;g=(a[768256]&1^1)&255;h=f-g|0;c[e>>2]=h;a[768224]=(f|0)==(g|0)|0;g=h>>>31;a[768240]=g&255;h=b>>>31;b=d>>>31;d=b^1;f=h&d;e=g^1;a[768256]=(e&h|f|e&d)&255;a[768232]=(e&f|(h^1)&b&g)&255;return}function m_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=b&7;f=a[776584+((b>>>3&7)<<2)|0]|0;if(f<<24>>24!=0){b=f&31;f=776584+(e<<2)|0;g=c[f>>2]|0;a[768256]=(g&1<<b-1|0)!=0|0;c[f>>2]=g<<32-b|g>>>(b>>>0)}b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){h=4295;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=(d[130328+b|0]|0)-1|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=4295}}while(0);if((h|0)==4295){c[194192]=0;i=d[147072+b|0]|0}c[204526]=i+2;i=c[776584+(e<<2)>>2]|0;a[768240]=i>>>31&255;a[768224]=(i|0)==0|0;return}function m$(b){b=b|0;var d=0;d=c[776584+((b>>>3&7)<<2)>>2]&c[776584+((b&7)<<2)>>2];a[768240]=d>>>31&255;a[768224]=(d|0)==0|0;return}function m0(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=-d|0;c[776584+((b&7)<<2)>>2]=e;a[768224]=(d|0)==0|0;a[768240]=e>>>31&255;a[768256]=(d>>>31^1)&(d-1|0)>>>31&255;a[768232]=(d&e)>>>31&255;return}function m1(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[776584+((b&7)<<2)>>2]|0;a[768224]=(e|0)==(d|0)|0;b=(e-d|0)>>>31;a[768240]=b&255;f=e>>>31;e=d>>>31;d=e^1;g=f&d;h=b^1;a[768256]=(h&f|g|h&d)&255;a[768232]=(h&g|(f^1)&e&b)&255;return}function m2(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[776584+((b&7)<<2)>>2]|0;b=e+d|0;a[768224]=(b|0)==0|0;f=b>>>31;a[768240]=f&255;b=e>>>31;e=d>>>31;d=b&e;g=f^1;a[768256]=(g&b|d|g&e)&255;a[768232]=(g&d|(b^1)&(e^1)&f)&255;return}function m3(b){b=b|0;var d=0,e=0;d=776584+((b&7)<<2)|0;e=c[d>>2]|c[776584+((b>>>3&7)<<2)>>2];c[d>>2]=e;a[768224]=(e|0)==0|0;a[768240]=e>>>31&255;return}function m4(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;c[204526]=1;e=776584+((b&7)<<2)|0;f=c[e>>2]|0;c[e>>2]=ac(c[776584+((b>>>3&7)<<2)>>2]|0,f)|0;b=f>>31^f;do{if(b>>>0<65536){c[204526]=2;g=2}else{if(b>>>0<16777216){c[204526]=3;g=3;break}else{c[204526]=4;g=4;break}}}while(0);b=255>>>((8-g|0)>>>0)|c[194192]<<g;c[194192]=b;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){if((b&1|0)==0){h=4312;break}i=b&255;if((b&2|0)==0){c[194192]=i>>>1|b&-256;j=(d[130328+f|0]|0)-1|0;break}else{c[194192]=i>>>2|b&-256;j=0;break}}else{h=4312}}while(0);if((h|0)==4312){c[194192]=0;j=d[147072+f|0]|0}c[204526]=g+1+j;j=c[e>>2]|0;a[768224]=(j|0)==0|0;a[768240]=j>>>31&255;return}function m5(b){b=b|0;var d=0,e=0;d=776584+((b&7)<<2)|0;e=c[d>>2]&~c[776584+((b>>>3&7)<<2)>>2];c[d>>2]=e;a[768224]=(e|0)==0|0;a[768240]=e>>>31&255;return}function m6(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=~d;c[776584+((b&7)<<2)>>2]=e;a[768224]=(d|0)==-1|0;a[768240]=e>>>31&255;return}function m7(a){a=a|0;var b=0;b=776584+((a&7)<<2)|0;c[b>>2]=(c[b>>2]|0)+(c[776584+((a>>>3&7|8)<<2)>>2]|0);return}function m8(a){a=a|0;var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a&7;f=776584+((b|8)<<2)|0;c[f>>2]=(c[f>>2]|0)+(c[776584+((a>>>3&7)<<2)>>2]|0);if((b|0)!=7){return}b=c[194161]|0;a=b&-2;c[194193]=a;f=a+2|0;c[194161]=f;g=b>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&a)>>1]|0;a=f>>>24;c[203400]=e[(c[774536+(a<<3)>>2]|0)+(c[774540+(a<<3)>>2]&f)>>1]|0;f=g&15;do{if((f-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=d[i+f|0]|0}else{a=g>>>1&127|g&-256;c[194192]=a;j=a;k=0}if((j&1|0)==0){l=k;m=4329;break}a=j&255;if((j&2|0)==0){c[194192]=a>>>1|j&-256;n=(d[130328+f|0]|0)-1|0;o=k;break}else{c[194192]=a>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=d[130328+f|0]|0;m=4329}}while(0);if((m|0)==4329){c[194192]=0;n=d[147072+f|0]|0;o=l}c[204526]=o<<n+4;return}function m9(b){b=b|0;var d=0;b=c[194161]|0;d=(a[52040]&1)!=0;if((c[31194]|0)!=27){km(27,1,0)}c[194160]=b-(d?4:2);c[194161]=4;a[52040]=1;a[130632]=0;c[194193]=4;d=c[193635]|0;b=c[193634]|0;c[203402]=c[b+(d&4)>>2];c[203400]=c[b+(d&8)>>2];c[194161]=8;return}function na(a){a=a|0;var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a&7;f=776584+((b|8)<<2)|0;c[f>>2]=(c[f>>2]|0)+(c[776584+((a>>>3&7|8)<<2)>>2]|0);if((b|0)!=7){return}b=c[194161]|0;a=b&-2;c[194193]=a;f=a+2|0;c[194161]=f;g=b>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&a)>>1]|0;a=f>>>24;c[203400]=e[(c[774536+(a<<3)>>2]|0)+(c[774540+(a<<3)>>2]&f)>>1]|0;f=g&15;do{if((f-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=d[i+f|0]|0}else{a=g>>>1&127|g&-256;c[194192]=a;j=a;k=0}if((j&1|0)==0){l=k;m=4349;break}a=j&255;if((j&2|0)==0){c[194192]=a>>>1|j&-256;n=(d[130328+f|0]|0)-1|0;o=k;break}else{c[194192]=a>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=d[130328+f|0]|0;m=4349}}while(0);if((m|0)==4349){c[194192]=0;n=d[147072+f|0]|0;o=l}c[204526]=o<<n+4;return}function nb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7|8)<<2)>>2]|0;e=c[776584+((b&7)<<2)>>2]|0;a[768224]=(e|0)==(d|0)|0;b=(e-d|0)>>>31;a[768240]=b&255;f=e>>>31;e=d>>>31;d=e^1;g=f&d;h=b^1;a[768256]=(h&f|g|h&d)&255;a[768232]=(h&g|(f^1)&e&b)&255;return}function nc(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=c[776584+((b&7|8)<<2)>>2]|0;a[768224]=(e|0)==(d|0)|0;b=(e-d|0)>>>31;a[768240]=b&255;f=e>>>31;e=d>>>31;d=e^1;g=f&d;h=b^1;a[768256]=(h&f|g|h&d)&255;a[768232]=(h&g|(f^1)&e&b)&255;return}function nd(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=c[776584+((b>>>3&7|8)<<2)>>2]|0;e=c[776584+((b&7|8)<<2)>>2]|0;a[768224]=(e|0)==(d|0)|0;b=(e-d|0)>>>31;a[768240]=b&255;f=e>>>31;e=d>>>31;d=e^1;g=f&d;h=b^1;a[768256]=(h&f|g|h&d)&255;a[768232]=(h&g|(f^1)&e&b)&255;return}function ne(a){a=a|0;c[776584+((a&7)<<2)>>2]=c[776584+((a>>>3&7|8)<<2)>>2];return}function nf(a){a=a|0;var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a&7;c[776584+((b|8)<<2)>>2]=c[776584+((a>>>3&7)<<2)>>2];if((b|0)!=7){return}b=c[194161]|0;a=b&-2;c[194193]=a;f=a+2|0;c[194161]=f;g=b>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&a)>>1]|0;a=f>>>24;c[203400]=e[(c[774536+(a<<3)>>2]|0)+(c[774540+(a<<3)>>2]&f)>>1]|0;f=g&15;do{if((f-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=d[i+f|0]|0}else{a=g>>>1&127|g&-256;c[194192]=a;j=a;k=0}if((j&1|0)==0){l=k;m=4370;break}a=j&255;if((j&2|0)==0){c[194192]=a>>>1|j&-256;n=(d[130328+f|0]|0)-1|0;o=k;break}else{c[194192]=a>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=d[130328+f|0]|0;m=4370}}while(0);if((m|0)==4370){c[194192]=0;n=d[147072+f|0]|0;o=l}c[204526]=o<<n+4;return}function ng(a){a=a|0;var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a&7;c[776584+((b|8)<<2)>>2]=c[776584+((a>>>3&7|8)<<2)>>2];if((b|0)!=7){return}b=c[194161]|0;a=b&-2;c[194193]=a;f=a+2|0;c[194161]=f;g=b>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&a)>>1]|0;a=f>>>24;c[203400]=e[(c[774536+(a<<3)>>2]|0)+(c[774540+(a<<3)>>2]&f)>>1]|0;f=g&15;do{if((f-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=d[i+f|0]|0}else{a=g>>>1&127|g&-256;c[194192]=a;j=a;k=0}if((j&1|0)==0){l=k;m=4387;break}a=j&255;if((j&2|0)==0){c[194192]=a>>>1|j&-256;n=(d[130328+f|0]|0)-1|0;o=k;break}else{c[194192]=a>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=d[130328+f|0]|0;m=4387}}while(0);if((m|0)==4387){c[194192]=0;n=d[147072+f|0]|0;o=l}c[204526]=o<<n+4;return}function nh(b){b=b|0;var f=0,g=0,h=0,i=0,j=0;c[194192]=0;f=776584+((b>>>3&15)<<2)|0;b=c[f>>2]|0;c[194161]=b;if((c[f>>2]&1|0)==0){a[52040]=1;f=b&-4;c[194193]=f;g=f+4|0;c[194161]=g;h=b>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&f)>>2];f=g>>>24;c[203400]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2];g=h&15;h=(d[125296+g|0]|0)<<1;c[194192]=0;i=(d[130616+g|0]|0)+h|0;j=i+3|0;c[204526]=j;return}a[52040]=0;h=b&-2;c[194193]=h;g=h+2|0;c[194161]=g;f=b>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;h=g>>>24;c[203400]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>1]|0;g=f&15;if((g-8|0)>>>0>=6){c[194192]=0}f=(d[130328+g|0]|0)<<1;c[194192]=0;i=(d[147072+g|0]|0)+f|0;j=i+3|0;c[204526]=j;return}function ni(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[194161]&-4)+(b<<2&1020)|0;f=e>>>24;c[776584+((b>>>8&7)<<2)>>2]=c[(c[774536+(f<<3)>>2]|0)+(e&c[774540+(f<<3)>>2])>>2];c[194192]=0;e=f&15;f=d[130616+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0;g=0}else{if((a[776764]&1)==0){g=0;break}b=(1<<(f&1^1|f))-1|0;c[194192]=b;g=b}}while(0);e=f+3|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){if((g&1|0)==0){break}b=g&255;if((g&2|0)==0){c[194192]=b>>>1|g&-256;h=(d[130328+f|0]|0)-1|0;i=e+h|0;c[204526]=i;return}else{c[194192]=b>>>2|g&-256;h=0;i=e+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[147072+f|0]|0;i=e+h|0;c[204526]=i;return}function nj(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>6&7)<<2)>>2]|0)+(c[776584+((b>>>3&7)<<2)>>2]|0)|0;kg(e,c[776584+((b&7)<<2)>>2]|0);b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+b|0]|0)-1|0;i=e+2|0;j=i+h|0;c[204526]=j;return}else{c[194192]=g>>>2|f&-256;h=0;i=e+2|0;j=i+h|0;c[204526]=j;return}}}while(0);c[194192]=0;h=d[147072+b|0]|0;i=e+2|0;j=i+h|0;c[204526]=j;return}function nk(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=(c[776584+((e>>>6&7)<<2)>>2]|0)+(c[776584+((e>>>3&7)<<2)>>2]|0)|0;kh(f,b[776584+((e&7)<<2)>>1]|0);e=f>>>24&15;f=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}h=g&255;if((g&2|0)==0){c[194192]=h>>>1|g&-256;i=(d[130328+e|0]|0)-1|0;j=f+2|0;k=j+i|0;c[204526]=k;return}else{c[194192]=h>>>2|g&-256;i=0;j=f+2|0;k=j+i|0;c[204526]=k;return}}}while(0);c[194192]=0;i=d[147072+e|0]|0;j=f+2|0;k=j+i|0;c[204526]=k;return}function nl(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>6&7)<<2)>>2]|0)+(c[776584+((b>>>3&7)<<2)>>2]|0)|0;n2(e,a[776584+((b&7)<<2)|0]|0);b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+b|0]|0)-1|0;i=e+2|0;j=i+h|0;c[204526]=j;return}else{c[194192]=g>>>2|f&-256;h=0;i=e+2|0;j=i+h|0;c[204526]=j;return}}}while(0);c[194192]=0;h=d[147072+b|0]|0;i=e+2|0;j=i+h|0;c[204526]=j;return}function nm(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>6&7)<<2)>>2]|0)+(c[776584+((b>>>3&7)<<2)>>2]|0)|0;c[776584+((b&7)<<2)>>2]=(n0(e)|0)<<24>>24;b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+3|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[147072+e|0]|0;i=b+h|0;c[204526]=i;return}function nn(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>6&7)<<2)>>2]|0)+(c[776584+((b>>>3&7)<<2)>>2]|0)|0;c[776584+((b&7)<<2)>>2]=ke(e)|0;b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+3|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[147072+e|0]|0;i=b+h|0;c[204526]=i;return}function no(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>6&7)<<2)>>2]|0)+(c[776584+((b>>>3&7)<<2)>>2]|0)|0;c[776584+((b&7)<<2)>>2]=ki(e)|0;b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+3|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[147072+e|0]|0;i=b+h|0;c[204526]=i;return}function np(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>6&7)<<2)>>2]|0)+(c[776584+((b>>>3&7)<<2)>>2]|0)|0;c[776584+((b&7)<<2)>>2]=(n0(e)|0)&255;b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+3|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[147072+e|0]|0;i=b+h|0;c[204526]=i;return}function nq(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>6&7)<<2)>>2]|0)+(c[776584+((b>>>3&7)<<2)>>2]|0)|0;f=ki(e)|0;if((e&1|0)==0){g=f&65535}else{g=(f&255)<<24>>24}c[776584+((b&7)<<2)>>2]=g<<16>>16;g=e>>>24&15;e=d[147072+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);g=e+3|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}f=b&255;if((b&2|0)==0){c[194192]=f>>>1|b&-256;h=(d[130328+e|0]|0)-1|0;i=g+h|0;c[204526]=i;return}else{c[194192]=f>>>2|b&-256;h=0;i=g+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[147072+e|0]|0;i=g+h|0;c[204526]=i;return}function nr(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>3&7)<<2)>>2]|0)+(b>>>6<<2&124)|0;kg(e,c[776584+((b&7)<<2)>>2]|0);b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+b|0]|0)-1|0;i=e+2|0;j=i+h|0;c[204526]=j;return}else{c[194192]=g>>>2|f&-256;h=0;i=e+2|0;j=i+h|0;c[204526]=j;return}}}while(0);c[194192]=0;h=d[147072+b|0]|0;i=e+2|0;j=i+h|0;c[204526]=j;return}function ns(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>3&7)<<2)>>2]|0)+(b>>>6<<2&124)|0;c[776584+((b&7)<<2)>>2]=ke(e)|0;b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+3|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[147072+e|0]|0;i=b+h|0;c[204526]=i;return}function nt(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>3&7)<<2)>>2]|0)+(b>>>6&31)|0;n2(e,a[776584+((b&7)<<2)|0]|0);b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+b|0]|0)-1|0;i=e+2|0;j=i+h|0;c[204526]=j;return}else{c[194192]=g>>>2|f&-256;h=0;i=e+2|0;j=i+h|0;c[204526]=j;return}}}while(0);c[194192]=0;h=d[147072+b|0]|0;i=e+2|0;j=i+h|0;c[204526]=j;return}function nu(a){a=a|0;var b=0;b=a<<2&508;c[194159]=(c[194159]|0)+((a&128|0)==0?b:-b|0);return}function nv(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[194159]|0)+(b<<2&1020)|0;f=e>>>24;c[776584+((b>>>8&7)<<2)>>2]=c[(c[774536+(f<<3)>>2]|0)+(e&c[774540+(f<<3)>>2])>>2];e=f&15;f=d[130616+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);e=f+3|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}g=b&255;if((b&2|0)==0){c[194192]=g>>>1|b&-256;h=(d[130328+f|0]|0)-1|0;i=e+h|0;c[204526]=i;return}else{c[194192]=g>>>2|b&-256;h=0;i=e+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[147072+f|0]|0;i=e+h|0;c[204526]=i;return}function nw(a){a=a|0;c[776584+((a>>>8&7)<<2)>>2]=(c[194161]&-4)+(a<<2&1020);return}function nx(a){a=a|0;c[776584+((a>>>8&7)<<2)>>2]=(c[194159]|0)+(a<<2&1020);return}function ny(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>3&7)<<2)>>2]|0)+(b>>>6&31)|0;c[776584+((b&7)<<2)>>2]=(n0(e)|0)&255;b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+3|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[147072+e|0]|0;i=b+h|0;c[204526]=i;return}function nz(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=(c[776584+((e>>>3&7)<<2)>>2]|0)+(e>>>6<<1&62)|0;kh(f,b[776584+((e&7)<<2)>>1]|0);e=f>>>24&15;f=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}h=g&255;if((g&2|0)==0){c[194192]=h>>>1|g&-256;i=(d[130328+e|0]|0)-1|0;j=f+2|0;k=j+i|0;c[204526]=k;return}else{c[194192]=h>>>2|g&-256;i=0;j=f+2|0;k=j+i|0;c[204526]=k;return}}}while(0);c[194192]=0;i=d[147072+e|0]|0;j=f+2|0;k=j+i|0;c[204526]=k;return}function nA(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>3&7)<<2)>>2]|0)+(b>>>6<<1&62)|0;c[776584+((b&7)<<2)>>2]=ki(e)|0;b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+3|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[147072+e|0]|0;i=b+h|0;c[204526]=i;return}function nB(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[194159]|0)+(b<<2&1020)|0;kg(e,c[776584+((b>>>8&7)<<2)>>2]|0);b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+b|0]|0)-1|0;i=e+2|0;j=i+h|0;c[204526]=j;return}else{c[194192]=g>>>2|f&-256;h=0;i=e+2|0;j=i+h|0;c[204526]=j;return}}}while(0);c[194192]=0;h=d[147072+b|0]|0;i=e+2|0;j=i+h|0;c[204526]=j;return}function nC(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[194159]|0)-((d[817848+(b&255)|0]|0)<<2)|0;f=e&-4;if((b&1|0)==0){g=0;h=f}else{kg(f,c[194146]|0);i=e>>>24&15;j=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);g=1;h=f+4|0}if((b&2|0)==0){k=g;l=h}else{kg(h,c[194147]|0);f=h>>>24&15;j=d[((g|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);k=g+1|0;l=h+4|0}if((b&4|0)==0){m=k;n=l}else{kg(l,c[194148]|0);h=l>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);m=k+1|0;n=l+4|0}if((b&8|0)==0){o=m;p=n}else{kg(n,c[194149]|0);l=n>>>24&15;k=d[((m|0)==0?130616:125296)+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);o=m+1|0;p=n+4|0}if((b&16|0)==0){q=o;r=p}else{kg(p,c[194150]|0);n=p>>>24&15;m=d[((o|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+1|0;r=p+4|0}if((b&32|0)==0){s=q;t=r}else{kg(r,c[194151]|0);p=r>>>24&15;o=d[((q|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+1|0;t=r+4|0}if((b&64|0)==0){u=s;v=t}else{kg(t,c[194152]|0);r=t>>>24&15;q=d[((s|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+1|0;v=t+4|0}if((b&128|0)!=0){kg(v,c[194153]|0);b=v>>>24&15;v=d[((u|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0)}v=(c[194193]|0)>>>24&15;do{if((v-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}u=b&255;if((b&2|0)==0){c[194192]=u>>>1|b&-256;w=(d[130328+v|0]|0)-1|0;x=w+1|0;y=c[204526]|0;z=x+y|0;c[204526]=z;c[194159]=e;return}else{c[194192]=u>>>2|b&-256;w=0;x=w+1|0;y=c[204526]|0;z=x+y|0;c[204526]=z;c[194159]=e;return}}}while(0);c[194192]=0;w=d[147072+v|0]|0;x=w+1|0;y=c[204526]|0;z=x+y|0;c[204526]=z;c[194159]=e;return}function nD(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[194159]|0)-4-((d[817848+(b&255)|0]|0)<<2)|0;f=e&-4;if((b&1|0)==0){g=0;h=f}else{kg(f,c[194146]|0);i=e>>>24&15;j=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);g=1;h=f+4|0}if((b&2|0)==0){k=g;l=h}else{kg(h,c[194147]|0);f=h>>>24&15;j=d[((g|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);k=g+1|0;l=h+4|0}if((b&4|0)==0){m=k;n=l}else{kg(l,c[194148]|0);h=l>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);m=k+1|0;n=l+4|0}if((b&8|0)==0){o=m;p=n}else{kg(n,c[194149]|0);l=n>>>24&15;k=d[((m|0)==0?130616:125296)+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);o=m+1|0;p=n+4|0}if((b&16|0)==0){q=o;r=p}else{kg(p,c[194150]|0);n=p>>>24&15;m=d[((o|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+1|0;r=p+4|0}if((b&32|0)==0){s=q;t=r}else{kg(r,c[194151]|0);p=r>>>24&15;o=d[((q|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+1|0;t=r+4|0}if((b&64|0)==0){u=s;v=t}else{kg(t,c[194152]|0);r=t>>>24&15;q=d[((s|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+1|0;v=t+4|0}if((b&128|0)==0){w=u;x=v}else{kg(v,c[194153]|0);t=v>>>24&15;s=d[((u|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);w=u+1|0;x=v+4|0}if((b&256|0)!=0){kg(x,c[194160]|0);b=x>>>24&15;x=d[((w|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0)}x=(c[194193]|0)>>>24&15;do{if((x-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}w=b&255;if((b&2|0)==0){c[194192]=w>>>1|b&-256;y=(d[130328+x|0]|0)-1|0;z=y+1|0;A=c[204526]|0;B=z+A|0;c[204526]=B;c[194159]=e;return}else{c[194192]=w>>>2|b&-256;y=0;z=y+1|0;A=c[204526]|0;B=z+A|0;c[204526]=B;c[194159]=e;return}}}while(0);c[194192]=0;y=d[147072+x|0]|0;z=y+1|0;A=c[204526]|0;B=z+A|0;c[204526]=B;c[194159]=e;return}function nE(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=c[194159]|0;f=e&-4;g=((d[817848+(b&255)|0]|0)<<2)+e|0;if((b&1|0)==0){h=0;i=f}else{c[194146]=ke(f)|0;j=e>>>24&15;e=d[130616+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);h=1;i=f+4|0}if((b&2|0)==0){k=h;l=i}else{c[194147]=ke(i)|0;f=i>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);k=h+1|0;l=i+4|0}if((b&4|0)==0){m=k;n=l}else{c[194148]=ke(l)|0;i=l>>>24&15;h=d[((k|0)==0?130616:125296)+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);c[204526]=h+1+(c[204526]|0);m=k+1|0;n=l+4|0}if((b&8|0)==0){o=m;p=n}else{c[194149]=ke(n)|0;l=n>>>24&15;k=d[((m|0)==0?130616:125296)+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);o=m+1|0;p=n+4|0}if((b&16|0)==0){q=o;r=p}else{c[194150]=ke(p)|0;n=p>>>24&15;m=d[((o|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+1|0;r=p+4|0}if((b&32|0)==0){s=q;t=r}else{c[194151]=ke(r)|0;p=r>>>24&15;o=d[((q|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+1|0;t=r+4|0}if((b&64|0)==0){u=s;v=t}else{c[194152]=ke(t)|0;r=t>>>24&15;q=d[((s|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+1|0;v=t+4|0}if((b&128|0)!=0){c[194153]=ke(v)|0;b=v>>>24&15;v=d[((u|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0)}c[194159]=g;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){v=c[194192]|0;if((v&1|0)==0){break}b=v&255;if((v&2|0)==0){c[194192]=b>>>1|v&-256;w=(d[130328+g|0]|0)-1|0;x=w+2|0;c[204526]=x;return}else{c[194192]=b>>>2|v&-256;w=0;x=w+2|0;c[204526]=x;return}}}while(0);c[194192]=0;w=d[147072+g|0]|0;x=w+2|0;c[204526]=x;return}function nF(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=c[194159]|0;g=f&-4;h=f+4+((d[817848+(b&255)|0]|0)<<2)|0;if((b&1|0)==0){i=0;j=g}else{c[194146]=ke(g)|0;k=f>>>24&15;f=d[130616+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);i=1;j=g+4|0}if((b&2|0)==0){l=i;m=j}else{c[194147]=ke(j)|0;g=j>>>24&15;f=d[((i|0)==0?130616:125296)+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);l=i+1|0;m=j+4|0}if((b&4|0)==0){n=l;o=m}else{c[194148]=ke(m)|0;j=m>>>24&15;i=d[((l|0)==0?130616:125296)+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);c[204526]=i+1+(c[204526]|0);n=l+1|0;o=m+4|0}if((b&8|0)==0){p=n;q=o}else{c[194149]=ke(o)|0;m=o>>>24&15;l=d[((n|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+1|0;q=o+4|0}if((b&16|0)==0){r=p;s=q}else{c[194150]=ke(q)|0;o=q>>>24&15;n=d[((p|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+1|0;s=q+4|0}if((b&32|0)==0){t=r;u=s}else{c[194151]=ke(s)|0;q=s>>>24&15;p=d[((r|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+1|0;u=s+4|0}if((b&64|0)==0){v=t;w=u}else{c[194152]=ke(u)|0;s=u>>>24&15;r=d[((t|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+1|0;w=u+4|0}if((b&128|0)==0){x=v;y=w}else{c[194153]=ke(w)|0;b=w>>>24&15;u=d[((v|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);x=v+1|0;y=w+4|0}w=ke(y)|0;v=w&-2;c[194161]=v;u=y>>>24&15;y=d[((x|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(y&1^1|y))-1}}while(0);u=y+1+(c[204526]|0)|0;c[194193]=v;y=v+2|0;c[194161]=y;c[194159]=h;h=w>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&v)>>1]|0;v=y>>>24;c[203400]=e[(c[774536+(v<<3)>>2]|0)+(c[774540+(v<<3)>>2]&y)>>1]|0;c[194192]=0;c[204526]=u+3+((d[147072+(h&15)|0]|0)<<1);return}function nG(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>8&7)<<2)|0;f=c[e>>2]|0;g=f&-4;h=((d[817848+(b&255)|0]|0)<<2)+f|0;if((b&1|0)==0){i=g;j=0}else{kg(g,c[194146]|0);c[e>>2]=h;k=f>>>24&15;f=d[130616+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);i=g+4|0;j=1}if((b&2|0)==0){l=i;m=j}else{kg(i,c[194147]|0);c[e>>2]=h;g=i>>>24&15;f=d[((j|0)==0?130616:125296)+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);l=i+4|0;m=j+1|0}if((b&4|0)==0){n=l;o=m}else{kg(l,c[194148]|0);c[e>>2]=h;j=l>>>24&15;i=d[((m|0)==0?130616:125296)+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);c[204526]=i+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&8|0)==0){p=n;q=o}else{kg(n,c[194149]|0);c[e>>2]=h;m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&16|0)==0){r=p;s=q}else{kg(p,c[194150]|0);c[e>>2]=h;o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&32|0)==0){t=r;u=s}else{kg(r,c[194151]|0);c[e>>2]=h;q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&64|0)==0){v=t;w=u}else{kg(t,c[194152]|0);c[e>>2]=h;s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&128|0)!=0){kg(v,c[194153]|0);c[e>>2]=h;h=v>>>24&15;v=d[((w|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0)}v=(c[194193]|0)>>>24&15;do{if((v-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){break}w=h&255;if((h&2|0)==0){c[194192]=w>>>1|h&-256;x=(d[130328+v|0]|0)-1|0;y=x+1|0;c[204526]=y;return}else{c[194192]=w>>>2|h&-256;x=0;y=x+1|0;c[204526]=y;return}}}while(0);c[194192]=0;x=d[147072+v|0]|0;y=x+1|0;c[204526]=y;return}function nH(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>8&7;f=776584+(e<<2)|0;g=c[f>>2]|0;h=g&-4;i=((d[817848+(b&255)|0]|0)<<2)+g|0;if((b&1|0)==0){j=h;k=0}else{c[194146]=ke(h)|0;l=g>>>24&15;g=d[130616+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);j=h+4|0;k=1}if((b&2|0)==0){m=j;n=k}else{c[194147]=ke(j)|0;h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);m=j+4|0;n=k+1|0}if((b&4|0)==0){o=m;p=n}else{c[194148]=ke(m)|0;k=m>>>24&15;j=d[((n|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);o=m+4|0;p=n+1|0}if((b&8|0)==0){q=o;r=p}else{c[194149]=ke(o)|0;n=o>>>24&15;m=d[((p|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+4|0;r=p+1|0}if((b&16|0)==0){s=q;t=r}else{c[194150]=ke(q)|0;p=q>>>24&15;o=d[((r|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+4|0;t=r+1|0}if((b&32|0)==0){u=s;v=t}else{c[194151]=ke(s)|0;r=s>>>24&15;q=d[((t|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+4|0;v=t+1|0}if((b&64|0)==0){w=u;x=v}else{c[194152]=ke(u)|0;t=u>>>24&15;s=d[((v|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);w=u+4|0;x=v+1|0}if((b&128|0)!=0){c[194153]=ke(w)|0;v=w>>>24&15;w=d[((x|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0)}w=(c[194193]|0)>>>24&15;do{if((w-8|0)>>>0<6){v=c[194192]|0;if((v&1|0)==0){y=5033;break}x=v&255;if((v&2|0)==0){c[194192]=x>>>1|v&-256;z=(d[130328+w|0]|0)-1|0;break}else{c[194192]=x>>>2|v&-256;z=0;break}}else{y=5033}}while(0);if((y|0)==5033){c[194192]=0;z=d[147072+w|0]|0}c[204526]=z+2;if((1<<e&b|0)!=0){return}c[f>>2]=i;return}function nI(b){b=b|0;var d=0,f=0;if((a[768224]&1)==0){return}d=(c[194161]|0)+(b<<24>>23)|0;c[194193]=d;b=d+2|0;c[194161]=b;f=d>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&d)>>1]|0;d=b>>>24;c[203400]=e[(c[774536+(d<<3)>>2]|0)+(c[774540+(d<<3)>>2]&b)>>1]|0;c[204526]=30;c[194192]=0;return}function nJ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[768224]&1)!=0){return}f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5056;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5056}}while(0);if((m|0)==5056){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nK(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[768256]&1)==0){return}f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5073;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5073}}while(0);if((m|0)==5073){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nL(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[768256]&1)!=0){return}f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5090;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5090}}while(0);if((m|0)==5090){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nM(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[768240]&1)==0){return}f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5107;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5107}}while(0);if((m|0)==5107){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nN(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[768240]&1)!=0){return}f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5124;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5124}}while(0);if((m|0)==5124){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nO(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[768232]&1)==0){return}f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5141;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5141}}while(0);if((m|0)==5141){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nP(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[768232]&1)!=0){return}f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5158;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5158}}while(0);if((m|0)==5158){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nQ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[768256]&1)==0){return}if((a[768224]&1)!=0){return}f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5176;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5176}}while(0);if((m|0)==5176){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nR(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;do{if((a[768256]&1)!=0){if((a[768224]&1)!=0){break}return}}while(0);f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5195;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5195}}while(0);if((m|0)==5195){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nS(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(((a[768232]^a[768240])&1)!=0){return}f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5212;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5212}}while(0);if((m|0)==5212){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nT(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(((a[768232]^a[768240])&1)==0){return}f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5229;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5229}}while(0);if((m|0)==5229){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nU(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[768224]&1)!=0){return}if(((a[768232]^a[768240])&1)!=0){return}f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5247;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5247}}while(0);if((m|0)==5247){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nV(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;do{if((a[768224]&1)==0){if(((a[768232]^a[768240])&1)!=0){break}return}}while(0);f=(c[194161]|0)+(b<<24>>23)|0;c[194193]=f;b=f+2|0;c[194161]=b;g=f>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=g&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0>255){c[194192]=0;h=0;i=147072}else{h=g;i=130328}j=h;k=(d[i+b|0]|0)<<1}else{f=g>>>1&127|g&-256;c[194192]=f;j=f;k=0}if((j&1|0)==0){l=k;m=5266;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=f>>>2|j&-256;n=0;o=k;break}}else{c[194192]=0;l=(d[130328+b|0]|0)<<1;m=5266}}while(0);if((m|0)==5266){c[194192]=0;n=d[147072+b|0]|0;o=l}c[204526]=o+3+n;c[194192]=0;return}function nW(a){a=a|0;var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a<<1;f=(c[194161]|0)+((a&1024|0)==0?b&2046:b|-2048)|0;c[194193]=f;b=f+2|0;c[194161]=b;a=f>>>24;c[203402]=e[(c[774536+(a<<3)>>2]|0)+(c[774540+(a<<3)>>2]&f)>>1]|0;f=b>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;b=a&15;do{if((b-8|0)>>>0<6){a=c[194192]|0;if((a&1|0)==0){if(a>>>0>255){c[194192]=0;g=0;h=147072}else{g=a;h=130328}i=g;j=(d[h+b|0]|0)<<1}else{f=a>>>1&127|a&-256;c[194192]=f;i=f;j=0}if((i&1|0)==0){k=j;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;l=(d[130328+b|0]|0)-1|0;m=j;n=m+3|0;o=n+l|0;c[204526]=o;c[194192]=0;return}else{c[194192]=f>>>2|i&-256;l=0;m=j;n=m+3|0;o=n+l|0;c[204526]=o;c[194192]=0;return}}else{c[194192]=0;k=(d[130328+b|0]|0)<<1}}while(0);c[194192]=0;l=d[147072+b|0]|0;m=k;n=m+3|0;o=n+l|0;c[204526]=o;c[194192]=0;return}function nX(a){a=a|0;c[204526]=(d[147072]|0)+3+((d[130328]|0)<<1);c[194192]=0;n$(a&255);return}function nY(a){a=a|0;var b=0,e=0,f=0;c[194160]=(c[194161]|0)+(a<<12&8384512);a=(c[194193]|0)>>>24&15;do{if((a-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)!=0){c[194192]=b>>>1&127|b&-256;e=0;f=e+1|0;c[204526]=f;return}if(b>>>0<=255){break}c[194192]=0;e=d[147072+a|0]|0;f=e+1|0;c[204526]=f;return}else{c[194192]=0}}while(0);e=d[130328+a|0]|0;f=e+1|0;c[204526]=f;return}function nZ(a){a=a|0;var b=0,e=0,f=0;c[194160]=(c[194161]|0)+(a<<12|-8388608);a=(c[194193]|0)>>>24&15;do{if((a-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)!=0){c[194192]=b>>>1&127|b&-256;e=0;f=e+1|0;c[204526]=f;return}if(b>>>0<=255){break}c[194192]=0;e=d[147072+a|0]|0;f=e+1|0;c[204526]=f;return}else{c[194192]=0}}while(0);e=d[130328+a|0]|0;f=e+1|0;c[204526]=f;return}function n_(a){a=a|0;var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=(c[194161]|0)-2|0;f=(c[194160]|0)+(a<<1&4094)|0;a=f&-2;c[194193]=a;g=a+2|0;c[194161]=g;c[194160]=b|1;b=f>>>24;c[203402]=e[(c[774536+(b<<3)>>2]|0)+(a&c[774540+(b<<3)>>2])>>1]|0;a=g>>>24;c[203400]=e[(c[774536+(a<<3)>>2]|0)+(c[774540+(a<<3)>>2]&g)>>1]|0;g=b&15;do{if((g-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){if(b>>>0>255){c[194192]=0;h=0;i=147072}else{h=b;i=130328}j=h;k=(d[i+g|0]|0)<<1}else{a=b>>>1&127|b&-256;c[194192]=a;j=a;k=0}if((j&1|0)==0){l=k;break}a=j&255;if((j&2|0)==0){c[194192]=a>>>1|j&-256;m=(d[130328+g|0]|0)-1|0;n=k;o=n+3|0;p=o+m|0;c[204526]=p;c[194192]=0;return}else{c[194192]=a>>>2|j&-256;m=0;n=k;o=n+3|0;p=o+m|0;c[204526]=p;c[194192]=0;return}}else{c[194192]=0;l=(d[130328+g|0]|0)<<1}}while(0);c[194192]=0;m=d[147072+g|0]|0;n=l;o=n+3|0;p=o+m|0;c[204526]=p;c[194192]=0;return}function n$(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0;e=a[52040]&1;switch((e<<24>>24==0?d:d>>16)|0){case 21:{d=c[194146]|0;f=c[194147]|0;g=ke(d&-4)|0;h=d+4|0;if((h&234881024|0)==0){return}d=g>>>8;if(((d&2097151)+h&234881024|0)==0|(d|0)==0){return}else{i=d;j=0;k=0;l=0;m=f;n=h}L6998:while(1){h=n+1|0;f=(n0(n)|0)&255;d=f&127;L7000:do{if((f&128|0)==0){g=d+1|0;o=0;p=h;q=m;r=l;s=k;t=j;u=i;while(1){if((o|0)>=(g|0)){v=p;w=q;x=r;y=s;z=t;A=u;break L7000}B=((n0(p)|0)&255)<<s|r;C=t+1|0;if((C|0)==2){kh(q,B&65535);D=q+2|0;E=0;F=0;G=0}else{D=q;E=B;F=s+8|0;G=C}C=u-1|0;if((C|0)==0){H=5540;break L6998}else{o=o+1|0;p=p+1|0;q=D;r=E;s=F;t=G;u=C}}}else{u=n+2|0;t=d+3|0;s=(n0(h)|0)&255;r=0;q=m;p=l;o=k;g=j;C=i;while(1){if((r|0)>=(t|0)){v=u;w=q;x=p;y=o;z=g;A=C;break L7000}B=p|s<<o;I=g+1|0;if((I|0)==2){kh(q,B&65535);J=q+2|0;K=0;L=0;M=0}else{J=q;K=B;L=o+8|0;M=I}I=C-1|0;if((I|0)==0){H=5538;break L6998}else{r=r+1|0;q=J;p=K;o=L;g=M;C=I}}}}while(0);if((A|0)>0){i=A;j=z;k=y;l=x;m=w;n=v}else{H=5521;break}}if((H|0)==5521){return}else if((H|0)==5538){return}else if((H|0)==5540){return}break};case 13:{c[194146]=-1162995585;return};case 9:{v=c[194146]|0;n=(ac(v,v)|0)>>14;w=-n|0;c[194146]=(ac(((ac(((ac(((ac(((ac(((ac(((ac(((n*-169|0)>>14)+912|0,w)|0)>>14)+2332|0,w)|0)>>14)+4022|0,w)|0)>>14)+5802|0,w)|0)>>14)+8321|0,w)|0)>>14)+13905|0,w)|0)>>14)+41721|0,v)|0)>>16;return};case 18:{v=c[194146]|0;w=c[194147]|0;n=ke(v)|0;m=v+4|0;if((m&234881024|0)==0){return}v=n>>>8;if(((v&2097151)+m&234881024|0)==0|(v|0)==0){return}else{N=0;O=0;P=v;Q=0;R=w;T=m}L7030:while(1){m=T+1|0;w=n0(T)|0;L7032:do{if(w<<24>>24==0){v=0;n=m;x=R;l=Q;y=P;k=O;z=N;while(1){if((v|0)>=8){U=n;V=x;W=l;X=y;Y=k;Z=z;break L7032}j=((n0(n)|0)&255)<<z|k;A=l+1|0;if((A|0)==2){kh(x,j&65535);_=x+2|0;$=0;aa=0;ab=0}else{_=x;$=A;aa=j;ab=z+8|0}j=y-1|0;if((j|0)==0){H=5531;break L7030}else{v=v+1|0;n=n+1|0;x=_;l=$;y=j;k=aa;z=ab}}}else{z=N;k=O;y=P;l=w;x=0;n=Q;v=R;j=m;while(1){A=j+1|0;i=(n0(j)|0)&255;L7035:do{if(l<<24>>24>-1){M=i<<z|k;L=n+1|0;if((L|0)==2){kh(v,M&65535);ad=v+2|0;ae=0;af=0;ag=0}else{ad=v;ae=L;af=M;ag=z+8|0}M=y-1|0;if((M|0)==0){H=5543;break L7030}else{ah=A;ai=ad;aj=ae;ak=M;al=af;am=ag}}else{M=j+2|0;L=(i>>>4)+3|0;K=0;J=v-1+n-((n0(A)|0)&255|i<<8&3840)|0;G=v;F=n;E=y;D=k;h=z;while(1){if((K|0)>=(L|0)){ah=M;ai=G;aj=F;ak=E;al=D;am=h;break L7035}d=((n0(J)|0)&255)<<h|D;f=F+1|0;if((f|0)==2){kh(G,d&65535);an=G+2|0;ao=0;ap=0;aq=0}else{an=G;ao=f;ap=d;aq=h+8|0}d=E-1|0;if((d|0)==0){H=5556;break L7030}else{K=K+1|0;J=J+1|0;G=an;F=ao;E=d;D=ap;h=aq}}}}while(0);i=x+1|0;if((i|0)<8){z=am;k=al;y=ak;l=l<<1;x=i;n=aj;v=ai;j=ah}else{U=ah;V=ai;W=aj;X=ak;Y=al;Z=am;break}}}}while(0);if((X|0)>0){N=Z;O=Y;P=X;Q=W;R=V;T=U}else{H=5528;break}}if((H|0)==5528){return}else if((H|0)==5531){return}else if((H|0)==5543){return}else if((H|0)==5556){return}break};case 19:{U=c[194146]|0;T=c[194147]|0;V=ke(U)|0;R=U+4|0;if((R&234881024|0)==0){return}W=V>>>8;if(((W&2097151)+R&234881024|0)==0){return}Q=U+5|0;X=(((n0(R)|0)&255)<<1|1)+Q|0;R=ke(X)|0;P=X+4|0;X=n0(Q)|0;Y=U+6|0;if((V&15|0)==8){V=0;U=0;O=0;Z=X;N=P;am=0;al=R;ak=W;aj=T;L7068:while(1){ai=V;ah=U;aq=O;ap=Z;ao=am;an=-2147483648;ag=ak;af=aj;while(1){if((ag|0)<=0){break L7068}ae=ap&255;if((ao|0)==0){ar=1}else{ar=ao+2+(ae<<1&126)|0}if((an&al|0)==0){ad=n0(ar+Q|0)|0;if((ae&128|0)==0){as=ai;at=ah;au=aq;av=ad;aw=ar;ax=ag;ay=af}else{az=ad;H=5457}}else{ad=n0(ar+Y|0)|0;if((ae&64|0)==0){as=ai;at=ah;au=aq;av=ad;aw=ar;ax=ag;ay=af}else{az=ad;H=5457}}do{if((H|0)==5457){H=0;ad=(az&255)<<aq|ai;ae=ah+1|0;if((ae|0)!=4){as=ad;at=ae;au=aq+8|0;av=X;aw=0;ax=ag;ay=af;break}kg(af,ad);as=0;at=0;au=0;av=X;aw=0;ax=ag-4|0;ay=af+4|0}}while(0);ad=an>>>1;if((ad|0)==0){break}else{ai=as;ah=at;aq=au;ap=av;ao=aw;an=ad;ag=ax;af=ay}}af=ke(N)|0;V=as;U=at;O=au;Z=av;N=N+4|0;am=aw;al=af;ak=ax;aj=ay}return}else{aA=0;aB=0;aC=0;aD=0;aE=0;aF=X;aG=P;aH=0;aI=R;aJ=W;aK=T}L7085:while(1){T=aA;W=aB;R=aC;P=aD;ay=aE;aj=aF;ax=aH;ak=-2147483648;al=aJ;aw=aK;while(1){if((al|0)<=0){break L7085}am=aj&255;if((ax|0)==0){aL=1}else{aL=ax+2+(am<<1&126)|0}if((ak&aI|0)==0){N=n0(aL+Q|0)|0;if((am&128|0)==0){aM=T;aN=W;aO=R;aP=P;aQ=ay;aR=N;aS=aL;aT=al;aU=aw}else{aV=N;H=5467}}else{N=n0(aL+Y|0)|0;if((am&64|0)==0){aM=T;aN=W;aO=R;aP=P;aQ=ay;aR=N;aS=aL;aT=al;aU=aw}else{aV=N;H=5467}}do{if((H|0)==5467){H=0;N=aV&255;am=((W|0)==0?N:N<<4)|T;N=W+4|0;if((N|0)!=8){aM=am;aN=N;aO=R;aP=P;aQ=ay;aR=X;aS=0;aT=al;aU=aw;break}N=am<<ay|R;am=P+1|0;if((am|0)!=4){aM=0;aN=0;aO=N;aP=am;aQ=ay+8|0;aR=X;aS=0;aT=al;aU=aw;break}kg(aw,N);aM=0;aN=0;aO=0;aP=0;aQ=0;aR=X;aS=0;aT=al-4|0;aU=aw+4|0}}while(0);N=ak>>>1;if((N|0)==0){break}else{T=aM;W=aN;R=aO;P=aP;ay=aQ;aj=aR;ax=aS;ak=N;al=aT;aw=aU}}aw=ke(aG)|0;aA=aM;aB=aN;aC=aO;aD=aP;aE=aQ;aF=aR;aG=aG+4|0;aH=aS;aI=aw;aJ=aT;aK=aU}return};case 42:{aU=0;aK=c[194146]|0;do{kg(aK,156);aK=(c[194146]|0)+4|0;c[194146]=aK;aU=aU+1|0;}while((aU|0)<36);return};case 14:{aU=c[194148]|0;if((aU|0)<=0){return}aK=0;aT=c[194147]|0;aJ=c[194146]|0;while(1){aI=ke(aJ)|0;aS=ke(aJ+4|0)|0;aH=ki(aJ+8|0)|0;aG=ki(aJ+10|0)|0;aR=ki(aJ+12|0)|0;aF=ki(aJ+14|0)|0;aQ=(ki(aJ+16|0)|0)>>>8;aE=b[1304+((aQ+64&255)<<1)>>1]|0;aP=b[1304+((aQ&65535)<<1)>>1]|0;aQ=aR<<16>>16;aR=(ac(aE,aQ)|0)>>>14&65535;aD=(ac(aP,aQ)|0)>>>14;aQ=aF<<16>>16;aF=(ac(aP,aQ)|0)>>>14&65535;aP=(ac(aE,aQ)|0)>>>14&65535;kh(aT,aR);aQ=aD<<16>>16;kh(aT+2|0,-aQ&65535);kh(aT+4|0,aF);kh(aT+6|0,aP);aD=aH<<16>>16;aH=aI-(ac(aR<<16>>16,aD)|0)|0;aR=aG<<16>>16;aG=aH+(ac(aQ,aR)|0)|0;aQ=ac(aF<<16>>16,aD)|0;aD=aS-(ac(aP<<16>>16,aR)|0)-aQ|0;kg(aT+8|0,aG);kg(aT+12|0,aD);aD=aK+1|0;if((aD|0)<(aU|0)){aK=aD;aT=aT+16|0;aJ=aJ+20|0}else{break}}return};case 1:{kl(c[194146]|0);return};case 0:{a[52040]=1;c[31194]=31;a[130632]=0;a[768224]=0;a[768240]=0;a[768232]=0;a[768256]=0;c[194159]=50364160;c[194160]=0;c[194162]=0;c[194164]=50364320;c[194165]=0;c[194166]=0;c[194174]=50364384;c[194175]=0;c[194176]=0;aJ=c[120070]|0;aT=a[aJ+32762|0]|0;v3(aJ+32256|0,0,512);aJ=aT<<24>>24==0;aT=aJ?134217728:33554432;c[194193]=aT;c[194161]=aJ?134217732:33554436;aJ=aT>>>24;aK=c[774540+(aJ<<3)>>2]|0;aU=c[774536+(aJ<<3)>>2]|0;c[203402]=c[aU+(aK&aT)>>2];c[203400]=c[aU+(aK&(aT|4))>>2];return};case 22:{aT=c[194146]|0;aK=c[194147]|0;aU=ke(aT)|0;aJ=aT+4|0;if((aJ&234881024|0)==0){return}aD=aU>>>8;if(((aD&2097151)+aJ&234881024|0)==0){return}aU=n0(aJ)|0;n2(aK,aU);aJ=aD-1|0;if((aJ|0)<=0){return}aD=aU;aU=aT+5|0;aT=aJ;aJ=aK;while(1){aK=aJ+1|0;aG=(n0(aU)|0)+aD&255;n2(aK,aG);aQ=aT-1|0;if((aQ|0)>0){aD=aG;aU=aU+1|0;aT=aQ;aJ=aK}else{break}}return};case 4:case 5:case 6:case 7:{aJ=c[194161]|0;if((c[31194]|0)!=19){km(19,1,0)}c[194160]=aJ-(e<<24>>24!=0?4:2);c[194161]=8;a[52040]=1;a[130632]=0;c[194193]=8;e=c[193635]|0;aJ=c[193634]|0;c[203402]=c[aJ+(e&8)>>2];c[203400]=c[aJ+(e&12)>>2];c[194161]=12;return};case 17:{e=c[194146]|0;aJ=c[194147]|0;aT=ke(e)|0;aU=e+4|0;if((aU&234881024|0)==0){return}e=aT>>>8;if(((e&2097151)+aU&234881024|0)==0|(e|0)==0){return}else{aW=e;aX=aJ;aY=aU}L7142:while(1){aU=aY+1|0;aJ=n0(aY)|0;if(aJ<<24>>24==0){n2(aX,n0(aU)|0);if((aW|0)==1){H=5593;break}n2(aX+1|0,n0(aY+2|0)|0);if((aW|0)==2){H=5589;break}n2(aX+2|0,n0(aY+3|0)|0);if((aW|0)==3){H=5595;break}n2(aX+3|0,n0(aY+4|0)|0);if((aW|0)==4){H=5584;break}n2(aX+4|0,n0(aY+5|0)|0);if((aW|0)==5){H=5588;break}n2(aX+5|0,n0(aY+6|0)|0);if((aW|0)==6){H=5575;break}n2(aX+6|0,n0(aY+7|0)|0);if((aW|0)==7){H=5596;break}n2(aX+7|0,n0(aY+8|0)|0);e=aW-8|0;if((e|0)==0){H=5526;break}aZ=aY+9|0;a_=aX+8|0;a$=e}else{e=aJ;aJ=0;aT=aW;aD=aX;aK=aU;while(1){if(e<<24>>24>-1){n2(aD,n0(aK)|0);aU=aT-1|0;if((aU|0)==0){H=5594;break L7142}else{a0=aK;a1=aD+1|0;a2=aU}}else{aU=aK+1|0;aQ=((n0(aK)|0)&255)<<8;aG=(aQ|(n0(aU)|0)&255)&65535;aQ=(aG>>>12)+3|0;aR=aT;aP=aD;aS=aD-1-(aG&4095)|0;aG=0;while(1){n2(aP,n0(aS)|0);aF=aR-1|0;if((aF|0)==0){H=5592;break L7142}aH=aP+1|0;aI=aG+1|0;if((aI|0)<(aQ|0)){aR=aF;aP=aH;aS=aS+1|0;aG=aI}else{a0=aU;a1=aH;a2=aF;break}}}aU=a0+1|0;aG=aJ+1|0;if((aG|0)<8){e=e<<1;aJ=aG;aT=a2;aD=a1;aK=aU}else{aZ=aU;a_=a1;a$=a2;break}}}if((a$|0)>0){aW=a$;aX=a_;aY=aZ}else{H=5591;break}}if((H|0)==5526){return}else if((H|0)==5575){return}else if((H|0)==5584){return}else if((H|0)==5588){return}else if((H|0)==5589){return}else if((H|0)==5591){return}else if((H|0)==5592){return}else if((H|0)==5593){return}else if((H|0)==5594){return}else if((H|0)==5595){return}else if((H|0)==5596){return}break};case 3:{a[767384]=1;a[767376]=1;c[203364]=c[195148];return};case 16:{aZ=c[194146]|0;aY=c[194147]|0;a_=c[194148]|0;aX=ki(a_)|0;if((aZ&234881024|0)==0){return}if((aX+aZ&234881024|0)==0){return}a$=(n0(a_+2|0)|0)&255;aW=ke(a_+4|0)|0;a2=(aW|0)<0;a1=aW&2147483647;aW=(n0(a_+3|0)|0)&255;a_=aX-1|0;if((a_|0)<0){return}aX=255>>>((8-a$|0)>>>0);a0=0;aK=0;aD=aY;aY=aZ;aZ=a_;while(1){a_=(n0(aY)|0)&255;aT=a0;aJ=aK;e=aX;aU=aD;aG=0;while(1){aS=e&a_;aP=((aS|0)!=0|a2?a1:0)+(aS>>>(aG>>>0))<<aJ|aT;aS=aJ+aW|0;if((aS|0)>31){kg(aU,aP);a3=aU+4|0;a4=0;a5=0}else{a3=aU;a4=aS;a5=aP}aP=aG+a$|0;if((aP|0)>7){break}else{aT=a5;aJ=a4;e=e<<a$;aU=a3;aG=aP}}aG=aZ-1|0;if((aG|0)<0){break}else{a0=a5;aK=a4;aD=a3;aY=aY+1|0;aZ=aG}}return};case 15:{aZ=c[194148]|0;aY=c[194149]|0;if((aZ|0)<=0){return}a3=0;aD=c[194147]|0;a4=c[194146]|0;while(1){aK=ki(a4)|0;a5=ki(a4+2|0)|0;a0=(ki(a4+4|0)|0)>>>8;a$=b[1304+((a0+64&255)<<1)>>1]|0;aW=b[1304+((a0&65535)<<1)>>1]|0;a0=aK<<16>>16;aK=(ac(a$,a0)|0)>>>14&65535;a1=(ac(aW,a0)|0)>>>14;a0=a5<<16>>16;a5=(ac(aW,a0)|0)>>>14&65535;aW=(ac(a$,a0)|0)>>>14&65535;kh(aD,aK);aK=aD+aY|0;kh(aK,-a1&65535);a1=aK+aY|0;kh(a1,a5);a5=a1+aY|0;kh(a5,aW);aW=a3+1|0;if((aW|0)<(aZ|0)){a3=aW;aD=a5+aY|0;a4=a4+8|0}else{break}}return};case 12:{a4=c[194146]|0;if((a4&234881024|0)==0){return}aY=c[194148]|0;if(((aY<<2&2097148)+a4&234881024|0)==0){return}aD=a4&-4;a4=c[194147]&-4;a3=aY&2097151;aZ=(a3|0)==0;if((aY&16777216|0)!=0){if(aZ){return}if(aD>>>0>251658239){aY=a4;a5=a3;while(1){kg(aY,-1157627909);kg(aY+4|0,-1157627909);kg(aY+8|0,-1157627909);kg(aY+12|0,-1157627909);kg(aY+16|0,-1157627909);kg(aY+20|0,-1157627909);kg(aY+24|0,-1157627909);kg(aY+28|0,-1157627909);aW=a5-8|0;if((aW|0)>0){aY=aY+32|0;a5=aW}else{break}}return}else{a5=a4;aY=a3;while(1){aW=ke(aD)|0;kg(a5,aW);kg(a5+4|0,aW);kg(a5+8|0,aW);kg(a5+12|0,aW);kg(a5+16|0,aW);kg(a5+20|0,aW);kg(a5+24|0,aW);kg(a5+28|0,aW);aW=aY-8|0;if((aW|0)>0){a5=a5+32|0;aY=aW}else{break}}return}}if(aZ){return}else{a6=a4;a7=a3;a8=aD}while(1){if(a8>>>0>251658239){a9=-1157627909}else{a9=ke(a8)|0}kg(a6,a9);aD=a8+4|0;if(aD>>>0>251658239){ba=-1157627909}else{ba=ke(aD)|0}kg(a6+4|0,ba);aD=a8+8|0;if(aD>>>0>251658239){bb=-1157627909}else{bb=ke(aD)|0}kg(a6+8|0,bb);aD=a8+12|0;if(aD>>>0>251658239){bc=-1157627909}else{bc=ke(aD)|0}kg(a6+12|0,bc);aD=a8+16|0;if(aD>>>0>251658239){bd=-1157627909}else{bd=ke(aD)|0}kg(a6+16|0,bd);aD=a8+20|0;if(aD>>>0>251658239){be=-1157627909}else{be=ke(aD)|0}kg(a6+20|0,be);aD=a8+24|0;if(aD>>>0>251658239){bf=-1157627909}else{bf=ke(aD)|0}kg(a6+24|0,bf);aD=a8+28|0;if(aD>>>0>251658239){bg=-1157627909}else{bg=ke(aD)|0}kg(a6+28|0,bg);aD=a7-8|0;if((aD|0)>0){a6=a6+32|0;a7=aD;a8=a8+32|0}else{break}}return};case 20:{a8=c[194146]|0;a7=c[194147]|0;a6=ke(a8&-4)|0;bg=a8+4|0;if((bg&234881024|0)==0){return}a8=a6>>>8;if(((a8&2097151)+bg&234881024|0)==0|(a8|0)==0){return}else{bh=a8;bi=a7;bj=bg}L7259:while(1){bg=bj+1|0;a7=(n0(bj)|0)&255;a8=a7&127;if((a7&128|0)==0){a7=a8+1|0;a6=bh;bf=bi;be=bg;bd=0;while(1){n2(bf,n0(be)|0);bc=a6-1|0;if((bc|0)==0){H=5518;break L7259}bb=be+1|0;ba=bf+1|0;a9=bd+1|0;if((a9|0)<(a7|0)){a6=bc;bf=ba;be=bb;bd=a9}else{bk=bb;bl=ba;bm=bc;break}}}else{bd=bj+2|0;be=n0(bg)|0;bf=a8+3|0;a6=bh;a7=bi;bc=0;while(1){n2(a7,be);ba=a6-1|0;if((ba|0)==0){H=5517;break L7259}bb=a7+1|0;a9=bc+1|0;if((a9|0)<(bf|0)){a6=ba;a7=bb;bc=a9}else{bk=bd;bl=bb;bm=ba;break}}}if((bm|0)>0){bh=bm;bi=bl;bj=bk}else{H=5560;break}}if((H|0)==5517){return}else if((H|0)==5518){return}else if((H|0)==5560){return}break};case 2:{a[767384]=1;c[203364]=c[195148];return};case 31:{H=ke((c[194146]|0)+4|0)|0;c[194146]=~~(+(H|0)/+dc(+((+((180-(c[194147]|0)|0)>>>0>>>0)- +((c[194148]|0)>>>0>>>0)*.00390625)/12.0)));return};case 24:{H=c[194146]|0;bk=c[194147]|0;bj=ke(H)|0;bl=H+4|0;if((bl&234881024|0)==0){return}bi=bj>>>8;if(((bi&2097151)+bl&234881024|0)==0){return}bj=(ki(bl)|0)&65535;kh(bk,bj);bl=bi-2|0;if((bl|0)<=1){return}bi=bj;bj=H+6|0;H=bl;bl=bk;while(1){bk=bl+2|0;bm=(ki(bj)|0)+(bi&65535)&65535;kh(bk,bm);bh=H-2|0;if((bh|0)>1){bi=bm;bj=bj+2|0;H=bh;bl=bk}else{break}}return};case 10:{bl=c[194146]|0;H=c[194147]|0;L7293:do{if((H|0)==0){bn=bl>>>16&32768}else{if((bl|0)==0){bn=H>>>16&32768|16384;break}bj=(bl|0)>-1?bl:-bl|0;bi=(H|0)>-1?H:-H|0;do{if((bj|0)<=(bi|0)){if(!((bj|0)!=(bi|0)|(H&bl|0)<0)){break}bk=bl<<14;bh=(bk|0)/(H|0)|0;c[194147]=(bk|0)%(H|0)|0;c[194149]=(bh|0)<0?-bh|0:bh;bk=(ac(bh,bh)|0)>>14;bm=-bk|0;bd=(ac(((ac(((ac(((ac(((ac(((ac(((ac(((bk*-169|0)>>14)+912|0,bm)|0)>>14)+2332|0,bm)|0)>>14)+4022|0,bm)|0)>>14)+5802|0,bm)|0)>>14)+8321|0,bm)|0)>>14)+13905|0,bm)|0)>>14)+41721|0,bh)|0)>>16;c[194146]=bd;bn=(H>>>16&32768|16384)-bd|0;break L7293}}while(0);bi=H<<14;bj=(bi|0)/(bl|0)|0;c[194147]=(bi|0)%(bl|0)|0;c[194149]=(bj|0)<0?-bj|0:bj;bi=(ac(bj,bj)|0)>>14;bd=-bi|0;bh=(ac(((ac(((ac(((ac(((ac(((ac(((ac(((bi*-169|0)>>14)+912|0,bd)|0)>>14)+2332|0,bd)|0)>>14)+4022|0,bd)|0)>>14)+5802|0,bd)|0)>>14)+8321|0,bd)|0)>>14)+13905|0,bd)|0)>>14)+41721|0,bj)|0)>>16;c[194146]=bh;if((bl|0)<0){bn=bh+32768|0;break}else{bn=bh+(H>>>16<<1&65536)|0;break}}}while(0);c[194146]=bn;return};case 11:{bn=c[194146]|0;if((bn&234881024|0)==0){return}H=c[194148]|0;if(((H<<2&2097148)+bn&234881024|0)==0){return}bl=c[194147]|0;bh=H&2097151;if((H&67108864|0)==0){if((H&16777216|0)==0){if((bh|0)==0){return}else{bo=bh;bp=bl;bq=bn}while(1){if(bq>>>0>251658239){br=7341}else{br=(ki(bq)|0)&65535}kh(bp,br);bj=bo-1|0;if((bj|0)==0){break}else{bo=bj;bp=bp+2|0;bq=bq+2|0}}return}else{if(bn>>>0>251658239){bs=7341}else{bs=(ki(bn)|0)&65535}if((bh|0)==0){return}else{bt=bh;bu=bl}while(1){kh(bu,bs);bq=bt-1|0;if((bq|0)==0){break}else{bt=bq;bu=bu+2|0}}return}}else{bu=bn&-4;bn=bl&-4;if((H&16777216|0)==0){if((bh|0)==0){return}else{bv=bh;bw=bn;bx=bu}while(1){if(bx>>>0>251658239){by=481107117}else{by=ke(bx)|0}kg(bw,by);H=bv-1|0;if((H|0)==0){break}else{bv=H;bw=bw+4|0;bx=bx+4|0}}return}else{if(bu>>>0>251658239){bz=481107117}else{bz=ke(bu)|0}if((bh|0)==0){return}else{bA=bh;bB=bn}while(1){kg(bB,bz);bn=bA-1|0;if((bn|0)==0){break}else{bA=bn;bB=bB+4|0}}return}}break};case 8:{c[194146]=~~+S(+(+((c[194146]|0)>>>0>>>0)));return};case 23:{bB=c[194146]|0;bA=c[194147]|0;bz=ke(bB)|0;bn=bB+4|0;if((bn&234881024|0)==0){return}bh=bz>>>8;if(((bh&2097151)+bn&234881024|0)==0){return}bu=n0(bn)|0;if(bz>>>0<=511){return}bz=bA;bA=bh;bh=bu;bn=bu&255;bu=8;bx=1;bw=bB+5|0;while(1){bB=bw;bv=bx;by=bu;H=bn;bl=bh;while(1){bC=bB+1|0;bD=(n0(bB)|0)+bl&255;bE=((bD&255)<<by|H&65535)&65535;bt=bv+1|0;if((bt|0)==2){break}else{bB=bC;bv=bt;by=by+8|0;H=bE;bl=bD}}kh(bz,bE);bl=bA-2|0;if((bl|0)>1){bz=bz+2|0;bA=bl;bh=bD;bn=0;bu=0;bx=0;bw=bC}else{break}}return};default:{return}}}function n0(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;L7376:do{switch(e>>>24|0){case 7:{f=a[(c[37240]|0)+(e&1023)|0]|0;return f|0};case 8:case 9:case 10:case 11:case 12:{f=a[(c[36856]|0)+(e&33554431)|0]|0;return f|0};case 13:{if(a[9600]|0){break L7376}switch(c[191532]|0){case 2:{g=(c[191542]|0)+1|0;c[191542]=g;if((g|0)!=4){f=0;return f|0}c[191532]=3;c[191542]=0;c[191536]=0;f=0;return f|0};case 3:{g=c[191542]|0;h=c[191536]|0;i=((d[(c[2374]|0)+(h+(c[191544]<<3))|0]|0)&1<<(g&7^7)|0)!=0;j=g+1|0;c[191542]=j;if((j&7|0)==0){c[191536]=h+1}h=i&1;if((j|0)!=64){f=h;return f|0}c[191532]=0;f=h;return f|0};case 0:case 1:case 4:{f=1;return f|0};default:{f=0;return f|0}}break};case 14:{if((a[9592]&1^1|a[9576]&1^1)<<24>>24==0){break L7376}h=c[191526]|0;if((h|0)==0){f=a[341e3+(c[191528]<<16|e&65535)|0]|0;return f|0}else if((h|0)==3){j=e&255;if((j|0)==0){f=c[2348]&255;return f|0}else if((j|0)==1){f=c[2350]&255;return f|0}else{f=0;return f|0}}else if((h|0)==7){c[191524]=0;c[191526]=0;f=-1;return f|0}else{f=0;return f|0}break};case 4:{if(e>>>0>=67109888){break L7376}h=e&1023;if((a[816784+h|0]&1)==0){break L7376}f=a[(c[120068]|0)+h|0]|0;return f|0};case 2:{f=a[(c[36848]|0)+(e&262143)|0]|0;return f|0};case 3:{f=a[(c[120070]|0)+(e&32767)|0]|0;return f|0};case 6:{do{if((b[390344]&7)>>>0>2){if((e&114688|0)==98304){f=0}else{break}return f|0}}while(0);f=a[(c[36850]|0)+(((e&98304|0)==98304?98303:131071)&e)|0]|0;return f|0};case 0:{if((c[194161]|0)>>>0<=16777215){f=a[(c[191664]|0)+(e&16383)|0]|0;return f|0}if(e>>>0>=16384){break L7376}f=a[780600+(e&3)|0]|0;return f|0};case 5:{f=a[(c[191862]|0)+(e&1023)|0]|0;return f|0};default:{}}}while(0);h=c[194161]|0;if((a[52040]&1)==0){j=h+(e&1)|0;i=j>>>24;f=a[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&j)|0]|0;return f|0}else{j=h+(e&3)|0;e=j>>>24;f=a[(c[774536+(e<<3)>>2]|0)+(c[774540+(e<<3)>>2]&j)|0]|0;return f|0}return 0}function n1(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&c[776584+((b&15)<<2)>>2]<<(b>>>7&31);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=5667;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=5667}}while(0);if((g|0)==5667){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=5677;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=5678;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=5679;break}}else{g=5677}}while(0);if((g|0)==5677){c[194192]=0;m=d[130616+k|0]|0;n=0;g=5678}if((g|0)==5678){i=m+3|0;if(l){o=n;p=i;g=5679}else{q=i;g=5685}}do{if((g|0)==5679){if((o&1|0)==0){if(o>>>0<=255){q=p;g=5685;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==5685){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function n2(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;switch(d>>>24|0){case 5:{f=e&255;b[(c[191862]|0)+(d&1022)>>1]=(f<<8|f)&65535;return};case 6:{f=b[390344]&7;do{if(f>>>0>2){if((d&114688|0)!=98304){break}return}}while(0);g=((d&98304|0)==98304?98302:131070)&d;if(g>>>0>=(c[125280+((f+1|0)>>>2<<2)>>2]|0)>>>0){return}f=e&255;b[(c[36850]|0)+g>>1]=(f<<8|f)&65535;return};case 13:{if(a[9600]|0){return}jR(e);return};case 14:{if((c[36854]|0)==5){return}if((a[766136]&1^1|a[9576]&1^1|a[9592]&1^1)<<24>>24==0){return}fa[c[2396]&127](d,e);return};case 2:{a[(c[36848]|0)+(d&262143)|0]=e;return};case 4:{if(d>>>0>=67109888){return}switch(d&1023|0){case 96:case 97:case 98:case 99:case 100:case 101:case 104:case 105:case 108:case 109:case 112:case 113:case 114:case 115:case 116:case 117:case 120:case 121:case 124:case 125:case 128:case 129:case 132:case 133:case 144:case 145:case 146:case 147:case 148:case 149:case 150:case 151:case 152:case 153:case 154:case 155:case 156:case 157:case 158:case 159:{f=d&255;jG(c[124824+(f-96<<2)>>2]|0,f,e);return};case 769:{if(e<<24>>24==-128){a[767376]=1}a[767384]=1;c[203364]=c[195148];return};default:{f=d&1022;g=b[(c[120068]|0)+f>>1]|0;if((d&1|0)==0){h=g&-256|e&255}else{h=g&255|(e&255)<<8}kd(f,h);return}}break};case 3:{a[(c[120070]|0)+(d&32767)|0]=e;return};default:{return}}}function n3(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=5742;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=5742}}while(0);if((j|0)==5742){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=5752;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=5753;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=5754;break}}else{j=5752}}while(0);if((j|0)==5752){c[194192]=0;o=d[130616+m|0]|0;p=0;j=5753}if((j|0)==5753){f=o+4|0;if(n){q=p;r=f;j=5754}else{s=f;j=5760}}do{if((j|0)==5754){if((q&1|0)==0){if(q>>>0<=255){s=r;j=5760;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==5760){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function n4(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&g;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=5775;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=5775}}while(0);if((h|0)==5775){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=5785;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=5786;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=5787;break}}else{h=5785}}while(0);if((h|0)==5785){c[194192]=0;m=d[130616+k|0]|0;n=0;h=5786}if((h|0)==5786){f=m+3|0;if(l){o=n;p=f;h=5787}else{q=f;h=5793}}do{if((h|0)==5787){if((o&1|0)==0){if(o>>>0<=255){q=p;h=5793;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==5793){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function n5(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=5810;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=5810}}while(0);if((j|0)==5810){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=5820;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=5821;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=5822;break}}else{j=5820}}while(0);if((j|0)==5820){c[194192]=0;o=d[130616+m|0]|0;p=0;j=5821}if((j|0)==5821){f=o+4|0;if(n){q=p;r=f;j=5822}else{s=f;j=5828}}do{if((j|0)==5822){if((q&1|0)==0){if(q>>>0<=255){s=r;j=5828;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==5828){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function n6(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=5841;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=5841}}while(0);if((g|0)==5841){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=5851;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=5852;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=5853;break}}else{g=5851}}while(0);if((g|0)==5851){c[194192]=0;m=d[130616+k|0]|0;n=0;g=5852}if((g|0)==5852){i=m+3|0;if(l){o=n;p=i;g=5853}else{q=i;g=5859}}do{if((g|0)==5853){if((o&1|0)==0){if(o>>>0<=255){q=p;g=5859;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==5859){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function n7(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&j;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=5876;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=5876}}while(0);if((k|0)==5876){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=5886;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=5887;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=5888;break}}else{k=5886}}while(0);if((k|0)==5886){c[194192]=0;p=d[130616+n|0]|0;q=0;k=5887}if((k|0)==5887){f=p+4|0;if(o){r=q;s=f;k=5888}else{t=f;k=5894}}do{if((k|0)==5888){if((r&1|0)==0){if(r>>>0<=255){t=s;k=5894;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==5894){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function n8(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=5910;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=5910}}while(0);if((i|0)==5910){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=5920;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=5921;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=5922;break}}else{i=5920}}while(0);if((i|0)==5920){c[194192]=0;n=d[130616+l|0]|0;o=0;i=5921}if((i|0)==5921){f=n+3|0;if(m){p=o;q=f;i=5922}else{r=f;i=5928}}do{if((i|0)==5922){if((p&1|0)==0){if(p>>>0<=255){r=q;i=5928;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==5928){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function n9(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=5943;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=5943}}while(0);if((i|0)==5943){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=5953;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=5954;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=5955;break}}else{i=5953}}while(0);if((i|0)==5953){c[194192]=0;n=d[130616+l|0]|0;o=0;i=5954}if((i|0)==5954){f=n+4|0;if(m){p=o;q=f;i=5955}else{r=f;i=5961}}do{if((i|0)==5955){if((p&1|0)==0){if(p>>>0<=255){r=q;i=5961;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==5961){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function oa(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[776584+((a>>>8&15)<<2)>>2]|0;c[776584+((a>>>16&15)<<2)>>2]=ac(c[776584+((a&15)<<2)>>2]|0,b)|0;a=b>>31^b;do{if(a>>>0<65536){b=(c[204526]|0)+1|0;c[204526]=b;e=b}else{b=c[204526]|0;if(a>>>0<16777216){f=b+2|0;c[204526]=f;e=f;break}else{f=b+3|0;c[204526]=f;e=f;break}}}while(0);a=c[194192]|0;if((a|0)==0){f=(1<<e)-1|0;c[194192]=f;g=f}else{g=a}a=(c[194193]|0)>>>24&15;do{if((a-8|0)>>>0<6){if((g&1|0)==0){break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;h=(d[130328+a|0]|0)-1|0;i=e+1|0;j=i+h|0;c[204526]=j;return}else{c[194192]=f>>>2|g&-256;h=0;i=e+1|0;j=i+h|0;c[204526]=j;return}}}while(0);c[194192]=0;h=d[130616+a|0]|0;i=e+1|0;j=i+h|0;c[204526]=j;return}function ob(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=c[776584+((e&15)<<2)>>2]|0;g=776584+((e>>>16&15)<<2)|0;h=c[g>>2]|0;kh(h,b[776584+((e>>>12&15)<<2)>>1]|0);c[g>>2]=h-f;f=h>>>24&15;h=d[147072+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);f=h+2|0;h=(c[194193]|0)>>>24&15;do{if((h-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}e=g&255;if((g&2|0)==0){c[194192]=e>>>1|g&-256;i=(d[130328+h|0]|0)-1|0;j=f+i|0;c[204526]=j;return}else{c[194192]=e>>>2|g&-256;i=0;j=f+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+h|0]|0;j=f+i|0;c[204526]=j;return}function oc(b){b=b|0;var d=0;b=c[194161]|0;d=(a[52040]&1)!=0;if((c[31194]|0)!=27){km(27,1,0)}c[194160]=b-(d?4:2);c[194161]=4;a[52040]=1;a[130632]=0;c[194193]=4;d=c[193635]|0;b=c[193634]|0;c[203402]=c[b+(d&4)>>2];c[203400]=c[b+(d&8)>>2];c[194161]=8;return}function od(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(h&1<<32-g|0)!=0;j=h<<g}g=c[776584+((b>>>16&15)<<2)>>2]&j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=6015;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=6015}}while(0);if((k|0)==6015){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6027;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=6028;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=6029;break}}else{k=6027}}while(0);if((k|0)==6027){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6028}if((k|0)==6028){g=p+3|0;if(o){r=q;s=g;k=6029}else{t=g;k=6035}}do{if((k|0)==6029){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6035;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6035){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function oe(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]&1|0)!=0;j=0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<32-h|0)!=0;j=k<<h}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]&j;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(h|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=6055;break}c[194192]=0;m=d[130616+b|0]|0;break}h=i&255;if((i&2|0)==0){c[194192]=h>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=h>>>2|i&-256;m=0;break}}else{l=6055}}while(0);if((l|0)==6055){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;h=m>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=i>>>24;o=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;h=m>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=i>>>24;o=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=6067;break}i=b&255;if((b&2|0)==0){h=i>>>1|b&-256;c[194192]=h;q=(d[130328+o|0]|0)-1|0;r=h;l=6068;break}else{h=i>>>2|b&-256;c[194192]=h;s=h;t=4;l=6069;break}}else{l=6067}}while(0);if((l|0)==6067){c[194192]=0;q=d[130616+o|0]|0;r=0;l=6068}if((l|0)==6068){h=q+4|0;if(p){s=r;t=h;l=6069}else{u=h;l=6075}}do{if((l|0)==6069){if((s&1|0)==0){if(s>>>0<=255){u=t;l=6075;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}h=s&255;if((s&2|0)==0){c[194192]=h>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=h>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==6075){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function of(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=h>>>31;j=0}else{i=h&1<<g-1;j=h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]&j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=(i|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=6093;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=6093}}while(0);if((k|0)==6093){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6105;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=6106;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=6107;break}}else{k=6105}}while(0);if((k|0)==6105){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6106}if((k|0)==6106){g=p+3|0;if(o){r=q;s=g;k=6107}else{t=g;k=6113}}do{if((k|0)==6107){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6113;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6113){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function og(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]|0)<0;j=0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<h-1|0)!=0;j=k>>>(h>>>0)}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]&j;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(h|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=6133;break}c[194192]=0;m=d[130616+b|0]|0;break}h=i&255;if((i&2|0)==0){c[194192]=h>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=h>>>2|i&-256;m=0;break}}else{l=6133}}while(0);if((l|0)==6133){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;h=m>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=i>>>24;o=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;h=m>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=i>>>24;o=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=6145;break}i=b&255;if((b&2|0)==0){h=i>>>1|b&-256;c[194192]=h;q=(d[130328+o|0]|0)-1|0;r=h;l=6146;break}else{h=i>>>2|b&-256;c[194192]=h;s=h;t=4;l=6147;break}}else{l=6145}}while(0);if((l|0)==6145){c[194192]=0;q=d[130616+o|0]|0;r=0;l=6146}if((l|0)==6146){h=q+4|0;if(p){s=r;t=h;l=6147}else{u=h;l=6153}}do{if((l|0)==6147){if((s&1|0)==0){if(s>>>0<=255){u=t;l=6153;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}h=s&255;if((s&2|0)==0){c[194192]=h>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=h>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==6153){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oh(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(h|0)<0;j=31}else{i=(h&1<<g-1|0)!=0;j=g}g=c[776584+((b>>>16&15)<<2)>>2]&h>>j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=6171;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=6171}}while(0);if((k|0)==6171){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6183;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=6184;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=6185;break}}else{k=6183}}while(0);if((k|0)==6183){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6184}if((k|0)==6184){g=p+3|0;if(o){r=q;s=g;k=6185}else{t=g;k=6191}}do{if((k|0)==6185){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6191;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6191){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function oi(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=b>>>12&15;g=a[768256]|0;h=a[776584+((b>>>8&15)<<2)|0]|0;i=h&255;do{if((h&255)<32){j=c[776584+((b&15)<<2)>>2]|0;if(h<<24>>24==0){k=(g&1)!=0;l=j;break}else{k=(j&1<<i-1|0)!=0;l=j>>i;break}}else{j=c[776584+((b&15)<<2)>>2]|0;k=(j|0)<0;l=j>>31}}while(0);i=c[776584+((b>>>16&15)<<2)>>2]&l;c[776584+(f<<2)>>2]=i;if((f|0)!=15){a[768240]=i>>>31&255;a[768224]=(i|0)==0|0;a[768256]=k&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){if(k>>>0<=255){m=6211;break}c[194192]=0;n=d[130616+b|0]|0;break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;n=d[130328+b|0]|0;break}else{c[194192]=i>>>2|k&-256;n=0;break}}else{m=6211}}while(0);if((m|0)==6211){n=d[125296+b|0]|0}o=n+2|0;c[204526]=o;return}n=c[194163]&31;if((c[31194]|0)!=(n|0)){km(n,0,1)}n=c[194161]|0;if((a[52040]&1)==0){b=n&-2;c[194193]=b;k=b+2|0;c[194161]=k;i=n>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=k>>>24;p=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&k)>>1]|0;q=b}else{b=n&-4;c[194193]=b;k=b+4|0;c[194161]=k;i=n>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=k>>>24;p=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&k)>>2]|0;q=b}c[203400]=p;p=q>>>24&15;q=(p-8|0)>>>0<6;do{if(q){b=c[194192]|0;if((b&1|0)==0){m=6223;break}k=b&255;if((b&2|0)==0){i=k>>>1|b&-256;c[194192]=i;r=(d[130328+p|0]|0)-1|0;s=i;m=6224;break}else{i=k>>>2|b&-256;c[194192]=i;t=i;u=4;m=6225;break}}else{m=6223}}while(0);if((m|0)==6223){c[194192]=0;r=d[130616+p|0]|0;s=0;m=6224}if((m|0)==6224){i=r+4|0;if(q){t=s;u=i;m=6225}else{v=i;m=6231}}do{if((m|0)==6225){if((t&1|0)==0){if(t>>>0<=255){v=u;m=6231;break}c[194192]=0;w=d[130616+p|0]|0;x=u;break}i=t&255;if((t&2|0)==0){c[194192]=i>>>1|t&-256;w=d[130328+p|0]|0;x=u;break}else{c[194192]=i>>>2|t&-256;w=0;x=u;break}}}while(0);if((m|0)==6231){w=d[125296+p|0]|0;x=v}o=(w<<1)+x|0;c[204526]=o;return}function oj(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=1;j=(d[768256]|0)<<31|h>>>1}else{i=1<<g-1;j=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]&j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=(i&h|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=6249;break}c[194192]=0;l=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;l=0;break}}else{k=6249}}while(0);if((k|0)==6249){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6261;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=6262;break}else{i=h>>>2|b&-256;c[194192]=i;r=i;s=3;k=6263;break}}else{k=6261}}while(0);if((k|0)==6261){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6262}if((k|0)==6262){i=p+3|0;if(o){r=q;s=i;k=6263}else{t=i;k=6269}}do{if((k|0)==6263){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6269;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6269){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function ok(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[776584+((b>>>8&15)<<2)>>2]|0;f=ac(c[776584+((b&15)<<2)>>2]|0,e)|0;c[776584+((b>>>16&15)<<2)>>2]=f;a[768240]=f>>>31&255;a[768224]=(f|0)==0|0;f=e>>31^e;do{if(f>>>0<65536){e=(c[204526]|0)+1|0;c[204526]=e;g=e}else{e=c[204526]|0;if(f>>>0<16777216){b=e+2|0;c[204526]=b;g=b;break}else{b=e+3|0;c[204526]=b;g=b;break}}}while(0);f=c[194192]|0;if((f|0)==0){b=(1<<g)-1|0;c[194192]=b;h=b}else{h=f}f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){if((h&1|0)==0){break}b=h&255;if((h&2|0)==0){c[194192]=b>>>1|h&-256;i=(d[130328+f|0]|0)-1|0;j=g+1|0;k=j+i|0;c[204526]=k;return}else{c[194192]=b>>>2|h&-256;i=0;j=g+1|0;k=j+i|0;c[204526]=k;return}}}while(0);c[194192]=0;i=d[130616+f|0]|0;j=g+1|0;k=j+i|0;c[204526]=k;return}function ol(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;i=c[776584+((b&15)<<2)>>2]|0;if((h&31|0)==0){j=g<<24>>24==0?(a[768256]&1)!=0:(i|0)<0;k=i}else{j=(1<<h-1&i|0)!=0;k=i<<32-h|i>>>(h>>>0)}h=c[776584+((b>>>16&15)<<2)>>2]&k;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(h|0)==0|0;a[768256]=j&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=6304;break}c[194192]=0;m=d[130616+b|0]|0;break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=h>>>2|j&-256;m=0;break}}else{l=6304}}while(0);if((l|0)==6304){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;h=m>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=j>>>24;o=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;h=m>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=j>>>24;o=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=6316;break}j=b&255;if((b&2|0)==0){h=j>>>1|b&-256;c[194192]=h;q=(d[130328+o|0]|0)-1|0;r=h;l=6317;break}else{h=j>>>2|b&-256;c[194192]=h;s=h;t=4;l=6318;break}}else{l=6316}}while(0);if((l|0)==6316){c[194192]=0;q=d[130616+o|0]|0;r=0;l=6317}if((l|0)==6317){h=q+4|0;if(p){s=r;t=h;l=6318}else{u=h;l=6324}}do{if((l|0)==6318){if((s&1|0)==0){if(s>>>0<=255){u=t;l=6324;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}h=s&255;if((s&2|0)==0){c[194192]=h>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=h>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==6324){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function om(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=c[776584+((b&15)<<2)>>2]|0;b=776584+(f<<2)|0;h=c[b>>2]|0;c[776584+(e<<2)>>2]=ki(h)|0;if((e|0)!=(f|0)){c[b>>2]=h-g}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=h>>>24&15;g=d[125296+b|0]|0;f=b-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function on(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=c[776584+((b&15)<<2)>>2]|0;b=776584+(f<<2)|0;h=c[b>>2]|0;c[776584+(e<<2)>>2]=(n0(h)|0)<<24>>24;if((e|0)!=(f|0)){c[b>>2]=h-g}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=h>>>24&15;g=d[125296+b|0]|0;f=b-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function oo(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]^c[776584+((b&15)<<2)>>2]<<(b>>>7&31);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=6387;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=6387}}while(0);if((g|0)==6387){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=6397;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=6398;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=6399;break}}else{g=6397}}while(0);if((g|0)==6397){c[194192]=0;m=d[130616+k|0]|0;n=0;g=6398}if((g|0)==6398){i=m+3|0;if(l){o=n;p=i;g=6399}else{q=i;g=6405}}do{if((g|0)==6399){if((o&1|0)==0){if(o>>>0<=255){q=p;g=6405;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==6405){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function op(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]^i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=6422;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=6422}}while(0);if((j|0)==6422){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=6432;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=6433;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=6434;break}}else{j=6432}}while(0);if((j|0)==6432){c[194192]=0;o=d[130616+m|0]|0;p=0;j=6433}if((j|0)==6433){f=o+4|0;if(n){q=p;r=f;j=6434}else{s=f;j=6440}}do{if((j|0)==6434){if((q&1|0)==0){if(q>>>0<=255){s=r;j=6440;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==6440){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function oq(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]^g;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=6455;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=6455}}while(0);if((h|0)==6455){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=6465;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=6466;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=6467;break}}else{h=6465}}while(0);if((h|0)==6465){c[194192]=0;m=d[130616+k|0]|0;n=0;h=6466}if((h|0)==6466){f=m+3|0;if(l){o=n;p=f;h=6467}else{q=f;h=6473}}do{if((h|0)==6467){if((o&1|0)==0){if(o>>>0<=255){q=p;h=6473;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==6473){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function or(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=c[776584+((b&15)<<2)>>2]|0;b=776584+(f<<2)|0;h=c[b>>2]|0;i=ki(h)|0;if((h&1|0)==0){j=i&65535}else{j=(i&255)<<24>>24}c[776584+(e<<2)>>2]=j<<16>>16;if((e|0)!=(f|0)){c[b>>2]=h-g}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=h>>>24&15;g=d[125296+b|0]|0;f=b-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;k=e+5|0;l=b;m=f}else{f=h>>>24&15;k=3;l=f;m=f-2|0}f=d[147072+l|0]|0;do{if(m>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);m=(c[194193]|0)>>>24&15;do{if((m-8|0)>>>0<6){l=c[194192]|0;if((l&1|0)==0){break}h=l&255;if((l&2|0)==0){c[194192]=h>>>1|l&-256;n=(d[130328+m|0]|0)-1|0;o=k+f|0;p=o+n|0;c[204526]=p;return}else{c[194192]=h>>>2|l&-256;n=0;o=k+f|0;p=o+n|0;c[204526]=p;return}}}while(0);c[194192]=0;n=d[130616+m|0]|0;o=k+f|0;p=o+n|0;c[204526]=p;return}function os(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]^i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=6517;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=6517}}while(0);if((j|0)==6517){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=6527;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=6528;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=6529;break}}else{j=6527}}while(0);if((j|0)==6527){c[194192]=0;o=d[130616+m|0]|0;p=0;j=6528}if((j|0)==6528){f=o+4|0;if(n){q=p;r=f;j=6529}else{s=f;j=6535}}do{if((j|0)==6529){if((q&1|0)==0){if(q>>>0<=255){s=r;j=6535;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==6535){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function ot(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]^c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=6548;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=6548}}while(0);if((g|0)==6548){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=6558;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=6559;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=6560;break}}else{g=6558}}while(0);if((g|0)==6558){c[194192]=0;m=d[130616+k|0]|0;n=0;g=6559}if((g|0)==6559){i=m+3|0;if(l){o=n;p=i;g=6560}else{q=i;g=6566}}do{if((g|0)==6560){if((o&1|0)==0){if(o>>>0<=255){q=p;g=6566;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==6566){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function ou(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]^j;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=6583;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=6583}}while(0);if((k|0)==6583){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6593;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=6594;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=6595;break}}else{k=6593}}while(0);if((k|0)==6593){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6594}if((k|0)==6594){f=p+4|0;if(o){r=q;s=f;k=6595}else{t=f;k=6601}}do{if((k|0)==6595){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6601;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6601){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function ov(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]^h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=6617;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=6617}}while(0);if((i|0)==6617){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=6627;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=6628;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=6629;break}}else{i=6627}}while(0);if((i|0)==6627){c[194192]=0;n=d[130616+l|0]|0;o=0;i=6628}if((i|0)==6628){f=n+3|0;if(m){p=o;q=f;i=6629}else{r=f;i=6635}}do{if((i|0)==6629){if((p&1|0)==0){if(p>>>0<=255){r=q;i=6635;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==6635){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function ow(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]^h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=6650;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=6650}}while(0);if((i|0)==6650){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=6660;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=6661;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=6662;break}}else{i=6660}}while(0);if((i|0)==6660){c[194192]=0;n=d[130616+l|0]|0;o=0;i=6661}if((i|0)==6661){f=n+4|0;if(m){p=o;q=f;i=6662}else{r=f;i=6668}}do{if((i|0)==6662){if((p&1|0)==0){if(p>>>0<=255){r=q;i=6668;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==6668){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function ox(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[776584+((a>>>8&15)<<2)>>2]|0;e=ac(c[776584+((a&15)<<2)>>2]|0,b)|0;c[776584+((a>>>16&15)<<2)>>2]=e+(c[776584+((a>>>12&15)<<2)>>2]|0);a=b>>31^b;do{if(a>>>0<65536){b=(c[204526]|0)+1|0;c[204526]=b;f=b}else{b=c[204526]|0;if(a>>>0<16777216){e=b+2|0;c[204526]=e;f=e;break}else{e=b+3|0;c[204526]=e;f=e;break}}}while(0);a=c[194192]|0;if((a|0)==0){e=(1<<f)-1|0;c[194192]=e;g=e}else{g=a}a=(c[194193]|0)>>>24&15;do{if((a-8|0)>>>0<6){if((g&1|0)==0){break}e=g&255;if((g&2|0)==0){c[194192]=e>>>1|g&-256;h=(d[130328+a|0]|0)-1|0;i=f+1|0;j=i+h|0;c[204526]=j;return}else{c[194192]=e>>>2|g&-256;h=0;i=f+1|0;j=i+h|0;c[204526]=j;return}}}while(0);c[194192]=0;h=d[130616+a|0]|0;i=f+1|0;j=i+h|0;c[204526]=j;return}function oy(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(h&1<<32-g|0)!=0;j=h<<g}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g^j;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(g|0)==(j|0)|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=31;break}c[194192]=0;l=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;l=0;break}}else{k=31}}while(0);if((k|0)==31){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=43;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=44;break}else{j=i>>>2|b&-256;c[194192]=j;r=j;s=3;k=45;break}}else{k=43}}while(0);if((k|0)==43){c[194192]=0;p=d[130616+n|0]|0;q=0;k=44}if((k|0)==44){j=p+3|0;if(o){r=q;s=j;k=45}else{t=j;k=51}}do{if((k|0)==45){if((r&1|0)==0){if(r>>>0<=255){t=s;k=51;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==51){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function oz(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]&1|0)!=0;j=0}else if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<32-h|0)!=0;j=k<<h}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h^j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(h|0)==(j|0)|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=71;break}c[194192]=0;m=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;m=0;break}}else{l=71}}while(0);if((l|0)==71){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=m>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;o=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=m>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;o=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=83;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;q=(d[130328+o|0]|0)-1|0;r=j;l=84;break}else{j=i>>>2|b&-256;c[194192]=j;s=j;t=4;l=85;break}}else{l=83}}while(0);if((l|0)==83){c[194192]=0;q=d[130616+o|0]|0;r=0;l=84}if((l|0)==84){j=q+4|0;if(p){s=r;t=j;l=85}else{u=j;l=91}}do{if((l|0)==85){if((s&1|0)==0){if(s>>>0<=255){u=t;l=91;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}j=s&255;if((s&2|0)==0){c[194192]=j>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=j>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==91){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oA(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=h>>>31;j=0}else{i=h&1<<g-1;j=h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g^j;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(g|0)==(j|0)|0;a[768256]=(i|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=109;break}c[194192]=0;l=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;l=0;break}}else{k=109}}while(0);if((k|0)==109){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=121;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=122;break}else{j=i>>>2|b&-256;c[194192]=j;r=j;s=3;k=123;break}}else{k=121}}while(0);if((k|0)==121){c[194192]=0;p=d[130616+n|0]|0;q=0;k=122}if((k|0)==122){j=p+3|0;if(o){r=q;s=j;k=123}else{t=j;k=129}}do{if((k|0)==123){if((r&1|0)==0){if(r>>>0<=255){t=s;k=129;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==129){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function oB(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]|0)<0;j=0}else if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<h-1|0)!=0;j=k>>>(h>>>0)}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h^j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(h|0)==(j|0)|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=149;break}c[194192]=0;m=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;m=0;break}}else{l=149}}while(0);if((l|0)==149){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=m>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;o=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=m>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;o=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=161;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;q=(d[130328+o|0]|0)-1|0;r=j;l=162;break}else{j=i>>>2|b&-256;c[194192]=j;s=j;t=4;l=163;break}}else{l=161}}while(0);if((l|0)==161){c[194192]=0;q=d[130616+o|0]|0;r=0;l=162}if((l|0)==162){j=q+4|0;if(p){s=r;t=j;l=163}else{u=j;l=169}}do{if((l|0)==163){if((s&1|0)==0){if(s>>>0<=255){u=t;l=169;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}j=s&255;if((s&2|0)==0){c[194192]=j>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=j>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==169){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oC(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(h|0)<0;j=31}else{i=(h&1<<g-1|0)!=0;j=g}g=h>>j;j=c[776584+((b>>>16&15)<<2)>>2]|0;h=j^g;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(j|0)==(g|0)|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=187;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=187}}while(0);if((k|0)==187){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=199;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=200;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=201;break}}else{k=199}}while(0);if((k|0)==199){c[194192]=0;p=d[130616+n|0]|0;q=0;k=200}if((k|0)==200){g=p+3|0;if(o){r=q;s=g;k=201}else{t=g;k=207}}do{if((k|0)==201){if((r&1|0)==0){if(r>>>0<=255){t=s;k=207;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==207){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function oD(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=b>>>12&15;g=a[768256]|0;h=a[776584+((b>>>8&15)<<2)|0]|0;i=h&255;do{if((h&255)<32){j=c[776584+((b&15)<<2)>>2]|0;if(h<<24>>24==0){k=(g&1)!=0;l=j;break}else{k=(j&1<<i-1|0)!=0;l=j>>i;break}}else{j=c[776584+((b&15)<<2)>>2]|0;k=(j|0)<0;l=j>>31}}while(0);i=c[776584+((b>>>16&15)<<2)>>2]|0;g=i^l;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(i|0)==(l|0)|0;a[768256]=k&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){if(k>>>0<=255){m=227;break}c[194192]=0;n=d[130616+b|0]|0;break}l=k&255;if((k&2|0)==0){c[194192]=l>>>1|k&-256;n=d[130328+b|0]|0;break}else{c[194192]=l>>>2|k&-256;n=0;break}}else{m=227}}while(0);if((m|0)==227){n=d[125296+b|0]|0}o=n+2|0;c[204526]=o;return}n=c[194163]&31;if((c[31194]|0)!=(n|0)){km(n,0,1)}n=c[194161]|0;if((a[52040]&1)==0){b=n&-2;c[194193]=b;k=b+2|0;c[194161]=k;l=n>>>24;c[203402]=e[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&b)>>1]|0;l=k>>>24;p=e[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&k)>>1]|0;q=b}else{b=n&-4;c[194193]=b;k=b+4|0;c[194161]=k;l=n>>>24;c[203402]=c[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&b)>>2];l=k>>>24;p=c[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&k)>>2]|0;q=b}c[203400]=p;p=q>>>24&15;q=(p-8|0)>>>0<6;do{if(q){b=c[194192]|0;if((b&1|0)==0){m=239;break}k=b&255;if((b&2|0)==0){l=k>>>1|b&-256;c[194192]=l;r=(d[130328+p|0]|0)-1|0;s=l;m=240;break}else{l=k>>>2|b&-256;c[194192]=l;t=l;u=4;m=241;break}}else{m=239}}while(0);if((m|0)==239){c[194192]=0;r=d[130616+p|0]|0;s=0;m=240}if((m|0)==240){l=r+4|0;if(q){t=s;u=l;m=241}else{v=l;m=247}}do{if((m|0)==241){if((t&1|0)==0){if(t>>>0<=255){v=u;m=247;break}c[194192]=0;w=d[130616+p|0]|0;x=u;break}l=t&255;if((t&2|0)==0){c[194192]=l>>>1|t&-256;w=d[130328+p|0]|0;x=u;break}else{c[194192]=l>>>2|t&-256;w=0;x=u;break}}}while(0);if((m|0)==247){w=d[125296+p|0]|0;x=v}o=(w<<1)+x|0;c[204526]=o;return}function oE(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=1;j=(d[768256]|0)<<31|h>>>1}else{i=1<<g-1;j=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;k=g^j;c[776584+(f<<2)>>2]=k;if((f|0)!=15){a[768240]=k>>>31&255;a[768224]=(g|0)==(j|0)|0;a[768256]=(i&h|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=265;break}c[194192]=0;m=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;m=0;break}}else{l=265}}while(0);if((l|0)==265){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=m>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;o=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=m>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;o=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=277;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;q=(d[130328+o|0]|0)-1|0;r=i;l=278;break}else{i=h>>>2|b&-256;c[194192]=i;s=i;t=3;l=279;break}}else{l=277}}while(0);if((l|0)==277){c[194192]=0;q=d[130616+o|0]|0;r=0;l=278}if((l|0)==278){i=q+3|0;if(p){s=r;t=i;l=279}else{u=i;l=285}}do{if((l|0)==279){if((s&1|0)==0){if(s>>>0<=255){u=t;l=285;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}i=s&255;if((s&2|0)==0){c[194192]=i>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=i>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==285){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oF(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;i=c[776584+((b&15)<<2)>>2]|0;if((h&31|0)==0){j=g<<24>>24==0?(a[768256]&1)!=0:(i|0)<0;k=i}else{j=(1<<h-1&i|0)!=0;k=i<<32-h|i>>>(h>>>0)}h=c[776584+((b>>>16&15)<<2)>>2]|0;i=h^k;c[776584+(f<<2)>>2]=i;if((f|0)!=15){a[768240]=i>>>31&255;a[768224]=(h|0)==(k|0)|0;a[768256]=j&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=303;break}c[194192]=0;m=d[130616+b|0]|0;break}k=j&255;if((j&2|0)==0){c[194192]=k>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|j&-256;m=0;break}}else{l=303}}while(0);if((l|0)==303){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=j>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=j>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=315;break}j=b&255;if((b&2|0)==0){k=j>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=316;break}else{k=j>>>2|b&-256;c[194192]=k;s=k;t=4;l=317;break}}else{l=315}}while(0);if((l|0)==315){c[194192]=0;q=d[130616+o|0]|0;r=0;l=316}if((l|0)==316){k=q+4|0;if(p){s=r;t=k;l=317}else{u=k;l=323}}do{if((l|0)==317){if((s&1|0)==0){if(s>>>0<=255){u=t;l=323;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==323){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oG(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[776584+((b>>>8&15)<<2)>>2]|0;f=ac(c[776584+((b&15)<<2)>>2]|0,e)|0;g=f+(c[776584+((b>>>12&15)<<2)>>2]|0)|0;c[776584+((b>>>16&15)<<2)>>2]=g;a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;g=e>>31^e;do{if(g>>>0<65536){e=(c[204526]|0)+1|0;c[204526]=e;h=e}else{e=c[204526]|0;if(g>>>0<16777216){b=e+2|0;c[204526]=b;h=b;break}else{b=e+3|0;c[204526]=b;h=b;break}}}while(0);g=c[194192]|0;if((g|0)==0){b=(1<<h)-1|0;c[194192]=b;i=b}else{i=g}g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){if((i&1|0)==0){break}b=i&255;if((i&2|0)==0){c[194192]=b>>>1|i&-256;j=(d[130328+g|0]|0)-1|0;k=h+1|0;l=k+j|0;c[204526]=l;return}else{c[194192]=b>>>2|i&-256;j=0;k=h+1|0;l=k+j|0;c[204526]=l;return}}}while(0);c[194192]=0;j=d[130616+g|0]|0;k=h+1|0;l=k+j|0;c[204526]=l;return}function oH(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]<<(b>>>7&31));if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=353;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=353}}while(0);if((g|0)==353){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=363;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=364;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=365;break}}else{g=363}}while(0);if((g|0)==363){c[194192]=0;m=d[130616+k|0]|0;n=0;g=364}if((g|0)==364){i=m+3|0;if(l){o=n;p=i;g=365}else{q=i;g=371}}do{if((g|0)==365){if((o&1|0)==0){if(o>>>0<=255){q=p;g=371;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==371){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function oI(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=388;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=388}}while(0);if((j|0)==388){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=398;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=399;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=400;break}}else{j=398}}while(0);if((j|0)==398){c[194192]=0;o=d[130616+m|0]|0;p=0;j=399}if((j|0)==399){f=o+4|0;if(n){q=p;r=f;j=400}else{s=f;j=406}}do{if((j|0)==400){if((q&1|0)==0){if(q>>>0<=255){s=r;j=406;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==406){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function oJ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-g;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=421;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=421}}while(0);if((h|0)==421){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=431;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=432;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=433;break}}else{h=431}}while(0);if((h|0)==431){c[194192]=0;m=d[130616+k|0]|0;n=0;h=432}if((h|0)==432){f=m+3|0;if(l){o=n;p=f;h=433}else{q=f;h=439}}do{if((h|0)==433){if((o&1|0)==0){if(o>>>0<=255){q=p;h=439;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==439){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function oK(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=456;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=456}}while(0);if((j|0)==456){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=466;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=467;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=468;break}}else{j=466}}while(0);if((j|0)==466){c[194192]=0;o=d[130616+m|0]|0;p=0;j=467}if((j|0)==467){f=o+4|0;if(n){q=p;r=f;j=468}else{s=f;j=474}}do{if((j|0)==468){if((q&1|0)==0){if(q>>>0<=255){s=r;j=474;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==474){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function oL(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f));if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=487;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=487}}while(0);if((g|0)==487){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=497;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=498;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=499;break}}else{g=497}}while(0);if((g|0)==497){c[194192]=0;m=d[130616+k|0]|0;n=0;g=498}if((g|0)==498){i=m+3|0;if(l){o=n;p=i;g=499}else{q=i;g=505}}do{if((g|0)==499){if((o&1|0)==0){if(o>>>0<=255){q=p;g=505;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==505){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function oM(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-j;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=522;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=522}}while(0);if((k|0)==522){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=532;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=533;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=534;break}}else{k=532}}while(0);if((k|0)==532){c[194192]=0;p=d[130616+n|0]|0;q=0;k=533}if((k|0)==533){f=p+4|0;if(o){r=q;s=f;k=534}else{t=f;k=540}}do{if((k|0)==534){if((r&1|0)==0){if(r>>>0<=255){t=s;k=540;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==540){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function oN(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=556;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=556}}while(0);if((i|0)==556){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=566;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=567;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=568;break}}else{i=566}}while(0);if((i|0)==566){c[194192]=0;n=d[130616+l|0]|0;o=0;i=567}if((i|0)==567){f=n+3|0;if(m){p=o;q=f;i=568}else{r=f;i=574}}do{if((i|0)==568){if((p&1|0)==0){if(p>>>0<=255){r=q;i=574;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==574){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function oO(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=589;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=589}}while(0);if((i|0)==589){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=599;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=600;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=601;break}}else{i=599}}while(0);if((i|0)==599){c[194192]=0;n=d[130616+l|0]|0;o=0;i=600}if((i|0)==600){f=n+4|0;if(m){p=o;q=f;i=601}else{r=f;i=607}}do{if((i|0)==601){if((p&1|0)==0){if(p>>>0<=255){r=q;i=607;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==607){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function oP(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=776584+((e>>>16&15)<<2)|0;g=c[f>>2]|0;kh(g,b[776584+((e>>>12&15)<<2)>>1]|0);c[f>>2]=g-(e>>>4&240|e&15);e=g>>>24&15;g=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}h=f&255;if((f&2|0)==0){c[194192]=h>>>1|f&-256;i=(d[130328+g|0]|0)-1|0;j=e+i|0;c[204526]=j;return}else{c[194192]=h>>>2|f&-256;i=0;j=e+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+g|0]|0;j=e+i|0;c[204526]=j;return}function oQ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);h=c[776584+((b>>>16&15)<<2)>>2]|0;i=h-g|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(h|0)==(g|0)|0;i=h>>>31;h=g>>>31;g=h^1;j=g&i;k=f^1;a[768232]=(j&k|(i^1)&h&f)&255;a[768256]=(k&i|j|k&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){l=638;break}c[194192]=0;m=d[130616+b|0]|0;break}k=g&255;if((g&2|0)==0){c[194192]=k>>>1|g&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|g&-256;m=0;break}}else{l=638}}while(0);if((l|0)==638){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;g=b+2|0;c[194161]=g;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=g>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>1]|0;p=b}else{b=m&-4;c[194193]=b;g=b+4|0;c[194161]=g;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=g>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=650;break}g=b&255;if((b&2|0)==0){k=g>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=651;break}else{k=g>>>2|b&-256;c[194192]=k;s=k;t=3;l=652;break}}else{l=650}}while(0);if((l|0)==650){c[194192]=0;q=d[130616+o|0]|0;r=0;l=651}if((l|0)==651){k=q+3|0;if(p){s=r;t=k;l=652}else{u=k;l=658}}do{if((l|0)==652){if((s&1|0)==0){if(s>>>0<=255){u=t;l=658;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==658){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oR(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h-i|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(h|0)==(i|0)|0;g=h>>>31;h=i>>>31;i=h^1;j=g&i;k=f^1;a[768232]=(k&j|(g^1)&h&f)&255;a[768256]=(k&g|j|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=677;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=677}}while(0);if((l|0)==677){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=689;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=690;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=691;break}}else{l=689}}while(0);if((l|0)==689){c[194192]=0;q=d[130616+o|0]|0;r=0;l=690}if((l|0)==690){k=q+4|0;if(p){s=r;t=k;l=691}else{u=k;l=697}}do{if((l|0)==691){if((s&1|0)==0){if(s>>>0<=255){u=t;l=697;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==697){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oS(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;i=g-h|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(g|0)==(h|0)|0;i=g>>>31;g=h>>>31;h=g^1;j=i&h;k=f^1;a[768232]=(k&j|(i^1)&g&f)&255;a[768256]=(k&i|j|k&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=714;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=714}}while(0);if((l|0)==714){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=726;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=727;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=3;l=728;break}}else{l=726}}while(0);if((l|0)==726){c[194192]=0;q=d[130616+o|0]|0;r=0;l=727}if((l|0)==727){k=q+3|0;if(p){s=r;t=k;l=728}else{u=k;l=734}}do{if((l|0)==728){if((s&1|0)==0){if(s>>>0<=255){u=t;l=734;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==734){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oT(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h-i|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(h|0)==(i|0)|0;g=h>>>31;h=i>>>31;i=h^1;j=g&i;k=f^1;a[768232]=(k&j|(g^1)&h&f)&255;a[768256]=(k&g|j|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=753;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=753}}while(0);if((l|0)==753){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=765;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=766;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=767;break}}else{l=765}}while(0);if((l|0)==765){c[194192]=0;q=d[130616+o|0]|0;r=0;l=766}if((l|0)==766){k=q+4|0;if(p){s=r;t=k;l=767}else{u=k;l=773}}do{if((l|0)==767){if((s&1|0)==0){if(s>>>0<=255){u=t;l=773;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==773){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oU(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]>>((g|0)==0?31:g);g=c[776584+((b>>>16&15)<<2)>>2]|0;i=g-h|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(g|0)==(h|0)|0;i=g>>>31;g=h>>>31;h=g^1;j=h&i;k=f^1;a[768232]=(j&k|(i^1)&g&f)&255;a[768256]=(k&i|j|k&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=788;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=788}}while(0);if((l|0)==788){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=800;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=801;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=3;l=802;break}}else{l=800}}while(0);if((l|0)==800){c[194192]=0;q=d[130616+o|0]|0;r=0;l=801}if((l|0)==801){k=q+3|0;if(p){s=r;t=k;l=802}else{u=k;l=808}}do{if((l|0)==802){if((s&1|0)==0){if(s>>>0<=255){u=t;l=808;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==808){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oV(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h-j|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(h|0)==(j|0)|0;g=h>>>31;h=j>>>31;j=h^1;i=g&j;k=f^1;a[768232]=(k&i|(g^1)&h&f)&255;a[768256]=(k&g|i|k&j)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=827;break}c[194192]=0;m=d[130616+b|0]|0;break}k=j&255;if((j&2|0)==0){c[194192]=k>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|j&-256;m=0;break}}else{l=827}}while(0);if((l|0)==827){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=j>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=j>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=839;break}j=b&255;if((b&2|0)==0){k=j>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=840;break}else{k=j>>>2|b&-256;c[194192]=k;s=k;t=4;l=841;break}}else{l=839}}while(0);if((l|0)==839){c[194192]=0;q=d[130616+o|0]|0;r=0;l=840}if((l|0)==840){k=q+4|0;if(p){s=r;t=k;l=841}else{u=k;l=847}}do{if((l|0)==841){if((s&1|0)==0){if(s>>>0<=255){u=t;l=847;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==847){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oW(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(d[768256]|0)<<31|h>>>1}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g-i|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(g|0)==(i|0)|0;h=g>>>31;g=i>>>31;i=g^1;j=h&i;k=f^1;a[768232]=(k&j|(h^1)&g&f)&255;a[768256]=(k&h|j|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=865;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=865}}while(0);if((l|0)==865){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=877;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=878;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=3;l=879;break}}else{l=877}}while(0);if((l|0)==877){c[194192]=0;q=d[130616+o|0]|0;r=0;l=878}if((l|0)==878){k=q+3|0;if(p){s=r;t=k;l=879}else{u=k;l=885}}do{if((l|0)==879){if((s&1|0)==0){if(s>>>0<=255){u=t;l=885;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==885){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oX(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=d[776584+((b>>>8&15)<<2)|0]|0;h=c[776584+((b&15)<<2)>>2]|0;if((g&31|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g-i|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(g|0)==(i|0)|0;h=g>>>31;g=i>>>31;i=g^1;j=h&i;k=f^1;a[768232]=(k&j|(h^1)&g&f)&255;a[768256]=(k&h|j|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=902;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=902}}while(0);if((l|0)==902){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=914;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=915;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=916;break}}else{l=914}}while(0);if((l|0)==914){c[194192]=0;q=d[130616+o|0]|0;r=0;l=915}if((l|0)==915){k=q+4|0;if(p){s=r;t=k;l=916}else{u=k;l=922}}do{if((l|0)==916){if((s&1|0)==0){if(s>>>0<=255){u=t;l=922;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==922){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function oY(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=ki(h)|0;if((e|0)!=(f|0)){c[g>>2]=h-(b>>>4&240|b&15)}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24&15;b=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function oZ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=(n0(h)|0)<<24>>24;if((e|0)!=(f|0)){c[g>>2]=h-(b>>>4&240|b&15)}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24&15;b=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function o_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;i=ki(h)|0;if((h&1|0)==0){j=i&65535}else{j=(i&255)<<24>>24}c[776584+(e<<2)>>2]=j<<16>>16;if((e|0)!=(f|0)){c[g>>2]=h-(b>>>4&240|b&15)}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24&15;b=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;k=e+5|0;l=g;m=f}else{f=h>>>24&15;k=3;l=f;m=f-2|0}f=d[147072+l|0]|0;do{if(m>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);m=(c[194193]|0)>>>24&15;do{if((m-8|0)>>>0<6){l=c[194192]|0;if((l&1|0)==0){break}h=l&255;if((l&2|0)==0){c[194192]=h>>>1|l&-256;n=(d[130328+m|0]|0)-1|0;o=k+f|0;p=o+n|0;c[204526]=p;return}else{c[194192]=h>>>2|l&-256;n=0;o=k+f|0;p=o+n|0;c[204526]=p;return}}}while(0);c[194192]=0;n=d[130616+m|0]|0;o=k+f|0;p=o+n|0;c[204526]=p;return}function o$(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))-(c[776584+((b>>>16&15)<<2)>>2]|0);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=1012;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=1012}}while(0);if((g|0)==1012){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=1022;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=1023;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=1024;break}}else{g=1022}}while(0);if((g|0)==1022){c[194192]=0;m=d[130616+k|0]|0;n=0;g=1023}if((g|0)==1023){i=m+3|0;if(l){o=n;p=i;g=1024}else{q=i;g=1030}}do{if((g|0)==1024){if((o&1|0)==0){if(o>>>0<=255){q=p;g=1030;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==1030){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function o0(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=i-(c[776584+((b>>>16&15)<<2)>>2]|0);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=1047;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=1047}}while(0);if((j|0)==1047){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=1057;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=1058;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=1059;break}}else{j=1057}}while(0);if((j|0)==1057){c[194192]=0;o=d[130616+m|0]|0;p=0;j=1058}if((j|0)==1058){f=o+4|0;if(n){q=p;r=f;j=1059}else{s=f;j=1065}}do{if((j|0)==1059){if((q&1|0)==0){if(q>>>0<=255){s=r;j=1065;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==1065){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function o1(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=g-(c[776584+((b>>>16&15)<<2)>>2]|0);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=1080;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=1080}}while(0);if((h|0)==1080){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=1090;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=1091;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=1092;break}}else{h=1090}}while(0);if((h|0)==1090){c[194192]=0;m=d[130616+k|0]|0;n=0;h=1091}if((h|0)==1091){f=m+3|0;if(l){o=n;p=f;h=1092}else{q=f;h=1098}}do{if((h|0)==1092){if((o&1|0)==0){if(o>>>0<=255){q=p;h=1098;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==1098){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function o2(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=i-(c[776584+((b>>>16&15)<<2)>>2]|0);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=1115;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=1115}}while(0);if((j|0)==1115){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=1125;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=1126;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=1127;break}}else{j=1125}}while(0);if((j|0)==1125){c[194192]=0;o=d[130616+m|0]|0;p=0;j=1126}if((j|0)==1126){f=o+4|0;if(n){q=p;r=f;j=1127}else{s=f;j=1133}}do{if((j|0)==1127){if((q&1|0)==0){if(q>>>0<=255){s=r;j=1133;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==1133){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function o3(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f))-(c[776584+((b>>>16&15)<<2)>>2]|0);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=1146;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=1146}}while(0);if((g|0)==1146){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=1156;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=1157;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=1158;break}}else{g=1156}}while(0);if((g|0)==1156){c[194192]=0;m=d[130616+k|0]|0;n=0;g=1157}if((g|0)==1157){i=m+3|0;if(l){o=n;p=i;g=1158}else{q=i;g=1164}}do{if((g|0)==1158){if((o&1|0)==0){if(o>>>0<=255){q=p;g=1164;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==1164){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function o4(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=j-(c[776584+((b>>>16&15)<<2)>>2]|0);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=1181;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=1181}}while(0);if((k|0)==1181){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1191;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=1192;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=1193;break}}else{k=1191}}while(0);if((k|0)==1191){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1192}if((k|0)==1192){f=p+4|0;if(o){r=q;s=f;k=1193}else{t=f;k=1199}}do{if((k|0)==1193){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1199;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1199){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function o5(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=h-(c[776584+((b>>>16&15)<<2)>>2]|0);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=1215;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=1215}}while(0);if((i|0)==1215){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=1225;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=1226;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=1227;break}}else{i=1225}}while(0);if((i|0)==1225){c[194192]=0;n=d[130616+l|0]|0;o=0;i=1226}if((i|0)==1226){f=n+3|0;if(m){p=o;q=f;i=1227}else{r=f;i=1233}}do{if((i|0)==1227){if((p&1|0)==0){if(p>>>0<=255){r=q;i=1233;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==1233){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function o6(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=h-(c[776584+((b>>>16&15)<<2)>>2]|0);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=1248;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=1248}}while(0);if((i|0)==1248){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=1258;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=1259;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=1260;break}}else{i=1258}}while(0);if((i|0)==1258){c[194192]=0;n=d[130616+l|0]|0;o=0;i=1259}if((i|0)==1259){f=n+4|0;if(m){p=o;q=f;i=1260}else{r=f;i=1266}}do{if((i|0)==1260){if((p&1|0)==0){if(p>>>0<=255){r=q;i=1266;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==1266){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function o7(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);h=c[776584+((b>>>16&15)<<2)>>2]|0;i=g-h|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(g|0)==(h|0)|0;i=h>>>31;h=g>>>31;g=h^1;j=g&i;k=f^1;a[768232]=(j&k|(i^1)&h&f)&255;a[768256]=(k&i|j|k&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){l=1281;break}c[194192]=0;m=d[130616+b|0]|0;break}k=g&255;if((g&2|0)==0){c[194192]=k>>>1|g&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|g&-256;m=0;break}}else{l=1281}}while(0);if((l|0)==1281){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;g=b+2|0;c[194161]=g;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=g>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>1]|0;p=b}else{b=m&-4;c[194193]=b;g=b+4|0;c[194161]=g;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=g>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=1293;break}g=b&255;if((b&2|0)==0){k=g>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=1294;break}else{k=g>>>2|b&-256;c[194192]=k;s=k;t=3;l=1295;break}}else{l=1293}}while(0);if((l|0)==1293){c[194192]=0;q=d[130616+o|0]|0;r=0;l=1294}if((l|0)==1294){k=q+3|0;if(p){s=r;t=k;l=1295}else{u=k;l=1301}}do{if((l|0)==1295){if((s&1|0)==0){if(s>>>0<=255){u=t;l=1301;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==1301){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function o8(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=i-h|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(i|0)==(h|0)|0;g=h>>>31;h=i>>>31;i=h^1;j=g&i;k=f^1;a[768232]=(k&j|(g^1)&h&f)&255;a[768256]=(k&g|j|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=1320;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=1320}}while(0);if((l|0)==1320){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=1332;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=1333;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=1334;break}}else{l=1332}}while(0);if((l|0)==1332){c[194192]=0;q=d[130616+o|0]|0;r=0;l=1333}if((l|0)==1333){k=q+4|0;if(p){s=r;t=k;l=1334}else{u=k;l=1340}}do{if((l|0)==1334){if((s&1|0)==0){if(s>>>0<=255){u=t;l=1340;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==1340){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function o9(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;i=h-g|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(h|0)==(g|0)|0;i=g>>>31;g=h>>>31;h=g^1;j=i&h;k=f^1;a[768232]=(k&j|(i^1)&g&f)&255;a[768256]=(k&i|j|k&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=1357;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=1357}}while(0);if((l|0)==1357){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=1369;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=1370;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=3;l=1371;break}}else{l=1369}}while(0);if((l|0)==1369){c[194192]=0;q=d[130616+o|0]|0;r=0;l=1370}if((l|0)==1370){k=q+3|0;if(p){s=r;t=k;l=1371}else{u=k;l=1377}}do{if((l|0)==1371){if((s&1|0)==0){if(s>>>0<=255){u=t;l=1377;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==1377){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function pa(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=i-h|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(i|0)==(h|0)|0;g=h>>>31;h=i>>>31;i=h^1;j=g&i;k=f^1;a[768232]=(k&j|(g^1)&h&f)&255;a[768256]=(k&g|j|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=1396;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=1396}}while(0);if((l|0)==1396){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=1408;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=1409;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=1410;break}}else{l=1408}}while(0);if((l|0)==1408){c[194192]=0;q=d[130616+o|0]|0;r=0;l=1409}if((l|0)==1409){k=q+4|0;if(p){s=r;t=k;l=1410}else{u=k;l=1416}}do{if((l|0)==1410){if((s&1|0)==0){if(s>>>0<=255){u=t;l=1416;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==1416){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function pb(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]>>((g|0)==0?31:g);g=c[776584+((b>>>16&15)<<2)>>2]|0;i=h-g|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(h|0)==(g|0)|0;i=g>>>31;g=h>>>31;h=g^1;j=h&i;k=f^1;a[768232]=(j&k|(i^1)&g&f)&255;a[768256]=(k&i|j|k&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=1431;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=1431}}while(0);if((l|0)==1431){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=1443;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=1444;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=3;l=1445;break}}else{l=1443}}while(0);if((l|0)==1443){c[194192]=0;q=d[130616+o|0]|0;r=0;l=1444}if((l|0)==1444){k=q+3|0;if(p){s=r;t=k;l=1445}else{u=k;l=1451}}do{if((l|0)==1445){if((s&1|0)==0){if(s>>>0<=255){u=t;l=1451;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==1451){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function pc(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=j-h|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(j|0)==(h|0)|0;g=h>>>31;h=j>>>31;j=h^1;i=g&j;k=f^1;a[768232]=(k&i|(g^1)&h&f)&255;a[768256]=(k&g|i|k&j)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=1470;break}c[194192]=0;m=d[130616+b|0]|0;break}k=j&255;if((j&2|0)==0){c[194192]=k>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|j&-256;m=0;break}}else{l=1470}}while(0);if((l|0)==1470){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=j>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=j>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=1482;break}j=b&255;if((b&2|0)==0){k=j>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=1483;break}else{k=j>>>2|b&-256;c[194192]=k;s=k;t=4;l=1484;break}}else{l=1482}}while(0);if((l|0)==1482){c[194192]=0;q=d[130616+o|0]|0;r=0;l=1483}if((l|0)==1483){k=q+4|0;if(p){s=r;t=k;l=1484}else{u=k;l=1490}}do{if((l|0)==1484){if((s&1|0)==0){if(s>>>0<=255){u=t;l=1490;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==1490){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function pd(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(d[768256]|0)<<31|h>>>1}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=i-g|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(i|0)==(g|0)|0;h=g>>>31;g=i>>>31;i=g^1;j=h&i;k=f^1;a[768232]=(k&j|(h^1)&g&f)&255;a[768256]=(k&h|j|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=1508;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=1508}}while(0);if((l|0)==1508){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=1520;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=1521;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=3;l=1522;break}}else{l=1520}}while(0);if((l|0)==1520){c[194192]=0;q=d[130616+o|0]|0;r=0;l=1521}if((l|0)==1521){k=q+3|0;if(p){s=r;t=k;l=1522}else{u=k;l=1528}}do{if((l|0)==1522){if((s&1|0)==0){if(s>>>0<=255){u=t;l=1528;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==1528){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function pe(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]<<(b>>>7&31));if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=1541;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=1541}}while(0);if((g|0)==1541){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=1551;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=1552;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=1553;break}}else{g=1551}}while(0);if((g|0)==1551){c[194192]=0;m=d[130616+k|0]|0;n=0;g=1552}if((g|0)==1552){i=m+3|0;if(l){o=n;p=i;g=1553}else{q=i;g=1559}}do{if((g|0)==1553){if((o&1|0)==0){if(o>>>0<=255){q=p;g=1559;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==1559){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function pf(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=1576;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=1576}}while(0);if((j|0)==1576){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=1586;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=1587;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=1588;break}}else{j=1586}}while(0);if((j|0)==1586){c[194192]=0;o=d[130616+m|0]|0;p=0;j=1587}if((j|0)==1587){f=o+4|0;if(n){q=p;r=f;j=1588}else{s=f;j=1594}}do{if((j|0)==1588){if((q&1|0)==0){if(q>>>0<=255){s=r;j=1594;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==1594){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function pg(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=d[776584+((b>>>8&15)<<2)|0]|0;h=c[776584+((b&15)<<2)>>2]|0;if((g&31|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=i-g|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(i|0)==(g|0)|0;h=g>>>31;g=i>>>31;i=g^1;j=h&i;k=f^1;a[768232]=(k&j|(h^1)&g&f)&255;a[768256]=(k&h|j|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=1611;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=1611}}while(0);if((l|0)==1611){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=1623;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=1624;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=1625;break}}else{l=1623}}while(0);if((l|0)==1623){c[194192]=0;q=d[130616+o|0]|0;r=0;l=1624}if((l|0)==1624){k=q+4|0;if(p){s=r;t=k;l=1625}else{u=k;l=1631}}do{if((l|0)==1625){if((s&1|0)==0){if(s>>>0<=255){u=t;l=1631;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==1631){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function ph(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+g;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=1646;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=1646}}while(0);if((h|0)==1646){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=1656;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=1657;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=1658;break}}else{h=1656}}while(0);if((h|0)==1656){c[194192]=0;m=d[130616+k|0]|0;n=0;h=1657}if((h|0)==1657){f=m+3|0;if(l){o=n;p=f;h=1658}else{q=f;h=1664}}do{if((h|0)==1658){if((o&1|0)==0){if(o>>>0<=255){q=p;h=1664;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==1664){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function pi(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=1681;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=1681}}while(0);if((j|0)==1681){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=1691;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=1692;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=1693;break}}else{j=1691}}while(0);if((j|0)==1691){c[194192]=0;o=d[130616+m|0]|0;p=0;j=1692}if((j|0)==1692){f=o+4|0;if(n){q=p;r=f;j=1693}else{s=f;j=1699}}do{if((j|0)==1693){if((q&1|0)==0){if(q>>>0<=255){s=r;j=1699;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==1699){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function pj(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f));if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=1712;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=1712}}while(0);if((g|0)==1712){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=1722;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=1723;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=1724;break}}else{g=1722}}while(0);if((g|0)==1722){c[194192]=0;m=d[130616+k|0]|0;n=0;g=1723}if((g|0)==1723){i=m+3|0;if(l){o=n;p=i;g=1724}else{q=i;g=1730}}do{if((g|0)==1724){if((o&1|0)==0){if(o>>>0<=255){q=p;g=1730;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==1730){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function pk(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+j;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=1747;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=1747}}while(0);if((k|0)==1747){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1757;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=1758;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=1759;break}}else{k=1757}}while(0);if((k|0)==1757){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1758}if((k|0)==1758){f=p+4|0;if(o){r=q;s=f;k=1759}else{t=f;k=1765}}do{if((k|0)==1759){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1765;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1765){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pl(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=1781;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=1781}}while(0);if((i|0)==1781){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=1791;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=1792;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=1793;break}}else{i=1791}}while(0);if((i|0)==1791){c[194192]=0;n=d[130616+l|0]|0;o=0;i=1792}if((i|0)==1792){f=n+3|0;if(m){p=o;q=f;i=1793}else{r=f;i=1799}}do{if((i|0)==1793){if((p&1|0)==0){if(p>>>0<=255){r=q;i=1799;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==1799){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function pm(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=1814;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=1814}}while(0);if((i|0)==1814){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=1824;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=1825;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=1826;break}}else{i=1824}}while(0);if((i|0)==1824){c[194192]=0;n=d[130616+l|0]|0;o=0;i=1825}if((i|0)==1825){f=n+4|0;if(m){p=o;q=f;i=1826}else{r=f;i=1832}}do{if((i|0)==1826){if((p&1|0)==0){if(p>>>0<=255){r=q;i=1832;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==1832){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function pn(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[776584+((a>>>8&15)<<2)>>2]|0;e=wm(c[776584+((a&15)<<2)>>2]|0,0,b,0)|0;c[776584+((a>>>12&15)<<2)>>2]=e;c[776584+((a>>>16&15)<<2)>>2]=G;a=b>>31^b;do{if(a>>>0<65536){b=(c[204526]|0)+1|0;c[204526]=b;f=b}else{b=c[204526]|0;if(a>>>0<16777216){e=b+2|0;c[204526]=e;f=e;break}else{e=b+3|0;c[204526]=e;f=e;break}}}while(0);a=c[194192]|0;if((a|0)==0){e=(1<<f)-1|0;c[194192]=e;g=e}else{g=a}a=(c[194193]|0)>>>24&15;do{if((a-8|0)>>>0<6){if((g&1|0)==0){break}e=g&255;if((g&2|0)==0){c[194192]=e>>>1|g&-256;h=(d[130328+a|0]|0)-1|0;i=f+1|0;j=i+h|0;c[204526]=j;return}else{c[194192]=e>>>2|g&-256;h=0;i=f+1|0;j=i+h|0;c[204526]=j;return}}}while(0);c[194192]=0;h=d[130616+a|0]|0;i=f+1|0;j=i+h|0;c[204526]=j;return}function po(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=c[776584+((e&15)<<2)>>2]|0;g=776584+((e>>>16&15)<<2)|0;h=c[g>>2]|0;kh(h,b[776584+((e>>>12&15)<<2)>>1]|0);c[g>>2]=h+f;f=h>>>24&15;h=d[147072+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);f=h+2|0;h=(c[194193]|0)>>>24&15;do{if((h-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}e=g&255;if((g&2|0)==0){c[194192]=e>>>1|g&-256;i=(d[130328+h|0]|0)-1|0;j=f+i|0;c[204526]=j;return}else{c[194192]=e>>>2|g&-256;i=0;j=f+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+h|0]|0;j=f+i|0;c[204526]=j;return}function pp(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);h=c[776584+((b>>>16&15)<<2)>>2]|0;i=h+g|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(i|0)==0|0;i=h>>>31;h=g>>>31;g=i&h;j=f^1;a[768232]=(j&g|(i^1)&(h^1)&f)&255;a[768256]=(j&i|g|j&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=1880;break}c[194192]=0;l=d[130616+b|0]|0;break}j=h&255;if((h&2|0)==0){c[194192]=j>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|h&-256;l=0;break}}else{k=1880}}while(0);if((k|0)==1880){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=h>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=h>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1892;break}h=b&255;if((b&2|0)==0){j=h>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=1893;break}else{j=h>>>2|b&-256;c[194192]=j;r=j;s=3;k=1894;break}}else{k=1892}}while(0);if((k|0)==1892){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1893}if((k|0)==1893){j=p+3|0;if(o){r=q;s=j;k=1894}else{t=j;k=1900}}do{if((k|0)==1894){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1900;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1900){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pq(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h+i|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(g|0)==0|0;g=h>>>31;h=i>>>31;i=g&h;j=f^1;a[768232]=(j&i|(g^1)&(h^1)&f)&255;a[768256]=(j&g|i|j&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=1919;break}c[194192]=0;l=d[130616+b|0]|0;break}j=h&255;if((h&2|0)==0){c[194192]=j>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|h&-256;l=0;break}}else{k=1919}}while(0);if((k|0)==1919){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=h>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=h>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1931;break}h=b&255;if((b&2|0)==0){j=h>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=1932;break}else{j=h>>>2|b&-256;c[194192]=j;r=j;s=4;k=1933;break}}else{k=1931}}while(0);if((k|0)==1931){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1932}if((k|0)==1932){j=p+4|0;if(o){r=q;s=j;k=1933}else{t=j;k=1939}}do{if((k|0)==1933){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1939;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1939){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pr(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;i=g+h|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(i|0)==0|0;i=g>>>31;g=h>>>31;h=i&g;j=f^1;a[768232]=(j&h|(i^1)&(g^1)&f)&255;a[768256]=(j&i|h|j&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=1956;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=1956}}while(0);if((k|0)==1956){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1968;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=1969;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=3;k=1970;break}}else{k=1968}}while(0);if((k|0)==1968){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1969}if((k|0)==1969){j=p+3|0;if(o){r=q;s=j;k=1970}else{t=j;k=1976}}do{if((k|0)==1970){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1976;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1976){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function ps(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h+i|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(g|0)==0|0;g=h>>>31;h=i>>>31;i=g&h;j=f^1;a[768232]=(j&i|(g^1)&(h^1)&f)&255;a[768256]=(j&g|i|j&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=1995;break}c[194192]=0;l=d[130616+b|0]|0;break}j=h&255;if((h&2|0)==0){c[194192]=j>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|h&-256;l=0;break}}else{k=1995}}while(0);if((k|0)==1995){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=h>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=h>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2007;break}h=b&255;if((b&2|0)==0){j=h>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=2008;break}else{j=h>>>2|b&-256;c[194192]=j;r=j;s=4;k=2009;break}}else{k=2007}}while(0);if((k|0)==2007){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2008}if((k|0)==2008){j=p+4|0;if(o){r=q;s=j;k=2009}else{t=j;k=2015}}do{if((k|0)==2009){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2015;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2015){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pt(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]>>((g|0)==0?31:g);g=c[776584+((b>>>16&15)<<2)>>2]|0;i=g+h|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(i|0)==0|0;i=g>>>31;g=h>>>31;h=i&g;j=f^1;a[768232]=(j&h|(i^1)&(g^1)&f)&255;a[768256]=(j&i|h|j&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=2030;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=2030}}while(0);if((k|0)==2030){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2042;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=2043;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=3;k=2044;break}}else{k=2042}}while(0);if((k|0)==2042){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2043}if((k|0)==2043){j=p+3|0;if(o){r=q;s=j;k=2044}else{t=j;k=2050}}do{if((k|0)==2044){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2050;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2050){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pu(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h+j|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(g|0)==0|0;g=h>>>31;h=j>>>31;j=g&h;i=f^1;a[768232]=(i&j|(g^1)&(h^1)&f)&255;a[768256]=(i&g|j|i&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=2069;break}c[194192]=0;l=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;l=0;break}}else{k=2069}}while(0);if((k|0)==2069){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2081;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=2082;break}else{i=h>>>2|b&-256;c[194192]=i;r=i;s=4;k=2083;break}}else{k=2081}}while(0);if((k|0)==2081){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2082}if((k|0)==2082){i=p+4|0;if(o){r=q;s=i;k=2083}else{t=i;k=2089}}do{if((k|0)==2083){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2089;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2089){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pv(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(d[768256]|0)<<31|h>>>1}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g+i|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(h|0)==0|0;h=g>>>31;g=i>>>31;i=h&g;j=f^1;a[768232]=(j&i|(h^1)&(g^1)&f)&255;a[768256]=(j&h|i|j&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=2107;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=2107}}while(0);if((k|0)==2107){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2119;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=2120;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=3;k=2121;break}}else{k=2119}}while(0);if((k|0)==2119){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2120}if((k|0)==2120){j=p+3|0;if(o){r=q;s=j;k=2121}else{t=j;k=2127}}do{if((k|0)==2121){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2127;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2127){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pw(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=d[776584+((b>>>8&15)<<2)|0]|0;h=c[776584+((b&15)<<2)>>2]|0;if((g&31|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g+i|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(h|0)==0|0;h=g>>>31;g=i>>>31;i=h&g;j=f^1;a[768232]=(j&i|(h^1)&(g^1)&f)&255;a[768256]=(j&h|i|j&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=2144;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=2144}}while(0);if((k|0)==2144){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2156;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=2157;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=4;k=2158;break}}else{k=2156}}while(0);if((k|0)==2156){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2157}if((k|0)==2157){j=p+4|0;if(o){r=q;s=j;k=2158}else{t=j;k=2164}}do{if((k|0)==2158){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2164;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2164){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}
function px(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[776584+((b>>>8&15)<<2)>>2]|0;f=wm(c[776584+((b&15)<<2)>>2]|0,0,e,0)|0;g=G;h=776584+((b>>>12&15)<<2)|0;c[h>>2]=f;f=g;c[776584+((b>>>16&15)<<2)>>2]=f;a[768240]=(g>>>31|0<<1)&255;if((f|0)==0){i=(c[h>>2]|0)==0|0}else{i=0}a[768224]=i;i=e>>31^e;do{if(i>>>0<65536){e=(c[204526]|0)+1|0;c[204526]=e;j=e}else{e=c[204526]|0;if(i>>>0<16777216){h=e+2|0;c[204526]=h;j=h;break}else{h=e+3|0;c[204526]=h;j=h;break}}}while(0);i=c[194192]|0;if((i|0)==0){h=(1<<j)-1|0;c[194192]=h;k=h}else{k=i}i=(c[194193]|0)>>>24&15;do{if((i-8|0)>>>0<6){if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;l=(d[130328+i|0]|0)-1|0;m=j+1|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|k&-256;l=0;m=j+1|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+i|0]|0;m=j+1|0;n=m+l|0;c[204526]=n;return}function py(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))+(a[768256]&1);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=2196;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=2196}}while(0);if((g|0)==2196){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=2206;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=2207;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=2208;break}}else{g=2206}}while(0);if((g|0)==2206){c[194192]=0;m=d[130616+k|0]|0;n=0;g=2207}if((g|0)==2207){i=m+3|0;if(l){o=n;p=i;g=2208}else{q=i;g=2214}}do{if((g|0)==2208){if((o&1|0)==0){if(o>>>0<=255){q=p;g=2214;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==2214){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function pz(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=c[776584+((b&15)<<2)>>2]|0;b=776584+(f<<2)|0;h=c[b>>2]|0;c[776584+(e<<2)>>2]=ki(h)|0;if((e|0)!=(f|0)){c[b>>2]=h+g}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=h>>>24&15;g=d[125296+b|0]|0;f=b-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function pA(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=c[776584+((b&15)<<2)>>2]|0;b=776584+(f<<2)|0;h=c[b>>2]|0;c[776584+(e<<2)>>2]=(n0(h)|0)<<24>>24;if((e|0)!=(f|0)){c[b>>2]=h+g}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=h>>>24&15;g=d[125296+b|0]|0;f=b-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function pB(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=c[776584+((b&15)<<2)>>2]|0;b=776584+(f<<2)|0;h=c[b>>2]|0;i=ki(h)|0;if((h&1|0)==0){j=i&65535}else{j=(i&255)<<24>>24}c[776584+(e<<2)>>2]=j<<16>>16;if((e|0)!=(f|0)){c[b>>2]=h+g}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=h>>>24&15;g=d[125296+b|0]|0;f=b-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;k=e+5|0;l=b;m=f}else{f=h>>>24&15;k=3;l=f;m=f-2|0}f=d[147072+l|0]|0;do{if(m>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);m=(c[194193]|0)>>>24&15;do{if((m-8|0)>>>0<6){l=c[194192]|0;if((l&1|0)==0){break}h=l&255;if((l&2|0)==0){c[194192]=h>>>1|l&-256;n=(d[130328+m|0]|0)-1|0;o=k+f|0;p=o+n|0;c[204526]=p;return}else{c[194192]=h>>>2|l&-256;n=0;o=k+f|0;p=o+n|0;c[204526]=p;return}}}while(0);c[194192]=0;n=d[130616+m|0]|0;o=k+f|0;p=o+n|0;c[204526]=p;return}function pC(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+i+(a[768256]&1);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=2308;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=2308}}while(0);if((j|0)==2308){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=2318;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=2319;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=2320;break}}else{j=2318}}while(0);if((j|0)==2318){c[194192]=0;o=d[130616+m|0]|0;p=0;j=2319}if((j|0)==2319){f=o+4|0;if(n){q=p;r=f;j=2320}else{s=f;j=2326}}do{if((j|0)==2320){if((q&1|0)==0){if(q>>>0<=255){s=r;j=2326;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==2326){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function pD(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+g+(a[768256]&1);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=2341;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=2341}}while(0);if((h|0)==2341){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=2351;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=2352;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=2353;break}}else{h=2351}}while(0);if((h|0)==2351){c[194192]=0;m=d[130616+k|0]|0;n=0;h=2352}if((h|0)==2352){f=m+3|0;if(l){o=n;p=f;h=2353}else{q=f;h=2359}}do{if((h|0)==2353){if((o&1|0)==0){if(o>>>0<=255){q=p;h=2359;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==2359){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function pE(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+i+(a[768256]&1);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=2376;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=2376}}while(0);if((j|0)==2376){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=2386;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=2387;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=2388;break}}else{j=2386}}while(0);if((j|0)==2386){c[194192]=0;o=d[130616+m|0]|0;p=0;j=2387}if((j|0)==2387){f=o+4|0;if(n){q=p;r=f;j=2388}else{s=f;j=2394}}do{if((j|0)==2388){if((q&1|0)==0){if(q>>>0<=255){s=r;j=2394;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==2394){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function pF(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f))+(a[768256]&1);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=2407;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=2407}}while(0);if((g|0)==2407){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=2417;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=2418;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=2419;break}}else{g=2417}}while(0);if((g|0)==2417){c[194192]=0;m=d[130616+k|0]|0;n=0;g=2418}if((g|0)==2418){i=m+3|0;if(l){o=n;p=i;g=2419}else{q=i;g=2425}}do{if((g|0)==2419){if((o&1|0)==0){if(o>>>0<=255){q=p;g=2425;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==2425){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function pG(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+j+(a[768256]&1);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=2442;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=2442}}while(0);if((k|0)==2442){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2452;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=2453;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=2454;break}}else{k=2452}}while(0);if((k|0)==2452){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2453}if((k|0)==2453){f=p+4|0;if(o){r=q;s=f;k=2454}else{t=f;k=2460}}do{if((k|0)==2454){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2460;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2460){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pH(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=a[768256]|0;i=(h&255)<<31|g>>>1;j=h}else{i=g<<32-f|g>>>(f>>>0);j=a[768256]|0}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+i+(j&1);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=2476;break}c[194192]=0;l=d[130616+b|0]|0;break}i=j&255;if((j&2|0)==0){c[194192]=i>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|j&-256;l=0;break}}else{k=2476}}while(0);if((k|0)==2476){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=j>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=j>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2486;break}j=b&255;if((b&2|0)==0){i=j>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=2487;break}else{i=j>>>2|b&-256;c[194192]=i;r=i;s=3;k=2488;break}}else{k=2486}}while(0);if((k|0)==2486){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2487}if((k|0)==2487){i=p+3|0;if(o){r=q;s=i;k=2488}else{t=i;k=2494}}do{if((k|0)==2488){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2494;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2494){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pI(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+h+(a[768256]&1);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=2509;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=2509}}while(0);if((i|0)==2509){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=2519;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=2520;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=2521;break}}else{i=2519}}while(0);if((i|0)==2519){c[194192]=0;n=d[130616+l|0]|0;o=0;i=2520}if((i|0)==2520){f=n+4|0;if(m){p=o;q=f;i=2521}else{r=f;i=2527}}do{if((i|0)==2521){if((p&1|0)==0){if(p>>>0<=255){r=q;i=2527;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==2527){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function pJ(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[776584+((a>>>8&15)<<2)>>2]|0;e=776584+((a>>>16&15)<<2)|0;f=776584+((a>>>12&15)<<2)|0;g=c[f>>2]|0;h=c[e>>2]|0;i=wm(c[776584+((a&15)<<2)>>2]|0,0,b,0)|0;a=wc(i,G,g,h)|0;c[f>>2]=a;c[e>>2]=G;e=b>>31^b;do{if(e>>>0<65536){b=(c[204526]|0)+1|0;c[204526]=b;j=b}else{b=c[204526]|0;if(e>>>0<16777216){a=b+2|0;c[204526]=a;j=a;break}else{a=b+3|0;c[204526]=a;j=a;break}}}while(0);e=c[194192]|0;if((e|0)==0){a=(1<<j)-1|0;c[194192]=a;k=a}else{k=e}e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){if((k&1|0)==0){break}a=k&255;if((k&2|0)==0){c[194192]=a>>>1|k&-256;l=(d[130328+e|0]|0)-1|0;m=j+1|0;n=m+l|0;c[204526]=n;return}else{c[194192]=a>>>2|k&-256;l=0;m=j+1|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+e|0]|0;m=j+1|0;n=m+l|0;c[204526]=n;return}function pK(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);h=c[776584+((b>>>16&15)<<2)>>2]|0;i=h+g+(a[768256]&1)|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(i|0)==0|0;i=h>>>31;h=g>>>31;g=i&h;j=f^1;a[768232]=(j&g|(i^1)&(h^1)&f)&255;a[768256]=(j&i|g|j&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=2559;break}c[194192]=0;l=d[130616+b|0]|0;break}j=h&255;if((h&2|0)==0){c[194192]=j>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|h&-256;l=0;break}}else{k=2559}}while(0);if((k|0)==2559){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=h>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=h>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2571;break}h=b&255;if((b&2|0)==0){j=h>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=2572;break}else{j=h>>>2|b&-256;c[194192]=j;r=j;s=3;k=2573;break}}else{k=2571}}while(0);if((k|0)==2571){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2572}if((k|0)==2572){j=p+3|0;if(o){r=q;s=j;k=2573}else{t=j;k=2579}}do{if((k|0)==2573){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2579;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2579){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pL(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h+i+(a[768256]&1)|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(g|0)==0|0;g=h>>>31;h=i>>>31;i=g&h;j=f^1;a[768232]=(j&i|(g^1)&(h^1)&f)&255;a[768256]=(j&g|i|j&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=2598;break}c[194192]=0;l=d[130616+b|0]|0;break}j=h&255;if((h&2|0)==0){c[194192]=j>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|h&-256;l=0;break}}else{k=2598}}while(0);if((k|0)==2598){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=h>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=h>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2610;break}h=b&255;if((b&2|0)==0){j=h>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=2611;break}else{j=h>>>2|b&-256;c[194192]=j;r=j;s=4;k=2612;break}}else{k=2610}}while(0);if((k|0)==2610){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2611}if((k|0)==2611){j=p+4|0;if(o){r=q;s=j;k=2612}else{t=j;k=2618}}do{if((k|0)==2612){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2618;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2618){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pM(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;i=g+h+(a[768256]&1)|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(i|0)==0|0;i=g>>>31;g=h>>>31;h=i&g;j=f^1;a[768232]=(j&h|(i^1)&(g^1)&f)&255;a[768256]=(j&i|h|j&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=2635;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=2635}}while(0);if((k|0)==2635){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2647;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=2648;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=3;k=2649;break}}else{k=2647}}while(0);if((k|0)==2647){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2648}if((k|0)==2648){j=p+3|0;if(o){r=q;s=j;k=2649}else{t=j;k=2655}}do{if((k|0)==2649){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2655;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2655){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pN(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h+i+(a[768256]&1)|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(g|0)==0|0;g=h>>>31;h=i>>>31;i=g&h;j=f^1;a[768232]=(j&i|(g^1)&(h^1)&f)&255;a[768256]=(j&g|i|j&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=2674;break}c[194192]=0;l=d[130616+b|0]|0;break}j=h&255;if((h&2|0)==0){c[194192]=j>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|h&-256;l=0;break}}else{k=2674}}while(0);if((k|0)==2674){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=h>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=h>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2686;break}h=b&255;if((b&2|0)==0){j=h>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=2687;break}else{j=h>>>2|b&-256;c[194192]=j;r=j;s=4;k=2688;break}}else{k=2686}}while(0);if((k|0)==2686){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2687}if((k|0)==2687){j=p+4|0;if(o){r=q;s=j;k=2688}else{t=j;k=2694}}do{if((k|0)==2688){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2694;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2694){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pO(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]>>((g|0)==0?31:g);g=c[776584+((b>>>16&15)<<2)>>2]|0;i=g+h+(a[768256]&1)|0;c[776584+(f<<2)>>2]=i;if((f|0)!=15){f=i>>>31;a[768240]=f&255;a[768224]=(i|0)==0|0;i=g>>>31;g=h>>>31;h=i&g;j=f^1;a[768232]=(j&h|(i^1)&(g^1)&f)&255;a[768256]=(j&i|h|j&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=2709;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=2709}}while(0);if((k|0)==2709){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2721;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=2722;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=3;k=2723;break}}else{k=2721}}while(0);if((k|0)==2721){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2722}if((k|0)==2722){j=p+3|0;if(o){r=q;s=j;k=2723}else{t=j;k=2729}}do{if((k|0)==2723){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2729;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2729){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pP(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h+j+(a[768256]&1)|0;c[776584+(f<<2)>>2]=g;if((f|0)!=15){f=g>>>31;a[768240]=f&255;a[768224]=(g|0)==0|0;g=h>>>31;h=j>>>31;j=g&h;i=f^1;a[768232]=(i&j|(g^1)&(h^1)&f)&255;a[768256]=(i&g|j|i&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=2748;break}c[194192]=0;l=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;l=0;break}}else{k=2748}}while(0);if((k|0)==2748){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2760;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=2761;break}else{i=h>>>2|b&-256;c[194192]=i;r=i;s=4;k=2762;break}}else{k=2760}}while(0);if((k|0)==2760){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2761}if((k|0)==2761){i=p+4|0;if(o){r=q;s=i;k=2762}else{t=i;k=2768}}do{if((k|0)==2762){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2768;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2768){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pQ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=a[768256]|0;j=(i&255)<<31|h>>>1;k=i}else{j=h<<32-g|h>>>(g>>>0);k=a[768256]|0}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g+j+(k&1)|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(h|0)==0|0;h=g>>>31;g=j>>>31;j=h&g;k=f^1;a[768232]=(k&j|(h^1)&(g^1)&f)&255;a[768256]=(k&h|j|k&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){l=2786;break}c[194192]=0;m=d[130616+b|0]|0;break}k=g&255;if((g&2|0)==0){c[194192]=k>>>1|g&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|g&-256;m=0;break}}else{l=2786}}while(0);if((l|0)==2786){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;g=b+2|0;c[194161]=g;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=g>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>1]|0;p=b}else{b=m&-4;c[194193]=b;g=b+4|0;c[194161]=g;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=g>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=2798;break}g=b&255;if((b&2|0)==0){k=g>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=2799;break}else{k=g>>>2|b&-256;c[194192]=k;s=k;t=3;l=2800;break}}else{l=2798}}while(0);if((l|0)==2798){c[194192]=0;q=d[130616+o|0]|0;r=0;l=2799}if((l|0)==2799){k=q+3|0;if(p){s=r;t=k;l=2800}else{u=k;l=2806}}do{if((l|0)==2800){if((s&1|0)==0){if(s>>>0<=255){u=t;l=2806;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==2806){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function pR(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[776584+((b>>>8&15)<<2)>>2]|0;f=776584+((b>>>16&15)<<2)|0;g=776584+((b>>>12&15)<<2)|0;h=c[g>>2]|0;i=c[f>>2]|0;j=wm(c[776584+((b&15)<<2)>>2]|0,0,e,0)|0;b=wc(j,G,h,i)|0;i=G;c[g>>2]=b;b=i;c[f>>2]=b;a[768240]=(i>>>31|0<<1)&255;if((b|0)==0){k=(c[g>>2]|0)==0|0}else{k=0}a[768224]=k;k=e>>31^e;do{if(k>>>0<65536){e=(c[204526]|0)+1|0;c[204526]=e;l=e}else{e=c[204526]|0;if(k>>>0<16777216){g=e+2|0;c[204526]=g;l=g;break}else{g=e+3|0;c[204526]=g;l=g;break}}}while(0);k=c[194192]|0;if((k|0)==0){g=(1<<l)-1|0;c[194192]=g;m=g}else{m=k}k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){if((m&1|0)==0){break}g=m&255;if((m&2|0)==0){c[194192]=g>>>1|m&-256;n=(d[130328+k|0]|0)-1|0;o=l+1|0;p=o+n|0;c[204526]=p;return}else{c[194192]=g>>>2|m&-256;n=0;o=l+1|0;p=o+n|0;c[204526]=p;return}}}while(0);c[194192]=0;n=d[130616+k|0]|0;o=l+1|0;p=o+n|0;c[204526]=p;return}function pS(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=2838;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=2838}}while(0);if((g|0)==2838){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=2848;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=2849;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=2850;break}}else{g=2848}}while(0);if((g|0)==2848){c[194192]=0;m=d[130616+k|0]|0;n=0;g=2849}if((g|0)==2849){i=m+3|0;if(l){o=n;p=i;g=2850}else{q=i;g=2856}}do{if((g|0)==2850){if((o&1|0)==0){if(o>>>0<=255){q=p;g=2856;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==2856){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function pT(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-i-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=2873;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=2873}}while(0);if((j|0)==2873){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=2883;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=2884;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=2885;break}}else{j=2883}}while(0);if((j|0)==2883){c[194192]=0;o=d[130616+m|0]|0;p=0;j=2884}if((j|0)==2884){f=o+4|0;if(n){q=p;r=f;j=2885}else{s=f;j=2891}}do{if((j|0)==2885){if((q&1|0)==0){if(q>>>0<=255){s=r;j=2891;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==2891){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function pU(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=d[776584+((b>>>8&15)<<2)|0]|0;h=c[776584+((b&15)<<2)>>2]|0;if((g&31|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g+i+(a[768256]&1)|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(h|0)==0|0;h=g>>>31;g=i>>>31;i=h&g;j=f^1;a[768232]=(j&i|(h^1)&(g^1)&f)&255;a[768256]=(j&h|i|j&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=2908;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=2908}}while(0);if((k|0)==2908){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=2920;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=2921;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=4;k=2922;break}}else{k=2920}}while(0);if((k|0)==2920){c[194192]=0;p=d[130616+n|0]|0;q=0;k=2921}if((k|0)==2921){j=p+4|0;if(o){r=q;s=j;k=2922}else{t=j;k=2928}}do{if((k|0)==2922){if((r&1|0)==0){if(r>>>0<=255){t=s;k=2928;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==2928){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pV(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-g-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=2943;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=2943}}while(0);if((h|0)==2943){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=2953;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=2954;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=2955;break}}else{h=2953}}while(0);if((h|0)==2953){c[194192]=0;m=d[130616+k|0]|0;n=0;h=2954}if((h|0)==2954){f=m+3|0;if(l){o=n;p=f;h=2955}else{q=f;h=2961}}do{if((h|0)==2955){if((o&1|0)==0){if(o>>>0<=255){q=p;h=2961;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==2961){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function pW(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-i-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=2978;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=2978}}while(0);if((j|0)==2978){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=2988;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=2989;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=2990;break}}else{j=2988}}while(0);if((j|0)==2988){c[194192]=0;o=d[130616+m|0]|0;p=0;j=2989}if((j|0)==2989){f=o+4|0;if(n){q=p;r=f;j=2990}else{s=f;j=2996}}do{if((j|0)==2990){if((q&1|0)==0){if(q>>>0<=255){s=r;j=2996;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==2996){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function pX(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f))-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=3009;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=3009}}while(0);if((g|0)==3009){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=3019;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=3020;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=3021;break}}else{g=3019}}while(0);if((g|0)==3019){c[194192]=0;m=d[130616+k|0]|0;n=0;g=3020}if((g|0)==3020){i=m+3|0;if(l){o=n;p=i;g=3021}else{q=i;g=3027}}do{if((g|0)==3021){if((o&1|0)==0){if(o>>>0<=255){q=p;g=3027;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==3027){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function pY(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-j-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=3044;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=3044}}while(0);if((k|0)==3044){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=3054;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=3055;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=3056;break}}else{k=3054}}while(0);if((k|0)==3054){c[194192]=0;p=d[130616+n|0]|0;q=0;k=3055}if((k|0)==3055){f=p+4|0;if(o){r=q;s=f;k=3056}else{t=f;k=3062}}do{if((k|0)==3056){if((r&1|0)==0){if(r>>>0<=255){t=s;k=3062;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==3062){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function pZ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=a[768256]|0;i=(h&255)<<31|g>>>1;j=h}else{i=g<<32-f|g>>>(f>>>0);j=a[768256]|0}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-i-((j&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=3078;break}c[194192]=0;l=d[130616+b|0]|0;break}i=j&255;if((j&2|0)==0){c[194192]=i>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|j&-256;l=0;break}}else{k=3078}}while(0);if((k|0)==3078){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=j>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=j>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=3088;break}j=b&255;if((b&2|0)==0){i=j>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=3089;break}else{i=j>>>2|b&-256;c[194192]=i;r=i;s=3;k=3090;break}}else{k=3088}}while(0);if((k|0)==3088){c[194192]=0;p=d[130616+n|0]|0;q=0;k=3089}if((k|0)==3089){i=p+3|0;if(o){r=q;s=i;k=3090}else{t=i;k=3096}}do{if((k|0)==3090){if((r&1|0)==0){if(r>>>0<=255){t=s;k=3096;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==3096){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function p_(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-h-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=3111;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=3111}}while(0);if((i|0)==3111){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=3121;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=3122;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=3123;break}}else{i=3121}}while(0);if((i|0)==3121){c[194192]=0;n=d[130616+l|0]|0;o=0;i=3122}if((i|0)==3122){f=n+4|0;if(m){p=o;q=f;i=3123}else{r=f;i=3129}}do{if((i|0)==3123){if((p&1|0)==0){if(p>>>0<=255){r=q;i=3129;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==3129){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function p$(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[776584+((a>>>8&15)<<2)>>2]|0;e=c[776584+((a&15)<<2)>>2]|0;f=wm(e,(e|0)<0?-1:0,b,(b|0)<0?-1:0)|0;c[776584+((a>>>12&15)<<2)>>2]=f;c[776584+((a>>>16&15)<<2)>>2]=G;a=b>>31^b;do{if(a>>>0<65536){b=(c[204526]|0)+1|0;c[204526]=b;g=b}else{b=c[204526]|0;if(a>>>0<16777216){f=b+2|0;c[204526]=f;g=f;break}else{f=b+3|0;c[204526]=f;g=f;break}}}while(0);a=c[194192]|0;if((a|0)==0){f=(1<<g)-1|0;c[194192]=f;h=f}else{h=a}a=(c[194193]|0)>>>24&15;do{if((a-8|0)>>>0<6){if((h&1|0)==0){break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;i=(d[130328+a|0]|0)-1|0;j=g+1|0;k=j+i|0;c[204526]=k;return}else{c[194192]=f>>>2|h&-256;i=0;j=g+1|0;k=j+i|0;c[204526]=k;return}}}while(0);c[194192]=0;i=d[130616+a|0]|0;j=g+1|0;k=j+i|0;c[204526]=k;return}function p0(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=776584+((e>>>16&15)<<2)|0;g=c[f>>2]|0;kh(g,b[776584+((e>>>12&15)<<2)>>1]|0);c[f>>2]=g+(e>>>4&240|e&15);e=g>>>24&15;g=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}h=f&255;if((f&2|0)==0){c[194192]=h>>>1|f&-256;i=(d[130328+g|0]|0)-1|0;j=e+i|0;c[204526]=j;return}else{c[194192]=h>>>2|f&-256;i=0;j=e+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+g|0]|0;j=e+i|0;c[204526]=j;return}function p1(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);h=c[776584+((b>>>16&15)<<2)>>2]|0;i=h-g|0;j=(a[768256]&1^1)&255;k=i-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(i|0)==(j|0)|0;j=h>>>31;h=g>>>31;g=h^1;i=g&j;k=f^1;a[768232]=(k&i|(j^1)&h&f)&255;a[768256]=(k&j|i|k&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){l=3177;break}c[194192]=0;m=d[130616+b|0]|0;break}k=g&255;if((g&2|0)==0){c[194192]=k>>>1|g&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|g&-256;m=0;break}}else{l=3177}}while(0);if((l|0)==3177){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;g=b+2|0;c[194161]=g;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=g>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>1]|0;p=b}else{b=m&-4;c[194193]=b;g=b+4|0;c[194161]=g;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=g>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3189;break}g=b&255;if((b&2|0)==0){k=g>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3190;break}else{k=g>>>2|b&-256;c[194192]=k;s=k;t=3;l=3191;break}}else{l=3189}}while(0);if((l|0)==3189){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3190}if((l|0)==3190){k=q+3|0;if(p){s=r;t=k;l=3191}else{u=k;l=3197}}do{if((l|0)==3191){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3197;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3197){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function p2(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h-i|0;j=(a[768256]&1^1)&255;k=g-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(g|0)==(j|0)|0;j=h>>>31;h=i>>>31;i=h^1;g=j&i;k=f^1;a[768232]=(k&g|(j^1)&h&f)&255;a[768256]=(k&j|g|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=3216;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=3216}}while(0);if((l|0)==3216){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3228;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3229;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=3230;break}}else{l=3228}}while(0);if((l|0)==3228){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3229}if((l|0)==3229){k=q+4|0;if(p){s=r;t=k;l=3230}else{u=k;l=3236}}do{if((l|0)==3230){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3236;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3236){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function p3(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;i=g-h|0;j=(a[768256]&1^1)&255;k=i-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(i|0)==(j|0)|0;j=g>>>31;g=h>>>31;h=g^1;i=j&h;k=f^1;a[768232]=(k&i|(j^1)&g&f)&255;a[768256]=(k&j|i|k&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=3253;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=3253}}while(0);if((l|0)==3253){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3265;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3266;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=3;l=3267;break}}else{l=3265}}while(0);if((l|0)==3265){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3266}if((l|0)==3266){k=q+3|0;if(p){s=r;t=k;l=3267}else{u=k;l=3273}}do{if((l|0)==3267){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3273;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3273){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function p4(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h-i|0;j=(a[768256]&1^1)&255;k=g-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(g|0)==(j|0)|0;j=h>>>31;h=i>>>31;i=h^1;g=j&i;k=f^1;a[768232]=(k&g|(j^1)&h&f)&255;a[768256]=(k&j|g|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=3292;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=3292}}while(0);if((l|0)==3292){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3304;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3305;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=3306;break}}else{l=3304}}while(0);if((l|0)==3304){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3305}if((l|0)==3305){k=q+4|0;if(p){s=r;t=k;l=3306}else{u=k;l=3312}}do{if((l|0)==3306){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3312;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3312){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function p5(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]>>((g|0)==0?31:g);g=c[776584+((b>>>16&15)<<2)>>2]|0;i=g-h|0;j=(a[768256]&1^1)&255;k=i-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(i|0)==(j|0)|0;j=g>>>31;g=h>>>31;h=g^1;i=h&j;k=f^1;a[768232]=(k&i|(j^1)&g&f)&255;a[768256]=(k&j|i|k&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=3327;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=3327}}while(0);if((l|0)==3327){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3339;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3340;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=3;l=3341;break}}else{l=3339}}while(0);if((l|0)==3339){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3340}if((l|0)==3340){k=q+3|0;if(p){s=r;t=k;l=3341}else{u=k;l=3347}}do{if((l|0)==3341){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3347;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3347){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function p6(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=h-j|0;i=(a[768256]&1^1)&255;k=g-i|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(g|0)==(i|0)|0;i=h>>>31;h=j>>>31;j=h^1;g=i&j;k=f^1;a[768232]=(k&g|(i^1)&h&f)&255;a[768256]=(k&i|g|k&j)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=3366;break}c[194192]=0;m=d[130616+b|0]|0;break}k=j&255;if((j&2|0)==0){c[194192]=k>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|j&-256;m=0;break}}else{l=3366}}while(0);if((l|0)==3366){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=j>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=j>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3378;break}j=b&255;if((b&2|0)==0){k=j>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3379;break}else{k=j>>>2|b&-256;c[194192]=k;s=k;t=4;l=3380;break}}else{l=3378}}while(0);if((l|0)==3378){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3379}if((l|0)==3379){k=q+4|0;if(p){s=r;t=k;l=3380}else{u=k;l=3386}}do{if((l|0)==3380){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3386;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3386){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function p7(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=a[768256]|0;j=(i&255)<<31|h>>>1;k=i}else{j=h<<32-g|h>>>(g>>>0);k=a[768256]|0}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g-j|0;i=(k&1^1)&255;k=h-i|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(h|0)==(i|0)|0;i=g>>>31;g=j>>>31;j=g^1;h=i&j;k=f^1;a[768232]=(k&h|(i^1)&g&f)&255;a[768256]=(k&i|h|k&j)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=3404;break}c[194192]=0;m=d[130616+b|0]|0;break}k=j&255;if((j&2|0)==0){c[194192]=k>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|j&-256;m=0;break}}else{l=3404}}while(0);if((l|0)==3404){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=j>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=j>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3416;break}j=b&255;if((b&2|0)==0){k=j>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3417;break}else{k=j>>>2|b&-256;c[194192]=k;s=k;t=3;l=3418;break}}else{l=3416}}while(0);if((l|0)==3416){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3417}if((l|0)==3417){k=q+3|0;if(p){s=r;t=k;l=3418}else{u=k;l=3424}}do{if((l|0)==3418){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3424;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3424){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function p8(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=d[776584+((b>>>8&15)<<2)|0]|0;h=c[776584+((b&15)<<2)>>2]|0;if((g&31|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g-i|0;j=(a[768256]&1^1)&255;k=h-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(h|0)==(j|0)|0;j=g>>>31;g=i>>>31;i=g^1;h=j&i;k=f^1;a[768232]=(k&h|(j^1)&g&f)&255;a[768256]=(k&j|h|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=3441;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=3441}}while(0);if((l|0)==3441){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3453;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3454;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=3455;break}}else{l=3453}}while(0);if((l|0)==3453){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3454}if((l|0)==3454){k=q+4|0;if(p){s=r;t=k;l=3455}else{u=k;l=3461}}do{if((l|0)==3455){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3461;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3461){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function p9(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[776584+((b>>>8&15)<<2)>>2]|0;f=c[776584+((b&15)<<2)>>2]|0;g=wm(f,(f|0)<0?-1:0,e,(e|0)<0?-1:0)|0;f=G;h=776584+((b>>>12&15)<<2)|0;c[h>>2]=g;g=f;c[776584+((b>>>16&15)<<2)>>2]=g;a[768240]=(f>>>31|0<<1)&255;if((g|0)==0){i=(c[h>>2]|0)==0|0}else{i=0}a[768224]=i;i=e>>31^e;do{if(i>>>0<65536){e=(c[204526]|0)+1|0;c[204526]=e;j=e}else{e=c[204526]|0;if(i>>>0<16777216){h=e+2|0;c[204526]=h;j=h;break}else{h=e+3|0;c[204526]=h;j=h;break}}}while(0);i=c[194192]|0;if((i|0)==0){h=(1<<j)-1|0;c[194192]=h;k=h}else{k=i}i=(c[194193]|0)>>>24&15;do{if((i-8|0)>>>0<6){if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;l=(d[130328+i|0]|0)-1|0;m=j+1|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|k&-256;l=0;m=j+1|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+i|0]|0;m=j+1|0;n=m+l|0;c[204526]=n;return}function qa(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))-(c[776584+((b>>>16&15)<<2)>>2]|0)-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=3493;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=3493}}while(0);if((g|0)==3493){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=3503;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=3504;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=3505;break}}else{g=3503}}while(0);if((g|0)==3503){c[194192]=0;m=d[130616+k|0]|0;n=0;g=3504}if((g|0)==3504){i=m+3|0;if(l){o=n;p=i;g=3505}else{q=i;g=3511}}do{if((g|0)==3505){if((o&1|0)==0){if(o>>>0<=255){q=p;g=3511;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==3511){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function qb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=ki(h)|0;if((e|0)!=(f|0)){c[g>>2]=h+(b>>>4&240|b&15)}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24&15;b=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function qc(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=(n0(h)|0)<<24>>24;if((e|0)!=(f|0)){c[g>>2]=h+(b>>>4&240|b&15)}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24&15;b=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function qd(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;i=ki(h)|0;if((h&1|0)==0){j=i&65535}else{j=(i&255)<<24>>24}c[776584+(e<<2)>>2]=j<<16>>16;if((e|0)!=(f|0)){c[g>>2]=h+(b>>>4&240|b&15)}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24&15;b=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;k=e+5|0;l=g;m=f}else{f=h>>>24&15;k=3;l=f;m=f-2|0}f=d[147072+l|0]|0;do{if(m>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);m=(c[194193]|0)>>>24&15;do{if((m-8|0)>>>0<6){l=c[194192]|0;if((l&1|0)==0){break}h=l&255;if((l&2|0)==0){c[194192]=h>>>1|l&-256;n=(d[130328+m|0]|0)-1|0;o=k+f|0;p=o+n|0;c[204526]=p;return}else{c[194192]=h>>>2|l&-256;n=0;o=k+f|0;p=o+n|0;c[204526]=p;return}}}while(0);c[194192]=0;n=d[130616+m|0]|0;o=k+f|0;p=o+n|0;c[204526]=p;return}function qe(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=i-(c[776584+((b>>>16&15)<<2)>>2]|0)-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=3605;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=3605}}while(0);if((j|0)==3605){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=3615;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=3616;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=3617;break}}else{j=3615}}while(0);if((j|0)==3615){c[194192]=0;o=d[130616+m|0]|0;p=0;j=3616}if((j|0)==3616){f=o+4|0;if(n){q=p;r=f;j=3617}else{s=f;j=3623}}do{if((j|0)==3617){if((q&1|0)==0){if(q>>>0<=255){s=r;j=3623;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==3623){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function qf(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=g-(c[776584+((b>>>16&15)<<2)>>2]|0)-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=3638;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=3638}}while(0);if((h|0)==3638){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=3648;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=3649;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=3650;break}}else{h=3648}}while(0);if((h|0)==3648){c[194192]=0;m=d[130616+k|0]|0;n=0;h=3649}if((h|0)==3649){f=m+3|0;if(l){o=n;p=f;h=3650}else{q=f;h=3656}}do{if((h|0)==3650){if((o&1|0)==0){if(o>>>0<=255){q=p;h=3656;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==3656){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function qg(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=i-(c[776584+((b>>>16&15)<<2)>>2]|0)-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=3673;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=3673}}while(0);if((j|0)==3673){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=3683;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=3684;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=3685;break}}else{j=3683}}while(0);if((j|0)==3683){c[194192]=0;o=d[130616+m|0]|0;p=0;j=3684}if((j|0)==3684){f=o+4|0;if(n){q=p;r=f;j=3685}else{s=f;j=3691}}do{if((j|0)==3685){if((q&1|0)==0){if(q>>>0<=255){s=r;j=3691;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==3691){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function qh(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f))-(c[776584+((b>>>16&15)<<2)>>2]|0)-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=3704;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=3704}}while(0);if((g|0)==3704){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=3714;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=3715;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=3716;break}}else{g=3714}}while(0);if((g|0)==3714){c[194192]=0;m=d[130616+k|0]|0;n=0;g=3715}if((g|0)==3715){i=m+3|0;if(l){o=n;p=i;g=3716}else{q=i;g=3722}}do{if((g|0)==3716){if((o&1|0)==0){if(o>>>0<=255){q=p;g=3722;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==3722){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function qi(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=j-(c[776584+((b>>>16&15)<<2)>>2]|0)-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=3739;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=3739}}while(0);if((k|0)==3739){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=3749;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=3750;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=3751;break}}else{k=3749}}while(0);if((k|0)==3749){c[194192]=0;p=d[130616+n|0]|0;q=0;k=3750}if((k|0)==3750){f=p+4|0;if(o){r=q;s=f;k=3751}else{t=f;k=3757}}do{if((k|0)==3751){if((r&1|0)==0){if(r>>>0<=255){t=s;k=3757;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==3757){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function qj(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=a[768256]|0;i=(h&255)<<31|g>>>1;j=h}else{i=g<<32-f|g>>>(f>>>0);j=a[768256]|0}c[776584+((b>>>12&15)<<2)>>2]=i-(c[776584+((b>>>16&15)<<2)>>2]|0)-((j&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=3773;break}c[194192]=0;l=d[130616+b|0]|0;break}i=j&255;if((j&2|0)==0){c[194192]=i>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|j&-256;l=0;break}}else{k=3773}}while(0);if((k|0)==3773){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=j>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=j>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=3783;break}j=b&255;if((b&2|0)==0){i=j>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=3784;break}else{i=j>>>2|b&-256;c[194192]=i;r=i;s=3;k=3785;break}}else{k=3783}}while(0);if((k|0)==3783){c[194192]=0;p=d[130616+n|0]|0;q=0;k=3784}if((k|0)==3784){i=p+3|0;if(o){r=q;s=i;k=3785}else{t=i;k=3791}}do{if((k|0)==3785){if((r&1|0)==0){if(r>>>0<=255){t=s;k=3791;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==3791){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function qk(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=h-(c[776584+((b>>>16&15)<<2)>>2]|0)-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=3806;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=3806}}while(0);if((i|0)==3806){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=3816;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=3817;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=3818;break}}else{i=3816}}while(0);if((i|0)==3816){c[194192]=0;n=d[130616+l|0]|0;o=0;i=3817}if((i|0)==3817){f=n+4|0;if(m){p=o;q=f;i=3818}else{r=f;i=3824}}do{if((i|0)==3818){if((p&1|0)==0){if(p>>>0<=255){r=q;i=3824;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==3824){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function ql(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[776584+((a>>>8&15)<<2)>>2]|0;e=776584+((a>>>16&15)<<2)|0;f=776584+((a>>>12&15)<<2)|0;g=c[f>>2]|0;h=c[e>>2]|0;i=c[776584+((a&15)<<2)>>2]|0;a=wm(i,(i|0)<0?-1:0,b,(b|0)<0?-1:0)|0;i=wc(a,G,g,h)|0;c[f>>2]=i;c[e>>2]=G;e=b>>31^b;do{if(e>>>0<65536){b=(c[204526]|0)+1|0;c[204526]=b;j=b}else{b=c[204526]|0;if(e>>>0<16777216){i=b+2|0;c[204526]=i;j=i;break}else{i=b+3|0;c[204526]=i;j=i;break}}}while(0);e=c[194192]|0;if((e|0)==0){i=(1<<j)-1|0;c[194192]=i;k=i}else{k=e}e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;l=(d[130328+e|0]|0)-1|0;m=j+1|0;n=m+l|0;c[204526]=n;return}else{c[194192]=i>>>2|k&-256;l=0;m=j+1|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+e|0]|0;m=j+1|0;n=m+l|0;c[204526]=n;return}function qm(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);h=c[776584+((b>>>16&15)<<2)>>2]|0;i=g-h|0;j=(a[768256]&1^1)&255;k=i-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(i|0)==(j|0)|0;j=h>>>31;h=g>>>31;g=h^1;i=g&j;k=f^1;a[768232]=(k&i|(j^1)&h&f)&255;a[768256]=(k&j|i|k&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){l=3856;break}c[194192]=0;m=d[130616+b|0]|0;break}k=g&255;if((g&2|0)==0){c[194192]=k>>>1|g&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|g&-256;m=0;break}}else{l=3856}}while(0);if((l|0)==3856){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;g=b+2|0;c[194161]=g;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=g>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>1]|0;p=b}else{b=m&-4;c[194193]=b;g=b+4|0;c[194161]=g;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=g>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3868;break}g=b&255;if((b&2|0)==0){k=g>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3869;break}else{k=g>>>2|b&-256;c[194192]=k;s=k;t=3;l=3870;break}}else{l=3868}}while(0);if((l|0)==3868){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3869}if((l|0)==3869){k=q+3|0;if(p){s=r;t=k;l=3870}else{u=k;l=3876}}do{if((l|0)==3870){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3876;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3876){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function qn(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=i-h|0;j=(a[768256]&1^1)&255;k=g-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(g|0)==(j|0)|0;j=h>>>31;h=i>>>31;i=h^1;g=j&i;k=f^1;a[768232]=(k&g|(j^1)&h&f)&255;a[768256]=(k&j|g|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=3895;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=3895}}while(0);if((l|0)==3895){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3907;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3908;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=3909;break}}else{l=3907}}while(0);if((l|0)==3907){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3908}if((l|0)==3908){k=q+4|0;if(p){s=r;t=k;l=3909}else{u=k;l=3915}}do{if((l|0)==3909){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3915;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3915){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function qo(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;i=h-g|0;j=(a[768256]&1^1)&255;k=i-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(i|0)==(j|0)|0;j=g>>>31;g=h>>>31;h=g^1;i=j&h;k=f^1;a[768232]=(k&i|(j^1)&g&f)&255;a[768256]=(k&j|i|k&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=3932;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=3932}}while(0);if((l|0)==3932){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3944;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3945;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=3;l=3946;break}}else{l=3944}}while(0);if((l|0)==3944){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3945}if((l|0)==3945){k=q+3|0;if(p){s=r;t=k;l=3946}else{u=k;l=3952}}do{if((l|0)==3946){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3952;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3952){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function qp(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=i-h|0;j=(a[768256]&1^1)&255;k=g-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(g|0)==(j|0)|0;j=h>>>31;h=i>>>31;i=h^1;g=j&i;k=f^1;a[768232]=(k&g|(j^1)&h&f)&255;a[768256]=(k&j|g|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=3971;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=3971}}while(0);if((l|0)==3971){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=3983;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=3984;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=3985;break}}else{l=3983}}while(0);if((l|0)==3983){c[194192]=0;q=d[130616+o|0]|0;r=0;l=3984}if((l|0)==3984){k=q+4|0;if(p){s=r;t=k;l=3985}else{u=k;l=3991}}do{if((l|0)==3985){if((s&1|0)==0){if(s>>>0<=255){u=t;l=3991;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==3991){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function qq(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]>>((g|0)==0?31:g);g=c[776584+((b>>>16&15)<<2)>>2]|0;i=h-g|0;j=(a[768256]&1^1)&255;k=i-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(i|0)==(j|0)|0;j=g>>>31;g=h>>>31;h=g^1;i=h&j;k=f^1;a[768232]=(k&i|(j^1)&g&f)&255;a[768256]=(k&j|i|k&h)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=4006;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=4006}}while(0);if((l|0)==4006){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=4018;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=4019;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=3;l=4020;break}}else{l=4018}}while(0);if((l|0)==4018){c[194192]=0;q=d[130616+o|0]|0;r=0;l=4019}if((l|0)==4019){k=q+3|0;if(p){s=r;t=k;l=4020}else{u=k;l=4026}}do{if((l|0)==4020){if((s&1|0)==0){if(s>>>0<=255){u=t;l=4026;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==4026){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function qr(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;g=j-h|0;i=(a[768256]&1^1)&255;k=g-i|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(g|0)==(i|0)|0;i=h>>>31;h=j>>>31;j=h^1;g=i&j;k=f^1;a[768232]=(k&g|(i^1)&h&f)&255;a[768256]=(k&i|g|k&j)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=4045;break}c[194192]=0;m=d[130616+b|0]|0;break}k=j&255;if((j&2|0)==0){c[194192]=k>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|j&-256;m=0;break}}else{l=4045}}while(0);if((l|0)==4045){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=j>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=j>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=4057;break}j=b&255;if((b&2|0)==0){k=j>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=4058;break}else{k=j>>>2|b&-256;c[194192]=k;s=k;t=4;l=4059;break}}else{l=4057}}while(0);if((l|0)==4057){c[194192]=0;q=d[130616+o|0]|0;r=0;l=4058}if((l|0)==4058){k=q+4|0;if(p){s=r;t=k;l=4059}else{u=k;l=4065}}do{if((l|0)==4059){if((s&1|0)==0){if(s>>>0<=255){u=t;l=4065;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==4065){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function qs(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=a[768256]|0;j=(i&255)<<31|h>>>1;k=i}else{j=h<<32-g|h>>>(g>>>0);k=a[768256]|0}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=j-g|0;i=(k&1^1)&255;k=h-i|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(h|0)==(i|0)|0;i=g>>>31;g=j>>>31;j=g^1;h=i&j;k=f^1;a[768232]=(k&h|(i^1)&g&f)&255;a[768256]=(k&i|h|k&j)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=4083;break}c[194192]=0;m=d[130616+b|0]|0;break}k=j&255;if((j&2|0)==0){c[194192]=k>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|j&-256;m=0;break}}else{l=4083}}while(0);if((l|0)==4083){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=j>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=j>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=4095;break}j=b&255;if((b&2|0)==0){k=j>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=4096;break}else{k=j>>>2|b&-256;c[194192]=k;s=k;t=3;l=4097;break}}else{l=4095}}while(0);if((l|0)==4095){c[194192]=0;q=d[130616+o|0]|0;r=0;l=4096}if((l|0)==4096){k=q+3|0;if(p){s=r;t=k;l=4097}else{u=k;l=4103}}do{if((l|0)==4097){if((s&1|0)==0){if(s>>>0<=255){u=t;l=4103;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==4103){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function qt(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[776584+((b>>>8&15)<<2)>>2]|0;f=776584+((b>>>16&15)<<2)|0;g=776584+((b>>>12&15)<<2)|0;h=c[g>>2]|0;i=c[f>>2]|0;j=c[776584+((b&15)<<2)>>2]|0;b=wm(j,(j|0)<0?-1:0,e,(e|0)<0?-1:0)|0;j=wc(b,G,h,i)|0;i=G;c[g>>2]=j;j=i;c[f>>2]=j;a[768240]=(i>>>31|0<<1)&255;if((j|0)==0){k=(c[g>>2]|0)==0|0}else{k=0}a[768224]=k;k=e>>31^e;do{if(k>>>0<65536){e=(c[204526]|0)+1|0;c[204526]=e;l=e}else{e=c[204526]|0;if(k>>>0<16777216){g=e+2|0;c[204526]=g;l=g;break}else{g=e+3|0;c[204526]=g;l=g;break}}}while(0);k=c[194192]|0;if((k|0)==0){g=(1<<l)-1|0;c[194192]=g;m=g}else{m=k}k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){if((m&1|0)==0){break}g=m&255;if((m&2|0)==0){c[194192]=g>>>1|m&-256;n=(d[130328+k|0]|0)-1|0;o=l+1|0;p=o+n|0;c[204526]=p;return}else{c[194192]=g>>>2|m&-256;n=0;o=l+1|0;p=o+n|0;c[204526]=p;return}}}while(0);c[194192]=0;n=d[130616+k|0]|0;o=l+1|0;p=o+n|0;c[204526]=p;return}function qu(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=d[776584+((b>>>8&15)<<2)|0]|0;h=c[776584+((b&15)<<2)>>2]|0;if((g&31|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=i-g|0;j=(a[768256]&1^1)&255;k=h-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(h|0)==(j|0)|0;j=g>>>31;g=i>>>31;i=g^1;h=j&i;k=f^1;a[768232]=(k&h|(j^1)&g&f)&255;a[768256]=(k&j|h|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=4139;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=4139}}while(0);if((l|0)==4139){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=4151;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=4152;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=4153;break}}else{l=4151}}while(0);if((l|0)==4151){c[194192]=0;q=d[130616+o|0]|0;r=0;l=4152}if((l|0)==4152){k=q+4|0;if(p){s=r;t=k;l=4153}else{u=k;l=4159}}do{if((l|0)==4153){if((s&1|0)==0){if(s>>>0<=255){u=t;l=4159;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==4159){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function qv(b){b=b|0;var d=0,e=0;if((b&268374015|0)==17760256){d=c[194162]&64;e=(a[768240]&1)==0?d:d|-2147483648;d=(a[768224]&1)==0?e:e|1073741824;e=(a[768256]&1)==0?d:d|536870912;d=(a[768232]&1)==0?e:e|268435456;e=(a[52040]&1)==0?d|32:d;d=((a[130632]&1)==0?e|128:e)|c[31194]&31;c[194162]=d;c[776584+((b>>>12&15)<<2)>>2]=d;return}d=c[194161]|0;b=(a[52040]&1)!=0;if((c[31194]|0)!=27){km(27,1,0)}c[194160]=d-(b?4:2);c[194161]=4;a[52040]=1;a[130632]=0;c[194193]=4;b=c[193635]|0;d=c[193634]|0;c[203402]=c[d+(b&4)>>2];c[203400]=c[d+(b&8)>>2];c[194161]=8;return}function qw(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=c[776584+((b>>>16&15)<<2)>>2]|0;f=ke(e)|0;kg(e,c[776584+((b&15)<<2)>>2]|0);c[776584+((b>>>12&15)<<2)>>2]=f;f=e>>>24&15;e=d[130616+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);f=(e<<1)+4|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}g=b&255;if((b&2|0)==0){c[194192]=g>>>1|b&-256;h=(d[130328+e|0]|0)-1|0;i=f+h|0;c[204526]=i;return}else{c[194192]=g>>>2|b&-256;h=0;i=f+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=f+h|0;c[204526]=i;return}function qx(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=(c[776584+((e>>>16&15)<<2)>>2]|0)-(c[776584+((e&15)<<2)>>2]|0)|0;kh(f,b[776584+((e>>>12&15)<<2)>>1]|0);e=f>>>24&15;f=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);e=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}h=g&255;if((g&2|0)==0){c[194192]=h>>>1|g&-256;i=(d[130328+f|0]|0)-1|0;j=e+i|0;c[204526]=j;return}else{c[194192]=h>>>2|g&-256;i=0;j=e+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+f|0]|0;j=e+i|0;c[204526]=j;return}function qy(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(a[768256]&1)!=0;i=g}else{h=(g&1<<32-f|0)!=0;i=g<<f}f=c[776584+((b>>>16&15)<<2)>>2]&i;a[768240]=f>>>31&255;a[768224]=(f|0)==0|0;a[768256]=h&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){j=4213;break}c[194192]=0;k=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;k=0;break}}else{j=4213}}while(0);if((j|0)==4213){k=d[125296+b|0]|0}l=k+1|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;n=b}else{b=k&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=4223;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=4224;break}else{f=h>>>2|b&-256;c[194192]=f;q=f;r=3;j=4225;break}}else{j=4223}}while(0);if((j|0)==4223){c[194192]=0;o=d[130616+m|0]|0;p=0;j=4224}if((j|0)==4224){f=o+3|0;if(n){q=p;r=f;j=4225}else{s=f;j=4231}}do{if((j|0)==4225){if((q&1|0)==0){if(q>>>0<=255){s=r;j=4231;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==4231){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function qz(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;do{if((f<<24>>24|0)==32){h=(c[776584+((b&15)<<2)>>2]&1|0)!=0;i=0}else if((f<<24>>24|0)==0){h=(a[768256]&1)!=0;i=c[776584+((b&15)<<2)>>2]|0}else{if((f&255)>=32){h=0;i=0;break}j=c[776584+((b&15)<<2)>>2]|0;h=(j&1<<32-g|0)!=0;i=j<<g}}while(0);g=c[776584+((b>>>16&15)<<2)>>2]&i;a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=h&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=4249;break}c[194192]=0;l=d[130616+b|0]|0;break}g=h&255;if((h&2|0)==0){c[194192]=g>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|h&-256;l=0;break}}else{k=4249}}while(0);if((k|0)==4249){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=h>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=h>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=4259;break}h=b&255;if((b&2|0)==0){g=h>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=4260;break}else{g=h>>>2|b&-256;c[194192]=g;r=g;s=4;k=4261;break}}else{k=4259}}while(0);if((k|0)==4259){c[194192]=0;p=d[130616+n|0]|0;q=0;k=4260}if((k|0)==4260){g=p+4|0;if(o){r=q;s=g;k=4261}else{t=g;k=4267}}do{if((k|0)==4261){if((r&1|0)==0){if(r>>>0<=255){t=s;k=4267;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==4267){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function qA(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=g>>>31;i=0}else{h=g&1<<f-1;i=g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]&i;a[768240]=f>>>31&255;a[768224]=(f|0)==0|0;a[768256]=(h|0)!=0|0;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){j=4283;break}c[194192]=0;k=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;k=0;break}}else{j=4283}}while(0);if((j|0)==4283){k=d[125296+b|0]|0}l=k+1|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;n=b}else{b=k&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=4293;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=4294;break}else{f=h>>>2|b&-256;c[194192]=f;q=f;r=3;j=4295;break}}else{j=4293}}while(0);if((j|0)==4293){c[194192]=0;o=d[130616+m|0]|0;p=0;j=4294}if((j|0)==4294){f=o+3|0;if(n){q=p;r=f;j=4295}else{s=f;j=4301}}do{if((j|0)==4295){if((q&1|0)==0){if(q>>>0<=255){s=r;j=4301;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==4301){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function qB(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;do{if((f<<24>>24|0)==32){h=(c[776584+((b&15)<<2)>>2]|0)<0;i=0}else if((f<<24>>24|0)==0){h=(a[768256]&1)!=0;i=c[776584+((b&15)<<2)>>2]|0}else{if((f&255)>=32){h=0;i=0;break}j=c[776584+((b&15)<<2)>>2]|0;h=(j&1<<g-1|0)!=0;i=j>>>(g>>>0)}}while(0);g=c[776584+((b>>>16&15)<<2)>>2]&i;a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=h&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=4319;break}c[194192]=0;l=d[130616+b|0]|0;break}g=h&255;if((h&2|0)==0){c[194192]=g>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|h&-256;l=0;break}}else{k=4319}}while(0);if((k|0)==4319){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=h>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=h>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=4329;break}h=b&255;if((b&2|0)==0){g=h>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=4330;break}else{g=h>>>2|b&-256;c[194192]=g;r=g;s=4;k=4331;break}}else{k=4329}}while(0);if((k|0)==4329){c[194192]=0;p=d[130616+n|0]|0;q=0;k=4330}if((k|0)==4330){g=p+4|0;if(o){r=q;s=g;k=4331}else{t=g;k=4337}}do{if((k|0)==4331){if((r&1|0)==0){if(r>>>0<=255){t=s;k=4337;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==4337){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function qC(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(g|0)<0;i=31}else{h=(g&1<<f-1|0)!=0;i=f}f=c[776584+((b>>>16&15)<<2)>>2]&g>>i;a[768240]=f>>>31&255;a[768224]=(f|0)==0|0;a[768256]=h&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){j=4353;break}c[194192]=0;k=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;k=0;break}}else{j=4353}}while(0);if((j|0)==4353){k=d[125296+b|0]|0}l=k+1|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;n=b}else{b=k&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=4363;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=4364;break}else{f=h>>>2|b&-256;c[194192]=f;q=f;r=3;j=4365;break}}else{j=4363}}while(0);if((j|0)==4363){c[194192]=0;o=d[130616+m|0]|0;p=0;j=4364}if((j|0)==4364){f=o+3|0;if(n){q=p;r=f;j=4365}else{s=f;j=4371}}do{if((j|0)==4365){if((q&1|0)==0){if(q>>>0<=255){s=r;j=4371;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==4371){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function qD(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=a[768256]|0;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=(f&1)!=0;k=i;break}else{j=(i&1<<h-1|0)!=0;k=i>>h;break}}else{i=c[776584+((b&15)<<2)>>2]|0;j=(i|0)<0;k=i>>31}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]&k;a[768240]=h>>>31&255;a[768224]=(h|0)==0|0;a[768256]=j&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=4389;break}c[194192]=0;m=d[130616+b|0]|0;break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=h>>>2|j&-256;m=0;break}}else{l=4389}}while(0);if((l|0)==4389){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;h=m>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=j>>>24;o=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;h=m>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=j>>>24;o=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=4399;break}j=b&255;if((b&2|0)==0){h=j>>>1|b&-256;c[194192]=h;q=(d[130328+o|0]|0)-1|0;r=h;l=4400;break}else{h=j>>>2|b&-256;c[194192]=h;s=h;t=4;l=4401;break}}else{l=4399}}while(0);if((l|0)==4399){c[194192]=0;q=d[130616+o|0]|0;r=0;l=4400}if((l|0)==4400){h=q+4|0;if(p){s=r;t=h;l=4401}else{u=h;l=4407}}do{if((l|0)==4401){if((s&1|0)==0){if(s>>>0<=255){u=t;l=4407;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}h=s&255;if((s&2|0)==0){c[194192]=h>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=h>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==4407){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function qE(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=1;i=(d[768256]|0)<<31|g>>>1}else{h=1<<f-1;i=g<<32-f|g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]&i;a[768240]=f>>>31&255;a[768224]=(f|0)==0|0;a[768256]=(h&g|0)!=0|0;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){j=4423;break}c[194192]=0;k=d[130616+b|0]|0;break}h=g&255;if((g&2|0)==0){c[194192]=h>>>1|g&-256;k=d[130328+b|0]|0;break}else{c[194192]=h>>>2|g&-256;k=0;break}}else{j=4423}}while(0);if((j|0)==4423){k=d[125296+b|0]|0}l=k+1|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;g=b+2|0;c[194161]=g;h=k>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=g>>>24;m=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>1]|0;n=b}else{b=k&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=k>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=g>>>24;m=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=4433;break}g=b&255;if((b&2|0)==0){h=g>>>1|b&-256;c[194192]=h;o=(d[130328+m|0]|0)-1|0;p=h;j=4434;break}else{h=g>>>2|b&-256;c[194192]=h;q=h;r=3;j=4435;break}}else{j=4433}}while(0);if((j|0)==4433){c[194192]=0;o=d[130616+m|0]|0;p=0;j=4434}if((j|0)==4434){h=o+3|0;if(n){q=p;r=h;j=4435}else{s=h;j=4441}}do{if((j|0)==4435){if((q&1|0)==0){if(q>>>0<=255){s=r;j=4441;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}h=q&255;if((q&2|0)==0){c[194192]=h>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=h>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==4441){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function qF(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;h=c[776584+((b&15)<<2)>>2]|0;if((g&31|0)==0){i=f<<24>>24==0?(a[768256]&1)!=0:(h|0)<0;j=h}else{i=(1<<g-1&h|0)!=0;j=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]&j;a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=i&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=4457;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=4457}}while(0);if((k|0)==4457){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=4467;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=4468;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=4;k=4469;break}}else{k=4467}}while(0);if((k|0)==4467){c[194192]=0;p=d[130616+n|0]|0;q=0;k=4468}if((k|0)==4468){g=p+4|0;if(o){r=q;s=g;k=4469}else{t=g;k=4475}}do{if((k|0)==4469){if((r&1|0)==0){if(r>>>0<=255){t=s;k=4475;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==4475){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function qG(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]|0)|0;c[776584+(e<<2)>>2]=ki(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function qH(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]|0)|0;c[776584+(e<<2)>>2]=(n0(f)|0)<<24>>24;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function qI(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(a[768256]&1)!=0;i=g}else{h=(g&1<<32-f|0)!=0;i=g<<f}f=c[776584+((b>>>16&15)<<2)>>2]|0;a[768240]=(f^i)>>>31&255;a[768224]=(f|0)==(i|0)|0;a[768256]=h&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){j=4537;break}c[194192]=0;k=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;k=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;k=0;break}}else{j=4537}}while(0);if((j|0)==4537){k=d[125296+b|0]|0}l=k+1|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=k>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;m=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;n=b}else{b=k&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=k>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;m=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=4547;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;o=(d[130328+m|0]|0)-1|0;p=i;j=4548;break}else{i=h>>>2|b&-256;c[194192]=i;q=i;r=3;j=4549;break}}else{j=4547}}while(0);if((j|0)==4547){c[194192]=0;o=d[130616+m|0]|0;p=0;j=4548}if((j|0)==4548){i=o+3|0;if(n){q=p;r=i;j=4549}else{s=i;j=4555}}do{if((j|0)==4549){if((q&1|0)==0){if(q>>>0<=255){s=r;j=4555;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}i=q&255;if((q&2|0)==0){c[194192]=i>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=i>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==4555){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function qJ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]|0)|0;b=ki(f)|0;if((f&1|0)==0){g=b&65535}else{g=(b&255)<<24>>24}c[776584+(e<<2)>>2]=g<<16>>16;c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=f>>>24&15;g=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function qK(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((d&267452400|0)!=18935808){f=c[194161]|0;g=(a[52040]&1)!=0;if((c[31194]|0)!=27){km(27,1,0)}c[194160]=f-(g?4:2);c[194161]=4;a[52040]=1;a[130632]=0;c[194193]=4;g=c[193635]|0;f=c[193634]|0;c[203402]=c[f+(g&4)>>2];c[203400]=c[f+(g&8)>>2];c[194161]=8;return}g=c[194162]&64;f=(a[768240]&1)==0?g:g|-2147483648;g=(a[768224]&1)==0?f:f|1073741824;f=(a[768256]&1)==0?g:g|536870912;g=(a[768232]&1)==0?f:f|268435456;f=(a[52040]&1)==0?g|32:g;g=(a[130632]&1)==0?f|128:f;f=c[31194]|0;h=g|f&31;c[194162]=h;i=c[776584+((d&15)<<2)>>2]|0;do{if((f|0)>16){if((d&65536|0)==0){j=h}else{j=g&-256|i&255}if((d&131072|0)==0){k=j}else{k=j&-65281|i&65280}if((d&262144|0)==0){l=k;break}l=k&-16711681|i&16711680}else{l=h}}while(0);if((d&524288|0)==0){m=l}else{m=l&16777215|i&-16777216}i=m|16;l=i&31;if((f|0)!=(l|0)){km(l,0,1)}c[194162]=i;a[768240]=m>>>31&255;a[768224]=m>>>30&1;a[768256]=m>>>29&1;a[768232]=m>>>28&1;i=(m>>>5&1^1)&255;a[52040]=i;l=m>>>7&1;a[130632]=(l^1)&255;do{if((l|0)==0){if((b[390600]&b[390601])<<16>>16==0){break}if((b[390604]&1)==0){break}c[203364]=c[195148]}}while(0);if(i<<24>>24!=0){return}i=c[194193]|0;l=i>>>24;c[203402]=e[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&i)>>1]|0;l=i+2|0;i=l>>>24;c[203400]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&l)>>1]|0;c[194161]=l;return}function qL(b){b=b|0;var f=0,g=0,h=0;if((b&268435440|0)!=19922704){f=c[194161]|0;g=(a[52040]&1)!=0;if((c[31194]|0)!=27){km(27,1,0)}c[194160]=f-(g?4:2);c[194161]=4;a[52040]=1;a[130632]=0;c[194193]=4;g=c[193635]|0;f=c[193634]|0;c[203402]=c[f+(g&4)>>2];c[203400]=c[f+(g&8)>>2];c[194161]=8;return}c[194192]=0;g=c[776584+((b&15)<<2)>>2]|0;b=g&1;a[52040]=(b^1)&255;if((b|0)==0){b=g&-4;c[194193]=b;f=b+4|0;c[194161]=f;h=g>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=f>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&f)>>2];f=h&15;h=((d[125296+f|0]|0)<<1)+3|0;c[194192]=0;c[204526]=h+(d[130616+f|0]|0);return}f=g&-2;c[194193]=f;h=f+2|0;c[194161]=h;b=g>>>24;c[203402]=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&f)>>1]|0;f=h>>>24;c[203400]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;h=b&15;if((h-8|0)>>>0>=6){c[194192]=0}b=((d[130328+h|0]|0)<<1)+3|0;c[194192]=0;c[204526]=b+(d[147072+h|0]|0);return}function qM(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=776584+((e>>>16&15)<<2)|0;g=(c[f>>2]|0)-(c[776584+((e&15)<<2)>>2]|0)|0;c[f>>2]=g;kh(g,b[776584+((e>>>12&15)<<2)>>1]|0);e=g>>>24&15;g=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}h=f&255;if((f&2|0)==0){c[194192]=h>>>1|f&-256;i=(d[130328+g|0]|0)-1|0;j=e+i|0;c[204526]=j;return}else{c[194192]=h>>>2|f&-256;i=0;j=e+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+g|0]|0;j=e+i|0;c[204526]=j;return}function qN(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;do{if((f<<24>>24|0)==0){h=(a[768256]&1)!=0;i=c[776584+((b&15)<<2)>>2]|0}else if((f<<24>>24|0)==32){h=(c[776584+((b&15)<<2)>>2]&1|0)!=0;i=0}else{if((f&255)>=32){h=0;i=0;break}j=c[776584+((b&15)<<2)>>2]|0;h=(j&1<<32-g|0)!=0;i=j<<g}}while(0);g=c[776584+((b>>>16&15)<<2)>>2]|0;a[768240]=(g^i)>>>31&255;a[768224]=(g|0)==(i|0)|0;a[768256]=h&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=4652;break}c[194192]=0;l=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;l=0;break}}else{k=4652}}while(0);if((k|0)==4652){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=4662;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=4663;break}else{i=h>>>2|b&-256;c[194192]=i;r=i;s=4;k=4664;break}}else{k=4662}}while(0);if((k|0)==4662){c[194192]=0;p=d[130616+n|0]|0;q=0;k=4663}if((k|0)==4663){i=p+4|0;if(o){r=q;s=i;k=4664}else{t=i;k=4670}}do{if((k|0)==4664){if((r&1|0)==0){if(r>>>0<=255){t=s;k=4670;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==4670){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function qO(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=g>>>31;i=0}else{h=g&1<<f-1;i=g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]|0;a[768240]=(f^i)>>>31&255;a[768224]=(f|0)==(i|0)|0;a[768256]=(h|0)!=0|0;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){j=4686;break}c[194192]=0;k=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;k=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;k=0;break}}else{j=4686}}while(0);if((j|0)==4686){k=d[125296+b|0]|0}l=k+1|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=k>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;m=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;n=b}else{b=k&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=k>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;m=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=4696;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;o=(d[130328+m|0]|0)-1|0;p=i;j=4697;break}else{i=h>>>2|b&-256;c[194192]=i;q=i;r=3;j=4698;break}}else{j=4696}}while(0);if((j|0)==4696){c[194192]=0;o=d[130616+m|0]|0;p=0;j=4697}if((j|0)==4697){i=o+3|0;if(n){q=p;r=i;j=4698}else{s=i;j=4704}}do{if((j|0)==4698){if((q&1|0)==0){if(q>>>0<=255){s=r;j=4704;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}i=q&255;if((q&2|0)==0){c[194192]=i>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=i>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==4704){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function qP(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;do{if((f<<24>>24|0)==32){h=(c[776584+((b&15)<<2)>>2]|0)<0;i=0}else if((f<<24>>24|0)==0){h=(a[768256]&1)!=0;i=c[776584+((b&15)<<2)>>2]|0}else{if((f&255)>=32){h=0;i=0;break}j=c[776584+((b&15)<<2)>>2]|0;h=(j&1<<g-1|0)!=0;i=j>>>(g>>>0)}}while(0);g=c[776584+((b>>>16&15)<<2)>>2]|0;a[768240]=(g^i)>>>31&255;a[768224]=(g|0)==(i|0)|0;a[768256]=h&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=4722;break}c[194192]=0;l=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;l=0;break}}else{k=4722}}while(0);if((k|0)==4722){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=4732;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=4733;break}else{i=h>>>2|b&-256;c[194192]=i;r=i;s=4;k=4734;break}}else{k=4732}}while(0);if((k|0)==4732){c[194192]=0;p=d[130616+n|0]|0;q=0;k=4733}if((k|0)==4733){i=p+4|0;if(o){r=q;s=i;k=4734}else{t=i;k=4740}}do{if((k|0)==4734){if((r&1|0)==0){if(r>>>0<=255){t=s;k=4740;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==4740){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function qQ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(g|0)<0;i=31}else{h=(g&1<<f-1|0)!=0;i=f}f=g>>i;i=c[776584+((b>>>16&15)<<2)>>2]|0;a[768240]=(i^f)>>>31&255;a[768224]=(i|0)==(f|0)|0;a[768256]=h&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){j=4756;break}c[194192]=0;k=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;k=0;break}}else{j=4756}}while(0);if((j|0)==4756){k=d[125296+b|0]|0}l=k+1|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;n=b}else{b=k&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=4766;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=4767;break}else{f=h>>>2|b&-256;c[194192]=f;q=f;r=3;j=4768;break}}else{j=4766}}while(0);if((j|0)==4766){c[194192]=0;o=d[130616+m|0]|0;p=0;j=4767}if((j|0)==4767){f=o+3|0;if(n){q=p;r=f;j=4768}else{s=f;j=4774}}do{if((j|0)==4768){if((q&1|0)==0){if(q>>>0<=255){s=r;j=4774;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==4774){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function qR(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=a[768256]|0;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=(f&1)!=0;k=i;break}else{j=(i&1<<h-1|0)!=0;k=i>>h;break}}else{i=c[776584+((b&15)<<2)>>2]|0;j=(i|0)<0;k=i>>31}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|0;a[768240]=(h^k)>>>31&255;a[768224]=(h|0)==(k|0)|0;a[768256]=j&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=4792;break}c[194192]=0;m=d[130616+b|0]|0;break}k=j&255;if((j&2|0)==0){c[194192]=k>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|j&-256;m=0;break}}else{l=4792}}while(0);if((l|0)==4792){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=j>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=j>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=4802;break}j=b&255;if((b&2|0)==0){k=j>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=4803;break}else{k=j>>>2|b&-256;c[194192]=k;s=k;t=4;l=4804;break}}else{l=4802}}while(0);if((l|0)==4802){c[194192]=0;q=d[130616+o|0]|0;r=0;l=4803}if((l|0)==4803){k=q+4|0;if(p){s=r;t=k;l=4804}else{u=k;l=4810}}do{if((l|0)==4804){if((s&1|0)==0){if(s>>>0<=255){u=t;l=4810;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==4810){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function qS(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=1;i=(d[768256]|0)<<31|g>>>1}else{h=1<<f-1;i=g<<32-f|g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]|0;a[768240]=(f^i)>>>31&255;a[768224]=(f|0)==(i|0)|0;a[768256]=(h&g|0)!=0|0;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){j=4826;break}c[194192]=0;k=d[130616+b|0]|0;break}h=g&255;if((g&2|0)==0){c[194192]=h>>>1|g&-256;k=d[130328+b|0]|0;break}else{c[194192]=h>>>2|g&-256;k=0;break}}else{j=4826}}while(0);if((j|0)==4826){k=d[125296+b|0]|0}l=k+1|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;g=b+2|0;c[194161]=g;h=k>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=g>>>24;m=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>1]|0;n=b}else{b=k&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=k>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=g>>>24;m=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=4836;break}g=b&255;if((b&2|0)==0){h=g>>>1|b&-256;c[194192]=h;o=(d[130328+m|0]|0)-1|0;p=h;j=4837;break}else{h=g>>>2|b&-256;c[194192]=h;q=h;r=3;j=4838;break}}else{j=4836}}while(0);if((j|0)==4836){c[194192]=0;o=d[130616+m|0]|0;p=0;j=4837}if((j|0)==4837){h=o+3|0;if(n){q=p;r=h;j=4838}else{s=h;j=4844}}do{if((j|0)==4838){if((q&1|0)==0){if(q>>>0<=255){s=r;j=4844;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}h=q&255;if((q&2|0)==0){c[194192]=h>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=h>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==4844){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function qT(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;h=c[776584+((b&15)<<2)>>2]|0;if((g&31|0)==0){i=f<<24>>24==0?(a[768256]&1)!=0:(h|0)<0;j=h}else{i=(1<<g-1&h|0)!=0;j=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;a[768240]=(g^j)>>>31&255;a[768224]=(g|0)==(j|0)|0;a[768256]=i&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=4860;break}c[194192]=0;l=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;l=0;break}}else{k=4860}}while(0);if((k|0)==4860){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=4870;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=4871;break}else{j=i>>>2|b&-256;c[194192]=j;r=j;s=4;k=4872;break}}else{k=4870}}while(0);if((k|0)==4870){c[194192]=0;p=d[130616+n|0]|0;q=0;k=4871}if((k|0)==4871){j=p+4|0;if(o){r=q;s=j;k=4872}else{t=j;k=4878}}do{if((k|0)==4872){if((r&1|0)==0){if(r>>>0<=255){t=s;k=4878;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==4878){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function qU(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-(c[776584+((b&15)<<2)>>2]|0)|0;c[776584+(e<<2)>>2]=ki(h)|0;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function qV(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-(c[776584+((b&15)<<2)>>2]|0)|0;c[776584+(e<<2)>>2]=(n0(h)|0)<<24>>24;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function qW(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-(c[776584+((b&15)<<2)>>2]|0)|0;b=ki(h)|0;if((h&1|0)==0){i=b&65535}else{i=(b&255)<<24>>24}c[776584+(e<<2)>>2]=i<<16>>16;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;i=e>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;i=f-2|0;do{if(i>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=f;l=i}else{i=h>>>24&15;j=3;k=i;l=i-2|0}i=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+i|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+i|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+i|0;o=n+m|0;c[204526]=o;return}function qX(b){b=b|0;var d=0;if((b&268374015|0)==21954560){c[776584+((b>>>12&15)<<2)>>2]=c[194163];return}b=c[194161]|0;d=(a[52040]&1)!=0;if((c[31194]|0)!=27){km(27,1,0)}c[194160]=b-(d?4:2);c[194161]=4;a[52040]=1;a[130632]=0;c[194193]=4;d=c[193635]|0;b=c[193634]|0;c[203402]=c[b+(d&4)>>2];c[203400]=c[b+(d&8)>>2];c[194161]=8;return}function qY(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);g=c[776584+((b>>>16&15)<<2)>>2]|0;h=(g-f|0)>>>31;a[768240]=h&255;a[768224]=(g|0)==(f|0)|0;i=g>>>31;g=f>>>31;f=g^1;j=f&i;k=h^1;a[768232]=(j&k|(i^1)&g&h)&255;a[768256]=(k&i|j|k&f)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){l=4976;break}c[194192]=0;m=d[130616+b|0]|0;break}k=f&255;if((f&2|0)==0){c[194192]=k>>>1|f&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|f&-256;m=0;break}}else{l=4976}}while(0);if((l|0)==4976){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;f=b+2|0;c[194161]=f;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=f>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&f)>>1]|0;p=b}else{b=m&-4;c[194193]=b;f=b+4|0;c[194161]=f;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=f>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&f)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=4986;break}f=b&255;if((b&2|0)==0){k=f>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=4987;break}else{k=f>>>2|b&-256;c[194192]=k;s=k;t=3;l=4988;break}}else{l=4986}}while(0);if((l|0)==4986){c[194192]=0;q=d[130616+o|0]|0;r=0;l=4987}if((l|0)==4987){k=q+3|0;if(p){s=r;t=k;l=4988}else{u=k;l=4994}}do{if((l|0)==4988){if((s&1|0)==0){if(s>>>0<=255){u=t;l=4994;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==4994){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function qZ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;do{if((f<<24>>24|0)==0){h=c[776584+((b&15)<<2)>>2]|0}else if((f<<24>>24|0)==32){h=0}else{if((f&255)>=32){h=0;break}h=c[776584+((b&15)<<2)>>2]<<g}}while(0);g=c[776584+((b>>>16&15)<<2)>>2]|0;f=(g-h|0)>>>31;a[768240]=f&255;a[768224]=(g|0)==(h|0)|0;i=g>>>31;g=h>>>31;h=g^1;j=i&h;k=f^1;a[768232]=(k&j|(i^1)&g&f)&255;a[768256]=(k&i|j|k&h)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=5011;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=5011}}while(0);if((l|0)==5011){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=5021;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=5022;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=4;l=5023;break}}else{l=5021}}while(0);if((l|0)==5021){c[194192]=0;q=d[130616+o|0]|0;r=0;l=5022}if((l|0)==5022){k=q+4|0;if(p){s=r;t=k;l=5023}else{u=k;l=5029}}do{if((l|0)==5023){if((s&1|0)==0){if(s>>>0<=255){u=t;l=5029;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==5029){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function q_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=c[776584+((b>>>16&15)<<2)>>2]|0;f=(n0(e)|0)&255;n2(e,a[776584+((b&15)<<2)|0]|0);c[776584+((b>>>12&15)<<2)>>2]=f;f=e>>>24&15;e=d[130616+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);f=(e<<1)+4|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}g=b&255;if((b&2|0)==0){c[194192]=g>>>1|b&-256;h=(d[130328+e|0]|0)-1|0;i=f+h|0;c[204526]=i;return}else{c[194192]=g>>>2|b&-256;h=0;i=f+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=f+h|0;c[204526]=i;return}function q$(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=(c[776584+((e>>>16&15)<<2)>>2]|0)-(e>>>4&240|e&15)|0;kh(f,b[776584+((e>>>12&15)<<2)>>1]|0);e=f>>>24&15;f=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);e=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}h=g&255;if((g&2|0)==0){c[194192]=h>>>1|g&-256;i=(d[130328+f|0]|0)-1|0;j=e+i|0;c[204526]=j;return}else{c[194192]=h>>>2|g&-256;i=0;j=e+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+f|0]|0;j=e+i|0;c[204526]=j;return}function q0(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]|0;h=(f-g|0)>>>31;a[768240]=h&255;a[768224]=(f|0)==(g|0)|0;i=f>>>31;f=g>>>31;g=f^1;j=i&g;k=h^1;a[768232]=(k&j|(i^1)&f&h)&255;a[768256]=(k&i|j|k&g)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){l=5074;break}c[194192]=0;m=d[130616+b|0]|0;break}k=g&255;if((g&2|0)==0){c[194192]=k>>>1|g&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|g&-256;m=0;break}}else{l=5074}}while(0);if((l|0)==5074){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;g=b+2|0;c[194161]=g;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=g>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>1]|0;p=b}else{b=m&-4;c[194193]=b;g=b+4|0;c[194161]=g;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=g>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=5084;break}g=b&255;if((b&2|0)==0){k=g>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=5085;break}else{k=g>>>2|b&-256;c[194192]=k;s=k;t=3;l=5086;break}}else{l=5084}}while(0);if((l|0)==5084){c[194192]=0;q=d[130616+o|0]|0;r=0;l=5085}if((l|0)==5085){k=q+3|0;if(p){s=r;t=k;l=5086}else{u=k;l=5092}}do{if((l|0)==5086){if((s&1|0)==0){if(s>>>0<=255){u=t;l=5092;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==5092){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function q1(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;do{if((f<<24>>24|0)==0){h=c[776584+((b&15)<<2)>>2]|0}else if((f<<24>>24|0)==32){h=0}else{if((f&255)>=32){h=0;break}h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}}while(0);g=c[776584+((b>>>16&15)<<2)>>2]|0;f=(g-h|0)>>>31;a[768240]=f&255;a[768224]=(g|0)==(h|0)|0;i=g>>>31;g=h>>>31;h=g^1;j=i&h;k=f^1;a[768232]=(k&j|(i^1)&g&f)&255;a[768256]=(k&i|j|k&h)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=5109;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=5109}}while(0);if((l|0)==5109){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=5119;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=5120;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=4;l=5121;break}}else{l=5119}}while(0);if((l|0)==5119){c[194192]=0;q=d[130616+o|0]|0;r=0;l=5120}if((l|0)==5120){k=q+4|0;if(p){s=r;t=k;l=5121}else{u=k;l=5127}}do{if((l|0)==5121){if((s&1|0)==0){if(s>>>0<=255){u=t;l=5127;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==5127){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function q2(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f);f=c[776584+((b>>>16&15)<<2)>>2]|0;h=(f-g|0)>>>31;a[768240]=h&255;a[768224]=(f|0)==(g|0)|0;i=f>>>31;f=g>>>31;g=f^1;j=g&i;k=h^1;a[768232]=(j&k|(i^1)&f&h)&255;a[768256]=(k&i|j|k&g)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){l=5140;break}c[194192]=0;m=d[130616+b|0]|0;break}k=g&255;if((g&2|0)==0){c[194192]=k>>>1|g&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|g&-256;m=0;break}}else{l=5140}}while(0);if((l|0)==5140){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;g=b+2|0;c[194161]=g;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=g>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>1]|0;p=b}else{b=m&-4;c[194193]=b;g=b+4|0;c[194161]=g;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=g>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&g)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=5150;break}g=b&255;if((b&2|0)==0){k=g>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=5151;break}else{k=g>>>2|b&-256;c[194192]=k;s=k;t=3;l=5152;break}}else{l=5150}}while(0);if((l|0)==5150){c[194192]=0;q=d[130616+o|0]|0;r=0;l=5151}if((l|0)==5151){k=q+3|0;if(p){s=r;t=k;l=5152}else{u=k;l=5158}}do{if((l|0)==5152){if((s&1|0)==0){if(s>>>0<=255){u=t;l=5158;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==5158){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function q3(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;do{if((f&255)<32){h=c[776584+((b&15)<<2)>>2]|0;if(f<<24>>24==0){i=h;break}i=h>>g}else{i=c[776584+((b&15)<<2)>>2]>>31}}while(0);g=c[776584+((b>>>16&15)<<2)>>2]|0;f=(g-i|0)>>>31;a[768240]=f&255;a[768224]=(g|0)==(i|0)|0;h=g>>>31;g=i>>>31;i=g^1;j=h&i;k=f^1;a[768232]=(k&j|(h^1)&g&f)&255;a[768256]=(k&h|j|k&i)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=5175;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=5175}}while(0);if((l|0)==5175){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=5185;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=5186;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=4;l=5187;break}}else{l=5185}}while(0);if((l|0)==5185){c[194192]=0;q=d[130616+o|0]|0;r=0;l=5186}if((l|0)==5186){k=q+4|0;if(p){s=r;t=k;l=5187}else{u=k;l=5193}}do{if((l|0)==5187){if((s&1|0)==0){if(s>>>0<=255){u=t;l=5193;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==5193){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function q4(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]|0;g=(f-h|0)>>>31;a[768240]=g&255;a[768224]=(f|0)==(h|0)|0;i=f>>>31;f=h>>>31;h=f^1;j=i&h;k=g^1;a[768232]=(k&j|(i^1)&f&g)&255;a[768256]=(k&i|j|k&h)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=5209;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=5209}}while(0);if((l|0)==5209){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=5219;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=5220;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=3;l=5221;break}}else{l=5219}}while(0);if((l|0)==5219){c[194192]=0;q=d[130616+o|0]|0;r=0;l=5220}if((l|0)==5220){k=q+3|0;if(p){s=r;t=k;l=5221}else{u=k;l=5227}}do{if((l|0)==5221){if((s&1|0)==0){if(s>>>0<=255){u=t;l=5227;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==5227){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function q5(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]|0;g=(f-h|0)>>>31;a[768240]=g&255;a[768224]=(f|0)==(h|0)|0;i=f>>>31;f=h>>>31;h=f^1;j=i&h;k=g^1;a[768232]=(k&j|(i^1)&f&g)&255;a[768256]=(k&i|j|k&h)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=5242;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=5242}}while(0);if((l|0)==5242){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=5252;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=5253;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=4;l=5254;break}}else{l=5252}}while(0);if((l|0)==5252){c[194192]=0;q=d[130616+o|0]|0;r=0;l=5253}if((l|0)==5253){k=q+4|0;if(p){s=r;t=k;l=5254}else{u=k;l=5260}}do{if((l|0)==5254){if((s&1|0)==0){if(s>>>0<=255){u=t;l=5260;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==5260){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function q6(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(b>>>4&240|b&15)|0;c[776584+(e<<2)>>2]=ki(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function q7(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(b>>>4&240|b&15)|0;c[776584+(e<<2)>>2]=(n0(f)|0)<<24>>24;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function q8(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(b>>>4&240|b&15)|0;b=ki(f)|0;if((f&1|0)==0){g=b&65535}else{g=(b&255)<<24>>24}c[776584+(e<<2)>>2]=g<<16>>16;c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=f>>>24&15;g=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function q9(b){b=b|0;var d=0,e=0;if((b&267452400|0)!=23130112){d=c[194161]|0;e=(a[52040]&1)!=0;if((c[31194]|0)!=27){km(27,1,0)}c[194160]=d-(e?4:2);c[194161]=4;a[52040]=1;a[130632]=0;c[194193]=4;e=c[193635]|0;d=c[193634]|0;c[203402]=c[d+(e&4)>>2];c[203400]=c[d+(e&8)>>2];c[194161]=8;return}e=c[776584+((b&15)<<2)>>2]|0;if(((c[31194]|0)-17|0)>>>0>=14){return}if((b&65536|0)!=0){c[194163]=c[194163]&-256|e&255}if((b&131072|0)!=0){c[194163]=c[194163]&-65281|e&65280}if((b&262144|0)!=0){c[194163]=c[194163]&-16711681|e&16711680}if((b&524288|0)==0){return}c[194163]=c[194163]&16777215|e&-16777216;return}function ra(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=776584+((e>>>16&15)<<2)|0;g=(c[f>>2]|0)-(e>>>4&240|e&15)|0;c[f>>2]=g;kh(g,b[776584+((e>>>12&15)<<2)>>1]|0);e=g>>>24&15;g=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}h=f&255;if((f&2|0)==0){c[194192]=h>>>1|f&-256;i=(d[130328+g|0]|0)-1|0;j=e+i|0;c[204526]=j;return}else{c[194192]=h>>>2|f&-256;i=0;j=e+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+g|0]|0;j=e+i|0;c[204526]=j;return}function rb(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g+f|0;i=h>>>31;a[768240]=i&255;a[768224]=(h|0)==0|0;h=g>>>31;g=f>>>31;f=h&g;j=i^1;a[768232]=(j&f|(h^1)&(g^1)&i)&255;a[768256]=(j&h|f|j&g)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=5378;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=5378}}while(0);if((k|0)==5378){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=5388;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=5389;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=3;k=5390;break}}else{k=5388}}while(0);if((k|0)==5388){c[194192]=0;p=d[130616+n|0]|0;q=0;k=5389}if((k|0)==5389){j=p+3|0;if(o){r=q;s=j;k=5390}else{t=j;k=5396}}do{if((k|0)==5390){if((r&1|0)==0){if(r>>>0<=255){t=s;k=5396;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==5396){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rc(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;do{if((f<<24>>24|0)==32){h=0}else if((f<<24>>24|0)==0){h=c[776584+((b&15)<<2)>>2]|0}else{if((f&255)>=32){h=0;break}h=c[776584+((b&15)<<2)>>2]<<g}}while(0);g=c[776584+((b>>>16&15)<<2)>>2]|0;f=g+h|0;i=f>>>31;a[768240]=i&255;a[768224]=(f|0)==0|0;f=g>>>31;g=h>>>31;h=f&g;j=i^1;a[768232]=(j&h|(f^1)&(g^1)&i)&255;a[768256]=(j&f|h|j&g)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=5413;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=5413}}while(0);if((k|0)==5413){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=5423;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=5424;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=4;k=5425;break}}else{k=5423}}while(0);if((k|0)==5423){c[194192]=0;p=d[130616+n|0]|0;q=0;k=5424}if((k|0)==5424){j=p+4|0;if(o){r=q;s=j;k=5425}else{t=j;k=5431}}do{if((k|0)==5425){if((r&1|0)==0){if(r>>>0<=255){t=s;k=5431;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==5431){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rd(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]|0;h=f+g|0;i=h>>>31;a[768240]=i&255;a[768224]=(h|0)==0|0;h=f>>>31;f=g>>>31;g=h&f;j=i^1;a[768232]=(j&g|(h^1)&(f^1)&i)&255;a[768256]=(j&h|g|j&f)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){k=5446;break}c[194192]=0;l=d[130616+b|0]|0;break}j=f&255;if((f&2|0)==0){c[194192]=j>>>1|f&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|f&-256;l=0;break}}else{k=5446}}while(0);if((k|0)==5446){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;f=b+2|0;c[194161]=f;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=f>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&f)>>1]|0;o=b}else{b=l&-4;c[194193]=b;f=b+4|0;c[194161]=f;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=f>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&f)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=5456;break}f=b&255;if((b&2|0)==0){j=f>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=5457;break}else{j=f>>>2|b&-256;c[194192]=j;r=j;s=3;k=5458;break}}else{k=5456}}while(0);if((k|0)==5456){c[194192]=0;p=d[130616+n|0]|0;q=0;k=5457}if((k|0)==5457){j=p+3|0;if(o){r=q;s=j;k=5458}else{t=j;k=5464}}do{if((k|0)==5458){if((r&1|0)==0){if(r>>>0<=255){t=s;k=5464;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==5464){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function re(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;do{if((f<<24>>24|0)==32){h=0}else if((f<<24>>24|0)==0){h=c[776584+((b&15)<<2)>>2]|0}else{if((f&255)>=32){h=0;break}h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}}while(0);g=c[776584+((b>>>16&15)<<2)>>2]|0;f=g+h|0;i=f>>>31;a[768240]=i&255;a[768224]=(f|0)==0|0;f=g>>>31;g=h>>>31;h=f&g;j=i^1;a[768232]=(j&h|(f^1)&(g^1)&i)&255;a[768256]=(j&f|h|j&g)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=5481;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=5481}}while(0);if((k|0)==5481){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=5491;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=5492;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=4;k=5493;break}}else{k=5491}}while(0);if((k|0)==5491){c[194192]=0;p=d[130616+n|0]|0;q=0;k=5492}if((k|0)==5492){j=p+4|0;if(o){r=q;s=j;k=5493}else{t=j;k=5499}}do{if((k|0)==5493){if((r&1|0)==0){if(r>>>0<=255){t=s;k=5499;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==5499){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rf(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f);f=c[776584+((b>>>16&15)<<2)>>2]|0;h=f+g|0;i=h>>>31;a[768240]=i&255;a[768224]=(h|0)==0|0;h=f>>>31;f=g>>>31;g=h&f;j=i^1;a[768232]=(j&g|(h^1)&(f^1)&i)&255;a[768256]=(j&h|g|j&f)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){k=5512;break}c[194192]=0;l=d[130616+b|0]|0;break}j=f&255;if((f&2|0)==0){c[194192]=j>>>1|f&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|f&-256;l=0;break}}else{k=5512}}while(0);if((k|0)==5512){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;f=b+2|0;c[194161]=f;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=f>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&f)>>1]|0;o=b}else{b=l&-4;c[194193]=b;f=b+4|0;c[194161]=f;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=f>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&f)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=5522;break}f=b&255;if((b&2|0)==0){j=f>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=5523;break}else{j=f>>>2|b&-256;c[194192]=j;r=j;s=3;k=5524;break}}else{k=5522}}while(0);if((k|0)==5522){c[194192]=0;p=d[130616+n|0]|0;q=0;k=5523}if((k|0)==5523){j=p+3|0;if(o){r=q;s=j;k=5524}else{t=j;k=5530}}do{if((k|0)==5524){if((r&1|0)==0){if(r>>>0<=255){t=s;k=5530;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==5530){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rg(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a[776584+((b>>>8&15)<<2)|0]|0;g=f&255;do{if((f&255)<32){h=c[776584+((b&15)<<2)>>2]|0;if(f<<24>>24==0){i=h;break}i=h>>g}else{i=c[776584+((b&15)<<2)>>2]>>31}}while(0);g=c[776584+((b>>>16&15)<<2)>>2]|0;f=g+i|0;h=f>>>31;a[768240]=h&255;a[768224]=(f|0)==0|0;f=g>>>31;g=i>>>31;i=f&g;j=h^1;a[768232]=(j&i|(f^1)&(g^1)&h)&255;a[768256]=(j&f|i|j&g)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=5547;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=5547}}while(0);if((k|0)==5547){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=5557;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=5558;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=4;k=5559;break}}else{k=5557}}while(0);if((k|0)==5557){c[194192]=0;p=d[130616+n|0]|0;q=0;k=5558}if((k|0)==5558){j=p+4|0;if(o){r=q;s=j;k=5559}else{t=j;k=5565}}do{if((k|0)==5559){if((r&1|0)==0){if(r>>>0<=255){t=s;k=5565;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==5565){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rh(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]|0;g=f+h|0;i=g>>>31;a[768240]=i&255;a[768224]=(g|0)==0|0;g=f>>>31;f=h>>>31;h=g&f;j=i^1;a[768232]=(j&h|(g^1)&(f^1)&i)&255;a[768256]=(j&g|h|j&f)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){k=5581;break}c[194192]=0;l=d[130616+b|0]|0;break}j=f&255;if((f&2|0)==0){c[194192]=j>>>1|f&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|f&-256;l=0;break}}else{k=5581}}while(0);if((k|0)==5581){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;f=b+2|0;c[194161]=f;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=f>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&f)>>1]|0;o=b}else{b=l&-4;c[194193]=b;f=b+4|0;c[194161]=f;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=f>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&f)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=5591;break}f=b&255;if((b&2|0)==0){j=f>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=5592;break}else{j=f>>>2|b&-256;c[194192]=j;r=j;s=3;k=5593;break}}else{k=5591}}while(0);if((k|0)==5591){c[194192]=0;p=d[130616+n|0]|0;q=0;k=5592}if((k|0)==5592){j=p+3|0;if(o){r=q;s=j;k=5593}else{t=j;k=5599}}do{if((k|0)==5593){if((r&1|0)==0){if(r>>>0<=255){t=s;k=5599;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==5599){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function ri(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]|0;g=f+h|0;i=g>>>31;a[768240]=i&255;a[768224]=(g|0)==0|0;g=f>>>31;f=h>>>31;h=g&f;j=i^1;a[768232]=(j&h|(g^1)&(f^1)&i)&255;a[768256]=(j&g|h|j&f)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){k=5614;break}c[194192]=0;l=d[130616+b|0]|0;break}j=f&255;if((f&2|0)==0){c[194192]=j>>>1|f&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|f&-256;l=0;break}}else{k=5614}}while(0);if((k|0)==5614){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;f=b+2|0;c[194161]=f;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=f>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&f)>>1]|0;o=b}else{b=l&-4;c[194193]=b;f=b+4|0;c[194161]=f;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=f>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&f)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=5624;break}f=b&255;if((b&2|0)==0){j=f>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=5625;break}else{j=f>>>2|b&-256;c[194192]=j;r=j;s=4;k=5626;break}}else{k=5624}}while(0);if((k|0)==5624){c[194192]=0;p=d[130616+n|0]|0;q=0;k=5625}if((k|0)==5625){j=p+4|0;if(o){r=q;s=j;k=5626}else{t=j;k=5632}}do{if((k|0)==5626){if((r&1|0)==0){if(r>>>0<=255){t=s;k=5632;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==5632){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rj(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-(b>>>4&240|b&15)|0;c[776584+(e<<2)>>2]=ki(h)|0;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function rk(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-(b>>>4&240|b&15)|0;c[776584+(e<<2)>>2]=(n0(h)|0)<<24>>24;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function rl(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]|c[776584+((b&15)<<2)>>2]<<(b>>>7&31);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=5695;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=5695}}while(0);if((g|0)==5695){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=5705;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=5706;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=5707;break}}else{g=5705}}while(0);if((g|0)==5705){c[194192]=0;m=d[130616+k|0]|0;n=0;g=5706}if((g|0)==5706){i=m+3|0;if(l){o=n;p=i;g=5707}else{q=i;g=5713}}do{if((g|0)==5707){if((o&1|0)==0){if(o>>>0<=255){q=p;g=5713;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==5713){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function rm(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]|i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=5730;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=5730}}while(0);if((j|0)==5730){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=5740;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=5741;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=5742;break}}else{j=5740}}while(0);if((j|0)==5740){c[194192]=0;o=d[130616+m|0]|0;p=0;j=5741}if((j|0)==5741){f=o+4|0;if(n){q=p;r=f;j=5742}else{s=f;j=5748}}do{if((j|0)==5742){if((q&1|0)==0){if(q>>>0<=255){s=r;j=5748;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==5748){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function rn(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]|g;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=5763;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=5763}}while(0);if((h|0)==5763){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=5773;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=5774;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=5775;break}}else{h=5773}}while(0);if((h|0)==5773){c[194192]=0;m=d[130616+k|0]|0;n=0;h=5774}if((h|0)==5774){f=m+3|0;if(l){o=n;p=f;h=5775}else{q=f;h=5781}}do{if((h|0)==5775){if((o&1|0)==0){if(o>>>0<=255){q=p;h=5781;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==5781){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function ro(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-(b>>>4&240|b&15)|0;b=ki(h)|0;if((h&1|0)==0){i=b&65535}else{i=(b&255)<<24>>24}c[776584+(e<<2)>>2]=i<<16>>16;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;i=e>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;i=f-2|0;do{if(i>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=f;l=i}else{i=h>>>24&15;j=3;k=i;l=i-2|0}i=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+i|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+i|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+i|0;o=n+m|0;c[204526]=o;return}function rp(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]|i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=5825;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=5825}}while(0);if((j|0)==5825){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=5835;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=5836;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=5837;break}}else{j=5835}}while(0);if((j|0)==5835){c[194192]=0;o=d[130616+m|0]|0;p=0;j=5836}if((j|0)==5836){f=o+4|0;if(n){q=p;r=f;j=5837}else{s=f;j=5843}}do{if((j|0)==5837){if((q&1|0)==0){if(q>>>0<=255){s=r;j=5843;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==5843){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function rq(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]|c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=5856;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=5856}}while(0);if((g|0)==5856){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=5866;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=5867;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=5868;break}}else{g=5866}}while(0);if((g|0)==5866){c[194192]=0;m=d[130616+k|0]|0;n=0;g=5867}if((g|0)==5867){i=m+3|0;if(l){o=n;p=i;g=5868}else{q=i;g=5874}}do{if((g|0)==5868){if((o&1|0)==0){if(o>>>0<=255){q=p;g=5874;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==5874){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function rr(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]|j;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=5891;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=5891}}while(0);if((k|0)==5891){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=5901;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=5902;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=5903;break}}else{k=5901}}while(0);if((k|0)==5901){c[194192]=0;p=d[130616+n|0]|0;q=0;k=5902}if((k|0)==5902){f=p+4|0;if(o){r=q;s=f;k=5903}else{t=f;k=5909}}do{if((k|0)==5903){if((r&1|0)==0){if(r>>>0<=255){t=s;k=5909;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==5909){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rs(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]|h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=5925;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=5925}}while(0);if((i|0)==5925){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=5935;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=5936;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=5937;break}}else{i=5935}}while(0);if((i|0)==5935){c[194192]=0;n=d[130616+l|0]|0;o=0;i=5936}if((i|0)==5936){f=n+3|0;if(m){p=o;q=f;i=5937}else{r=f;i=5943}}do{if((i|0)==5937){if((p&1|0)==0){if(p>>>0<=255){r=q;i=5943;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==5943){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function rt(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]|h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=5958;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=5958}}while(0);if((i|0)==5958){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=5968;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=5969;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=5970;break}}else{i=5968}}while(0);if((i|0)==5968){c[194192]=0;n=d[130616+l|0]|0;o=0;i=5969}if((i|0)==5969){f=n+4|0;if(m){p=o;q=f;i=5970}else{r=f;i=5976}}do{if((i|0)==5970){if((p&1|0)==0){if(p>>>0<=255){r=q;i=5976;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==5976){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function ru(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=(c[776584+((e>>>16&15)<<2)>>2]|0)+(c[776584+((e&15)<<2)>>2]|0)|0;kh(f,b[776584+((e>>>12&15)<<2)>>1]|0);e=f>>>24&15;f=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);e=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}h=g&255;if((g&2|0)==0){c[194192]=h>>>1|g&-256;i=(d[130328+f|0]|0)-1|0;j=e+i|0;c[204526]=j;return}else{c[194192]=h>>>2|g&-256;i=0;j=e+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+f|0]|0;j=e+i|0;c[204526]=j;return}function rv(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(h&1<<32-g|0)!=0;j=h<<g}g=c[776584+((b>>>16&15)<<2)>>2]|j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=6010;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=6010}}while(0);if((k|0)==6010){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6022;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=6023;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=6024;break}}else{k=6022}}while(0);if((k|0)==6022){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6023}if((k|0)==6023){g=p+3|0;if(o){r=q;s=g;k=6024}else{t=g;k=6030}}do{if((k|0)==6024){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6030;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6030){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rw(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]&1|0)!=0;j=0}else if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<32-h|0)!=0;j=k<<h}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|j;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(h|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=6050;break}c[194192]=0;m=d[130616+b|0]|0;break}h=i&255;if((i&2|0)==0){c[194192]=h>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=h>>>2|i&-256;m=0;break}}else{l=6050}}while(0);if((l|0)==6050){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;h=m>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=i>>>24;o=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;h=m>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=i>>>24;o=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=6062;break}i=b&255;if((b&2|0)==0){h=i>>>1|b&-256;c[194192]=h;q=(d[130328+o|0]|0)-1|0;r=h;l=6063;break}else{h=i>>>2|b&-256;c[194192]=h;s=h;t=4;l=6064;break}}else{l=6062}}while(0);if((l|0)==6062){c[194192]=0;q=d[130616+o|0]|0;r=0;l=6063}if((l|0)==6063){h=q+4|0;if(p){s=r;t=h;l=6064}else{u=h;l=6070}}do{if((l|0)==6064){if((s&1|0)==0){if(s>>>0<=255){u=t;l=6070;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}h=s&255;if((s&2|0)==0){c[194192]=h>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=h>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==6070){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function rx(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=h>>>31;j=0}else{i=h&1<<g-1;j=h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=(i|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=6088;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=6088}}while(0);if((k|0)==6088){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6100;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=6101;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=6102;break}}else{k=6100}}while(0);if((k|0)==6100){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6101}if((k|0)==6101){g=p+3|0;if(o){r=q;s=g;k=6102}else{t=g;k=6108}}do{if((k|0)==6102){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6108;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6108){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function ry(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]|0)<0;j=0}else if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<h-1|0)!=0;j=k>>>(h>>>0)}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]|j;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(h|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=6128;break}c[194192]=0;m=d[130616+b|0]|0;break}h=i&255;if((i&2|0)==0){c[194192]=h>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=h>>>2|i&-256;m=0;break}}else{l=6128}}while(0);if((l|0)==6128){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;h=m>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=i>>>24;o=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;h=m>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=i>>>24;o=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=6140;break}i=b&255;if((b&2|0)==0){h=i>>>1|b&-256;c[194192]=h;q=(d[130328+o|0]|0)-1|0;r=h;l=6141;break}else{h=i>>>2|b&-256;c[194192]=h;s=h;t=4;l=6142;break}}else{l=6140}}while(0);if((l|0)==6140){c[194192]=0;q=d[130616+o|0]|0;r=0;l=6141}if((l|0)==6141){h=q+4|0;if(p){s=r;t=h;l=6142}else{u=h;l=6148}}do{if((l|0)==6142){if((s&1|0)==0){if(s>>>0<=255){u=t;l=6148;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}h=s&255;if((s&2|0)==0){c[194192]=h>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=h>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==6148){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function rz(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(h|0)<0;j=31}else{i=(h&1<<g-1|0)!=0;j=g}g=c[776584+((b>>>16&15)<<2)>>2]|h>>j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=6166;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=6166}}while(0);if((k|0)==6166){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6178;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=6179;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=6180;break}}else{k=6178}}while(0);if((k|0)==6178){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6179}if((k|0)==6179){g=p+3|0;if(o){r=q;s=g;k=6180}else{t=g;k=6186}}do{if((k|0)==6180){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6186;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6186){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rA(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=b>>>12&15;g=a[768256]|0;h=a[776584+((b>>>8&15)<<2)|0]|0;i=h&255;do{if((h&255)<32){j=c[776584+((b&15)<<2)>>2]|0;if(h<<24>>24==0){k=(g&1)!=0;l=j;break}else{k=(j&1<<i-1|0)!=0;l=j>>i;break}}else{j=c[776584+((b&15)<<2)>>2]|0;k=(j|0)<0;l=j>>31}}while(0);i=c[776584+((b>>>16&15)<<2)>>2]|l;c[776584+(f<<2)>>2]=i;if((f|0)!=15){a[768240]=i>>>31&255;a[768224]=(i|0)==0|0;a[768256]=k&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){if(k>>>0<=255){m=6206;break}c[194192]=0;n=d[130616+b|0]|0;break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;n=d[130328+b|0]|0;break}else{c[194192]=i>>>2|k&-256;n=0;break}}else{m=6206}}while(0);if((m|0)==6206){n=d[125296+b|0]|0}o=n+2|0;c[204526]=o;return}n=c[194163]&31;if((c[31194]|0)!=(n|0)){km(n,0,1)}n=c[194161]|0;if((a[52040]&1)==0){b=n&-2;c[194193]=b;k=b+2|0;c[194161]=k;i=n>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=k>>>24;p=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&k)>>1]|0;q=b}else{b=n&-4;c[194193]=b;k=b+4|0;c[194161]=k;i=n>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=k>>>24;p=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&k)>>2]|0;q=b}c[203400]=p;p=q>>>24&15;q=(p-8|0)>>>0<6;do{if(q){b=c[194192]|0;if((b&1|0)==0){m=6218;break}k=b&255;if((b&2|0)==0){i=k>>>1|b&-256;c[194192]=i;r=(d[130328+p|0]|0)-1|0;s=i;m=6219;break}else{i=k>>>2|b&-256;c[194192]=i;t=i;u=4;m=6220;break}}else{m=6218}}while(0);if((m|0)==6218){c[194192]=0;r=d[130616+p|0]|0;s=0;m=6219}if((m|0)==6219){i=r+4|0;if(q){t=s;u=i;m=6220}else{v=i;m=6226}}do{if((m|0)==6220){if((t&1|0)==0){if(t>>>0<=255){v=u;m=6226;break}c[194192]=0;w=d[130616+p|0]|0;x=u;break}i=t&255;if((t&2|0)==0){c[194192]=i>>>1|t&-256;w=d[130328+p|0]|0;x=u;break}else{c[194192]=i>>>2|t&-256;w=0;x=u;break}}}while(0);if((m|0)==6226){w=d[125296+p|0]|0;x=v}o=(w<<1)+x|0;c[204526]=o;return}function rB(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=1;j=(d[768256]|0)<<31|h>>>1}else{i=1<<g-1;j=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=(i&h|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=6244;break}c[194192]=0;l=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;l=0;break}}else{k=6244}}while(0);if((k|0)==6244){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6256;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=6257;break}else{i=h>>>2|b&-256;c[194192]=i;r=i;s=3;k=6258;break}}else{k=6256}}while(0);if((k|0)==6256){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6257}if((k|0)==6257){i=p+3|0;if(o){r=q;s=i;k=6258}else{t=i;k=6264}}do{if((k|0)==6258){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6264;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6264){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rC(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;i=c[776584+((b&15)<<2)>>2]|0;if((h&31|0)==0){j=g<<24>>24==0?(a[768256]&1)!=0:(i|0)<0;k=i}else{j=(1<<h-1&i|0)!=0;k=i<<32-h|i>>>(h>>>0)}h=c[776584+((b>>>16&15)<<2)>>2]|k;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(h|0)==0|0;a[768256]=j&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=6282;break}c[194192]=0;m=d[130616+b|0]|0;break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=h>>>2|j&-256;m=0;break}}else{l=6282}}while(0);if((l|0)==6282){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;h=m>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=j>>>24;o=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;h=m>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=j>>>24;o=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=6294;break}j=b&255;if((b&2|0)==0){h=j>>>1|b&-256;c[194192]=h;q=(d[130328+o|0]|0)-1|0;r=h;l=6295;break}else{h=j>>>2|b&-256;c[194192]=h;s=h;t=4;l=6296;break}}else{l=6294}}while(0);if((l|0)==6294){c[194192]=0;q=d[130616+o|0]|0;r=0;l=6295}if((l|0)==6295){h=q+4|0;if(p){s=r;t=h;l=6296}else{u=h;l=6302}}do{if((l|0)==6296){if((s&1|0)==0){if(s>>>0<=255){u=t;l=6302;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}h=s&255;if((s&2|0)==0){c[194192]=h>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=h>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==6302){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function rD(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]|0)|0;c[776584+(e<<2)>>2]=ki(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function rE(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]|0)|0;c[776584+(e<<2)>>2]=(n0(f)|0)<<24>>24;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function rF(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]|0)|0;b=ki(f)|0;if((f&1|0)==0){g=b&65535}else{g=(b&255)<<24>>24}c[776584+(e<<2)>>2]=g<<16>>16;c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=f>>>24&15;g=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function rG(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=6386;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=6386}}while(0);if((g|0)==6386){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=6396;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=6397;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=6398;break}}else{g=6396}}while(0);if((g|0)==6396){c[194192]=0;m=d[130616+k|0]|0;n=0;g=6397}if((g|0)==6397){i=m+3|0;if(l){o=n;p=i;g=6398}else{q=i;g=6404}}do{if((g|0)==6398){if((o&1|0)==0){if(o>>>0<=255){q=p;g=6404;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==6404){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function rH(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=6421;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=6421}}while(0);if((j|0)==6421){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=6431;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=6432;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=6433;break}}else{j=6431}}while(0);if((j|0)==6431){c[194192]=0;o=d[130616+m|0]|0;p=0;j=6432}if((j|0)==6432){f=o+4|0;if(n){q=p;r=f;j=6433}else{s=f;j=6439}}do{if((j|0)==6433){if((q&1|0)==0){if(q>>>0<=255){s=r;j=6439;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==6439){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function rI(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=g;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=6454;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=6454}}while(0);if((h|0)==6454){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=6464;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=6465;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=6466;break}}else{h=6464}}while(0);if((h|0)==6464){c[194192]=0;m=d[130616+k|0]|0;n=0;h=6465}if((h|0)==6465){f=m+3|0;if(l){o=n;p=f;h=6466}else{q=f;h=6472}}do{if((h|0)==6466){if((o&1|0)==0){if(o>>>0<=255){q=p;h=6472;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==6472){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function rJ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=6489;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=6489}}while(0);if((j|0)==6489){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=6499;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=6500;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=6501;break}}else{j=6499}}while(0);if((j|0)==6499){c[194192]=0;o=d[130616+m|0]|0;p=0;j=6500}if((j|0)==6500){f=o+4|0;if(n){q=p;r=f;j=6501}else{s=f;j=6507}}do{if((j|0)==6501){if((q&1|0)==0){if(q>>>0<=255){s=r;j=6507;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==6507){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function rK(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=6520;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=6520}}while(0);if((g|0)==6520){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=6530;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=6531;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=6532;break}}else{g=6530}}while(0);if((g|0)==6530){c[194192]=0;m=d[130616+k|0]|0;n=0;g=6531}if((g|0)==6531){i=m+3|0;if(l){o=n;p=i;g=6532}else{q=i;g=6538}}do{if((g|0)==6532){if((o&1|0)==0){if(o>>>0<=255){q=p;g=6538;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==6538){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function rL(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=j;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=6555;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=6555}}while(0);if((k|0)==6555){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6565;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=6566;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=6567;break}}else{k=6565}}while(0);if((k|0)==6565){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6566}if((k|0)==6566){f=p+4|0;if(o){r=q;s=f;k=6567}else{t=f;k=6573}}do{if((k|0)==6567){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6573;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6573){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rM(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=6589;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=6589}}while(0);if((i|0)==6589){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=6599;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=6600;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=6601;break}}else{i=6599}}while(0);if((i|0)==6599){c[194192]=0;n=d[130616+l|0]|0;o=0;i=6600}if((i|0)==6600){f=n+3|0;if(m){p=o;q=f;i=6601}else{r=f;i=6607}}do{if((i|0)==6601){if((p&1|0)==0){if(p>>>0<=255){r=q;i=6607;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==6607){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function rN(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=6622;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=6622}}while(0);if((i|0)==6622){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=6632;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=6633;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=6634;break}}else{i=6632}}while(0);if((i|0)==6632){c[194192]=0;n=d[130616+l|0]|0;o=0;i=6633}if((i|0)==6633){f=n+4|0;if(m){p=o;q=f;i=6634}else{r=f;i=6640}}do{if((i|0)==6634){if((p&1|0)==0){if(p>>>0<=255){r=q;i=6640;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==6640){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function rO(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=776584+((e>>>16&15)<<2)|0;g=(c[f>>2]|0)+(c[776584+((e&15)<<2)>>2]|0)|0;c[f>>2]=g;kh(g,b[776584+((e>>>12&15)<<2)>>1]|0);e=g>>>24&15;g=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}h=f&255;if((f&2|0)==0){c[194192]=h>>>1|f&-256;i=(d[130328+g|0]|0)-1|0;j=e+i|0;c[204526]=j;return}else{c[194192]=h>>>2|f&-256;i=0;j=e+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+g|0]|0;j=e+i|0;c[204526]=j;return}function rP(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(h&1<<32-g|0)!=0;j=h<<g}c[776584+(f<<2)>>2]=j;if((f|0)!=15){a[768240]=j>>>31&255;a[768224]=(j|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=6674;break}c[194192]=0;l=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;l=0;break}}else{k=6674}}while(0);if((k|0)==6674){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6686;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=6687;break}else{j=i>>>2|b&-256;c[194192]=j;r=j;s=3;k=6688;break}}else{k=6686}}while(0);if((k|0)==6686){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6687}if((k|0)==6687){j=p+3|0;if(o){r=q;s=j;k=6688}else{t=j;k=6694}}do{if((k|0)==6688){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6694;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6694){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rQ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]&1|0)!=0;j=0}else if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<32-h|0)!=0;j=k<<h}}while(0);c[776584+(f<<2)>>2]=j;if((f|0)!=15){a[768240]=j>>>31&255;a[768224]=(j|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=6714;break}c[194192]=0;m=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;m=0;break}}else{l=6714}}while(0);if((l|0)==6714){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=m>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;o=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=m>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;o=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=6726;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;q=(d[130328+o|0]|0)-1|0;r=j;l=6727;break}else{j=i>>>2|b&-256;c[194192]=j;s=j;t=4;l=6728;break}}else{l=6726}}while(0);if((l|0)==6726){c[194192]=0;q=d[130616+o|0]|0;r=0;l=6727}if((l|0)==6727){j=q+4|0;if(p){s=r;t=j;l=6728}else{u=j;l=6734}}do{if((l|0)==6728){if((s&1|0)==0){if(s>>>0<=255){u=t;l=6734;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}j=s&255;if((s&2|0)==0){c[194192]=j>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=j>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==6734){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function rR(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=h>>>31;j=0}else{i=h&1<<g-1;j=h>>>(g>>>0)}c[776584+(f<<2)>>2]=j;if((f|0)!=15){a[768240]=j>>>31&255;a[768224]=(j|0)==0|0;a[768256]=(i|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=6752;break}c[194192]=0;l=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;l=0;break}}else{k=6752}}while(0);if((k|0)==6752){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6764;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=6765;break}else{j=i>>>2|b&-256;c[194192]=j;r=j;s=3;k=6766;break}}else{k=6764}}while(0);if((k|0)==6764){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6765}if((k|0)==6765){j=p+3|0;if(o){r=q;s=j;k=6766}else{t=j;k=6772}}do{if((k|0)==6766){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6772;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6772){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rS(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]|0)<0;j=0}else if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<h-1|0)!=0;j=k>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=j;if((f|0)!=15){a[768240]=j>>>31&255;a[768224]=(j|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=6792;break}c[194192]=0;m=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;m=0;break}}else{l=6792}}while(0);if((l|0)==6792){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=m>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;o=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=m>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;o=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=6804;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;q=(d[130328+o|0]|0)-1|0;r=j;l=6805;break}else{j=i>>>2|b&-256;c[194192]=j;s=j;t=4;l=6806;break}}else{l=6804}}while(0);if((l|0)==6804){c[194192]=0;q=d[130616+o|0]|0;r=0;l=6805}if((l|0)==6805){j=q+4|0;if(p){s=r;t=j;l=6806}else{u=j;l=6812}}do{if((l|0)==6806){if((s&1|0)==0){if(s>>>0<=255){u=t;l=6812;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}j=s&255;if((s&2|0)==0){c[194192]=j>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=j>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==6812){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function rT(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(h|0)<0;j=31}else{i=(h&1<<g-1|0)!=0;j=g}g=h>>j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=6830;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=6830}}while(0);if((k|0)==6830){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6842;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=6843;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=6844;break}}else{k=6842}}while(0);if((k|0)==6842){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6843}if((k|0)==6843){g=p+3|0;if(o){r=q;s=g;k=6844}else{t=g;k=6850}}do{if((k|0)==6844){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6850;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6850){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rU(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=b>>>12&15;g=a[768256]|0;h=a[776584+((b>>>8&15)<<2)|0]|0;i=h&255;do{if((h&255)<32){j=c[776584+((b&15)<<2)>>2]|0;if(h<<24>>24==0){k=(g&1)!=0;l=j;break}else{k=(j&1<<i-1|0)!=0;l=j>>i;break}}else{j=c[776584+((b&15)<<2)>>2]|0;k=(j|0)<0;l=j>>31}}while(0);c[776584+(f<<2)>>2]=l;if((f|0)!=15){a[768240]=l>>>31&255;a[768224]=(l|0)==0|0;a[768256]=k&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){if(k>>>0<=255){m=6870;break}c[194192]=0;n=d[130616+b|0]|0;break}l=k&255;if((k&2|0)==0){c[194192]=l>>>1|k&-256;n=d[130328+b|0]|0;break}else{c[194192]=l>>>2|k&-256;n=0;break}}else{m=6870}}while(0);if((m|0)==6870){n=d[125296+b|0]|0}o=n+2|0;c[204526]=o;return}n=c[194163]&31;if((c[31194]|0)!=(n|0)){km(n,0,1)}n=c[194161]|0;if((a[52040]&1)==0){b=n&-2;c[194193]=b;k=b+2|0;c[194161]=k;l=n>>>24;c[203402]=e[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&b)>>1]|0;l=k>>>24;p=e[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&k)>>1]|0;q=b}else{b=n&-4;c[194193]=b;k=b+4|0;c[194161]=k;l=n>>>24;c[203402]=c[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&b)>>2];l=k>>>24;p=c[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&k)>>2]|0;q=b}c[203400]=p;p=q>>>24&15;q=(p-8|0)>>>0<6;do{if(q){b=c[194192]|0;if((b&1|0)==0){m=6882;break}k=b&255;if((b&2|0)==0){l=k>>>1|b&-256;c[194192]=l;r=(d[130328+p|0]|0)-1|0;s=l;m=6883;break}else{l=k>>>2|b&-256;c[194192]=l;t=l;u=4;m=6884;break}}else{m=6882}}while(0);if((m|0)==6882){c[194192]=0;r=d[130616+p|0]|0;s=0;m=6883}if((m|0)==6883){l=r+4|0;if(q){t=s;u=l;m=6884}else{v=l;m=6890}}do{if((m|0)==6884){if((t&1|0)==0){if(t>>>0<=255){v=u;m=6890;break}c[194192]=0;w=d[130616+p|0]|0;x=u;break}l=t&255;if((t&2|0)==0){c[194192]=l>>>1|t&-256;w=d[130328+p|0]|0;x=u;break}else{c[194192]=l>>>2|t&-256;w=0;x=u;break}}}while(0);if((m|0)==6890){w=d[125296+p|0]|0;x=v}o=(w<<1)+x|0;c[204526]=o;return}
function rV(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=1;j=(d[768256]|0)<<31|h>>>1}else{i=1<<g-1;j=h<<32-g|h>>>(g>>>0)}c[776584+(f<<2)>>2]=j;if((f|0)!=15){a[768240]=j>>>31&255;a[768224]=(j|0)==0|0;a[768256]=(i&h|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=6908;break}c[194192]=0;l=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;l=0;break}}else{k=6908}}while(0);if((k|0)==6908){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=6920;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=6921;break}else{i=h>>>2|b&-256;c[194192]=i;r=i;s=3;k=6922;break}}else{k=6920}}while(0);if((k|0)==6920){c[194192]=0;p=d[130616+n|0]|0;q=0;k=6921}if((k|0)==6921){i=p+3|0;if(o){r=q;s=i;k=6922}else{t=i;k=6928}}do{if((k|0)==6922){if((r&1|0)==0){if(r>>>0<=255){t=s;k=6928;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==6928){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function rW(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;i=c[776584+((b&15)<<2)>>2]|0;if((h&31|0)==0){j=g<<24>>24==0?(a[768256]&1)!=0:(i|0)<0;k=i}else{j=(1<<h-1&i|0)!=0;k=i<<32-h|i>>>(h>>>0)}c[776584+(f<<2)>>2]=k;if((f|0)!=15){a[768240]=k>>>31&255;a[768224]=(k|0)==0|0;a[768256]=j&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=6946;break}c[194192]=0;m=d[130616+b|0]|0;break}k=j&255;if((j&2|0)==0){c[194192]=k>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|j&-256;m=0;break}}else{l=6946}}while(0);if((l|0)==6946){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=j>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=j>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=6958;break}j=b&255;if((b&2|0)==0){k=j>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=6959;break}else{k=j>>>2|b&-256;c[194192]=k;s=k;t=4;l=6960;break}}else{l=6958}}while(0);if((l|0)==6958){c[194192]=0;q=d[130616+o|0]|0;r=0;l=6959}if((l|0)==6959){k=q+4|0;if(p){s=r;t=k;l=6960}else{u=k;l=6966}}do{if((l|0)==6960){if((s&1|0)==0){if(s>>>0<=255){u=t;l=6966;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==6966){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function rX(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)+(c[776584+((b&15)<<2)>>2]|0)|0;c[776584+(e<<2)>>2]=ki(h)|0;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function rY(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)+(c[776584+((b&15)<<2)>>2]|0)|0;c[776584+(e<<2)>>2]=(n0(h)|0)<<24>>24;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function rZ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)+(c[776584+((b&15)<<2)>>2]|0)|0;b=ki(h)|0;if((h&1|0)==0){i=b&65535}else{i=(b&255)<<24>>24}c[776584+(e<<2)>>2]=i<<16>>16;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;i=e>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;i=f-2|0;do{if(i>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=f;l=i}else{i=h>>>24&15;j=3;k=i;l=i-2|0}i=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+i|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+i|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+i|0;o=n+m|0;c[204526]=o;return}function r_(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&~(c[776584+((b&15)<<2)>>2]<<(b>>>7&31));if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=7056;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=7056}}while(0);if((g|0)==7056){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=7066;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=7067;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=7068;break}}else{g=7066}}while(0);if((g|0)==7066){c[194192]=0;m=d[130616+k|0]|0;n=0;g=7067}if((g|0)==7067){i=m+3|0;if(l){o=n;p=i;g=7068}else{q=i;g=7074}}do{if((g|0)==7068){if((o&1|0)==0){if(o>>>0<=255){q=p;g=7074;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==7074){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function r$(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&~i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=7091;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=7091}}while(0);if((j|0)==7091){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=7101;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=7102;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=7103;break}}else{j=7101}}while(0);if((j|0)==7101){c[194192]=0;o=d[130616+m|0]|0;p=0;j=7102}if((j|0)==7102){f=o+4|0;if(n){q=p;r=f;j=7103}else{s=f;j=7109}}do{if((j|0)==7103){if((q&1|0)==0){if(q>>>0<=255){s=r;j=7109;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==7109){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function r0(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=-1}else{g=~((c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0))}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&g;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=7124;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=7124}}while(0);if((h|0)==7124){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=7134;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=7135;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=7136;break}}else{h=7134}}while(0);if((h|0)==7134){c[194192]=0;m=d[130616+k|0]|0;n=0;h=7135}if((h|0)==7135){f=m+3|0;if(l){o=n;p=f;h=7136}else{q=f;h=7142}}do{if((h|0)==7136){if((o&1|0)==0){if(o>>>0<=255){q=p;h=7142;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==7142){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function r1(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=0}else if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&~i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=7159;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=7159}}while(0);if((j|0)==7159){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=7169;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=7170;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=7171;break}}else{j=7169}}while(0);if((j|0)==7169){c[194192]=0;o=d[130616+m|0]|0;p=0;j=7170}if((j|0)==7170){f=o+4|0;if(n){q=p;r=f;j=7171}else{s=f;j=7177}}do{if((j|0)==7171){if((q&1|0)==0){if(q>>>0<=255){s=r;j=7177;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==7177){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function r2(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&~(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f));if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=7190;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=7190}}while(0);if((g|0)==7190){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=7200;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=7201;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=7202;break}}else{g=7200}}while(0);if((g|0)==7200){c[194192]=0;m=d[130616+k|0]|0;n=0;g=7201}if((g|0)==7201){i=m+3|0;if(l){o=n;p=i;g=7202}else{q=i;g=7208}}do{if((g|0)==7202){if((o&1|0)==0){if(o>>>0<=255){q=p;g=7208;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==7208){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function r3(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&~j;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=7225;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=7225}}while(0);if((k|0)==7225){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=7235;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=7236;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=7237;break}}else{k=7235}}while(0);if((k|0)==7235){c[194192]=0;p=d[130616+n|0]|0;q=0;k=7236}if((k|0)==7236){f=p+4|0;if(o){r=q;s=f;k=7237}else{t=f;k=7243}}do{if((k|0)==7237){if((r&1|0)==0){if(r>>>0<=255){t=s;k=7243;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==7243){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function r4(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&~h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=7259;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=7259}}while(0);if((i|0)==7259){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=7269;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=7270;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=7271;break}}else{i=7269}}while(0);if((i|0)==7269){c[194192]=0;n=d[130616+l|0]|0;o=0;i=7270}if((i|0)==7270){f=n+3|0;if(m){p=o;q=f;i=7271}else{r=f;i=7277}}do{if((i|0)==7271){if((p&1|0)==0){if(p>>>0<=255){r=q;i=7277;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==7277){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function r5(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&~h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=7292;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=7292}}while(0);if((i|0)==7292){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=7302;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=7303;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=7304;break}}else{i=7302}}while(0);if((i|0)==7302){c[194192]=0;n=d[130616+l|0]|0;o=0;i=7303}if((i|0)==7303){f=n+4|0;if(m){p=o;q=f;i=7304}else{r=f;i=7310}}do{if((i|0)==7304){if((p&1|0)==0){if(p>>>0<=255){r=q;i=7310;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==7310){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function r6(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=(c[776584+((e>>>16&15)<<2)>>2]|0)+(e>>>4&240|e&15)|0;kh(f,b[776584+((e>>>12&15)<<2)>>1]|0);e=f>>>24&15;f=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);e=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}h=g&255;if((g&2|0)==0){c[194192]=h>>>1|g&-256;i=(d[130328+f|0]|0)-1|0;j=e+i|0;c[204526]=j;return}else{c[194192]=h>>>2|g&-256;i=0;j=e+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+f|0]|0;j=e+i|0;c[204526]=j;return}function r7(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(h&1<<32-g|0)!=0;j=h<<g}g=c[776584+((b>>>16&15)<<2)>>2]&~j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=7344;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=7344}}while(0);if((k|0)==7344){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=7356;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=7357;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=7358;break}}else{k=7356}}while(0);if((k|0)==7356){c[194192]=0;p=d[130616+n|0]|0;q=0;k=7357}if((k|0)==7357){g=p+3|0;if(o){r=q;s=g;k=7358}else{t=g;k=7364}}do{if((k|0)==7358){if((r&1|0)==0){if(r>>>0<=255){t=s;k=7364;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==7364){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function r8(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]&1|0)!=0;j=0}else if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<32-h|0)!=0;j=k<<h}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]&~j;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(h|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=7384;break}c[194192]=0;m=d[130616+b|0]|0;break}h=i&255;if((i&2|0)==0){c[194192]=h>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=h>>>2|i&-256;m=0;break}}else{l=7384}}while(0);if((l|0)==7384){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;h=m>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=i>>>24;o=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;h=m>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=i>>>24;o=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=7396;break}i=b&255;if((b&2|0)==0){h=i>>>1|b&-256;c[194192]=h;q=(d[130328+o|0]|0)-1|0;r=h;l=7397;break}else{h=i>>>2|b&-256;c[194192]=h;s=h;t=4;l=7398;break}}else{l=7396}}while(0);if((l|0)==7396){c[194192]=0;q=d[130616+o|0]|0;r=0;l=7397}if((l|0)==7397){h=q+4|0;if(p){s=r;t=h;l=7398}else{u=h;l=7404}}do{if((l|0)==7398){if((s&1|0)==0){if(s>>>0<=255){u=t;l=7404;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}h=s&255;if((s&2|0)==0){c[194192]=h>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=h>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==7404){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function r9(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=h>>>31;j=-1}else{i=h&1<<g-1;j=~(h>>>(g>>>0))}g=c[776584+((b>>>16&15)<<2)>>2]&j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=(i|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=7422;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=7422}}while(0);if((k|0)==7422){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=7434;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=7435;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=7436;break}}else{k=7434}}while(0);if((k|0)==7434){c[194192]=0;p=d[130616+n|0]|0;q=0;k=7435}if((k|0)==7435){g=p+3|0;if(o){r=q;s=g;k=7436}else{t=g;k=7442}}do{if((k|0)==7436){if((r&1|0)==0){if(r>>>0<=255){t=s;k=7442;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==7442){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function sa(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]|0)<0;j=0}else if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<h-1|0)!=0;j=k>>>(h>>>0)}}while(0);h=c[776584+((b>>>16&15)<<2)>>2]&~j;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(h|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=7462;break}c[194192]=0;m=d[130616+b|0]|0;break}h=i&255;if((i&2|0)==0){c[194192]=h>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=h>>>2|i&-256;m=0;break}}else{l=7462}}while(0);if((l|0)==7462){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;h=m>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=i>>>24;o=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;h=m>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=i>>>24;o=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=7474;break}i=b&255;if((b&2|0)==0){h=i>>>1|b&-256;c[194192]=h;q=(d[130328+o|0]|0)-1|0;r=h;l=7475;break}else{h=i>>>2|b&-256;c[194192]=h;s=h;t=4;l=7476;break}}else{l=7474}}while(0);if((l|0)==7474){c[194192]=0;q=d[130616+o|0]|0;r=0;l=7475}if((l|0)==7475){h=q+4|0;if(p){s=r;t=h;l=7476}else{u=h;l=7482}}do{if((l|0)==7476){if((s&1|0)==0){if(s>>>0<=255){u=t;l=7482;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}h=s&255;if((s&2|0)==0){c[194192]=h>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=h>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==7482){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function sb(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(h|0)<0;j=i;k=(i^1)<<31>>31}else{j=(h&1<<g-1|0)!=0;k=~(h>>g)}g=c[776584+((b>>>16&15)<<2)>>2]&k;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=j&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=7500;break}c[194192]=0;m=d[130616+b|0]|0;break}g=j&255;if((j&2|0)==0){c[194192]=g>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=g>>>2|j&-256;m=0;break}}else{l=7500}}while(0);if((l|0)==7500){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;g=m>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=j>>>24;o=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;g=m>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=j>>>24;o=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=7512;break}j=b&255;if((b&2|0)==0){g=j>>>1|b&-256;c[194192]=g;q=(d[130328+o|0]|0)-1|0;r=g;l=7513;break}else{g=j>>>2|b&-256;c[194192]=g;s=g;t=3;l=7514;break}}else{l=7512}}while(0);if((l|0)==7512){c[194192]=0;q=d[130616+o|0]|0;r=0;l=7513}if((l|0)==7513){g=q+3|0;if(p){s=r;t=g;l=7514}else{u=g;l=7520}}do{if((l|0)==7514){if((s&1|0)==0){if(s>>>0<=255){u=t;l=7520;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}g=s&255;if((s&2|0)==0){c[194192]=g>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=g>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==7520){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function sc(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=b>>>12&15;g=a[768256]|0;h=a[776584+((b>>>8&15)<<2)|0]|0;i=h&255;do{if((h&255)<32){j=c[776584+((b&15)<<2)>>2]|0;if(h<<24>>24==0){k=(g&1)!=0;l=j;break}else{k=(j&1<<i-1|0)!=0;l=j>>i;break}}else{j=c[776584+((b&15)<<2)>>2]|0;k=(j|0)<0;l=j>>31}}while(0);i=c[776584+((b>>>16&15)<<2)>>2]&~l;c[776584+(f<<2)>>2]=i;if((f|0)!=15){a[768240]=i>>>31&255;a[768224]=(i|0)==0|0;a[768256]=k&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){if(k>>>0<=255){m=7540;break}c[194192]=0;n=d[130616+b|0]|0;break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;n=d[130328+b|0]|0;break}else{c[194192]=i>>>2|k&-256;n=0;break}}else{m=7540}}while(0);if((m|0)==7540){n=d[125296+b|0]|0}o=n+2|0;c[204526]=o;return}n=c[194163]&31;if((c[31194]|0)!=(n|0)){km(n,0,1)}n=c[194161]|0;if((a[52040]&1)==0){b=n&-2;c[194193]=b;k=b+2|0;c[194161]=k;i=n>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=k>>>24;p=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&k)>>1]|0;q=b}else{b=n&-4;c[194193]=b;k=b+4|0;c[194161]=k;i=n>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=k>>>24;p=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&k)>>2]|0;q=b}c[203400]=p;p=q>>>24&15;q=(p-8|0)>>>0<6;do{if(q){b=c[194192]|0;if((b&1|0)==0){m=7552;break}k=b&255;if((b&2|0)==0){i=k>>>1|b&-256;c[194192]=i;r=(d[130328+p|0]|0)-1|0;s=i;m=7553;break}else{i=k>>>2|b&-256;c[194192]=i;t=i;u=4;m=7554;break}}else{m=7552}}while(0);if((m|0)==7552){c[194192]=0;r=d[130616+p|0]|0;s=0;m=7553}if((m|0)==7553){i=r+4|0;if(q){t=s;u=i;m=7554}else{v=i;m=7560}}do{if((m|0)==7554){if((t&1|0)==0){if(t>>>0<=255){v=u;m=7560;break}c[194192]=0;w=d[130616+p|0]|0;x=u;break}i=t&255;if((t&2|0)==0){c[194192]=i>>>1|t&-256;w=d[130328+p|0]|0;x=u;break}else{c[194192]=i>>>2|t&-256;w=0;x=u;break}}}while(0);if((m|0)==7560){w=d[125296+p|0]|0;x=v}o=(w<<1)+x|0;c[204526]=o;return}function sd(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=1;j=(d[768256]|0)<<31|h>>>1}else{i=1<<g-1;j=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]&~j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=(i&h|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=7578;break}c[194192]=0;l=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;l=0;break}}else{k=7578}}while(0);if((k|0)==7578){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=7590;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=7591;break}else{i=h>>>2|b&-256;c[194192]=i;r=i;s=3;k=7592;break}}else{k=7590}}while(0);if((k|0)==7590){c[194192]=0;p=d[130616+n|0]|0;q=0;k=7591}if((k|0)==7591){i=p+3|0;if(o){r=q;s=i;k=7592}else{t=i;k=7598}}do{if((k|0)==7592){if((r&1|0)==0){if(r>>>0<=255){t=s;k=7598;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==7598){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function se(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;i=c[776584+((b&15)<<2)>>2]|0;if((h&31|0)==0){j=g<<24>>24==0?(a[768256]&1)!=0:(i|0)<0;k=i}else{j=(1<<h-1&i|0)!=0;k=i<<32-h|i>>>(h>>>0)}h=c[776584+((b>>>16&15)<<2)>>2]&~k;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(h|0)==0|0;a[768256]=j&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=7616;break}c[194192]=0;m=d[130616+b|0]|0;break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=h>>>2|j&-256;m=0;break}}else{l=7616}}while(0);if((l|0)==7616){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;h=m>>>24;c[203402]=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>1]|0;h=j>>>24;o=e[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;h=m>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];h=j>>>24;o=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=7628;break}j=b&255;if((b&2|0)==0){h=j>>>1|b&-256;c[194192]=h;q=(d[130328+o|0]|0)-1|0;r=h;l=7629;break}else{h=j>>>2|b&-256;c[194192]=h;s=h;t=4;l=7630;break}}else{l=7628}}while(0);if((l|0)==7628){c[194192]=0;q=d[130616+o|0]|0;r=0;l=7629}if((l|0)==7629){h=q+4|0;if(p){s=r;t=h;l=7630}else{u=h;l=7636}}do{if((l|0)==7630){if((s&1|0)==0){if(s>>>0<=255){u=t;l=7636;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}h=s&255;if((s&2|0)==0){c[194192]=h>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=h>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==7636){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function sf(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(b>>>4&240|b&15)|0;c[776584+(e<<2)>>2]=ki(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function sg(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(b>>>4&240|b&15)|0;c[776584+(e<<2)>>2]=(n0(f)|0)<<24>>24;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function sh(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(b>>>4&240|b&15)|0;b=ki(f)|0;if((f&1|0)==0){g=b&65535}else{g=(b&255)<<24>>24}c[776584+(e<<2)>>2]=g<<16>>16;c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=f>>>24&15;g=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function si(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[776584+((b>>>12&15)<<2)>>2]=~(c[776584+((b&15)<<2)>>2]<<(b>>>7&31));if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=9;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=9}}while(0);if((g|0)==9){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=19;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=20;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=21;break}}else{g=19}}while(0);if((g|0)==19){c[194192]=0;m=d[130616+k|0]|0;n=0;g=20}if((g|0)==20){i=m+3|0;if(l){o=n;p=i;g=21}else{q=i;g=27}}do{if((g|0)==21){if((o&1|0)==0){if(o>>>0<=255){q=p;g=27;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==27){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function sj(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=c[776584+((b&15)<<2)>>2]<<h}}while(0);c[776584+(f<<2)>>2]=~i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=44;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=44}}while(0);if((j|0)==44){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=54;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=55;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=56;break}}else{j=54}}while(0);if((j|0)==54){c[194192]=0;o=d[130616+m|0]|0;p=0;j=55}if((j|0)==55){f=o+4|0;if(n){q=p;r=f;j=56}else{s=f;j=62}}do{if((j|0)==56){if((q&1|0)==0){if(q>>>0<=255){s=r;j=62;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==62){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function sk(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;if((f|0)==0){g=-1}else{g=~((c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0))}c[776584+((b>>>12&15)<<2)>>2]=g;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){h=77;break}c[194192]=0;i=d[130616+b|0]|0;break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;i=d[130328+b|0]|0;break}else{c[194192]=f>>>2|g&-256;i=0;break}}else{h=77}}while(0);if((h|0)==77){i=d[125296+b|0]|0}j=i+1|0;c[204526]=j;return}i=c[194161]|0;if((a[52040]&1)==0){b=i&-2;c[194193]=b;g=b+2|0;c[194161]=g;f=i>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=g>>>24;k=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>1]|0;l=b}else{b=i&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=i>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=g>>>24;k=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){h=87;break}g=b&255;if((b&2|0)==0){f=g>>>1|b&-256;c[194192]=f;m=(d[130328+k|0]|0)-1|0;n=f;h=88;break}else{f=g>>>2|b&-256;c[194192]=f;o=f;p=3;h=89;break}}else{h=87}}while(0);if((h|0)==87){c[194192]=0;m=d[130616+k|0]|0;n=0;h=88}if((h|0)==88){f=m+3|0;if(l){o=n;p=f;h=89}else{q=f;h=95}}do{if((h|0)==89){if((o&1|0)==0){if(o>>>0<=255){q=p;h=95;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}f=o&255;if((o&2|0)==0){c[194192]=f>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=f>>>2|o&-256;r=0;s=p;break}}}while(0);if((h|0)==95){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function sl(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=0}else{if((g&255)>=32){i=0;break}i=(c[776584+((b&15)<<2)>>2]|0)>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=~i;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){j=112;break}c[194192]=0;k=d[130616+b|0]|0;break}f=i&255;if((i&2|0)==0){c[194192]=f>>>1|i&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|i&-256;k=0;break}}else{j=112}}while(0);if((j|0)==112){k=d[125296+b|0]|0}l=k+2|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;i=b+2|0;c[194161]=i;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=i>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>1]|0;n=b}else{b=k&-4;c[194193]=b;i=b+4|0;c[194161]=i;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=i>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=122;break}i=b&255;if((b&2|0)==0){f=i>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=123;break}else{f=i>>>2|b&-256;c[194192]=f;q=f;r=4;j=124;break}}else{j=122}}while(0);if((j|0)==122){c[194192]=0;o=d[130616+m|0]|0;p=0;j=123}if((j|0)==123){f=o+4|0;if(n){q=p;r=f;j=124}else{s=f;j=130}}do{if((j|0)==124){if((q&1|0)==0){if(q>>>0<=255){s=r;j=130;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==130){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function sm(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b>>>7&31;c[776584+((b>>>12&15)<<2)>>2]=~(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f));if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=143;break}c[194192]=0;h=d[130616+b|0]|0;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=d[130328+b|0]|0;break}else{c[194192]=i>>>2|f&-256;h=0;break}}else{g=143}}while(0);if((g|0)==143){h=d[125296+b|0]|0}j=h+1|0;c[204526]=j;return}h=c[194161]|0;if((a[52040]&1)==0){b=h&-2;c[194193]=b;f=b+2|0;c[194161]=f;i=h>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=f>>>24;k=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>1]|0;l=b}else{b=h&-4;c[194193]=b;f=b+4|0;c[194161]=f;i=h>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=f>>>24;k=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&f)>>2]|0;l=b}c[203400]=k;k=l>>>24&15;l=(k-8|0)>>>0<6;do{if(l){b=c[194192]|0;if((b&1|0)==0){g=153;break}f=b&255;if((b&2|0)==0){i=f>>>1|b&-256;c[194192]=i;m=(d[130328+k|0]|0)-1|0;n=i;g=154;break}else{i=f>>>2|b&-256;c[194192]=i;o=i;p=3;g=155;break}}else{g=153}}while(0);if((g|0)==153){c[194192]=0;m=d[130616+k|0]|0;n=0;g=154}if((g|0)==154){i=m+3|0;if(l){o=n;p=i;g=155}else{q=i;g=161}}do{if((g|0)==155){if((o&1|0)==0){if(o>>>0<=255){q=p;g=161;break}c[194192]=0;r=d[130616+k|0]|0;s=p;break}i=o&255;if((o&2|0)==0){c[194192]=i>>>1|o&-256;r=d[130328+k|0]|0;s=p;break}else{c[194192]=i>>>2|o&-256;r=0;s=p;break}}}while(0);if((g|0)==161){r=d[125296+k|0]|0;s=q}j=(r<<1)+s|0;c[204526]=j;return}function sn(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g&255)<32){i=c[776584+((b&15)<<2)>>2]|0;if(g<<24>>24==0){j=i;break}j=i>>h}else{j=c[776584+((b&15)<<2)>>2]>>31}}while(0);c[776584+(f<<2)>>2]=~j;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){k=178;break}c[194192]=0;l=d[130616+b|0]|0;break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=d[130328+b|0]|0;break}else{c[194192]=f>>>2|j&-256;l=0;break}}else{k=178}}while(0);if((k|0)==178){l=d[125296+b|0]|0}m=l+2|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;j=b+2|0;c[194161]=j;f=l>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=j>>>24;n=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>1]|0;o=b}else{b=l&-4;c[194193]=b;j=b+4|0;c[194161]=j;f=l>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=j>>>24;n=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&j)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=188;break}j=b&255;if((b&2|0)==0){f=j>>>1|b&-256;c[194192]=f;p=(d[130328+n|0]|0)-1|0;q=f;k=189;break}else{f=j>>>2|b&-256;c[194192]=f;r=f;s=4;k=190;break}}else{k=188}}while(0);if((k|0)==188){c[194192]=0;p=d[130616+n|0]|0;q=0;k=189}if((k|0)==189){f=p+4|0;if(o){r=q;s=f;k=190}else{t=f;k=196}}do{if((k|0)==190){if((r&1|0)==0){if(r>>>0<=255){t=s;k=196;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}f=r&255;if((r&2|0)==0){c[194192]=f>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=f>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==196){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function so(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=~h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=212;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=212}}while(0);if((i|0)==212){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=222;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=223;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=224;break}}else{i=222}}while(0);if((i|0)==222){c[194192]=0;n=d[130616+l|0]|0;o=0;i=223}if((i|0)==223){f=n+3|0;if(m){p=o;q=f;i=224}else{r=f;i=230}}do{if((i|0)==224){if((p&1|0)==0){if(p>>>0<=255){r=q;i=230;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==230){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function sp(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d[776584+((b>>>8&15)<<2)|0]|0;g=c[776584+((b&15)<<2)>>2]|0;if((f&31|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=~h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=245;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=245}}while(0);if((i|0)==245){j=d[125296+b|0]|0}k=j+2|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=255;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=256;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=4;i=257;break}}else{i=255}}while(0);if((i|0)==255){c[194192]=0;n=d[130616+l|0]|0;o=0;i=256}if((i|0)==256){f=n+4|0;if(m){p=o;q=f;i=257}else{r=f;i=263}}do{if((i|0)==257){if((p&1|0)==0){if(p>>>0<=255){r=q;i=263;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==263){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function sq(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=776584+((e>>>16&15)<<2)|0;g=(c[f>>2]|0)+(e>>>4&240|e&15)|0;c[f>>2]=g;kh(g,b[776584+((e>>>12&15)<<2)>>1]|0);e=g>>>24&15;g=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}h=f&255;if((f&2|0)==0){c[194192]=h>>>1|f&-256;i=(d[130328+g|0]|0)-1|0;j=e+i|0;c[204526]=j;return}else{c[194192]=h>>>2|f&-256;i=0;j=e+i|0;c[204526]=j;return}}}while(0);c[194192]=0;i=d[130616+g|0]|0;j=e+i|0;c[204526]=j;return}function sr(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(h&1<<32-g|0)!=0;j=h<<g}c[776584+(f<<2)>>2]=~j;if((f|0)!=15){a[768240]=j>>>31&255^1;a[768224]=(j|0)==-1|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=297;break}c[194192]=0;l=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;l=0;break}}else{k=297}}while(0);if((k|0)==297){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=309;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=310;break}else{j=i>>>2|b&-256;c[194192]=j;r=j;s=3;k=311;break}}else{k=309}}while(0);if((k|0)==309){c[194192]=0;p=d[130616+n|0]|0;q=0;k=310}if((k|0)==310){j=p+3|0;if(o){r=q;s=j;k=311}else{t=j;k=317}}do{if((k|0)==311){if((r&1|0)==0){if(r>>>0<=255){t=s;k=317;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==317){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function ss(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]&1|0)!=0;j=0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<32-h|0)!=0;j=k<<h}}while(0);c[776584+(f<<2)>>2]=~j;if((f|0)!=15){a[768240]=j>>>31&255^1;a[768224]=(j|0)==-1|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=337;break}c[194192]=0;m=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;m=0;break}}else{l=337}}while(0);if((l|0)==337){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=m>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;o=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=m>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;o=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=349;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;q=(d[130328+o|0]|0)-1|0;r=j;l=350;break}else{j=i>>>2|b&-256;c[194192]=j;s=j;t=4;l=351;break}}else{l=349}}while(0);if((l|0)==349){c[194192]=0;q=d[130616+o|0]|0;r=0;l=350}if((l|0)==350){j=q+4|0;if(p){s=r;t=j;l=351}else{u=j;l=357}}do{if((l|0)==351){if((s&1|0)==0){if(s>>>0<=255){u=t;l=357;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}j=s&255;if((s&2|0)==0){c[194192]=j>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=j>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==357){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function st(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=h>>>31;j=-1}else{i=h&1<<g-1;j=~(h>>>(g>>>0))}c[776584+(f<<2)>>2]=j;if((f|0)!=15){a[768240]=j>>>31&255;a[768224]=(j|0)==0|0;a[768256]=(i|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=375;break}c[194192]=0;l=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;l=0;break}}else{k=375}}while(0);if((k|0)==375){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=387;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=388;break}else{j=i>>>2|b&-256;c[194192]=j;r=j;s=3;k=389;break}}else{k=387}}while(0);if((k|0)==387){c[194192]=0;p=d[130616+n|0]|0;q=0;k=388}if((k|0)==388){j=p+3|0;if(o){r=q;s=j;k=389}else{t=j;k=395}}do{if((k|0)==389){if((r&1|0)==0){if(r>>>0<=255){t=s;k=395;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==395){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function su(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;do{if((g<<24>>24|0)==0){i=(a[768256]&1)!=0;j=c[776584+((b&15)<<2)>>2]|0}else if((g<<24>>24|0)==32){i=(c[776584+((b&15)<<2)>>2]|0)<0;j=0}else{if((g&255)>=32){i=0;j=0;break}k=c[776584+((b&15)<<2)>>2]|0;i=(k&1<<h-1|0)!=0;j=k>>>(h>>>0)}}while(0);c[776584+(f<<2)>>2]=~j;if((f|0)!=15){a[768240]=j>>>31&255^1;a[768224]=(j|0)==-1|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=415;break}c[194192]=0;m=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;m=0;break}}else{l=415}}while(0);if((l|0)==415){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=m>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;o=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=m>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;o=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=427;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;q=(d[130328+o|0]|0)-1|0;r=j;l=428;break}else{j=i>>>2|b&-256;c[194192]=j;s=j;t=4;l=429;break}}else{l=427}}while(0);if((l|0)==427){c[194192]=0;q=d[130616+o|0]|0;r=0;l=428}if((l|0)==428){j=q+4|0;if(p){s=r;t=j;l=429}else{u=j;l=435}}do{if((l|0)==429){if((s&1|0)==0){if(s>>>0<=255){u=t;l=435;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}j=s&255;if((s&2|0)==0){c[194192]=j>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=j>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==435){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function sv(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(h|0)<0;j=i;k=(i^1)<<31>>31}else{j=(h&1<<g-1|0)!=0;k=~(h>>g)}c[776584+(f<<2)>>2]=k;if((f|0)!=15){a[768240]=k>>>31&255;a[768224]=(k|0)==0|0;a[768256]=j&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=453;break}c[194192]=0;m=d[130616+b|0]|0;break}k=j&255;if((j&2|0)==0){c[194192]=k>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|j&-256;m=0;break}}else{l=453}}while(0);if((l|0)==453){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=j>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=j>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=465;break}j=b&255;if((b&2|0)==0){k=j>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=466;break}else{k=j>>>2|b&-256;c[194192]=k;s=k;t=3;l=467;break}}else{l=465}}while(0);if((l|0)==465){c[194192]=0;q=d[130616+o|0]|0;r=0;l=466}if((l|0)==466){k=q+3|0;if(p){s=r;t=k;l=467}else{u=k;l=473}}do{if((l|0)==467){if((s&1|0)==0){if(s>>>0<=255){u=t;l=473;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==473){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function sw(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=b>>>12&15;g=a[768256]|0;h=a[776584+((b>>>8&15)<<2)|0]|0;i=h&255;do{if((h&255)<32){j=c[776584+((b&15)<<2)>>2]|0;if(h<<24>>24==0){k=(g&1)!=0;l=j;break}else{k=(j&1<<i-1|0)!=0;l=j>>i;break}}else{j=c[776584+((b&15)<<2)>>2]|0;k=(j|0)<0;l=j>>31}}while(0);c[776584+(f<<2)>>2]=~l;if((f|0)!=15){a[768240]=l>>>31&255^1;a[768224]=(l|0)==-1|0;a[768256]=k&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){if(k>>>0<=255){m=493;break}c[194192]=0;n=d[130616+b|0]|0;break}l=k&255;if((k&2|0)==0){c[194192]=l>>>1|k&-256;n=d[130328+b|0]|0;break}else{c[194192]=l>>>2|k&-256;n=0;break}}else{m=493}}while(0);if((m|0)==493){n=d[125296+b|0]|0}o=n+2|0;c[204526]=o;return}n=c[194163]&31;if((c[31194]|0)!=(n|0)){km(n,0,1)}n=c[194161]|0;if((a[52040]&1)==0){b=n&-2;c[194193]=b;k=b+2|0;c[194161]=k;l=n>>>24;c[203402]=e[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&b)>>1]|0;l=k>>>24;p=e[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&k)>>1]|0;q=b}else{b=n&-4;c[194193]=b;k=b+4|0;c[194161]=k;l=n>>>24;c[203402]=c[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&b)>>2];l=k>>>24;p=c[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&k)>>2]|0;q=b}c[203400]=p;p=q>>>24&15;q=(p-8|0)>>>0<6;do{if(q){b=c[194192]|0;if((b&1|0)==0){m=505;break}k=b&255;if((b&2|0)==0){l=k>>>1|b&-256;c[194192]=l;r=(d[130328+p|0]|0)-1|0;s=l;m=506;break}else{l=k>>>2|b&-256;c[194192]=l;t=l;u=4;m=507;break}}else{m=505}}while(0);if((m|0)==505){c[194192]=0;r=d[130616+p|0]|0;s=0;m=506}if((m|0)==506){l=r+4|0;if(q){t=s;u=l;m=507}else{v=l;m=513}}do{if((m|0)==507){if((t&1|0)==0){if(t>>>0<=255){v=u;m=513;break}c[194192]=0;w=d[130616+p|0]|0;x=u;break}l=t&255;if((t&2|0)==0){c[194192]=l>>>1|t&-256;w=d[130328+p|0]|0;x=u;break}else{c[194192]=l>>>2|t&-256;w=0;x=u;break}}}while(0);if((m|0)==513){w=d[125296+p|0]|0;x=v}o=(w<<1)+x|0;c[204526]=o;return}function sx(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=1;j=(d[768256]|0)<<31|h>>>1}else{i=1<<g-1;j=h<<32-g|h>>>(g>>>0)}c[776584+(f<<2)>>2]=~j;if((f|0)!=15){a[768240]=j>>>31&255^1;a[768224]=(j|0)==-1|0;a[768256]=(i&h|0)!=0|0}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){k=531;break}c[194192]=0;l=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;l=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;l=0;break}}else{k=531}}while(0);if((k|0)==531){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=l>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;n=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;o=b}else{b=l&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=l>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;n=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=543;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;p=(d[130328+n|0]|0)-1|0;q=i;k=544;break}else{i=h>>>2|b&-256;c[194192]=i;r=i;s=3;k=545;break}}else{k=543}}while(0);if((k|0)==543){c[194192]=0;p=d[130616+n|0]|0;q=0;k=544}if((k|0)==544){i=p+3|0;if(o){r=q;s=i;k=545}else{t=i;k=551}}do{if((k|0)==545){if((r&1|0)==0){if(r>>>0<=255){t=s;k=551;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}i=r&255;if((r&2|0)==0){c[194192]=i>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=i>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==551){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function sy(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=a[776584+((b>>>8&15)<<2)|0]|0;h=g&255;i=c[776584+((b&15)<<2)>>2]|0;if((h&31|0)==0){j=g<<24>>24==0?(a[768256]&1)!=0:(i|0)<0;k=i}else{j=(1<<h-1&i|0)!=0;k=i<<32-h|i>>>(h>>>0)}c[776584+(f<<2)>>2]=~k;if((f|0)!=15){a[768240]=k>>>31&255^1;a[768224]=(k|0)==-1|0;a[768256]=j&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){if(j>>>0<=255){l=569;break}c[194192]=0;m=d[130616+b|0]|0;break}k=j&255;if((j&2|0)==0){c[194192]=k>>>1|j&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|j&-256;m=0;break}}else{l=569}}while(0);if((l|0)==569){m=d[125296+b|0]|0}n=m+2|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;j=b+2|0;c[194161]=j;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=j>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>1]|0;p=b}else{b=m&-4;c[194193]=b;j=b+4|0;c[194161]=j;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=j>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&j)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=581;break}j=b&255;if((b&2|0)==0){k=j>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=582;break}else{k=j>>>2|b&-256;c[194192]=k;s=k;t=4;l=583;break}}else{l=581}}while(0);if((l|0)==581){c[194192]=0;q=d[130616+o|0]|0;r=0;l=582}if((l|0)==582){k=q+4|0;if(p){s=r;t=k;l=583}else{u=k;l=589}}do{if((l|0)==583){if((s&1|0)==0){if(s>>>0<=255){u=t;l=589;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==589){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function sz(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)+(b>>>4&240|b&15)|0;c[776584+(e<<2)>>2]=ki(h)|0;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function sA(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)+(b>>>4&240|b&15)|0;c[776584+(e<<2)>>2]=(n0(h)|0)<<24>>24;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function sB(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)+(b>>>4&240|b&15)|0;b=ki(h)|0;if((h&1|0)==0){i=b&65535}else{i=(b&255)<<24>>24}c[776584+(e<<2)>>2]=i<<16>>16;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;i=e>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;i=f-2|0;do{if(i>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=f;l=i}else{i=h>>>24&15;j=3;k=i;l=i-2|0}i=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+i|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+i|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+i|0;o=n+m|0;c[204526]=o;return}function sC(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=681;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=681}}while(0);if((i|0)==681){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=691;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=692;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=693;break}}else{i=691}}while(0);if((i|0)==691){c[194192]=0;n=d[130616+l|0]|0;o=0;i=692}if((i|0)==692){f=n+3|0;if(m){p=o;q=f;i=693}else{r=f;i=699}}do{if((i|0)==693){if((p&1|0)==0){if(p>>>0<=255){r=q;i=699;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==699){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function sD(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]^h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=714;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=714}}while(0);if((i|0)==714){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=724;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=725;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=726;break}}else{i=724}}while(0);if((i|0)==724){c[194192]=0;n=d[130616+l|0]|0;o=0;i=725}if((i|0)==725){f=n+3|0;if(m){p=o;q=f;i=726}else{r=f;i=732}}do{if((i|0)==726){if((p&1|0)==0){if(p>>>0<=255){r=q;i=732;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==732){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function sE(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(1<<g-1&h|0)!=0;j=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]&j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=750;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=750}}while(0);if((k|0)==750){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=762;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=763;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=764;break}}else{k=762}}while(0);if((k|0)==762){c[194192]=0;p=d[130616+n|0]|0;q=0;k=763}if((k|0)==763){g=p+3|0;if(o){r=q;s=g;k=764}else{t=g;k=770}}do{if((k|0)==764){if((r&1|0)==0){if(r>>>0<=255){t=s;k=770;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==770){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function sF(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=785;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=785}}while(0);if((i|0)==785){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=795;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=796;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=797;break}}else{i=795}}while(0);if((i|0)==795){c[194192]=0;n=d[130616+l|0]|0;o=0;i=796}if((i|0)==796){f=n+3|0;if(m){p=o;q=f;i=797}else{r=f;i=803}}do{if((i|0)==797){if((p&1|0)==0){if(p>>>0<=255){r=q;i=803;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==803){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function sG(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(1<<g-1&h|0)!=0;j=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g^j;c[776584+(f<<2)>>2]=h;if((f|0)!=15){a[768240]=h>>>31&255;a[768224]=(g|0)==(j|0)|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=821;break}c[194192]=0;l=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;l=0;break}}else{k=821}}while(0);if((k|0)==821){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=833;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=834;break}else{j=i>>>2|b&-256;c[194192]=j;r=j;s=3;k=835;break}}else{k=833}}while(0);if((k|0)==833){c[194192]=0;p=d[130616+n|0]|0;q=0;k=834}if((k|0)==834){j=p+3|0;if(o){r=q;s=j;k=835}else{t=j;k=841}}do{if((k|0)==835){if((r&1|0)==0){if(r>>>0<=255){t=s;k=841;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==841){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function sH(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g-i|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(g|0)==(i|0)|0;h=g>>>31;g=i>>>31;i=g^1;j=h&i;k=f^1;a[768232]=(k&j|(h^1)&g&f)&255;a[768256]=(k&h|j|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=858;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=858}}while(0);if((l|0)==858){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=870;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=871;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=3;l=872;break}}else{l=870}}while(0);if((l|0)==870){c[194192]=0;q=d[130616+o|0]|0;r=0;l=871}if((l|0)==871){k=q+3|0;if(p){s=r;t=k;l=872}else{u=k;l=878}}do{if((l|0)==872){if((s&1|0)==0){if(s>>>0<=255){u=t;l=878;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==878){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function sI(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=h-(c[776584+((b>>>16&15)<<2)>>2]|0);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=893;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=893}}while(0);if((i|0)==893){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=903;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=904;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=905;break}}else{i=903}}while(0);if((i|0)==903){c[194192]=0;n=d[130616+l|0]|0;o=0;i=904}if((i|0)==904){f=n+3|0;if(m){p=o;q=f;i=905}else{r=f;i=911}}do{if((i|0)==905){if((p&1|0)==0){if(p>>>0<=255){r=q;i=911;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==911){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function sJ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=926;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=926}}while(0);if((i|0)==926){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=936;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=937;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=938;break}}else{i=936}}while(0);if((i|0)==936){c[194192]=0;n=d[130616+l|0]|0;o=0;i=937}if((i|0)==937){f=n+3|0;if(m){p=o;q=f;i=938}else{r=f;i=944}}do{if((i|0)==938){if((p&1|0)==0){if(p>>>0<=255){r=q;i=944;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==944){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function sK(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=i-g|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(i|0)==(g|0)|0;h=g>>>31;g=i>>>31;i=g^1;j=h&i;k=f^1;a[768232]=(k&j|(h^1)&g&f)&255;a[768256]=(k&h|j|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=961;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=961}}while(0);if((l|0)==961){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=973;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=974;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=3;l=975;break}}else{l=973}}while(0);if((l|0)==973){c[194192]=0;q=d[130616+o|0]|0;r=0;l=974}if((l|0)==974){k=q+3|0;if(p){s=r;t=k;l=975}else{u=k;l=981}}do{if((l|0)==975){if((s&1|0)==0){if(s>>>0<=255){u=t;l=981;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==981){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function sL(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)+h+(a[768256]&1);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=996;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=996}}while(0);if((i|0)==996){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=1006;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=1007;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=1008;break}}else{i=1006}}while(0);if((i|0)==1006){c[194192]=0;n=d[130616+l|0]|0;o=0;i=1007}if((i|0)==1007){f=n+3|0;if(m){p=o;q=f;i=1008}else{r=f;i=1014}}do{if((i|0)==1008){if((p&1|0)==0){if(p>>>0<=255){r=q;i=1014;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==1014){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function sM(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g+i|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(h|0)==0|0;h=g>>>31;g=i>>>31;i=h&g;j=f^1;a[768232]=(j&i|(h^1)&(g^1)&f)&255;a[768256]=(j&h|i|j&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=1031;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=1031}}while(0);if((k|0)==1031){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1043;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=1044;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=3;k=1045;break}}else{k=1043}}while(0);if((k|0)==1043){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1044}if((k|0)==1044){j=p+3|0;if(o){r=q;s=j;k=1045}else{t=j;k=1051}}do{if((k|0)==1045){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1051;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1051){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function sN(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g+i+(a[768256]&1)|0;c[776584+(f<<2)>>2]=h;if((f|0)!=15){f=h>>>31;a[768240]=f&255;a[768224]=(h|0)==0|0;h=g>>>31;g=i>>>31;i=h&g;j=f^1;a[768232]=(j&i|(h^1)&(g^1)&f)&255;a[768256]=(j&h|i|j&g)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){if(g>>>0<=255){k=1068;break}c[194192]=0;l=d[130616+b|0]|0;break}j=g&255;if((g&2|0)==0){c[194192]=j>>>1|g&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|g&-256;l=0;break}}else{k=1068}}while(0);if((k|0)==1068){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;g=b+2|0;c[194161]=g;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=g>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>1]|0;o=b}else{b=l&-4;c[194193]=b;g=b+4|0;c[194161]=g;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=g>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&g)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1080;break}g=b&255;if((b&2|0)==0){j=g>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=1081;break}else{j=g>>>2|b&-256;c[194192]=j;r=j;s=3;k=1082;break}}else{k=1080}}while(0);if((k|0)==1080){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1081}if((k|0)==1081){j=p+3|0;if(o){r=q;s=j;k=1082}else{t=j;k=1088}}do{if((k|0)==1082){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1088;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1088){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function sO(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=(c[776584+((b>>>16&15)<<2)>>2]|0)-h-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=1103;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=1103}}while(0);if((i|0)==1103){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=1113;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=1114;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=1115;break}}else{i=1113}}while(0);if((i|0)==1113){c[194192]=0;n=d[130616+l|0]|0;o=0;i=1114}if((i|0)==1114){f=n+3|0;if(m){p=o;q=f;i=1115}else{r=f;i=1121}}do{if((i|0)==1115){if((p&1|0)==0){if(p>>>0<=255){r=q;i=1121;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==1121){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function sP(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=h-(c[776584+((b>>>16&15)<<2)>>2]|0)-((a[768256]&1^1)&255);if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=1136;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=1136}}while(0);if((i|0)==1136){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=1146;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=1147;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=1148;break}}else{i=1146}}while(0);if((i|0)==1146){c[194192]=0;n=d[130616+l|0]|0;o=0;i=1147}if((i|0)==1147){f=n+3|0;if(m){p=o;q=f;i=1148}else{r=f;i=1154}}do{if((i|0)==1148){if((p&1|0)==0){if(p>>>0<=255){r=q;i=1154;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==1154){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function sQ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=g-i|0;j=(a[768256]&1^1)&255;k=h-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(h|0)==(j|0)|0;j=g>>>31;g=i>>>31;i=g^1;h=j&i;k=f^1;a[768232]=(k&h|(j^1)&g&f)&255;a[768256]=(k&j|h|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=1171;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=1171}}while(0);if((l|0)==1171){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=1183;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=1184;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=3;l=1185;break}}else{l=1183}}while(0);if((l|0)==1183){c[194192]=0;q=d[130616+o|0]|0;r=0;l=1184}if((l|0)==1184){k=q+3|0;if(p){s=r;t=k;l=1185}else{u=k;l=1191}}do{if((l|0)==1185){if((s&1|0)==0){if(s>>>0<=255){u=t;l=1191;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==1191){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function sR(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=(a[768256]&1)!=0;i=g}else{h=(1<<f-1&g|0)!=0;i=g<<32-f|g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]&i;a[768240]=f>>>31&255;a[768224]=(f|0)==0|0;a[768256]=h&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){j=1207;break}c[194192]=0;k=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;k=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;k=0;break}}else{j=1207}}while(0);if((j|0)==1207){k=d[125296+b|0]|0}l=k+1|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=k>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;m=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;n=b}else{b=k&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=k>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;m=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=1217;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;o=(d[130328+m|0]|0)-1|0;p=f;j=1218;break}else{f=h>>>2|b&-256;c[194192]=f;q=f;r=3;j=1219;break}}else{j=1217}}while(0);if((j|0)==1217){c[194192]=0;o=d[130616+m|0]|0;p=0;j=1218}if((j|0)==1218){f=o+3|0;if(n){q=p;r=f;j=1219}else{s=f;j=1225}}do{if((j|0)==1219){if((q&1|0)==0){if(q>>>0<=255){s=r;j=1225;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}f=q&255;if((q&2|0)==0){c[194192]=f>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=f>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==1225){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function sS(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=h}else{i=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|0;h=i-g|0;j=(a[768256]&1^1)&255;k=h-j|0;c[776584+(f<<2)>>2]=k;if((f|0)!=15){f=k>>>31;a[768240]=f&255;a[768224]=(h|0)==(j|0)|0;j=g>>>31;g=i>>>31;i=g^1;h=j&i;k=f^1;a[768232]=(k&h|(j^1)&g&f)&255;a[768256]=(k&j|h|k&i)&255}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){l=1242;break}c[194192]=0;m=d[130616+b|0]|0;break}k=i&255;if((i&2|0)==0){c[194192]=k>>>1|i&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|i&-256;m=0;break}}else{l=1242}}while(0);if((l|0)==1242){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194163]&31;if((c[31194]|0)!=(m|0)){km(m,0,1)}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;i=b+2|0;c[194161]=i;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=i>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>1]|0;p=b}else{b=m&-4;c[194193]=b;i=b+4|0;c[194161]=i;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=i>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&i)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=1254;break}i=b&255;if((b&2|0)==0){k=i>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=1255;break}else{k=i>>>2|b&-256;c[194192]=k;s=k;t=3;l=1256;break}}else{l=1254}}while(0);if((l|0)==1254){c[194192]=0;q=d[130616+o|0]|0;r=0;l=1255}if((l|0)==1255){k=q+3|0;if(p){s=r;t=k;l=1256}else{u=k;l=1262}}do{if((l|0)==1256){if((s&1|0)==0){if(s>>>0<=255){u=t;l=1262;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==1262){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function sT(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((d&267448320|0)!=52490240){f=c[194161]|0;g=(a[52040]&1)!=0;if((c[31194]|0)!=27){km(27,1,0)}c[194160]=f-(g?4:2);c[194161]=4;a[52040]=1;a[130632]=0;c[194193]=4;g=c[193635]|0;f=c[193634]|0;c[203402]=c[f+(g&4)>>2];c[203400]=c[f+(g&8)>>2];c[194161]=8;return}g=c[194162]&64;f=(a[768240]&1)==0?g:g|-2147483648;g=(a[768224]&1)==0?f:f|1073741824;f=(a[768256]&1)==0?g:g|536870912;g=(a[768232]&1)==0?f:f|268435456;f=(a[52040]&1)==0?g|32:g;g=(a[130632]&1)==0?f|128:f;f=c[31194]|0;h=g|f&31;c[194162]=h;i=d&255;j=d>>>7&30;if((j|0)==0){k=i}else{k=i<<32-j|i>>>(j>>>0)}do{if((f|0)>16){if((d&65536|0)==0){l=h}else{l=k&255|g&-256}if((d&131072|0)==0){m=l}else{m=l&-65281|k&65280}if((d&262144|0)==0){n=m;break}n=m&-16711681|k&16711680}else{n=h}}while(0);if((d&524288|0)==0){o=n}else{o=n&16777215|k&-16777216}k=o|16;n=k&31;if((f|0)!=(n|0)){km(n,0,1)}c[194162]=k;a[768240]=o>>>31&255;a[768224]=o>>>30&1;a[768256]=o>>>29&1;a[768232]=o>>>28&1;k=(o>>>5&1^1)&255;a[52040]=k;n=o>>>7&1;a[130632]=(n^1)&255;do{if((n|0)==0){if((b[390600]&b[390601])<<16>>16==0){break}if((b[390604]&1)==0){break}c[203364]=c[195148]}}while(0);if(k<<24>>24!=0){return}k=c[194193]|0;n=k>>>24;c[203402]=e[(c[774536+(n<<3)>>2]|0)+(c[774540+(n<<3)>>2]&k)>>1]|0;n=k+2|0;k=n>>>24;c[203400]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&n)>>1]|0;c[194161]=n;return}function sU(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=(a[768256]&1)!=0;i=g}else{h=(1<<f-1&g|0)!=0;i=g<<32-f|g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]|0;a[768240]=(f^i)>>>31&255;a[768224]=(f|0)==(i|0)|0;a[768256]=h&1;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){j=1305;break}c[194192]=0;k=d[130616+b|0]|0;break}i=h&255;if((h&2|0)==0){c[194192]=i>>>1|h&-256;k=d[130328+b|0]|0;break}else{c[194192]=i>>>2|h&-256;k=0;break}}else{j=1305}}while(0);if((j|0)==1305){k=d[125296+b|0]|0}l=k+1|0;c[204526]=l;return}k=c[194161]|0;if((a[52040]&1)==0){b=k&-2;c[194193]=b;h=b+2|0;c[194161]=h;i=k>>>24;c[203402]=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>1]|0;i=h>>>24;m=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>1]|0;n=b}else{b=k&-4;c[194193]=b;h=b+4|0;c[194161]=h;i=k>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&b)>>2];i=h>>>24;m=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&h)>>2]|0;n=b}c[203400]=m;m=n>>>24&15;n=(m-8|0)>>>0<6;do{if(n){b=c[194192]|0;if((b&1|0)==0){j=1315;break}h=b&255;if((b&2|0)==0){i=h>>>1|b&-256;c[194192]=i;o=(d[130328+m|0]|0)-1|0;p=i;j=1316;break}else{i=h>>>2|b&-256;c[194192]=i;q=i;r=3;j=1317;break}}else{j=1315}}while(0);if((j|0)==1315){c[194192]=0;o=d[130616+m|0]|0;p=0;j=1316}if((j|0)==1316){i=o+3|0;if(n){q=p;r=i;j=1317}else{s=i;j=1323}}do{if((j|0)==1317){if((q&1|0)==0){if(q>>>0<=255){s=r;j=1323;break}c[194192]=0;t=d[130616+m|0]|0;u=r;break}i=q&255;if((q&2|0)==0){c[194192]=i>>>1|q&-256;t=d[130328+m|0]|0;u=r;break}else{c[194192]=i>>>2|q&-256;t=0;u=r;break}}}while(0);if((j|0)==1323){t=d[125296+m|0]|0;u=s}l=(t<<1)+u|0;c[204526]=l;return}function sV(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]|0;g=(f-h|0)>>>31;a[768240]=g&255;a[768224]=(f|0)==(h|0)|0;i=f>>>31;f=h>>>31;h=f^1;j=i&h;k=g^1;a[768232]=(k&j|(i^1)&f&g)&255;a[768256]=(k&i|j|k&h)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){l=1338;break}c[194192]=0;m=d[130616+b|0]|0;break}k=h&255;if((h&2|0)==0){c[194192]=k>>>1|h&-256;m=d[130328+b|0]|0;break}else{c[194192]=k>>>2|h&-256;m=0;break}}else{l=1338}}while(0);if((l|0)==1338){m=d[125296+b|0]|0}n=m+1|0;c[204526]=n;return}m=c[194161]|0;if((a[52040]&1)==0){b=m&-2;c[194193]=b;h=b+2|0;c[194161]=h;k=m>>>24;c[203402]=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>1]|0;k=h>>>24;o=e[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>1]|0;p=b}else{b=m&-4;c[194193]=b;h=b+4|0;c[194161]=h;k=m>>>24;c[203402]=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&b)>>2];k=h>>>24;o=c[(c[774536+(k<<3)>>2]|0)+(c[774540+(k<<3)>>2]&h)>>2]|0;p=b}c[203400]=o;o=p>>>24&15;p=(o-8|0)>>>0<6;do{if(p){b=c[194192]|0;if((b&1|0)==0){l=1348;break}h=b&255;if((b&2|0)==0){k=h>>>1|b&-256;c[194192]=k;q=(d[130328+o|0]|0)-1|0;r=k;l=1349;break}else{k=h>>>2|b&-256;c[194192]=k;s=k;t=3;l=1350;break}}else{l=1348}}while(0);if((l|0)==1348){c[194192]=0;q=d[130616+o|0]|0;r=0;l=1349}if((l|0)==1349){k=q+3|0;if(p){s=r;t=k;l=1350}else{u=k;l=1356}}do{if((l|0)==1350){if((s&1|0)==0){if(s>>>0<=255){u=t;l=1356;break}c[194192]=0;v=d[130616+o|0]|0;w=t;break}k=s&255;if((s&2|0)==0){c[194192]=k>>>1|s&-256;v=d[130328+o|0]|0;w=t;break}else{c[194192]=k>>>2|s&-256;v=0;w=t;break}}}while(0);if((l|0)==1356){v=d[125296+o|0]|0;w=u}n=(v<<1)+w|0;c[204526]=n;return}function sW(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}f=c[776584+((b>>>16&15)<<2)>>2]|0;g=f+h|0;i=g>>>31;a[768240]=i&255;a[768224]=(g|0)==0|0;g=f>>>31;f=h>>>31;h=g&f;j=i^1;a[768232]=(j&h|(g^1)&(f^1)&i)&255;a[768256]=(j&g|h|j&f)&255;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){k=1371;break}c[194192]=0;l=d[130616+b|0]|0;break}j=f&255;if((f&2|0)==0){c[194192]=j>>>1|f&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|f&-256;l=0;break}}else{k=1371}}while(0);if((k|0)==1371){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;f=b+2|0;c[194161]=f;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=f>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&f)>>1]|0;o=b}else{b=l&-4;c[194193]=b;f=b+4|0;c[194161]=f;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=f>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&f)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1381;break}f=b&255;if((b&2|0)==0){j=f>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=1382;break}else{j=f>>>2|b&-256;c[194192]=j;r=j;s=3;k=1383;break}}else{k=1381}}while(0);if((k|0)==1381){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1382}if((k|0)==1382){j=p+3|0;if(o){r=q;s=j;k=1383}else{t=j;k=1389}}do{if((k|0)==1383){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1389;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1389){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function sX(b){b=b|0;var d=0,e=0,f=0;if((b&267448320|0)!=56684544){d=c[194161]|0;e=(a[52040]&1)!=0;if((c[31194]|0)!=27){km(27,1,0)}c[194160]=d-(e?4:2);c[194161]=4;a[52040]=1;a[130632]=0;c[194193]=4;e=c[193635]|0;d=c[193634]|0;c[203402]=c[d+(e&4)>>2];c[203400]=c[d+(e&8)>>2];c[194161]=8;return}if(((c[31194]|0)-17|0)>>>0>=14){return}e=b&255;d=b>>>7&30;if((d|0)==0){f=e}else{f=e<<32-d|e>>>(d>>>0)}if((b&65536|0)!=0){c[194163]=c[194163]&-256|f&255}if((b&131072|0)!=0){c[194163]=c[194163]&-65281|f&65280}if((b&262144|0)!=0){c[194163]=c[194163]&-16711681|f&16711680}if((b&524288|0)==0){return}c[194163]=c[194163]&16777215|f&-16777216;return}function sY(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]|h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=1424;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=1424}}while(0);if((i|0)==1424){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=1434;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=1435;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=1436;break}}else{i=1434}}while(0);if((i|0)==1434){c[194192]=0;n=d[130616+l|0]|0;o=0;i=1435}if((i|0)==1435){f=n+3|0;if(m){p=o;q=f;i=1436}else{r=f;i=1442}}do{if((i|0)==1436){if((p&1|0)==0){if(p>>>0<=255){r=q;i=1442;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==1442){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function sZ(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=1457;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=1457}}while(0);if((i|0)==1457){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=1467;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=1468;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=1469;break}}else{i=1467}}while(0);if((i|0)==1467){c[194192]=0;n=d[130616+l|0]|0;o=0;i=1468}if((i|0)==1468){f=n+3|0;if(m){p=o;q=f;i=1469}else{r=f;i=1475}}do{if((i|0)==1469){if((p&1|0)==0){if(p>>>0<=255){r=q;i=1475;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==1475){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function s_(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(1<<g-1&h|0)!=0;j=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]|j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=1493;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=1493}}while(0);if((k|0)==1493){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1505;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=1506;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=1507;break}}else{k=1505}}while(0);if((k|0)==1505){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1506}if((k|0)==1506){g=p+3|0;if(o){r=q;s=g;k=1507}else{t=g;k=1513}}do{if((k|0)==1507){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1513;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1513){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function s$(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=c[776584+((b>>>16&15)<<2)>>2]&~h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=1528;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=1528}}while(0);if((i|0)==1528){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=1538;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=1539;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=1540;break}}else{i=1538}}while(0);if((i|0)==1538){c[194192]=0;n=d[130616+l|0]|0;o=0;i=1539}if((i|0)==1539){f=n+3|0;if(m){p=o;q=f;i=1540}else{r=f;i=1546}}do{if((i|0)==1540){if((p&1|0)==0){if(p>>>0<=255){r=q;i=1546;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==1546){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function s0(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(1<<g-1&h|0)!=0;j=h<<32-g|h>>>(g>>>0)}c[776584+(f<<2)>>2]=j;if((f|0)!=15){a[768240]=j>>>31&255;a[768224]=(j|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=1564;break}c[194192]=0;l=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;l=0;break}}else{k=1564}}while(0);if((k|0)==1564){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1576;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=1577;break}else{j=i>>>2|b&-256;c[194192]=j;r=j;s=3;k=1578;break}}else{k=1576}}while(0);if((k|0)==1576){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1577}if((k|0)==1577){j=p+3|0;if(o){r=q;s=j;k=1578}else{t=j;k=1584}}do{if((k|0)==1578){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1584;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1584){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function s1(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(1<<g-1&h|0)!=0;j=h<<32-g|h>>>(g>>>0)}g=c[776584+((b>>>16&15)<<2)>>2]&~j;c[776584+(f<<2)>>2]=g;if((f|0)!=15){a[768240]=g>>>31&255;a[768224]=(g|0)==0|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=1602;break}c[194192]=0;l=d[130616+b|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=g>>>2|i&-256;l=0;break}}else{k=1602}}while(0);if((k|0)==1602){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;g=l>>>24;c[203402]=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>1]|0;g=i>>>24;n=e[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;g=l>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];g=i>>>24;n=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1614;break}i=b&255;if((b&2|0)==0){g=i>>>1|b&-256;c[194192]=g;p=(d[130328+n|0]|0)-1|0;q=g;k=1615;break}else{g=i>>>2|b&-256;c[194192]=g;r=g;s=3;k=1616;break}}else{k=1614}}while(0);if((k|0)==1614){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1615}if((k|0)==1615){g=p+3|0;if(o){r=q;s=g;k=1616}else{t=g;k=1622}}do{if((k|0)==1616){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1622;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}g=r&255;if((r&2|0)==0){c[194192]=g>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=g>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1622){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function s2(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b>>>7&30;g=b&255;if((f|0)==0){h=g}else{h=g<<32-f|g>>>(f>>>0)}c[776584+((b>>>12&15)<<2)>>2]=~h;if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){i=1637;break}c[194192]=0;j=d[130616+b|0]|0;break}f=h&255;if((h&2|0)==0){c[194192]=f>>>1|h&-256;j=d[130328+b|0]|0;break}else{c[194192]=f>>>2|h&-256;j=0;break}}else{i=1637}}while(0);if((i|0)==1637){j=d[125296+b|0]|0}k=j+1|0;c[204526]=k;return}j=c[194161]|0;if((a[52040]&1)==0){b=j&-2;c[194193]=b;h=b+2|0;c[194161]=h;f=j>>>24;c[203402]=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>1]|0;f=h>>>24;l=e[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>1]|0;m=b}else{b=j&-4;c[194193]=b;h=b+4|0;c[194161]=h;f=j>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];f=h>>>24;l=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2]|0;m=b}c[203400]=l;l=m>>>24&15;m=(l-8|0)>>>0<6;do{if(m){b=c[194192]|0;if((b&1|0)==0){i=1647;break}h=b&255;if((b&2|0)==0){f=h>>>1|b&-256;c[194192]=f;n=(d[130328+l|0]|0)-1|0;o=f;i=1648;break}else{f=h>>>2|b&-256;c[194192]=f;p=f;q=3;i=1649;break}}else{i=1647}}while(0);if((i|0)==1647){c[194192]=0;n=d[130616+l|0]|0;o=0;i=1648}if((i|0)==1648){f=n+3|0;if(m){p=o;q=f;i=1649}else{r=f;i=1655}}do{if((i|0)==1649){if((p&1|0)==0){if(p>>>0<=255){r=q;i=1655;break}c[194192]=0;s=d[130616+l|0]|0;t=q;break}f=p&255;if((p&2|0)==0){c[194192]=f>>>1|p&-256;s=d[130328+l|0]|0;t=q;break}else{c[194192]=f>>>2|p&-256;s=0;t=q;break}}}while(0);if((i|0)==1655){s=d[125296+l|0]|0;t=r}k=(s<<1)+t|0;c[204526]=k;return}function s3(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b>>>12&15;g=b>>>7&30;h=b&255;if((g|0)==0){i=(a[768256]&1)!=0;j=h}else{i=(1<<g-1&h|0)!=0;j=h<<32-g|h>>>(g>>>0)}c[776584+(f<<2)>>2]=~j;if((f|0)!=15){a[768240]=j>>>31&255^1;a[768224]=(j|0)==-1|0;a[768256]=i&1}if((b&61440|0)!=61440){b=(c[194193]|0)>>>24&15;do{if((b-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){k=1673;break}c[194192]=0;l=d[130616+b|0]|0;break}j=i&255;if((i&2|0)==0){c[194192]=j>>>1|i&-256;l=d[130328+b|0]|0;break}else{c[194192]=j>>>2|i&-256;l=0;break}}else{k=1673}}while(0);if((k|0)==1673){l=d[125296+b|0]|0}m=l+1|0;c[204526]=m;return}l=c[194163]&31;if((c[31194]|0)!=(l|0)){km(l,0,1)}l=c[194161]|0;if((a[52040]&1)==0){b=l&-2;c[194193]=b;i=b+2|0;c[194161]=i;j=l>>>24;c[203402]=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>1]|0;j=i>>>24;n=e[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>1]|0;o=b}else{b=l&-4;c[194193]=b;i=b+4|0;c[194161]=i;j=l>>>24;c[203402]=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&b)>>2];j=i>>>24;n=c[(c[774536+(j<<3)>>2]|0)+(c[774540+(j<<3)>>2]&i)>>2]|0;o=b}c[203400]=n;n=o>>>24&15;o=(n-8|0)>>>0<6;do{if(o){b=c[194192]|0;if((b&1|0)==0){k=1685;break}i=b&255;if((b&2|0)==0){j=i>>>1|b&-256;c[194192]=j;p=(d[130328+n|0]|0)-1|0;q=j;k=1686;break}else{j=i>>>2|b&-256;c[194192]=j;r=j;s=3;k=1687;break}}else{k=1685}}while(0);if((k|0)==1685){c[194192]=0;p=d[130616+n|0]|0;q=0;k=1686}if((k|0)==1686){j=p+3|0;if(o){r=q;s=j;k=1687}else{t=j;k=1693}}do{if((k|0)==1687){if((r&1|0)==0){if(r>>>0<=255){t=s;k=1693;break}c[194192]=0;u=d[130616+n|0]|0;v=s;break}j=r&255;if((r&2|0)==0){c[194192]=j>>>1|r&-256;u=d[130328+n|0]|0;v=s;break}else{c[194192]=j>>>2|r&-256;u=0;v=s;break}}}while(0);if((k|0)==1693){u=d[125296+n|0]|0;v=t}m=(u<<1)+v|0;c[204526]=m;return}function s4(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);c[e>>2]=f-(b&4095);b=f>>>24&15;f=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function s5(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=ke(h)|0;if((e|0)!=(f|0)){c[g>>2]=h-(b&4095)}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24&15;b=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function s6(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);c[e>>2]=f-(b&4095);b=f>>>24&15;f=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function s7(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=(n0(h)|0)&255;if((e|0)!=(f|0)){c[g>>2]=h-(b&4095)}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24&15;b=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function s8(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);c[e>>2]=f+(b&4095);b=f>>>24&15;f=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function s9(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=ke(h)|0;if((e|0)!=(f|0)){c[g>>2]=h+(b&4095)}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24&15;b=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function ta(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);c[e>>2]=f+(b&4095);b=f>>>24&15;f=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function tb(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=(n0(h)|0)&255;if((e|0)!=(f|0)){c[g>>2]=h+(b&4095)}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24&15;b=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=h>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function tc(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-(b&4095)|0;kg(e,c[776584+((b>>>12&15)<<2)>>2]|0);b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function td(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(b&4095)|0;c[776584+(e<<2)>>2]=ke(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function te(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)-(b&4095)|0;c[e>>2]=f;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);b=f>>>24&15;f=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function tf(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-(b&4095)|0;c[776584+(e<<2)>>2]=ke(h)|0;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function tg(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-(b&4095)|0;n2(e,a[776584+((b>>>12&15)<<2)|0]|0);b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function th(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(b&4095)|0;c[776584+(e<<2)>>2]=(n0(f)|0)&255;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function ti(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)-(b&4095)|0;c[e>>2]=f;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);b=f>>>24&15;f=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function tj(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-(b&4095)|0;c[776584+(e<<2)>>2]=(n0(h)|0)&255;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function tk(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)+(b&4095)|0;kg(e,c[776584+((b>>>12&15)<<2)>>2]|0);b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function tl(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(b&4095)|0;c[776584+(e<<2)>>2]=ke(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function tm(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)+(b&4095)|0;c[e>>2]=f;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);b=f>>>24&15;f=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function tn(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)+(b&4095)|0;c[776584+(e<<2)>>2]=ke(h)|0;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function to(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)+(b&4095)|0;n2(e,a[776584+((b>>>12&15)<<2)|0]|0);b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function tp(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(b&4095)|0;c[776584+(e<<2)>>2]=(n0(f)|0)&255;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function tq(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)+(b&4095)|0;c[e>>2]=f;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);b=f>>>24&15;f=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function tr(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)+(b&4095)|0;c[776584+(e<<2)>>2]=(n0(h)|0)&255;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function ts(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);f=776584+((b>>>16&15)<<2)|0;g=c[f>>2]|0;kg(g,c[776584+((b>>>12&15)<<2)>>2]|0);c[f>>2]=g-e;e=g>>>24&15;g=d[130616+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}b=f&255;if((f&2|0)==0){c[194192]=b>>>1|f&-256;h=(d[130328+g|0]|0)-1|0;i=e+h|0;c[204526]=i;return}else{c[194192]=b>>>2|f&-256;h=0;i=e+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=e+h|0;c[204526]=i;return}function tt(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;g=c[e>>2]|0;kg(g,c[776584+((b>>>12&15)<<2)>>2]|0);c[e>>2]=g-f;f=g>>>24&15;g=d[130616+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);f=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=f+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=f+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=f+h|0;c[204526]=i;return}function tu(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e);e=776584+((b>>>16&15)<<2)|0;g=c[e>>2]|0;kg(g,c[776584+((b>>>12&15)<<2)>>2]|0);c[e>>2]=g-f;f=g>>>24&15;g=d[130616+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);f=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=f+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=f+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=f+h|0;c[204526]=i;return}function tv(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);c[e>>2]=f-g;g=f>>>24&15;f=d[130616+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);g=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=g+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=g+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=g+h|0;c[204526]=i;return}function tw(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=c[776584+((b&15)<<2)>>2]|0;h=776584+(f<<2)|0;i=c[h>>2]|0;c[776584+(e<<2)>>2]=ke(i)|0;if((e|0)!=(f|0)){c[h>>2]=i-(g<<(b>>>7&31))}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=i>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;j=e+5|0;k=g;l=h}else{h=i>>>24&15;j=3;k=h;l=h-2|0}h=d[130616+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+h|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+h|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+h|0;o=n+m|0;c[204526]=o;return}function tx(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=776584+(f<<2)|0;b=c[g>>2]|0;c[776584+(e<<2)>>2]=ke(b)|0;if((e|0)!=(f|0)){c[g>>2]=b-h}c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;g=h+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2];h=g>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24&15;h=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=b>>>24&15;i=3;j=f;k=f-2|0}f=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}b=j&255;if((j&2|0)==0){c[194192]=b>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=b>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function ty(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;b=776584+(f<<2)|0;i=c[b>>2]|0;c[776584+(e<<2)>>2]=ke(i)|0;if((e|0)!=(f|0)){c[b>>2]=i-(h>>((g|0)==0?31:g))}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;h=g+4|0;c[194161]=h;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=i>>>24&15;g=d[125296+h|0]|0;b=h-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=h;l=b}else{b=i>>>24&15;j=3;k=b;l=b-2|0}b=d[130616+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+b|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+b|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+b|0;o=n+m|0;c[204526]=o;return}function tz(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(d[768256]|0)<<31|h>>>1}else{i=h<<32-g|h>>>(g>>>0)}g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=ke(h)|0;if((e|0)!=(f|0)){c[g>>2]=h-i}c[204526]=0;if((e|0)==15){e=c[194161]|0;i=e&-4;c[194193]=i;g=i+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2];i=g>>>24;c[203400]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=h>>>24&15;i=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);e=i<<1;c[204526]=e+2;j=e+5|0;k=g;l=f}else{f=h>>>24&15;j=3;k=f;l=f-2|0}f=d[130616+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+f|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+f|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+f|0;o=n+m|0;c[204526]=o;return}function tA(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);f=776584+((b>>>16&15)<<2)|0;g=c[f>>2]|0;n2(g,a[776584+((b>>>12&15)<<2)|0]|0);c[f>>2]=g-e;e=g>>>24&15;g=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}b=f&255;if((f&2|0)==0){c[194192]=b>>>1|f&-256;h=(d[130328+g|0]|0)-1|0;i=e+h|0;c[204526]=i;return}else{c[194192]=b>>>2|f&-256;h=0;i=e+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=e+h|0;c[204526]=i;return}function tB(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;g=c[e>>2]|0;n2(g,a[776584+((b>>>12&15)<<2)|0]|0);c[e>>2]=g-f;f=g>>>24&15;g=d[147072+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);f=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=f+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=f+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=f+h|0;c[204526]=i;return}function tC(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e);e=776584+((b>>>16&15)<<2)|0;g=c[e>>2]|0;n2(g,a[776584+((b>>>12&15)<<2)|0]|0);c[e>>2]=g-f;f=g>>>24&15;g=d[147072+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);f=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=f+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=f+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=f+h|0;c[204526]=i;return}function tD(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);c[e>>2]=f-g;g=f>>>24&15;f=d[147072+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);g=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=g+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=g+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=g+h|0;c[204526]=i;return}function tE(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=c[776584+((b&15)<<2)>>2]|0;h=776584+(f<<2)|0;i=c[h>>2]|0;c[776584+(e<<2)>>2]=(n0(i)|0)&255;if((e|0)!=(f|0)){c[h>>2]=i-(g<<(b>>>7&31))}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=i>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;j=e+5|0;k=g;l=h}else{h=i>>>24&15;j=3;k=h;l=h-2|0}h=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+h|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+h|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+h|0;o=n+m|0;c[204526]=o;return}function tF(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=776584+(f<<2)|0;b=c[g>>2]|0;c[776584+(e<<2)>>2]=(n0(b)|0)&255;if((e|0)!=(f|0)){c[g>>2]=b-h}c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;g=h+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2];h=g>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24&15;h=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=b>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}b=j&255;if((j&2|0)==0){c[194192]=b>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=b>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function tG(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;b=776584+(f<<2)|0;i=c[b>>2]|0;c[776584+(e<<2)>>2]=(n0(i)|0)&255;if((e|0)!=(f|0)){c[b>>2]=i-(h>>((g|0)==0?31:g))}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;h=g+4|0;c[194161]=h;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=i>>>24&15;g=d[125296+h|0]|0;b=h-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=h;l=b}else{b=i>>>24&15;j=3;k=b;l=b-2|0}b=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+b|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+b|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+b|0;o=n+m|0;c[204526]=o;return}function tH(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(d[768256]|0)<<31|h>>>1}else{i=h<<32-g|h>>>(g>>>0)}g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=(n0(h)|0)&255;if((e|0)!=(f|0)){c[g>>2]=h-i}c[204526]=0;if((e|0)==15){e=c[194161]|0;i=e&-4;c[194193]=i;g=i+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2];i=g>>>24;c[203400]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=h>>>24&15;i=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);e=i<<1;c[204526]=e+2;j=e+5|0;k=g;l=f}else{f=h>>>24&15;j=3;k=f;l=f-2|0}f=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+f|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+f|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+f|0;o=n+m|0;c[204526]=o;return}function tI(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);f=776584+((b>>>16&15)<<2)|0;g=c[f>>2]|0;kg(g,c[776584+((b>>>12&15)<<2)>>2]|0);c[f>>2]=g+e;e=g>>>24&15;g=d[130616+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}b=f&255;if((f&2|0)==0){c[194192]=b>>>1|f&-256;h=(d[130328+g|0]|0)-1|0;i=e+h|0;c[204526]=i;return}else{c[194192]=b>>>2|f&-256;h=0;i=e+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=e+h|0;c[204526]=i;return}function tJ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;g=c[e>>2]|0;kg(g,c[776584+((b>>>12&15)<<2)>>2]|0);c[e>>2]=g+f;f=g>>>24&15;g=d[130616+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);f=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=f+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=f+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=f+h|0;c[204526]=i;return}function tK(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e);e=776584+((b>>>16&15)<<2)|0;g=c[e>>2]|0;kg(g,c[776584+((b>>>12&15)<<2)>>2]|0);c[e>>2]=g+f;f=g>>>24&15;g=d[130616+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);f=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=f+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=f+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=f+h|0;c[204526]=i;return}function tL(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);c[e>>2]=f+g;g=f>>>24&15;f=d[130616+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);g=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=g+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=g+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=g+h|0;c[204526]=i;return}function tM(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=c[776584+((b&15)<<2)>>2]|0;h=776584+(f<<2)|0;i=c[h>>2]|0;c[776584+(e<<2)>>2]=ke(i)|0;if((e|0)!=(f|0)){c[h>>2]=i+(g<<(b>>>7&31))}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=i>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;j=e+5|0;k=g;l=h}else{h=i>>>24&15;j=3;k=h;l=h-2|0}h=d[130616+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+h|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+h|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+h|0;o=n+m|0;c[204526]=o;return}function tN(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=776584+(f<<2)|0;b=c[g>>2]|0;c[776584+(e<<2)>>2]=ke(b)|0;if((e|0)!=(f|0)){c[g>>2]=b+h}c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;g=h+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2];h=g>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24&15;h=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=b>>>24&15;i=3;j=f;k=f-2|0}f=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}b=j&255;if((j&2|0)==0){c[194192]=b>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=b>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function tO(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;b=776584+(f<<2)|0;i=c[b>>2]|0;c[776584+(e<<2)>>2]=ke(i)|0;if((e|0)!=(f|0)){c[b>>2]=i+(h>>((g|0)==0?31:g))}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;h=g+4|0;c[194161]=h;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=i>>>24&15;g=d[125296+h|0]|0;b=h-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=h;l=b}else{b=i>>>24&15;j=3;k=b;l=b-2|0}b=d[130616+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+b|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+b|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+b|0;o=n+m|0;c[204526]=o;return}function tP(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(d[768256]|0)<<31|h>>>1}else{i=h<<32-g|h>>>(g>>>0)}g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=ke(h)|0;if((e|0)!=(f|0)){c[g>>2]=h+i}c[204526]=0;if((e|0)==15){e=c[194161]|0;i=e&-4;c[194193]=i;g=i+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2];i=g>>>24;c[203400]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=h>>>24&15;i=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);e=i<<1;c[204526]=e+2;j=e+5|0;k=g;l=f}else{f=h>>>24&15;j=3;k=f;l=f-2|0}f=d[130616+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+f|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+f|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+f|0;o=n+m|0;c[204526]=o;return}function tQ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=c[776584+((b&15)<<2)>>2]<<(b>>>7&31);f=776584+((b>>>16&15)<<2)|0;g=c[f>>2]|0;n2(g,a[776584+((b>>>12&15)<<2)|0]|0);c[f>>2]=g+e;e=g>>>24&15;g=d[147072+e|0]|0;do{if((e-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}b=f&255;if((f&2|0)==0){c[194192]=b>>>1|f&-256;h=(d[130328+g|0]|0)-1|0;i=e+h|0;c[204526]=i;return}else{c[194192]=b>>>2|f&-256;h=0;i=e+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=e+h|0;c[204526]=i;return}function tR(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;g=c[e>>2]|0;n2(g,a[776584+((b>>>12&15)<<2)|0]|0);c[e>>2]=g+f;f=g>>>24&15;g=d[147072+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);f=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=f+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=f+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=f+h|0;c[204526]=i;return}function tS(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e);e=776584+((b>>>16&15)<<2)|0;g=c[e>>2]|0;n2(g,a[776584+((b>>>12&15)<<2)|0]|0);c[e>>2]=g+f;f=g>>>24&15;g=d[147072+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);f=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=f+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=f+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=f+h|0;c[204526]=i;return}function tT(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);c[e>>2]=f+g;g=f>>>24&15;f=d[147072+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);g=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}b=e&255;if((e&2|0)==0){c[194192]=b>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=g+h|0;c[204526]=i;return}else{c[194192]=b>>>2|e&-256;h=0;i=g+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=g+h|0;c[204526]=i;return}function tU(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=c[776584+((b&15)<<2)>>2]|0;h=776584+(f<<2)|0;i=c[h>>2]|0;c[776584+(e<<2)>>2]=(n0(i)|0)&255;if((e|0)!=(f|0)){c[h>>2]=i+(g<<(b>>>7&31))}c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=i>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;j=e+5|0;k=g;l=h}else{h=i>>>24&15;j=3;k=h;l=h-2|0}h=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+h|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+h|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+h|0;o=n+m|0;c[204526]=o;return}function tV(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=776584+(f<<2)|0;b=c[g>>2]|0;c[776584+(e<<2)>>2]=(n0(b)|0)&255;if((e|0)!=(f|0)){c[g>>2]=b+h}c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;g=h+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&h)>>2];h=g>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24&15;h=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;i=e+5|0;j=g;k=f}else{f=b>>>24&15;i=3;j=f;k=f-2|0}f=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}b=j&255;if((j&2|0)==0){c[194192]=b>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+f|0;n=m+l|0;c[204526]=n;return}else{c[194192]=b>>>2|j&-256;l=0;m=i+f|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+f|0;n=m+l|0;c[204526]=n;return}function tW(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;b=776584+(f<<2)|0;i=c[b>>2]|0;c[776584+(e<<2)>>2]=(n0(i)|0)&255;if((e|0)!=(f|0)){c[b>>2]=i+(h>>((g|0)==0?31:g))}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;h=g+4|0;c[194161]=h;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=h>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=i>>>24&15;g=d[125296+h|0]|0;b=h-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=h;l=b}else{b=i>>>24&15;j=3;k=b;l=b-2|0}b=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+b|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+b|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+b|0;o=n+m|0;c[204526]=o;return}function tX(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(d[768256]|0)<<31|h>>>1}else{i=h<<32-g|h>>>(g>>>0)}g=776584+(f<<2)|0;h=c[g>>2]|0;c[776584+(e<<2)>>2]=(n0(h)|0)&255;if((e|0)!=(f|0)){c[g>>2]=h+i}c[204526]=0;if((e|0)==15){e=c[194161]|0;i=e&-4;c[194193]=i;g=i+4|0;c[194161]=g;f=e>>>24;c[203402]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&i)>>2];i=g>>>24;c[203400]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=h>>>24&15;i=d[125296+g|0]|0;f=g-2|0;do{if(f>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);e=i<<1;c[204526]=e+2;j=e+5|0;k=g;l=f}else{f=h>>>24&15;j=3;k=f;l=f-2|0}f=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+f|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+f|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+f|0;o=n+m|0;c[204526]=o;return}function tY(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;kg(e,c[776584+((b>>>12&15)<<2)>>2]|0);b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function tZ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-f|0;kg(e,c[776584+((b>>>12&15)<<2)>>2]|0);b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function t_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e))|0;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);b=f>>>24&15;f=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function t$(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-g|0;kg(e,c[776584+((b>>>12&15)<<2)>>2]|0);b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=f>>>2|g&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function t0(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[776584+(e<<2)>>2]=ke(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function t1(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}f=(c[776584+((b>>>16&15)<<2)>>2]|0)-g|0;c[776584+(e<<2)>>2]=ke(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=f>>>24&15;g=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function t2(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;g=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f))|0;c[776584+(e<<2)>>2]=ke(g)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;f=e&-4;c[194193]=f;b=f+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&f)>>2];f=b>>>24;c[203400]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24&15;f=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);e=f<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=g>>>24&15;i=3;j=h;k=h-2|0}h=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}g=j&255;if((j&2|0)==0){c[194192]=g>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=g>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function t3(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}f=(c[776584+((b>>>16&15)<<2)>>2]|0)-h|0;c[776584+(e<<2)>>2]=ke(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;b=h+4|0;c[194161]=b;g=e>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=b>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=f>>>24&15;h=d[125296+b|0]|0;g=b-2|0;do{if(g>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;i=e+5|0;j=b;k=g}else{g=f>>>24&15;i=3;j=g;k=g-2|0}g=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+g|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+g|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+g|0;n=m+l|0;c[204526]=n;return}function t4(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)-(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[e>>2]=f;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);b=f>>>24&15;f=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function t5(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;g=(c[e>>2]|0)-f|0;c[e>>2]=g;kg(g,c[776584+((b>>>12&15)<<2)>>2]|0);b=g>>>24&15;g=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);b=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}f=e&255;if((e&2|0)==0){c[194192]=f>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=f>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=b+h|0;c[204526]=i;return}function t6(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=776584+((b>>>16&15)<<2)|0;g=(c[f>>2]|0)-(c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e))|0;c[f>>2]=g;kg(g,c[776584+((b>>>12&15)<<2)>>2]|0);b=g>>>24&15;g=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);b=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}e=f&255;if((f&2|0)==0){c[194192]=e>>>1|f&-256;h=(d[130328+g|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=e>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=b+h|0;c[204526]=i;return}function t7(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)-g|0;c[e>>2]=f;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);b=f>>>24&15;f=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function t8(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[776584+(e<<2)>>2]=ke(h)|0;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function t9(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=776584+(f<<2)|0;b=(c[g>>2]|0)-h|0;c[776584+(e<<2)>>2]=ke(b)|0;if((e|0)!=(f|0)){c[g>>2]=b}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=b>>>24&15;g=d[125296+f|0]|0;h=f-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=h}else{h=b>>>24&15;i=3;j=h;k=h-2|0}h=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}b=j&255;if((j&2|0)==0){c[194192]=b>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=b>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function ua(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=776584+(f<<2)|0;i=(c[h>>2]|0)-(c[776584+((b&15)<<2)>>2]>>((g|0)==0?31:g))|0;c[776584+(e<<2)>>2]=ke(i)|0;if((e|0)!=(f|0)){c[h>>2]=i}c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;f=h+4|0;c[194161]=f;g=e>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=f>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&f)>>2];f=i>>>24&15;h=d[125296+f|0]|0;g=f-2|0;do{if(g>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;j=e+5|0;k=f;l=g}else{g=i>>>24&15;j=3;k=g;l=g-2|0}g=d[130616+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+g|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+g|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+g|0;o=n+m|0;c[204526]=o;return}function ub(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(d[768256]|0)<<31|h>>>1}else{i=h<<32-g|h>>>(g>>>0)}g=776584+(f<<2)|0;h=(c[g>>2]|0)-i|0;c[776584+(e<<2)>>2]=ke(h)|0;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;i=e>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;i=f-2|0;do{if(i>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=f;l=i}else{i=h>>>24&15;j=3;k=i;l=i-2|0}i=d[130616+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+i|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+i|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+i|0;o=n+m|0;c[204526]=o;return}function uc(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;n2(e,a[776584+((b>>>12&15)<<2)|0]|0);b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function ud(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-f|0;n2(e,a[776584+((b>>>12&15)<<2)|0]|0);b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function ue(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e))|0;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);b=f>>>24&15;f=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function uf(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-g|0;n2(e,a[776584+((b>>>12&15)<<2)|0]|0);b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=f>>>2|g&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function ug(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[776584+(e<<2)>>2]=(n0(f)|0)&255;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function uh(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}f=(c[776584+((b>>>16&15)<<2)>>2]|0)-g|0;c[776584+(e<<2)>>2]=(n0(f)|0)&255;c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=f>>>24&15;g=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function ui(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;g=(c[776584+((b>>>16&15)<<2)>>2]|0)-(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f))|0;c[776584+(e<<2)>>2]=(n0(g)|0)&255;c[204526]=0;if((e|0)==15){e=c[194161]|0;f=e&-4;c[194193]=f;b=f+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&f)>>2];f=b>>>24;c[203400]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24&15;f=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);e=f<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=g>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}g=j&255;if((j&2|0)==0){c[194192]=g>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=g>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function uj(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}f=(c[776584+((b>>>16&15)<<2)>>2]|0)-h|0;c[776584+(e<<2)>>2]=(n0(f)|0)&255;c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;b=h+4|0;c[194161]=b;g=e>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=b>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=f>>>24&15;h=d[125296+b|0]|0;g=b-2|0;do{if(g>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;i=e+5|0;j=b;k=g}else{g=f>>>24&15;i=3;j=g;k=g-2|0}g=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+g|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+g|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+g|0;n=m+l|0;c[204526]=n;return}function uk(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)-(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[e>>2]=f;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);b=f>>>24&15;f=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function ul(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;g=(c[e>>2]|0)-f|0;c[e>>2]=g;n2(g,a[776584+((b>>>12&15)<<2)|0]|0);b=g>>>24&15;g=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);b=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}f=e&255;if((e&2|0)==0){c[194192]=f>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=f>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=b+h|0;c[204526]=i;return}function um(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=776584+((b>>>16&15)<<2)|0;g=(c[f>>2]|0)-(c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e))|0;c[f>>2]=g;n2(g,a[776584+((b>>>12&15)<<2)|0]|0);b=g>>>24&15;g=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);b=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}e=f&255;if((f&2|0)==0){c[194192]=e>>>1|f&-256;h=(d[130328+g|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=e>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=b+h|0;c[204526]=i;return}function un(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)-g|0;c[e>>2]=f;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);b=f>>>24&15;f=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function uo(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[776584+(e<<2)>>2]=(n0(h)|0)&255;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function up(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=776584+(f<<2)|0;b=(c[g>>2]|0)-h|0;c[776584+(e<<2)>>2]=(n0(b)|0)&255;if((e|0)!=(f|0)){c[g>>2]=b}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=b>>>24&15;g=d[125296+f|0]|0;h=f-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=h}else{h=b>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}b=j&255;if((j&2|0)==0){c[194192]=b>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=b>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function uq(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=776584+(f<<2)|0;i=(c[h>>2]|0)-(c[776584+((b&15)<<2)>>2]>>((g|0)==0?31:g))|0;c[776584+(e<<2)>>2]=(n0(i)|0)&255;if((e|0)!=(f|0)){c[h>>2]=i}c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;f=h+4|0;c[194161]=f;g=e>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=f>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&f)>>2];f=i>>>24&15;h=d[125296+f|0]|0;g=f-2|0;do{if(g>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;j=e+5|0;k=f;l=g}else{g=i>>>24&15;j=3;k=g;l=g-2|0}g=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+g|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+g|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+g|0;o=n+m|0;c[204526]=o;return}function ur(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(d[768256]|0)<<31|h>>>1}else{i=h<<32-g|h>>>(g>>>0)}g=776584+(f<<2)|0;h=(c[g>>2]|0)-i|0;c[776584+(e<<2)>>2]=(n0(h)|0)&255;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;i=e>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;i=f-2|0;do{if(i>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=f;l=i}else{i=h>>>24&15;j=3;k=i;l=i-2|0}i=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+i|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+i|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+i|0;o=n+m|0;c[204526]=o;return}function us(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;kg(e,c[776584+((b>>>12&15)<<2)>>2]|0);b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function ut(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=(c[776584+((b>>>16&15)<<2)>>2]|0)+f|0;kg(e,c[776584+((b>>>12&15)<<2)>>2]|0);b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function uu(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e))|0;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);b=f>>>24&15;f=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function uv(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=(c[776584+((b>>>16&15)<<2)>>2]|0)+g|0;kg(e,c[776584+((b>>>12&15)<<2)>>2]|0);b=e>>>24&15;e=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=f>>>2|g&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function uw(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[776584+(e<<2)>>2]=ke(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function ux(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}f=(c[776584+((b>>>16&15)<<2)>>2]|0)+g|0;c[776584+(e<<2)>>2]=ke(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=f>>>24&15;g=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function uy(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;g=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f))|0;c[776584+(e<<2)>>2]=ke(g)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;f=e&-4;c[194193]=f;b=f+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&f)>>2];f=b>>>24;c[203400]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24&15;f=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);e=f<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=g>>>24&15;i=3;j=h;k=h-2|0}h=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}g=j&255;if((j&2|0)==0){c[194192]=g>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=g>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function uz(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}f=(c[776584+((b>>>16&15)<<2)>>2]|0)+h|0;c[776584+(e<<2)>>2]=ke(f)|0;c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;b=h+4|0;c[194161]=b;g=e>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=b>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=f>>>24&15;h=d[125296+b|0]|0;g=b-2|0;do{if(g>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;i=e+5|0;j=b;k=g}else{g=f>>>24&15;i=3;j=g;k=g-2|0}g=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+g|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+g|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+g|0;n=m+l|0;c[204526]=n;return}function uA(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)+(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[e>>2]=f;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);b=f>>>24&15;f=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function uB(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;g=(c[e>>2]|0)+f|0;c[e>>2]=g;kg(g,c[776584+((b>>>12&15)<<2)>>2]|0);b=g>>>24&15;g=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);b=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}f=e&255;if((e&2|0)==0){c[194192]=f>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=f>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=b+h|0;c[204526]=i;return}function uC(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=776584+((b>>>16&15)<<2)|0;g=(c[f>>2]|0)+(c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e))|0;c[f>>2]=g;kg(g,c[776584+((b>>>12&15)<<2)>>2]|0);b=g>>>24&15;g=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);b=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}e=f&255;if((f&2|0)==0){c[194192]=e>>>1|f&-256;h=(d[130328+g|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=e>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=b+h|0;c[204526]=i;return}function uD(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)+g|0;c[e>>2]=f;kg(f,c[776584+((b>>>12&15)<<2)>>2]|0);b=f>>>24&15;f=d[130616+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function uE(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)+(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[776584+(e<<2)>>2]=ke(h)|0;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function uF(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=776584+(f<<2)|0;b=(c[g>>2]|0)+h|0;c[776584+(e<<2)>>2]=ke(b)|0;if((e|0)!=(f|0)){c[g>>2]=b}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=b>>>24&15;g=d[125296+f|0]|0;h=f-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=h}else{h=b>>>24&15;i=3;j=h;k=h-2|0}h=d[130616+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}b=j&255;if((j&2|0)==0){c[194192]=b>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=b>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function uG(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=776584+(f<<2)|0;i=(c[h>>2]|0)+(c[776584+((b&15)<<2)>>2]>>((g|0)==0?31:g))|0;c[776584+(e<<2)>>2]=ke(i)|0;if((e|0)!=(f|0)){c[h>>2]=i}c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;f=h+4|0;c[194161]=f;g=e>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=f>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&f)>>2];f=i>>>24&15;h=d[125296+f|0]|0;g=f-2|0;do{if(g>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;j=e+5|0;k=f;l=g}else{g=i>>>24&15;j=3;k=g;l=g-2|0}g=d[130616+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+g|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+g|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+g|0;o=n+m|0;c[204526]=o;return}function uH(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(d[768256]|0)<<31|h>>>1}else{i=h<<32-g|h>>>(g>>>0)}g=776584+(f<<2)|0;h=(c[g>>2]|0)+i|0;c[776584+(e<<2)>>2]=ke(h)|0;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;i=e>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;i=f-2|0;do{if(i>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=f;l=i}else{i=h>>>24&15;j=3;k=i;l=i-2|0}i=d[130616+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+i|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+i|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+i|0;o=n+m|0;c[204526]=o;return}function uI(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;n2(e,a[776584+((b>>>12&15)<<2)|0]|0);b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function uJ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=(c[776584+((b>>>16&15)<<2)>>2]|0)+f|0;n2(e,a[776584+((b>>>12&15)<<2)|0]|0);b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}g=f&255;if((f&2|0)==0){c[194192]=g>>>1|f&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function uK(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e))|0;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);b=f>>>24&15;f=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function uL(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=(c[776584+((b>>>16&15)<<2)>>2]|0)+g|0;n2(e,a[776584+((b>>>12&15)<<2)|0]|0);b=e>>>24&15;e=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);b=e+2|0;e=(c[194193]|0)>>>24&15;do{if((e-8|0)>>>0<6){g=c[194192]|0;if((g&1|0)==0){break}f=g&255;if((g&2|0)==0){c[194192]=f>>>1|g&-256;h=(d[130328+e|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=f>>>2|g&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+e|0]|0;i=b+h|0;c[204526]=i;return}function uM(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[776584+(e<<2)>>2]=(n0(f)|0)&255;c[204526]=0;if((e|0)==15){e=c[194161]|0;b=e&-4;c[194193]=b;g=b+4|0;c[194161]=g;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=g>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24&15;b=d[125296+g|0]|0;h=g-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);e=b<<1;c[204526]=e+2;i=e+5|0;j=g;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function uN(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;if((f|0)==0){g=0}else{g=(c[776584+((b&15)<<2)>>2]|0)>>>(f>>>0)}f=(c[776584+((b>>>16&15)<<2)>>2]|0)+g|0;c[776584+(e<<2)>>2]=(n0(f)|0)&255;c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;b=g+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=b>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&b)>>2];b=f>>>24&15;g=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=f>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function uO(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;g=(c[776584+((b>>>16&15)<<2)>>2]|0)+(c[776584+((b&15)<<2)>>2]>>((f|0)==0?31:f))|0;c[776584+(e<<2)>>2]=(n0(g)|0)&255;c[204526]=0;if((e|0)==15){e=c[194161]|0;f=e&-4;c[194193]=f;b=f+4|0;c[194161]=b;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&f)>>2];f=b>>>24;c[203400]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&b)>>2];b=g>>>24&15;f=d[125296+b|0]|0;h=b-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);e=f<<1;c[204526]=e+2;i=e+5|0;j=b;k=h}else{h=g>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}g=j&255;if((j&2|0)==0){c[194192]=g>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=g>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function uP(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>7&31;g=c[776584+((b&15)<<2)>>2]|0;if((f|0)==0){h=(d[768256]|0)<<31|g>>>1}else{h=g<<32-f|g>>>(f>>>0)}f=(c[776584+((b>>>16&15)<<2)>>2]|0)+h|0;c[776584+(e<<2)>>2]=(n0(f)|0)&255;c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;b=h+4|0;c[194161]=b;g=e>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=b>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&b)>>2];b=f>>>24&15;h=d[125296+b|0]|0;g=b-2|0;do{if(g>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;i=e+5|0;j=b;k=g}else{g=f>>>24&15;i=3;j=g;k=g-2|0}g=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}f=j&255;if((j&2|0)==0){c[194192]=f>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+g|0;n=m+l|0;c[204526]=n;return}else{c[194192]=f>>>2|j&-256;l=0;m=i+g|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+g|0;n=m+l|0;c[204526]=n;return}function uQ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)+(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[e>>2]=f;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);b=f>>>24&15;f=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function uR(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;if((e|0)==0){f=0}else{f=(c[776584+((b&15)<<2)>>2]|0)>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;g=(c[e>>2]|0)+f|0;c[e>>2]=g;n2(g,a[776584+((b>>>12&15)<<2)|0]|0);b=g>>>24&15;g=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);b=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}f=e&255;if((e&2|0)==0){c[194192]=f>>>1|e&-256;h=(d[130328+g|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=f>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=b+h|0;c[204526]=i;return}function uS(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=776584+((b>>>16&15)<<2)|0;g=(c[f>>2]|0)+(c[776584+((b&15)<<2)>>2]>>((e|0)==0?31:e))|0;c[f>>2]=g;n2(g,a[776584+((b>>>12&15)<<2)|0]|0);b=g>>>24&15;g=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);b=g+2|0;g=(c[194193]|0)>>>24&15;do{if((g-8|0)>>>0<6){f=c[194192]|0;if((f&1|0)==0){break}e=f&255;if((f&2|0)==0){c[194192]=e>>>1|f&-256;h=(d[130328+g|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=e>>>2|f&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+g|0]|0;i=b+h|0;c[204526]=i;return}function uT(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>7&31;f=c[776584+((b&15)<<2)>>2]|0;if((e|0)==0){g=(d[768256]|0)<<31|f>>>1}else{g=f<<32-e|f>>>(e>>>0)}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)+g|0;c[e>>2]=f;n2(f,a[776584+((b>>>12&15)<<2)|0]|0);b=f>>>24&15;f=d[147072+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);b=f+2|0;f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}g=e&255;if((e&2|0)==0){c[194192]=g>>>1|e&-256;h=(d[130328+f|0]|0)-1|0;i=b+h|0;c[204526]=i;return}else{c[194192]=g>>>2|e&-256;h=0;i=b+h|0;c[204526]=i;return}}}while(0);c[194192]=0;h=d[130616+f|0]|0;i=b+h|0;c[204526]=i;return}function uU(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)+(c[776584+((b&15)<<2)>>2]<<(b>>>7&31))|0;c[776584+(e<<2)>>2]=(n0(h)|0)&255;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;b=f-2|0;do{if(b>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=b}else{b=h>>>24&15;i=3;j=b;k=b-2|0}b=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(b&1^1|b))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}h=j&255;if((j&2|0)==0){c[194192]=h>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+b|0;n=m+l|0;c[204526]=n;return}else{c[194192]=h>>>2|j&-256;l=0;m=i+b|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+b|0;n=m+l|0;c[204526]=n;return}function uV(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;if((g|0)==0){h=0}else{h=(c[776584+((b&15)<<2)>>2]|0)>>>(g>>>0)}g=776584+(f<<2)|0;b=(c[g>>2]|0)+h|0;c[776584+(e<<2)>>2]=(n0(b)|0)&255;if((e|0)!=(f|0)){c[g>>2]=b}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;h=e>>>24;c[203402]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=b>>>24&15;g=d[125296+f|0]|0;h=f-2|0;do{if(h>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;i=e+5|0;j=f;k=h}else{h=b>>>24&15;i=3;j=h;k=h-2|0}h=d[147072+j|0]|0;do{if(k>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);k=(c[194193]|0)>>>24&15;do{if((k-8|0)>>>0<6){j=c[194192]|0;if((j&1|0)==0){break}b=j&255;if((j&2|0)==0){c[194192]=b>>>1|j&-256;l=(d[130328+k|0]|0)-1|0;m=i+h|0;n=m+l|0;c[204526]=n;return}else{c[194192]=b>>>2|j&-256;l=0;m=i+h|0;n=m+l|0;c[204526]=n;return}}}while(0);c[194192]=0;l=d[130616+k|0]|0;m=i+h|0;n=m+l|0;c[204526]=n;return}function uW(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=776584+(f<<2)|0;i=(c[h>>2]|0)+(c[776584+((b&15)<<2)>>2]>>((g|0)==0?31:g))|0;c[776584+(e<<2)>>2]=(n0(i)|0)&255;if((e|0)!=(f|0)){c[h>>2]=i}c[204526]=0;if((e|0)==15){e=c[194161]|0;h=e&-4;c[194193]=h;f=h+4|0;c[194161]=f;g=e>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&h)>>2];h=f>>>24;c[203400]=c[(c[774536+(h<<3)>>2]|0)+(c[774540+(h<<3)>>2]&f)>>2];f=i>>>24&15;h=d[125296+f|0]|0;g=f-2|0;do{if(g>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);e=h<<1;c[204526]=e+2;j=e+5|0;k=f;l=g}else{g=i>>>24&15;j=3;k=g;l=g-2|0}g=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}i=k&255;if((k&2|0)==0){c[194192]=i>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+g|0;o=n+m|0;c[204526]=o;return}else{c[194192]=i>>>2|k&-256;m=0;n=j+g|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+g|0;o=n+m|0;c[204526]=o;return}function uX(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>12&15;f=b>>>16&15;g=b>>>7&31;h=c[776584+((b&15)<<2)>>2]|0;if((g|0)==0){i=(d[768256]|0)<<31|h>>>1}else{i=h<<32-g|h>>>(g>>>0)}g=776584+(f<<2)|0;h=(c[g>>2]|0)+i|0;c[776584+(e<<2)>>2]=(n0(h)|0)&255;if((e|0)!=(f|0)){c[g>>2]=h}c[204526]=0;if((e|0)==15){e=c[194161]|0;g=e&-4;c[194193]=g;f=g+4|0;c[194161]=f;i=e>>>24;c[203402]=c[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&g)>>2];g=f>>>24;c[203400]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];f=h>>>24&15;g=d[125296+f|0]|0;i=f-2|0;do{if(i>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);e=g<<1;c[204526]=e+2;j=e+5|0;k=f;l=i}else{i=h>>>24&15;j=3;k=i;l=i-2|0}i=d[147072+k|0]|0;do{if(l>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);l=(c[194193]|0)>>>24&15;do{if((l-8|0)>>>0<6){k=c[194192]|0;if((k&1|0)==0){break}h=k&255;if((k&2|0)==0){c[194192]=h>>>1|k&-256;m=(d[130328+l|0]|0)-1|0;n=j+i|0;o=n+m|0;c[204526]=o;return}else{c[194192]=h>>>2|k&-256;m=0;n=j+i|0;o=n+m|0;c[204526]=o;return}}}while(0);c[194192]=0;m=d[130616+l|0]|0;n=j+i|0;o=n+m|0;c[204526]=o;return}
function iZ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0;f=i;i=i+16|0;g=f|0;h=f+8|0;if((a[607928]&1)!=0){j=c[191244]|0;k=(j|0)!=0?j:c[q>>2]|0;eb(k|0,19416,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;k=c[191244]|0;j=(k|0)!=0?k:c[q>>2]|0;aZ(j|0)|0}c[g>>2]=0;c[h>>2]=0;dS(3379,g|0);dS(34024,h|0);if((a[607928]&1)!=0){j=c[191244]|0;k=(j|0)!=0?j:c[q>>2]|0;j=c[g>>2]|0;g=c[h>>2]|0;eb(k|0,17464,(l=i,i=i+16|0,c[l>>2]=j,c[l+8>>2]=g,l)|0)|0;i=l;g=c[191244]|0;j=(g|0)!=0?g:c[q>>2]|0;aZ(j|0)|0}aY(3553,0);j=b+48|0;dM(c[j>>2]|0,b+1644|0);g=(a[706956]&1)==0;k=(a[706957]&1)!=0;do{if(k){do{if((a[b+2584|0]&1)==0){h=a2(7939)|0;if((h|0)==0){m=0;break}m=(bu(h|0,15616)|0)!=0}else{m=0}}while(0);if((a[607928]&1)!=0){h=c[191244]|0;n=(h|0)!=0?h:c[q>>2]|0;h=m?48872:46680;eb(n|0,51104,(l=i,i=i+16|0,c[l>>2]=15616,c[l+8>>2]=h,l)|0)|0;i=l;h=c[191244]|0;n=(h|0)!=0?h:c[q>>2]|0;aZ(n|0)|0}if(m){break}else{o=0}i=f;return o|0}}while(0);L1177:do{if(g){if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=873;break L1177}b$(36160,c[b+1644+(m<<2)>>2]|0);dr(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=ck(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;p=872;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=873;break L1177}b$(36160,c[b+1644+(m<<2)>>2]|0);dr(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=ck(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;p=872;break}}}}else{cT(c[j>>2]|0,b+1676|0);a[b+1709|0]=1;if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=873;break L1177}b$(36160,c[b+1644+(m<<2)>>2]|0);dr(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;c0(36161,c[n>>2]|0);ce(36161,35056,d|0,e|0);c0(36161,0);dN(36160,36096,36161,c[n>>2]|0);dN(36160,36128,36161,c[n>>2]|0);n=ck(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;p=872;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=873;break L1177}b$(36160,c[b+1644+(m<<2)>>2]|0);dr(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;c0(36161,c[n>>2]|0);ce(36161,33189,d|0,e|0);c0(36161,0);dN(36160,36096,36161,c[n>>2]|0);n=ck(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;p=872;break}}}}}while(0);if((p|0)==872){e=c[191244]|0;d=(e|0)!=0?e:c[q>>2]|0;eb(d|0,13464,(l=i,i=i+16|0,c[l>>2]=r,c[l+8>>2]=s,l)|0)|0;i=l;l=c[191244]|0;s=(l|0)!=0?l:c[q>>2]|0;aZ(s|0)|0;o=0;i=f;return o|0}else if((p|0)==873){b$(36160,0);a[b+1708|0]=1;o=1;i=f;return o|0}return 0}function i_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0.0,A=0,B=0.0,C=0,D=0.0;d=i;i=i+64|0;e=d|0;f=+g[c>>2];h=+g[c+4>>2];j=+g[c+8>>2];k=+g[c+12>>2];l=+g[c+16>>2];m=+g[c+20>>2];n=+g[c+24>>2];o=+g[c+28>>2];p=+g[c+32>>2];q=+g[c+36>>2];r=+g[c+40>>2];s=+g[c+44>>2];t=+g[c+48>>2];u=+g[c+52>>2];v=+g[c+56>>2];w=+g[c+60>>2];c=0;do{x=+g[b+(c<<2)>>2];y=c+4|0;z=+g[b+(y<<2)>>2];A=c+8|0;B=+g[b+(A<<2)>>2];C=c+12|0;D=+g[b+(C<<2)>>2];g[e+(c<<2)>>2]=x*f+0.0+z*h+B*j+D*k;g[e+(y<<2)>>2]=x*l+0.0+z*m+B*n+D*o;g[e+(A<<2)>>2]=x*p+0.0+z*q+B*r+D*s;g[e+(C<<2)>>2]=x*t+0.0+z*u+B*v+D*w;c=c+1|0;}while(c>>>0<4);c=a;a=e;v6(c|0,a|0,64)|0;i=d;return}function i$(a){a=a|0;var b=0;b=c[a+2048>>2]|0;if((b|0)==0){return}e9[c[(c[a+2056>>2]|0)+12>>2]&2047](b);bf(1,a+2060|0);b=c[a+2076>>2]|0;if((b|0)==0){return}v_(b);return}function i0(b,d,e){b=b|0;d=d|0;e=+e;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0;d=i;if((a[522036]&1)==0){f=0;i=d;return f|0}h=b+2056|0;j=b+2048|0;k=h3((a[517933]|0)!=0?517933:766672,+g[130508])|0;c[j>>2]=k;if((k|0)==0){k=c[191244]|0;l=(k|0)!=0?k:c[q>>2]|0;eb(l|0,48064,(m=i,i=i+8|0,c[m>>2]=44392,m)|0)|0;i=m;l=c[191244]|0;k=(l|0)!=0?l:c[q>>2]|0;aZ(k|0)|0;c[h>>2]=0;c[j>>2]=0;j=c[191244]|0;k=(j|0)!=0?j:c[q>>2]|0;a3(47416,49,1,k|0)|0;k=c[191244]|0;j=(k|0)!=0?k:c[q>>2]|0;aZ(j|0)|0;f=0;i=d;return f|0}if((a[607928]&1)!=0){j=c[191244]|0;k=(j|0)!=0?j:c[q>>2]|0;eb(k|0,44512,(m=i,i=i+8|0,c[m>>2]=44392,m)|0)|0;i=m;m=c[191244]|0;k=(m|0)!=0?m:c[q>>2]|0;aZ(k|0)|0}c[h>>2]=9736;h=b+2060|0;bx(1,h|0);aY(3553,c[h>>2]|0);eV(3553,10242,33071);eV(3553,10243,33071);eV(3553,10240,9729);eV(3553,10241,9729);aY(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);dS(3379,b+2064|0);e=+g[130512];g[b+2344>>2]=e;n=+g[130513];g[b+2348>>2]=n;o=+g[130514];g[b+2352>>2]=o;g[b+2356>>2]=1.0;p=+g[130512];g[b+2360>>2]=p;r=+g[130513];g[b+2364>>2]=r;s=+g[130514];g[b+2368>>2]=s;g[b+2372>>2]=1.0;t=+g[130512];g[b+2376>>2]=t;u=+g[130513];g[b+2380>>2]=u;v=+g[130514];g[b+2384>>2]=v;g[b+2388>>2]=1.0;w=+g[130512];g[b+2392>>2]=w;x=+g[130513];g[b+2396>>2]=x;y=+g[130514];g[b+2400>>2]=y;g[b+2404>>2]=1.0;g[b+2408>>2]=e*.3;g[b+2412>>2]=n*.3;g[b+2416>>2]=o*.3;g[b+2420>>2]=1.0;g[b+2424>>2]=p*.3;g[b+2428>>2]=r*.3;g[b+2432>>2]=s*.3;g[b+2436>>2]=1.0;g[b+2440>>2]=t*.3;g[b+2444>>2]=u*.3;g[b+2448>>2]=v*.3;g[b+2452>>2]=1.0;g[b+2456>>2]=w*.3;g[b+2460>>2]=x*.3;g[b+2464>>2]=y*.3;g[b+2468>>2]=1.0;f=1;i=d;return f|0}function i1(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0.0,af=0.0,ag=0.0,ah=0.0;f=i;i=i+168|0;h=f|0;j=f+64|0;k=f+96|0;l=f+128|0;m=f+160|0;do{if((e|0)==0){n=+g[130510];o=+g[130511];if((a[522037]&1)==0){p=n;q=o;r=1.0;break}p=n;q=o;r=+((c[b+1744>>2]|0)>>>0>>>0)/+((c[b+1720>>2]|0)>>>0>>>0)}else{p=+g[e>>2];q=+g[e+4>>2];r=+g[e+8>>2]}}while(0);e=b+2048|0;if((c[e>>2]|0)==0){i=f;return}s=b+4|0;t=c[s>>2]|0;if((t|0)!=0){e9[c[t+12>>2]&2047](15)}iv(b,c[b+1728>>2]|0,c[b+1732>>2]|0,0);ej(3042);aY(3553,c[b+2060>>2]|0);t=l|0;u=b+2e3|0;v=u;w=b+2008|0;c[w>>2]=t;x=b+2080|0;if((cJ(x|0,d|0)|0)==0){y=c[b+2336>>2]|0;z=c[b+2340>>2]|0;A=b+2068|0;B=b+2072|0}else{C=b+2056|0;fw[c[(c[C>>2]|0)+4>>2]&127](c[e>>2]|0,d,m);D=c[m>>2]|0;E=c[D+24>>2]|0;F=(c[D+4>>2]|0)+E|0;G=c[D+28>>2]|0;H=(c[D+8>>2]|0)+G|0;I=c[D+48>>2]|0;if((I|0)==0){J=H;K=G;L=F;M=E}else{N=H;H=G;G=F;F=E;E=I;while(1){I=c[E+24>>2]|0;O=(c[E+4>>2]|0)+I|0;P=c[E+28>>2]|0;Q=(c[E+8>>2]|0)+P|0;R=(I|0)<(F|0)?I:F;I=(O|0)>(G|0)?O:G;O=(P|0)<(H|0)?P:H;P=(Q|0)>(N|0)?Q:N;Q=c[E+48>>2]|0;if((Q|0)==0){J=P;K=O;L=I;M=R;break}else{N=P;H=O;G=I;F=R;E=Q}}}E=L-M|0;L=J-K|0;J=E-1|0;F=J>>>1|J;J=F>>>2|F;F=J>>>4|J;J=F>>>8|F;F=(J>>>16|J)+1|0;J=L-1|0;G=J>>>1|J;J=G>>>2|G;G=J>>>4|J;J=G>>>8|G;G=(J>>>16|J)+1|0;J=c[b+2064>>2]|0;H=(F|0)>(J|0)?J:F;F=(G|0)>(J|0)?J:G;G=b+2068|0;J=c[G>>2]|0;N=b+2072|0;do{if((H|0)>(J|0)){S=912}else{Q=c[N>>2]|0;if((F|0)>(Q|0)){S=912;break}T=J;W=Q;X=b+2076|0}}while(0);if((S|0)==912){J=b+2076|0;Q=c[J>>2]|0;c[J>>2]=v$(Q,ac(H<<2,F)|0)|0;d1(3553,0,6408,H|0,F|0,0,6408,5121,0);c[G>>2]=H;c[N>>2]=F;T=H;W=F;X=J}J=c[X>>2]|0;v3(J|0,0,ac(W<<2,T)|0);if((D|0)!=0){T=D;do{D=c[X>>2]|0;W=c[G>>2]|0;J=c[N>>2]|0;F=(c[T+24>>2]|0)-M|0;H=c[T+8>>2]|0;Q=J-H+(K-(c[T+28>>2]|0))|0;R=Q-1|0;I=c[T>>2]|0;O=(F|0)<0;P=(c[T+4>>2]|0)+(O?F:0)|0;Y=(R|0)<0;Z=(Y?R:0)+H|0;if(O){_=I+(-F|0)|0;$=0}else{_=I;$=F}if(Y){aa=_+(ac(c[T+12>>2]|0,1-Q|0)|0)|0;ab=0}else{aa=_;ab=R}R=($+P|0)>(W|0)?W-$|0:P;P=(ab+Z|0)>(J|0)?J-ab|0:Z;do{if((P|0)>0){Z=T+12|0;if((R|0)<=0){break}J=aa;Q=D+((ac(ab,W)|0)+$<<2)|0;Y=0;while(1){F=Q;I=0;while(1){a[F]=-1;a[F+1|0]=-1;a[F+2|0]=-1;a[F+3|0]=a[J+I|0]|0;O=I+1|0;if((O|0)<(R|0)){F=F+4|0;I=O}else{break}}I=Y+1|0;if((I|0)<(P|0)){J=J+(c[Z>>2]|0)|0;Q=Q+(W<<2)|0;Y=I}else{break}}}}while(0);T=c[T+48>>2]|0;}while((T|0)!=0)}e2(3317,8);d3(3553,0,0,0,c[G>>2]|0,c[N>>2]|0,6408,5121,c[X>>2]|0);fa[c[(c[C>>2]|0)+8>>2]&127](c[e>>2]|0,m);m=256;e=x;x=d;while(1){d=m-1|0;if((d|0)==0){S=928;break}C=a[x]|0;a[e]=C;if(C<<24>>24==0){break}else{m=d;e=e+1|0;x=x+1|0}}do{if((S|0)==928){a[e]=0;if((a[x]|0)==0){break}else{ad=x}do{ad=ad+1|0;}while((a[ad]|0)!=0)}}while(0);c[b+2336>>2]=E;c[b+2340>>2]=L;y=E;z=L;A=G;B=N}N=j|0;G=k|0;o=+(y|0);n=+((c[b+1744>>2]|0)>>>0>>>0);ae=p+r*o/n;af=+(z|0);ag=+((c[b+1748>>2]|0)>>>0>>>0);ah=q+r*af/ag;g[N>>2]=p;g[j+8>>2]=ae;g[j+16>>2]=p;g[j+24>>2]=ae;g[j+4>>2]=ah;g[j+12>>2]=ah;g[j+20>>2]=q;g[j+28>>2]=q;r=2.0/n;n=2.0/ag;ag=p-r;g[G>>2]=ag;p=ah-n;g[k+4>>2]=p;ah=ae-r;g[k+8>>2]=ah;g[k+12>>2]=p;g[k+16>>2]=ag;ag=q-n;g[k+20>>2]=ag;g[k+24>>2]=ah;g[k+28>>2]=ag;ag=o/+(c[A>>2]|0);o=1.0-af/+(c[B>>2]|0);g[t>>2]=0.0;g[l+8>>2]=ag;g[l+16>>2]=0.0;g[l+24>>2]=ag;g[l+4>>2]=o;g[l+12>>2]=o;g[l+20>>2]=1.0;g[l+28>>2]=1.0;l=u;c[l>>2]=G;G=b+2004|0;c[G>>2]=b+2408;u=b+1872|0;t=c[s>>2]|0;do{if((t|0)!=0){B=c[t+32>>2]|0;fc[B&127](v)|0;B=c[s>>2]|0;if((B|0)==0){break}A=c[B+36>>2]|0;fc[A&127](u)|0}}while(0);c4(5,0,4);c[l>>2]=N;c[G>>2]=b+2344;N=c[s>>2]|0;do{if((N|0)!=0){t=c[N+32>>2]|0;fc[t&127](v)|0;t=c[s>>2]|0;if((t|0)==0){break}A=c[t+36>>2]|0;fc[A&127](u)|0}}while(0);c4(5,0,4);c[l>>2]=c[b+2016>>2];c[w>>2]=b+1840;c[G>>2]=c[b+2020>>2];aY(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);c9(3042);G=b+1936|0;v3(G|0,0,48);g[b+1996>>2]=1.0;g[G>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;o=+((c[b+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0;ag=+U(+o);af=+V(+o);v3(h|0,0,60);g[h+40>>2]=1.0;g[h+60>>2]=1.0;g[h>>2]=ag;g[h+20>>2]=ag;g[h+16>>2]=-0.0-af;g[h+4>>2]=af;i_(u,h,G);i=f;return}function i2(a){a=a|0;return}function i3(a,b){a=a|0;b=b|0;return}function i4(){return}function i5(a){a=a|0;return 0}function i6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return 0}function i7(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;if(a[9376]|0){e=0}else{a[9376]=1;e=1}return e|0}function i8(a,b){a=a|0;b=b|0;c[a>>2]=c[151978];c[b>>2]=c[151980];return}function i9(){return a[9376]|0}function ja(a,b){a=a|0;b=b|0;return+(+(a>>>0>>>0)/+(b>>>0>>>0))}function jb(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;if((a[607928]&1)!=0){g=c[191244]|0;h=(g|0)!=0?g:c[q>>2]|0;a3(35432,45,1,h|0)|0;h=c[191244]|0;g=(h|0)!=0?h:c[q>>2]|0;aZ(g|0)|0}if(a[9376]|0){if((a[607928]&1)==0){j=1;i=b;return j|0}g=c[191244]|0;h=(g|0)!=0?g:c[q>>2]|0;a3(28632,64,1,h|0)|0;h=c[191244]|0;g=(h|0)!=0?h:c[q>>2]|0;aZ(g|0)|0;j=1;i=b;return j|0}g=e_(0)|0;c[191516]=g;do{if((g|0)!=0){do{if((cz(g|0,0,0)|0)!=0){if((ee(c[191516]|0,9256,766080,1,f|0)|0)==0){break}h=ba(c[191516]|0,c[191520]|0,0,9240)|0;c[191518]=h;if((h|0)==0){break}h=ea(c[191516]|0,c[191520]|0,0,0)|0;c[191514]=h;if((h|0)==0){break}if((du(c[191516]|0,h|0,h|0,c[191518]|0)|0)==0){break}h=c[191516]|0;k=c[191514]|0;e1(h|0,k|0,12375,d|0)|0;k=c[191516]|0;h=c[191514]|0;e1(k|0,h|0,12374,e|0)|0;h=c[d>>2]|0;c[151978]=h;k=c[e>>2]|0;c[151980]=k;if((a[607928]&1)==0){j=1;i=b;return j|0}l=c[191244]|0;m=(l|0)!=0?l:c[q>>2]|0;eb(m|0,24552,(m=i,i=i+16|0,c[m>>2]=h,c[m+8>>2]=k,m)|0)|0;i=m;m=c[191244]|0;k=(m|0)!=0?m:c[q>>2]|0;aZ(k|0)|0;j=1;i=b;return j|0}}while(0);k=c[191516]|0;if((k|0)==0){break}du(k|0,0,0,0)|0;k=c[191518]|0;if((k|0)!=0){m=c[191516]|0;dh(m|0,k|0)|0}k=c[191514]|0;if((k|0)!=0){m=c[191516]|0;aV(m|0,k|0)|0}k=c[191516]|0;b6(k|0)|0}}while(0);c[191518]=0;c[191514]=0;c[191516]=0;c[191520]=0;a[9376]=0;j=0;i=b;return j|0}function jc(){var b=0,d=0;b=c[191516]|0;if((b|0)!=0){du(b|0,0,0,0)|0;b=c[191518]|0;if((b|0)!=0){d=c[191516]|0;dh(d|0,b|0)|0}b=c[191514]|0;if((b|0)!=0){d=c[191516]|0;aV(d|0,b|0)|0}b=c[191516]|0;b6(b|0)|0}c[191518]=0;c[191514]=0;c[191516]=0;c[191520]=0;a[9376]=0;return}function jd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)==1){d=(bg(12448)|0)!=0}else{d=0}return d|0}function je(){var b=0,d=0,e=0.0,f=0,g=0,j=0,k=0,l=0,m=0;b=i;i=i+128|0;d=b|0;a[d]=0;e=+a9()*1.0e3;f=~~e>>>0;g=+R(e)>=1.0?e>0.0?(ah(+Q(e/4294967296.0),4294967295.0)|0)>>>0:~~+ab((e- +(~~e>>>0))/4294967296.0)>>>0:0;do{if((c[191184]|0)==0){c[126270]=f;c[126271]=g;c[126268]=f;c[126269]=g;bN(d|0,128,31240,(j=i,i=i+8|0,c[j>>2]=764740,j)|0)|0;i=j}else{k=756280;l=c[k>>2]|0;m=wc(l,c[k+4>>2]|0,1,0)|0;k=756280;c[k>>2]=m;c[k+4>>2]=G;k=wd(f,g,c[126270]|0,c[126271]|0)|0;m=739896+((l&2047)<<3)|0;c[m>>2]=k;c[m+4>>2]=G;c[126270]=f;c[126271]=g;m=c[191184]|0;if((m&255|0)==0){k=wd(f,g,c[126268]|0,c[126269]|0)|0;c[126268]=f;c[126269]=g;e=256.0e6/(+(k>>>0)+ +(G|0)*4294967296.0);bN(d|0,128,14840,(j=i,i=i+24|0,c[j>>2]=764740,h[j+8>>3]=e,c[j+16>>2]=m,j)|0)|0;i=j;break}else{i=b;return}}}while(0);if((a[607928]&1)==0){i=b;return}g=c[191244]|0;eb(((g|0)!=0?g:c[q>>2]|0)|0,47400,(j=i,i=i+8|0,c[j>>2]=d,j)|0)|0;i=j;j=c[191244]|0;aZ(((j|0)!=0?j:c[q>>2]|0)|0)|0;i=b;return}function jf(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;g=i;i=i+24|0;h=g|0;j=g+8|0;ct(h|0,j|0,g+16|0);k=c[h>>2]|0;c[e>>2]=k;h=c[j>>2]|0;c[f>>2]=h;a[d]=(c[e>>2]|0)==(c[151978]|0)&(h|0)==(c[151980]|0)&1^1;c[151978]=k;c[151980]=h;a[b]=0;i=g;return}function jg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;c[a>>2]=0;d=vZ(48)|0;if((d|0)==0){return}if((c[d-4>>2]&3|0)!=0){v3(d|0,0,48)}e=bm()|0;c[d+44>>2]=e;if((e|0)==0){v_(d);return}v3(147440,0,1292);e=5616;f=276;while(1){c[147440+(f<<2)>>2]=c[e>>2];g=c[e+12>>2]|0;if((g|0)==0){break}else{e=e+8|0;f=g}}c[a>>2]=7352;c[b>>2]=d;return}function jh(a){a=a|0;return ca(a|0)|0}function ji(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aX=0,a_=0,a$=0,a0=0,a1=0,a2=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0.0,cY=0.0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0;e=i;i=i+848|0;f=e|0;j=e+64|0;k=e+128|0;l=e+192|0;m=e+256|0;n=e+320|0;o=e+384|0;p=e+448|0;r=e+512|0;s=e+576|0;t=e+640|0;u=e+704|0;v=e+768|0;w=e+832|0;x=vZ(109528)|0;if((x|0)==0){c[124232]=0;y=0;i=e;return y|0}if((c[x-4>>2]&3|0)!=0){v3(x|0,0,109528)}z=x;c[124232]=z;L1381:do{if((d|0)==0){A=c[191244]|0;B=(A|0)!=0?A:c[q>>2]|0;a3(28568,59,1,B|0)|0;B=c[191244]|0;A=(B|0)!=0?B:c[q>>2]|0;aZ(A|0)|0;c[(c[124232]|0)+72>>2]=1;A=dn(((a[496960]&1)!=0?20776:21120)|0)|0;c[(c[124232]|0)+4172>>2]=A;A=dn(((a[496960]&1)!=0?21736:22152)|0)|0;B=c[124232]|0;c[B+4176>>2]=A;a[B+4|0]=1}else{B=cf(d|0,46)|0;A=(B|0)==0?766672:B+1|0;if((cJ(A|0,40432)|0)==0){B=4096;C=x+76|0;D=d;while(1){E=B-1|0;if((E|0)==0){F=1021;break}G=a[D]|0;a[C]=G;if(G<<24>>24==0){break}else{B=E;C=C+1|0;D=D+1|0}}do{if((F|0)==1021){a[C]=0;if((a[D]|0)==0){break}else{H=D}do{H=H+1|0;}while((a[H]|0)!=0)}}while(0);c[x+72>>2]=1;a[x+4|0]=1;break}do{if((cJ(A|0,47392)|0)==0){D=gG(d,0)|0;if((D|0)==0){break}C=hZ(D,c[124232]|0)|0;a[(c[124232]|0)+4|0]=1;gE(D);if(C){break L1381}}else{C=v|0;if((a[607928]&1)!=0){D=c[191244]|0;B=(D|0)!=0?D:c[q>>2]|0;eb(B|0,24904,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;B=c[191244]|0;D=(B|0)!=0?B:c[q>>2]|0;aZ(D|0)|0}D=hq(d)|0;B=(D|0)!=0;L1402:do{if(B){E=D|0;G=c[E>>2]|0;if((G|0)==0){break}else{J=G}L1405:while(1){do{if((c[J+20>>2]|0)==0){if((cJ(c[J>>2]|0,19552)|0)!=0){break}K=J+8|0;G=K;while(1){L=c[G>>2]|0;if((L|0)==0){F=1042;break}if((cJ(17664,c[L>>2]|0)|0)==0){F=1037;break}else{G=L+8|0}}L1413:do{if((F|0)==1037){F=0;G=c[L+4>>2]|0;if((G|0)==0){F=1042;break}else{M=64;N=C;O=G}while(1){G=M-1|0;if((G|0)==0){break}P=a[O]|0;a[N]=P;if(P<<24>>24==0){break L1413}else{M=G;N=N+1|0;O=O+1|0}}a[N]=0;if((a[O]|0)==0){break}else{Q=O}do{Q=Q+1|0;}while((a[Q]|0)!=0)}}while(0);if((F|0)==1042){F=0;a[C]=0}if((cJ(C|0,15672)|0)==0){break L1405}}}while(0);G=c[J+16>>2]|0;if((G|0)==0){break L1402}else{J=G}}c[x>>2]=2;G=K;while(1){R=c[G>>2]|0;if((R|0)==0){F=1052;break}if((cJ(13568,c[R>>2]|0)|0)==0){F=1047;break}else{G=R+8|0}}L1429:do{if((F|0)==1047){G=c[R+4>>2]|0;if((G|0)==0){F=1052;break}else{S=64;T=C;U=G}while(1){G=S-1|0;if((G|0)==0){break}P=a[U]|0;a[T]=P;if(P<<24>>24==0){break L1429}else{S=G;T=T+1|0;U=U+1|0}}a[T]=0;if((a[U]|0)==0){break}else{V=U}do{V=V+1|0;}while((a[V]|0)!=0)}}while(0);if((F|0)==1052){a[C]=0}G=x+4|0;a[G]=(cJ(C|0,51192)|0)==0|0;P=x+5|0;W=K;while(1){X=c[W>>2]|0;if((X|0)==0){F=1057;break}if((cJ(48992,c[X>>2]|0)|0)==0){F=1056;break}else{W=X+8|0}}do{if((F|0)==1056){W=c[X+4>>2]|0;if((W|0)==0){F=1057;break}else{Y=64;Z=0;_=P;$=W}while(1){W=Y-1|0;if((W|0)==0){F=1060;break}aa=a[$]|0;a[_]=aa;if(aa<<24>>24==0){ab=Z;break}else{Y=W;Z=Z+1|0;_=_+1|0;$=$+1|0}}do{if((F|0)==1060){a[_]=0;if((a[$]|0)==0){ab=Z;break}else{ac=$;ad=Z}while(1){W=ac+1|0;aa=ad+1|0;if((a[W]|0)==0){ab=aa;break}else{ac=W;ad=aa}}}}while(0);if(ab>>>0>=64){break}if((a[607928]&1)==0){break}aa=c[191244]|0;eb(((aa|0)!=0?aa:c[q>>2]|0)|0,46720,(I=i,i=i+8|0,c[I>>2]=P,I)|0)|0;i=I;aa=c[191244]|0;aZ(((aa|0)!=0?aa:c[q>>2]|0)|0)|0}}while(0);if((F|0)==1057){a[P]=0}do{if((a[G]&1)==0){aa=c[191244]|0;W=(aa|0)!=0?aa:c[q>>2]|0;a3(44400,57,1,W|0)|0;W=c[191244]|0;aa=(W|0)!=0?W:c[q>>2]|0;aZ(aa|0)|0}else{if((a[607928]&1)==0){break}aa=c[191244]|0;W=(aa|0)!=0?aa:c[q>>2]|0;a3(45280,54,1,W|0)|0;W=c[191244]|0;aa=(W|0)!=0?W:c[q>>2]|0;aZ(aa|0)|0}}while(0);P=c[J+12>>2]|0;aa=x+72|0;L1463:do{if((P|0)==0){F=1390}else{W=f|0;ae=j|0;af=k|0;ag=l|0;ah=m|0;ai=n|0;aj=o|0;ak=p|0;al=r|0;am=s|0;an=t|0;ao=u|0;ap=x+66444|0;aq=x+99792|0;ar=x+109012|0;as=x+109016|0;at=P;L1465:while(1){if((c[aa>>2]|0)>>>0>=16){break L1463}do{if((c[at+20>>2]|0)==0){au=at+4|0;av=c[au>>2]|0;if((av|0)==0){break}aw=dn(av|0)|0;if((aw|0)==0){break}av=c[aa>>2]|0;ax=c[at>>2]|0;if((cJ(ax|0,43104)|0)==0){ay=z+76+(av*4148|0)+4096|0;if((c[ay>>2]|0)!=0){F=1078;break L1465}az=h$(aw,d,at)|0;if((az|0)==0){F=1080;break L1465}c[ay>>2]=az;break}if((cJ(ax|0,38800)|0)!=0){if((cJ(ax|0,34904)|0)==0){v_(aw);az=c[ap>>2]|0;if(az>>>0>7){ay=c[191244]|0;aA=(ay|0)!=0?ay:c[q>>2]|0;a3(14544,58,1,aA|0)|0;aA=c[191244]|0;ay=(aA|0)!=0?aA:c[q>>2]|0;aZ(ay|0)|0;break}ay=z+66448+(az*4168|0)|0;aA=at+8|0;aB=aA;while(1){aC=c[aB>>2]|0;if((aC|0)==0){F=1247;break}if((cJ(16648,c[aC>>2]|0)|0)==0){F=1242;break}else{aB=aC+8|0}}L1487:do{if((F|0)==1242){F=0;aB=c[aC+4>>2]|0;if((aB|0)==0){F=1247;break}else{aD=64;aE=ay;aF=aB}while(1){aB=aD-1|0;if((aB|0)==0){break}aG=a[aF]|0;a[aE]=aG;if(aG<<24>>24==0){break L1487}else{aD=aB;aE=aE+1|0;aF=aF+1|0}}a[aE]=0;if((a[aF]|0)==0){break}else{aH=aF}do{aH=aH+1|0;}while((a[aH]|0)!=0)}}while(0);if((F|0)==1247){F=0;a[ay]=0}aB=z+66448+(az*4168|0)+64|0;aG=aA;while(1){aI=c[aG>>2]|0;if((aI|0)==0){F=1256;break}if((cJ(14456,c[aI>>2]|0)|0)==0){F=1251;break}else{aG=aI+8|0}}L1501:do{if((F|0)==1251){F=0;aG=c[aI+4>>2]|0;if((aG|0)==0){F=1256;break}else{aJ=4096;aK=aB;aL=aG}while(1){aG=aJ-1|0;if((aG|0)==0){break}aM=a[aL]|0;a[aK]=aM;if(aM<<24>>24==0){break L1501}else{aJ=aG;aK=aK+1|0;aL=aL+1|0}}a[aK]=0;if((a[aL]|0)==0){break}else{aN=aL}do{aN=aN+1|0;}while((a[aN]|0)!=0)}}while(0);if((F|0)==1256){F=0;a[aB]=0}v3(W|0,0,64);aG=aA;while(1){aO=c[aG>>2]|0;if((aO|0)==0){F=1265;break}if((cJ(14312,c[aO>>2]|0)|0)==0){F=1260;break}else{aG=aO+8|0}}L1515:do{if((F|0)==1260){F=0;aG=c[aO+4>>2]|0;if((aG|0)==0){F=1265;break}else{aP=64;aQ=W;aR=aG}while(1){aG=aP-1|0;if((aG|0)==0){break}aA=a[aR]|0;a[aQ]=aA;if(aA<<24>>24==0){break L1515}else{aP=aG;aQ=aQ+1|0;aR=aR+1|0}}a[aQ]=0;if((a[aR]|0)==0){break}else{aS=aR}do{aS=aS+1|0;}while((a[aS]|0)!=0)}}while(0);if((F|0)==1265){F=0;a[W]=0}if((a[ay]|0)==0){F=1267;break L1465}if((a[aB]|0)==0){F=1269;break L1465}do{if((cJ(W|0,13784)|0)==0){c[z+66448+(az*4168|0)+4160>>2]=1}else{if((cJ(W|0,13616)|0)==0){c[z+66448+(az*4168|0)+4160>>2]=2;break}if((a[W]|0)!=0){F=1276;break L1465}c[z+66448+(az*4168|0)+4160>>2]=0}}while(0);c[ap>>2]=(c[ap>>2]|0)+1;break}if((cJ(ax|0,32552)|0)!=0){if((cJ(ax|0,31248)|0)!=0){break}v_(aw);if((c[ar>>2]|0)!=0){F=1363;break L1465}az=at+8|0;aB=az;while(1){aT=c[aB>>2]|0;if((aT|0)==0){F=1372;break}if((cJ(17736,c[aT>>2]|0)|0)==0){F=1367;break}else{aB=aT+8|0}}L1544:do{if((F|0)==1367){F=0;aB=c[aT+4>>2]|0;if((aB|0)==0){F=1372;break}else{aU=512;aV=as;aX=aB}while(1){aB=aU-1|0;if((aB|0)==0){break}ax=a[aX]|0;a[aV]=ax;if(ax<<24>>24==0){a_=az;break L1544}else{aU=aB;aV=aV+1|0;aX=aX+1|0}}a[aV]=0;if((a[aX]|0)==0){a_=az;break}else{a$=aX}while(1){aB=a$+1|0;if((a[aB]|0)==0){a_=az;break}else{a$=aB}}}}while(0);if((F|0)==1372){F=0;a[as]=0;a_=az}while(1){a0=c[a_>>2]|0;if((a0|0)==0){F=1380;break}if((cJ(17664,c[a0>>2]|0)|0)==0){F=1375;break}else{a_=a0+8|0}}L1557:do{if((F|0)==1375){F=0;az=c[a0+4>>2]|0;if((az|0)==0){F=1380;break}else{a1=64;a2=W;a4=az}while(1){az=a1-1|0;if((az|0)==0){break}aB=a[a4]|0;a[a2]=aB;if(aB<<24>>24==0){break L1557}else{a1=az;a2=a2+1|0;a4=a4+1|0}}a[a2]=0;if((a[a4]|0)==0){break}else{a5=a4}do{a5=a5+1|0;}while((a[a5]|0)!=0)}}while(0);if((F|0)==1380){F=0;a[W]=0}if((cJ(W|0,20336)|0)!=0){F=1382;break L1465}az=c[au>>2]|0;if((az|0)==0){F=1384;break L1465}aB=dn(az|0)|0;c[ar>>2]=aB;if((aB|0)==0){F=1388;break L1465}az=h$(aB,d,at)|0;c[ar>>2]=az;if((az|0)==0){F=1387;break L1465}else{break}}v_(aw);az=c[aq>>2]|0;if(az>>>0>63){F=1281;break L1465}aB=z+99796+(az*80|0)|0;ax=at+8|0;ay=ax;while(1){a6=c[ay>>2]|0;if((a6|0)==0){F=1290;break}if((cJ(16648,c[a6>>2]|0)|0)==0){F=1285;break}else{ay=a6+8|0}}L1576:do{if((F|0)==1285){F=0;ay=c[a6+4>>2]|0;if((ay|0)==0){F=1290;break}else{a7=64;a8=aB;a9=ay}while(1){ay=a7-1|0;if((ay|0)==0){break}au=a[a9]|0;a[a8]=au;if(au<<24>>24==0){ba=ax;break L1576}else{a7=ay;a8=a8+1|0;a9=a9+1|0}}a[a8]=0;if((a[a9]|0)==0){ba=ax;break}else{bb=a9}while(1){ay=bb+1|0;if((a[ay]|0)==0){ba=ax;break}else{bb=ay}}}}while(0);if((F|0)==1290){F=0;a[aB]=0;ba=ax}while(1){bc=c[ba>>2]|0;if((bc|0)==0){F=1298;break}if((cJ(16528,c[bc>>2]|0)|0)==0){F=1293;break}else{ba=bc+8|0}}L1589:do{if((F|0)==1293){F=0;ay=c[bc+4>>2]|0;if((ay|0)==0){F=1298;break}else{bd=64;be=W;bf=ay}while(1){ay=bd-1|0;if((ay|0)==0){break}au=a[bf]|0;a[be]=au;if(au<<24>>24==0){bg=ax;break L1589}else{bd=ay;be=be+1|0;bf=bf+1|0}}a[be]=0;if((a[bf]|0)==0){bg=ax;break}else{bh=bf}while(1){ay=bh+1|0;if((a[ay]|0)==0){bg=ax;break}else{bh=ay}}}}while(0);if((F|0)==1298){F=0;a[W]=0;bg=ax}while(1){bi=c[bg>>2]|0;if((bi|0)==0){F=1306;break}if((cJ(16408,c[bi>>2]|0)|0)==0){F=1301;break}else{bg=bi+8|0}}L1602:do{if((F|0)==1301){F=0;ay=c[bi+4>>2]|0;if((ay|0)==0){F=1306;break}else{bj=64;bk=ae;bl=ay}while(1){ay=bj-1|0;if((ay|0)==0){break}au=a[bl]|0;a[bk]=au;if(au<<24>>24==0){bm=ax;break L1602}else{bj=ay;bk=bk+1|0;bl=bl+1|0}}a[bk]=0;if((a[bl]|0)==0){bm=ax;break}else{bn=bl}while(1){ay=bn+1|0;if((a[ay]|0)==0){bm=ax;break}else{bn=ay}}}}while(0);if((F|0)==1306){F=0;a[ae]=0;bm=ax}while(1){bo=c[bm>>2]|0;if((bo|0)==0){F=1314;break}if((cJ(16312,c[bo>>2]|0)|0)==0){F=1309;break}else{bm=bo+8|0}}L1615:do{if((F|0)==1309){F=0;ay=c[bo+4>>2]|0;if((ay|0)==0){F=1314;break}else{bp=64;bq=af;br=ay}while(1){ay=bp-1|0;if((ay|0)==0){break}au=a[br]|0;a[bq]=au;if(au<<24>>24==0){bs=ax;break L1615}else{bp=ay;bq=bq+1|0;br=br+1|0}}a[bq]=0;if((a[br]|0)==0){bs=ax;break}else{bt=br}while(1){ay=bt+1|0;if((a[ay]|0)==0){bs=ax;break}else{bt=ay}}}}while(0);if((F|0)==1314){F=0;a[af]=0;bs=ax}while(1){bu=c[bs>>2]|0;if((bu|0)==0){F=1322;break}if((cJ(16144,c[bu>>2]|0)|0)==0){F=1317;break}else{bs=bu+8|0}}L1628:do{if((F|0)==1317){F=0;ay=c[bu+4>>2]|0;if((ay|0)==0){F=1322;break}else{bv=64;bw=ag;by=ay}while(1){ay=bv-1|0;if((ay|0)==0){break}au=a[by]|0;a[bw]=au;if(au<<24>>24==0){bz=ax;break L1628}else{bv=ay;bw=bw+1|0;by=by+1|0}}a[bw]=0;if((a[by]|0)==0){bz=ax;break}else{bA=by}while(1){ay=bA+1|0;if((a[ay]|0)==0){bz=ax;break}else{bA=ay}}}}while(0);if((F|0)==1322){F=0;a[ag]=0;bz=ax}while(1){bB=c[bz>>2]|0;if((bB|0)==0){F=1330;break}if((cJ(15968,c[bB>>2]|0)|0)==0){F=1325;break}else{bz=bB+8|0}}L1641:do{if((F|0)==1325){F=0;ax=c[bB+4>>2]|0;if((ax|0)==0){F=1330;break}else{bC=64;bD=ah;bE=ax}while(1){ax=bC-1|0;if((ax|0)==0){break}ay=a[bE]|0;a[bD]=ay;if(ay<<24>>24==0){break L1641}else{bC=ax;bD=bD+1|0;bE=bE+1|0}}a[bD]=0;if((a[bE]|0)==0){break}else{bF=bE}do{bF=bF+1|0;}while((a[bF]|0)!=0)}}while(0);if((F|0)==1330){F=0;a[ah]=0}if((a[W]|0)==0){F=1333;break L1465}if((a[aB]|0)==0){F=1333;break L1465}do{if((cJ(W|0,22440)|0)==0){c[z+99796+(az*80|0)+68>>2]=0;F=1347}else{if((cJ(W|0,20992)|0)==0){c[z+99796+(az*80|0)+68>>2]=1;F=1347;break}if((cJ(W|0,21960)|0)==0){c[z+99796+(az*80|0)+68>>2]=2;F=1347;break}if((cJ(W|0,21360)|0)==0){c[z+99796+(az*80|0)+68>>2]=3;F=1347;break}if((cJ(W|0,20488)|0)==0){c[z+99796+(az*80|0)+68>>2]=4;F=1347;break}if((cJ(W|0,20336)|0)!=0){F=1345;break L1465}c[z+99796+(az*80|0)+68>>2]=5}}while(0);do{if((F|0)==1347){F=0;if((a[af]|0)==0){if((a[ae]|0)==0){F=1354;break L1465}c[z+99796+(az*80|0)+64>>2]=aW(ae|0,0,16)|0;c[z+99796+(az*80|0)+72>>2]=1;break}aB=aW(af|0,0,0)|0;if((aB|0)==1){c[z+99796+(az*80|0)+72>>2]=2;break}else if((aB|0)==2){c[z+99796+(az*80|0)+72>>2]=3;break}else{F=1351;break L1465}}}while(0);if((a[ag]|0)!=0){b[z+99796+(az*80|0)+76>>1]=(aW(ag|0,0,16)|0)&65535}if((a[ah]|0)!=0){b[z+99796+(az*80|0)+78>>1]=(aW(ah|0,0,16)|0)&65535}c[aq>>2]=(c[aq>>2]|0)+1;break}if((a[G]&1)!=0){if((c[z+76+(av*4148|0)+4096>>2]|0)==0){F=1085;break L1465}}aB=h$(aw,d,at)|0;if((aB|0)==0){F=1087;break L1465}c[z+76+(av*4148|0)+4100>>2]=aB;aB=z+76+(av*4148|0)+4144|0;c[aB>>2]=0;ax=z+76+(av*4148|0)+4136|0;c[ax>>2]=0;ay=z+76+(av*4148|0)+4132|0;a[ay]=0;au=z+76+(av*4148|0)+4116|0;g[au>>2]=1.0;aG=z+76+(av*4148|0)+4120|0;g[aG>>2]=1.0;aA=z+76+(av*4148|0)+4112|0;c[aA>>2]=0;aM=z+76+(av*4148|0)+4108|0;c[aM>>2]=0;bG=z+76+(av*4148|0)+4104|0;a[bG]=0;bH=at+8|0;bI=bH;while(1){bJ=c[bI>>2]|0;if((bJ|0)==0){F=1092;break}if((cJ(14312,c[bJ>>2]|0)|0)==0){F=1091;break}else{bI=bJ+8|0}}do{if((F|0)==1091){F=0;bI=c[bJ+4>>2]|0;if((bI|0)==0){F=1092;break}else{bK=64;bL=0;bM=W;bN=bI}while(1){bI=bK-1|0;if((bI|0)==0){F=1095;break}az=a[bN]|0;a[bM]=az;if(az<<24>>24==0){bO=bL;break}else{bK=bI;bL=bL+1|0;bM=bM+1|0;bN=bN+1|0}}do{if((F|0)==1095){F=0;a[bM]=0;if((a[bN]|0)==0){bO=bL;break}else{bP=bN;bQ=bL}while(1){bI=bP+1|0;az=bQ+1|0;if((a[bI]|0)==0){bO=az;break}else{bP=bI;bQ=az}}}}while(0);if(bO>>>0>=64){bR=bH;F=1105;break}if((cJ(W|0,13616)|0)==0){c[ax>>2]=2;if((a[607928]&1)==0){bR=bH;F=1105;break}az=c[191244]|0;bI=(az|0)!=0?az:c[q>>2]|0;a3(13008,42,1,bI|0)|0;bI=c[191244]|0;az=(bI|0)!=0?bI:c[q>>2]|0;aZ(az|0)|0;bR=bH;F=1105;break}if((cJ(W|0,13784)|0)!=0){az=c[191244]|0;bI=(az|0)!=0?az:c[q>>2]|0;a3(12680,54,1,bI|0)|0;bI=c[191244]|0;az=(bI|0)!=0?bI:c[q>>2]|0;aZ(az|0)|0;bS=0;break}c[ax>>2]=1;if((a[607928]&1)==0){bR=bH;F=1105;break}az=c[191244]|0;a3(12840,41,1,((az|0)!=0?az:c[q>>2]|0)|0)|0;az=c[191244]|0;aZ(((az|0)!=0?az:c[q>>2]|0)|0)|0;bR=bH;F=1105}}while(0);if((F|0)==1092){F=0;a[W]=0;bR=bH;F=1105}do{if((F|0)==1105){while(1){F=0;bT=c[bR>>2]|0;if((bT|0)==0){F=1112;break}if((cJ(12608,c[bT>>2]|0)|0)==0){F=1107;break}else{bR=bT+8|0;F=1105}}L1719:do{if((F|0)==1107){F=0;ax=c[bT+4>>2]|0;if((ax|0)==0){F=1112;break}else{bU=64;bV=ae;bW=ax}while(1){ax=bU-1|0;if((ax|0)==0){break}az=a[bW]|0;a[bV]=az;if(az<<24>>24==0){bX=bH;break L1719}else{bU=ax;bV=bV+1|0;bW=bW+1|0}}a[bV]=0;if((a[bW]|0)==0){bX=bH;break}else{bY=bW}while(1){ax=bY+1|0;if((a[ax]|0)==0){bX=bH;break}else{bY=ax}}}}while(0);if((F|0)==1112){F=0;a[ae]=0;bX=bH}while(1){bZ=c[bX>>2]|0;if((bZ|0)==0){F=1120;break}if((cJ(12480,c[bZ>>2]|0)|0)==0){F=1115;break}else{bX=bZ+8|0}}L1732:do{if((F|0)==1115){F=0;ax=c[bZ+4>>2]|0;if((ax|0)==0){F=1120;break}else{b_=64;b$=af;b0=ax}while(1){ax=b_-1|0;if((ax|0)==0){break}az=a[b0]|0;a[b$]=az;if(az<<24>>24==0){b1=bH;break L1732}else{b_=ax;b$=b$+1|0;b0=b0+1|0}}a[b$]=0;if((a[b0]|0)==0){b1=bH;break}else{b2=b0}while(1){ax=b2+1|0;if((a[ax]|0)==0){b1=bH;break}else{b2=ax}}}}while(0);if((F|0)==1120){F=0;a[af]=0;b1=bH}while(1){b3=c[b1>>2]|0;if((b3|0)==0){F=1128;break}if((cJ(12384,c[b3>>2]|0)|0)==0){F=1123;break}else{b1=b3+8|0}}L1745:do{if((F|0)==1123){F=0;ax=c[b3+4>>2]|0;if((ax|0)==0){F=1128;break}else{b4=64;b5=ag;b6=ax}while(1){ax=b4-1|0;if((ax|0)==0){break}az=a[b6]|0;a[b5]=az;if(az<<24>>24==0){b7=bH;break L1745}else{b4=ax;b5=b5+1|0;b6=b6+1|0}}a[b5]=0;if((a[b6]|0)==0){b7=bH;break}else{b8=b6}while(1){ax=b8+1|0;if((a[ax]|0)==0){b7=bH;break}else{b8=ax}}}}while(0);if((F|0)==1128){F=0;a[ag]=0;b7=bH}while(1){b9=c[b7>>2]|0;if((b9|0)==0){F=1136;break}if((cJ(12256,c[b9>>2]|0)|0)==0){F=1131;break}else{b7=b9+8|0}}L1758:do{if((F|0)==1131){F=0;ax=c[b9+4>>2]|0;if((ax|0)==0){F=1136;break}else{ca=64;cb=ah;cc=ax}while(1){ax=ca-1|0;if((ax|0)==0){break}az=a[cc]|0;a[cb]=az;if(az<<24>>24==0){cd=bH;break L1758}else{ca=ax;cb=cb+1|0;cc=cc+1|0}}a[cb]=0;if((a[cc]|0)==0){cd=bH;break}else{ce=cc}while(1){ax=ce+1|0;if((a[ax]|0)==0){cd=bH;break}else{ce=ax}}}}while(0);if((F|0)==1136){F=0;a[ah]=0;cd=bH}while(1){cg=c[cd>>2]|0;if((cg|0)==0){F=1144;break}if((cJ(51440,c[cg>>2]|0)|0)==0){F=1139;break}else{cd=cg+8|0}}L1771:do{if((F|0)==1139){F=0;ax=c[cg+4>>2]|0;if((ax|0)==0){F=1144;break}else{ch=64;ci=ai;cj=ax}while(1){ax=ch-1|0;if((ax|0)==0){break}az=a[cj]|0;a[ci]=az;if(az<<24>>24==0){ck=bH;break L1771}else{ch=ax;ci=ci+1|0;cj=cj+1|0}}a[ci]=0;if((a[cj]|0)==0){ck=bH;break}else{cl=cj}while(1){ax=cl+1|0;if((a[ax]|0)==0){ck=bH;break}else{cl=ax}}}}while(0);if((F|0)==1144){F=0;a[ai]=0;ck=bH}while(1){cm=c[ck>>2]|0;if((cm|0)==0){F=1152;break}if((cJ(51272,c[cm>>2]|0)|0)==0){F=1147;break}else{ck=cm+8|0}}L1784:do{if((F|0)==1147){F=0;ax=c[cm+4>>2]|0;if((ax|0)==0){F=1152;break}else{cn=64;co=aj;cp=ax}while(1){ax=cn-1|0;if((ax|0)==0){break}az=a[cp]|0;a[co]=az;if(az<<24>>24==0){cq=bH;break L1784}else{cn=ax;co=co+1|0;cp=cp+1|0}}a[co]=0;if((a[cp]|0)==0){cq=bH;break}else{cr=cp}while(1){ax=cr+1|0;if((a[ax]|0)==0){cq=bH;break}else{cr=ax}}}}while(0);if((F|0)==1152){F=0;a[aj]=0;cq=bH}while(1){cs=c[cq>>2]|0;if((cs|0)==0){F=1160;break}if((cJ(50736,c[cs>>2]|0)|0)==0){F=1155;break}else{cq=cs+8|0}}L1797:do{if((F|0)==1155){F=0;ax=c[cs+4>>2]|0;if((ax|0)==0){F=1160;break}else{ct=64;cu=ak;cv=ax}while(1){ax=ct-1|0;if((ax|0)==0){break}az=a[cv]|0;a[cu]=az;if(az<<24>>24==0){cw=bH;break L1797}else{ct=ax;cu=cu+1|0;cv=cv+1|0}}a[cu]=0;if((a[cv]|0)==0){cw=bH;break}else{cx=cv}while(1){ax=cx+1|0;if((a[ax]|0)==0){cw=bH;break}else{cx=ax}}}}while(0);if((F|0)==1160){F=0;a[ak]=0;cw=bH}while(1){cy=c[cw>>2]|0;if((cy|0)==0){F=1168;break}if((cJ(50616,c[cy>>2]|0)|0)==0){F=1163;break}else{cw=cy+8|0}}L1810:do{if((F|0)==1163){F=0;ax=c[cy+4>>2]|0;if((ax|0)==0){F=1168;break}else{cz=64;cA=al;cB=ax}while(1){ax=cz-1|0;if((ax|0)==0){break}az=a[cB]|0;a[cA]=az;if(az<<24>>24==0){cC=bH;break L1810}else{cz=ax;cA=cA+1|0;cB=cB+1|0}}a[cA]=0;if((a[cB]|0)==0){cC=bH;break}else{cD=cB}while(1){ax=cD+1|0;if((a[ax]|0)==0){cC=bH;break}else{cD=ax}}}}while(0);if((F|0)==1168){F=0;a[al]=0;cC=bH}while(1){cE=c[cC>>2]|0;if((cE|0)==0){F=1176;break}if((cJ(50472,c[cE>>2]|0)|0)==0){F=1171;break}else{cC=cE+8|0}}L1823:do{if((F|0)==1171){F=0;ax=c[cE+4>>2]|0;if((ax|0)==0){F=1176;break}else{cF=64;cG=am;cH=ax}while(1){ax=cF-1|0;if((ax|0)==0){break}az=a[cH]|0;a[cG]=az;if(az<<24>>24==0){cI=bH;break L1823}else{cF=ax;cG=cG+1|0;cH=cH+1|0}}a[cG]=0;if((a[cH]|0)==0){cI=bH;break}else{cK=cH}while(1){ax=cK+1|0;if((a[ax]|0)==0){cI=bH;break}else{cK=ax}}}}while(0);if((F|0)==1176){F=0;a[am]=0;cI=bH}while(1){cL=c[cI>>2]|0;if((cL|0)==0){F=1184;break}if((cJ(50312,c[cL>>2]|0)|0)==0){F=1179;break}else{cI=cL+8|0}}L1836:do{if((F|0)==1179){F=0;ax=c[cL+4>>2]|0;if((ax|0)==0){F=1184;break}else{cM=64;cN=an;cO=ax}while(1){ax=cM-1|0;if((ax|0)==0){break}az=a[cO]|0;a[cN]=az;if(az<<24>>24==0){cP=bH;break L1836}else{cM=ax;cN=cN+1|0;cO=cO+1|0}}a[cN]=0;if((a[cO]|0)==0){cP=bH;break}else{cQ=cO}while(1){ax=cQ+1|0;if((a[ax]|0)==0){cP=bH;break}else{cQ=ax}}}}while(0);if((F|0)==1184){F=0;a[an]=0;cP=bH}while(1){cR=c[cP>>2]|0;if((cR|0)==0){F=1192;break}if((cJ(50144,c[cR>>2]|0)|0)==0){F=1187;break}else{cP=cR+8|0}}L1849:do{if((F|0)==1187){F=0;ax=c[cR+4>>2]|0;if((ax|0)==0){F=1192;break}else{cS=64;cT=ao;cU=ax}while(1){ax=cS-1|0;if((ax|0)==0){break}az=a[cU]|0;a[cT]=az;if(az<<24>>24==0){break L1849}else{cS=ax;cT=cT+1|0;cU=cU+1|0}}a[cT]=0;if((a[cU]|0)==0){break}else{cV=cU}do{cV=cV+1|0;}while((a[cV]|0)!=0)}}while(0);if((F|0)==1192){F=0;a[ao]=0}a[ay]=(cJ(ao|0,49992)|0)==0|0;do{if((a[an]|0)!=0){ax=aW(an|0,0,0)|0;c[aB>>2]=ax;if((a[607928]&1)==0){break}az=c[191244]|0;bI=(az|0)!=0?az:c[q>>2]|0;eb(bI|0,49872,(I=i,i=i+8|0,c[I>>2]=ax,I)|0)|0;i=I;ax=c[191244]|0;bI=(ax|0)!=0?ax:c[q>>2]|0;aZ(bI|0)|0}}while(0);do{if((a[ae]|0)==0){cW=0}else{cX=+v1(ae);g[au>>2]=cX;g[aG>>2]=cX;a[bG]=1;if((a[607928]&1)==0){cW=1;break}bI=c[191244]|0;ax=(bI|0)!=0?bI:c[q>>2]|0;cY=cX;eb(ax|0,49488,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;ax=c[191244]|0;bI=(ax|0)!=0?ax:c[q>>2]|0;aZ(bI|0)|0;cW=1}}while(0);if((a[af]|0)==0){c_=cW}else{cY=+v1(af);g[au>>2]=cY;a[bG]=1;if((a[607928]&1)!=0){bI=c[191244]|0;ax=(bI|0)!=0?bI:c[q>>2]|0;cX=cY;eb(ax|0,49320,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[191244]|0;bI=(ax|0)!=0?ax:c[q>>2]|0;aZ(bI|0)|0}c_=cW+1|0}if((a[ag]|0)==0){c$=cW}else{cX=+v1(ag);g[aG>>2]=cX;a[bG]=1;if((a[607928]&1)!=0){bI=c[191244]|0;ax=(bI|0)!=0?bI:c[q>>2]|0;cY=cX;eb(ax|0,49040,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;ax=c[191244]|0;bI=(ax|0)!=0?ax:c[q>>2]|0;aZ(bI|0)|0}c$=cW+1|0}if((a[ah]|0)==0){c0=c_;c1=c$}else{bI=aW(ah|0,0,0)|0;c[z+76+(av*4148|0)+4128>>2]=bI;c[z+76+(av*4148|0)+4124>>2]=bI;a[bG]=1;c[aA>>2]=1;c[aM>>2]=1;if((a[607928]&1)!=0){ax=c[191244]|0;az=(ax|0)!=0?ax:c[q>>2]|0;eb(az|0,48488,(I=i,i=i+8|0,c[I>>2]=bI,I)|0)|0;i=I;bI=c[191244]|0;az=(bI|0)!=0?bI:c[q>>2]|0;aZ(az|0)|0}c0=c_+1|0;c1=c$+1|0}if((a[ai]|0)==0){c2=c0}else{az=aW(ai|0,0,0)|0;c[z+76+(av*4148|0)+4124>>2]=az;a[bG]=1;c[aM>>2]=1;if((a[607928]&1)!=0){bI=c[191244]|0;ax=(bI|0)!=0?bI:c[q>>2]|0;eb(ax|0,48248,(I=i,i=i+8|0,c[I>>2]=az,I)|0)|0;i=I;az=c[191244]|0;ax=(az|0)!=0?az:c[q>>2]|0;aZ(ax|0)|0}c2=c0+1|0}if((a[aj]|0)==0){c3=c1}else{ax=aW(aj|0,0,0)|0;c[z+76+(av*4148|0)+4128>>2]=ax;a[bG]=1;c[aA>>2]=1;if((a[607928]&1)!=0){az=c[191244]|0;bI=(az|0)!=0?az:c[q>>2]|0;eb(bI|0,48032,(I=i,i=i+8|0,c[I>>2]=ax,I)|0)|0;i=I;ax=c[191244]|0;bI=(ax|0)!=0?ax:c[q>>2]|0;aZ(bI|0)|0}c3=c1+1|0}if((a[ak]|0)==0){c4=c2;c5=c3}else{cY=+v1(ak);g[aG>>2]=cY;g[au>>2]=cY;a[bG]=1;c[aA>>2]=2;c[aM>>2]=2;if((a[607928]&1)!=0){bI=c[191244]|0;ax=(bI|0)!=0?bI:c[q>>2]|0;cX=cY;eb(ax|0,47800,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[191244]|0;bI=(ax|0)!=0?ax:c[q>>2]|0;aZ(bI|0)|0}c4=c2+1|0;c5=c3+1|0}if((a[al]|0)==0){c6=c4}else{cX=+v1(al);g[au>>2]=cX;a[bG]=1;c[aM>>2]=2;if((a[607928]&1)!=0){bI=c[191244]|0;ax=(bI|0)!=0?bI:c[q>>2]|0;cY=cX;eb(ax|0,47712,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;ax=c[191244]|0;bI=(ax|0)!=0?ax:c[q>>2]|0;aZ(bI|0)|0}c6=c4+1|0}if((a[am]|0)==0){c7=c5}else{cY=+v1(am);g[aG>>2]=cY;a[bG]=1;c[aA>>2]=2;if((a[607928]&1)!=0){bI=c[191244]|0;ax=(bI|0)!=0?bI:c[q>>2]|0;cX=cY;eb(ax|0,47488,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[191244]|0;bI=(ax|0)!=0?ax:c[q>>2]|0;aZ(bI|0)|0}c7=c5+1|0}if(c6>>>0>1){bS=0;break}bS=c7>>>0<2}}while(0);if(!bS){F=1234;break L1465}c[aa>>2]=(c[aa>>2]|0)+1}}while(0);aA=c[at+16>>2]|0;if((aA|0)==0){F=1390;break L1463}else{at=aA}}if((F|0)==1363){at=c[191244]|0;am=(at|0)!=0?at:c[q>>2]|0;a3(17856,46,1,am|0)|0;am=c[191244]|0;at=(am|0)!=0?am:c[q>>2]|0;aZ(at|0)|0;F=1388}else if((F|0)==1382){at=c[191244]|0;a3(17288,52,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;F=1388}else if((F|0)==1384){c[ar>>2]=0;F=1388}else if((F|0)==1387){at=c[191244]|0;a3(17064,48,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;F=1388}else if((F|0)==1333){at=c[191244]|0;a3(15768,57,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;F=1360}else if((F|0)==1345){at=c[191244]|0;a3(15240,56,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;F=1360}else if((F|0)==1351){at=c[191244]|0;a3(15032,52,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;F=1360}else if((F|0)==1354){at=c[191244]|0;a3(14704,65,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;F=1360}else if((F|0)==1234){at=c[191244]|0;a3(36576,78,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;break L1402}else if((F|0)==1078){at=c[191244]|0;a3(41752,75,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;v_(aw);break L1402}else if((F|0)==1080){at=c[191244]|0;a3(39768,74,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;break L1402}else if((F|0)==1085){at=c[191244]|0;a3(37832,98,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;v_(aw);break L1402}else if((F|0)==1087){at=c[191244]|0;a3(39768,74,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;break L1402}else if((F|0)==1267){at=c[191244]|0;a3(14184,51,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;F=1278}else if((F|0)==1269){at=c[191244]|0;a3(13928,57,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;F=1278}else if((F|0)==1276){at=c[191244]|0;a3(13168,46,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;F=1278}else if((F|0)==1281){at=c[191244]|0;a3(16816,51,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;F=1360}if((F|0)==1388){at=c[191244]|0;am=(at|0)!=0?at:c[q>>2]|0;a3(30624,40,1,am|0)|0;am=c[191244]|0;at=(am|0)!=0?am:c[q>>2]|0;aZ(at|0)|0;break L1402}else if((F|0)==1360){at=c[191244]|0;a3(31984,46,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;break L1402}else if((F|0)==1278){at=c[191244]|0;a3(33624,51,1,((at|0)!=0?at:c[q>>2]|0)|0)|0;at=c[191244]|0;aZ(((at|0)!=0?at:c[q>>2]|0)|0)|0;break L1402}}}while(0);do{if((F|0)==1390){if((c[aa>>2]|0)!=0){break}G=c[191244]|0;P=(G|0)!=0?G:c[q>>2]|0;a3(30256,82,1,P|0)|0;P=c[191244]|0;G=(P|0)!=0?P:c[q>>2]|0;aZ(G|0)|0;break L1402}}while(0);aa=c[E>>2]|0;if((aa|0)!=0){hs(aa)}v_(D);break L1381}else{aa=c[191244]|0;eb(((aa|0)!=0?aa:c[q>>2]|0)|0,21680,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;aa=c[191244]|0;aZ(((aa|0)!=0?aa:c[q>>2]|0)|0)|0}}while(0);C=c[191244]|0;aa=(C|0)!=0?C:c[q>>2]|0;a3(29864,51,1,aa|0)|0;aa=c[191244]|0;C=(aa|0)!=0?aa:c[q>>2]|0;aZ(C|0)|0;if(!B){break}C=c[D>>2]|0;if((C|0)!=0){hs(C)}v_(D)}}while(0);A=c[191244]|0;C=(A|0)!=0?A:c[q>>2]|0;a3(35368,56,1,C|0)|0;C=c[191244]|0;A=(C|0)!=0?C:c[q>>2]|0;aZ(A|0)|0;y=0;i=e;return y|0}}while(0);h1(c[124232]|0,d);d=(a[496960]&1)==0;L1957:do{if((a[(c[124232]|0)+4|0]&1)==0){aw=c[191244]|0;bS=(aw|0)!=0?aw:c[q>>2]|0;a3(24456,90,1,bS|0)|0;bS=c[191244]|0;aw=(bS|0)!=0?bS:c[q>>2]|0;aZ(aw|0)|0}else{aw=ju(d?21120:20776,d?22152:21736,0)|0;c[126092]=aw;if((aw|0)==0){aw=c[191244]|0;bS=(aw|0)!=0?aw:c[q>>2]|0;a3(21520,60,1,bS|0)|0;bS=c[191244]|0;aw=(bS|0)!=0?bS:c[q>>2]|0;aZ(aw|0)|0;break}else{c8=0}while(1){c9=c[124232]|0;if(c8>>>0>=(c[c9+72>>2]|0)>>>0){F=1414;break}da=c9+76+(c8*4148|0)|0;aw=c9+76+(c8*4148|0)+4096|0;if((a[da]|0)==0){db=c[aw>>2]|0;dc=c[c9+76+(c8*4148|0)+4100>>2]|0}else{if((gf(da,aw)|0)<1){F=1411;break}bS=dn(c[aw>>2]|0)|0;c[c9+76+(c8*4148|0)+4100>>2]=bS;if((bS|0)==0){F=1411;break}c7=c[aw>>2]|0;if((c7|0)==0){F=1411;break}else{db=c7;dc=bS}}a[da]=0;bS=ju(db,dc,c8)|0;c7=c8+1|0;c[504368+(c7<<2)>>2]=bS;if((bS|0)==0){F=1413;break}else{c8=c7}}if((F|0)==1411){c7=c[191244]|0;bS=(c7|0)!=0?c7:c[q>>2]|0;eb(bS|0,27928,(I=i,i=i+8|0,c[I>>2]=da,I)|0)|0;i=I;bS=c[191244]|0;c7=(bS|0)!=0?bS:c[q>>2]|0;aZ(c7|0)|0;break}else if((F|0)==1413){c7=c[191244]|0;eb(((c7|0)!=0?c7:c[q>>2]|0)|0,27608,(I=i,i=i+8|0,c[I>>2]=c8,I)|0)|0;i=I;c7=c[191244]|0;aZ(((c7|0)!=0?c7:c[q>>2]|0)|0)|0;break}else if((F|0)==1414){c7=w;L1975:do{if((c[c9+66444>>2]|0)==0){dd=0}else{bx(1,504328);bS=c[124232]|0;if((c[bS+66444>>2]|0)==0){dd=0;break}aw=w|0;c6=w+4|0;c5=w+8|0;c4=0;c3=bS;while(1){if((a[607928]&1)==0){de=c3}else{bS=c[191244]|0;c2=(bS|0)!=0?bS:c[q>>2]|0;bS=c3+66448+(c4*4168|0)+64|0;eb(c2|0,28976,(I=i,i=i+8|0,c[I>>2]=bS,I)|0)|0;i=I;bS=c[191244]|0;c2=(bS|0)!=0?bS:c[q>>2]|0;aZ(c2|0)|0;de=c[124232]|0}v3(c7|0,0,12);c2=de+66448+(c4*4168|0)+64|0;if((a[766412]&1)==0){if(!(h7(c2,w,16,0)|0)){break}}else{if(!(h7(c2,w,0,16)|0)){break}}aY(3553,c[504328+(c4<<2)>>2]|0);eV(3553,10242,33071);eV(3553,10243,33071);c2=(c[(c[124232]|0)+66448+(c4*4168|0)+4160>>2]|0)==2?9728:9729;eV(3553,10240,c2|0);eV(3553,10241,c2|0);e2(3317,4);c2=(a[766412]&1)!=0?6408:32993;bS=c[c5>>2]|0;d1(3553,0,c2|0,c[aw>>2]|0,c[c6>>2]|0,0,c2|0,5121,bS|0);aY(3553,0);v_(bS);bS=c4+1|0;c2=c[124232]|0;if(bS>>>0<(c[c2+66444>>2]|0)>>>0){c4=bS;c3=c2}else{dd=0;break L1975}}c3=c[191244]|0;eb(((c3|0)!=0?c3:c[q>>2]|0)|0,28328,(I=i,i=i+8|0,c[I>>2]=(c[124232]|0)+66448+(c4*4168|0)+64,I)|0)|0;i=I;c3=c[191244]|0;aZ(((c3|0)!=0?c3:c[q>>2]|0)|0)|0;c3=c[191244]|0;a3(19360,48,1,((c3|0)!=0?c3:c[q>>2]|0)|0)|0;c3=c[191244]|0;aZ(((c3|0)!=0?c3:c[q>>2]|0)|0)|0;break L1957}}while(0);do{jv(dd,c[504368+(dd<<2)>>2]|0,496968+(dd*460|0)|0);dd=dd+1|0;df=c[124232]|0;}while(dd>>>0<=(c[df+72>>2]|0)>>>0);do{if((c[df+99792>>2]|0)!=0){c7=fc[c[37226]&127](2)|0;c3=c[124232]|0;c6=c[c3+99792>>2]|0;aw=vZ(12)|0;if((aw|0)==0){c[126090]=0}else{if((c[aw-4>>2]&3|0)!=0){v3(aw|0,0,12)}c5=aw;D=(c6|0)==0;do{if(D){dg=0}else{B=c6*112|0;if(c6>>>0<=65535){dg=B;break}dg=((B>>>0)/(c6>>>0)|0|0)==112?B:-1}}while(0);c4=vZ(dg)|0;do{if((c4|0)!=0){if((c[c4-4>>2]&3|0)==0){break}v3(c4|0,0,dg|0)}}while(0);B=c4;c2=aw;c[c2>>2]=B;c[aw+4>>2]=c6;L2007:do{if(!D){bS=aw+8|0;c1=aw+10|0;z=(c7|0)==0?147408:c7;c0=0;c$=B;while(1){c_=64;cW=c$+(c0*112|0)|0;cV=c3+99796+(c0*80|0)|0;while(1){cU=c_-1|0;if((cU|0)==0){F=1441;break}cT=a[cV]|0;a[cW]=cT;if(cT<<24>>24==0){break}else{c_=cU;cW=cW+1|0;cV=cV+1|0}}do{if((F|0)==1441){F=0;a[cW]=0;if((a[cV]|0)==0){break}else{dh=cV}do{dh=dh+1|0;}while((a[dh]|0)!=0)}}while(0);c[(c[c2>>2]|0)+(c0*112|0)+76>>2]=c[c3+99796+(c0*80|0)+64>>2];c[(c[c2>>2]|0)+(c0*112|0)+84>>2]=c[c3+99796+(c0*80|0)+68>>2];cV=b[c3+99796+(c0*80|0)+76>>1]|0;b[(c[c2>>2]|0)+(c0*112|0)+80>>1]=cV<<16>>16==0?-1:cV;b[(c[c2>>2]|0)+(c0*112|0)+82>>1]=b[c3+99796+(c0*80|0)+78>>1]|0;cV=c[c3+99796+(c0*80|0)+72>>2]|0;if((cV|0)==1){c[(c[c2>>2]|0)+(c0*112|0)+72>>2]=z}else if((cV|0)==2){c[(c[c2>>2]|0)+(c0*112|0)+68>>2]=bS;a[(c[c2>>2]|0)+(c0*112|0)+64|0]=1}else if((cV|0)==3){c[(c[c2>>2]|0)+(c0*112|0)+68>>2]=c1;a[(c[c2>>2]|0)+(c0*112|0)+64|0]=1}else{c[(c[c2>>2]|0)+(c0*112|0)+72>>2]=147408}cV=c0+1|0;if(cV>>>0>=c6>>>0){break L2007}c0=cV;c$=c[c2>>2]|0}}}while(0);c[126090]=c5;if((aw|0)!=0){break}}c2=c[191244]|0;c6=(c2|0)!=0?c2:c[q>>2]|0;a3(17408,50,1,c6|0)|0;c6=c[191244]|0;c2=(c6|0)!=0?c6:c[q>>2]|0;aZ(c2|0)|0}}while(0);a[9080]=1;c2=c[124232]|0;c6=c2+72|0;c[504368+((c[c6>>2]|0)+1<<2)>>2]=c[126092];c3=496968+(((c[c6>>2]|0)+1|0)*460|0)|0;v6(c3|0,496968,460)|0;if((a[c2+4|0]&1)==0){c[126107]=c[126092];v6(503868,496968,460)|0}else{c2=(a[496960]&1)!=0;c3=ju(c2?48640:50840,c2?13312:15424,15)|0;c[126107]=c3;jv(0,c3,503868)}if((c[126266]|0)!=0){c3=0;do{cZ(c[504952+(c3<<2)>>2]|0);c3=c3+1|0;}while(c3>>>0<(c[126266]|0)>>>0)}c[126266]=0;c3=0;while(1){es(1,480288+(c3*1040|0)|0);es(1,480808+(c3*1040|0)|0);c2=c3+1|0;if(c2>>>0<16){c3=c2}else{y=1;break}}i=e;return y|0}}}while(0);jj();y=0;i=e;return y|0}function jj(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;d0(0);f=e;g=e;h=0;do{j=c[504368+(h<<2)>>2]|0;do{if((j|0)!=0){if((h|0)!=0&(j|0)==(c[126092]|0)){break}c[e>>2]=0;c[e+4>>2]=0;b_(j|0,2,d|0,g|0);if((c[d>>2]|0)>0){k=0;do{l=f+(k<<2)|0;cO(j|0,c[l>>2]|0);bl(c[l>>2]|0);k=k+1|0;}while((k|0)<(c[d>>2]|0))}cc(j|0)}}while(0);h=h+1|0;}while(h>>>0<16);h=c[124232]|0;do{if((h|0)==0){m=0}else{d=c[h+66444>>2]|0;if((d|0)==0){m=h;break}bf(d|0,504328);m=c[124232]|0}}while(0);v3(504368,0,64);v3(496968,0,7360);a[9080]=0;c[191666]=0;if((m|0)!=0){if((c[m+72>>2]|0)==0){n=m}else{h=0;d=m;while(1){v_(c[d+76+(h*4148|0)+4096>>2]|0);v_(c[(c[124232]|0)+76+(h*4148|0)+4100>>2]|0);m=h+1|0;f=c[124232]|0;if(m>>>0<(c[f+72>>2]|0)>>>0){h=m;d=f}else{n=f;break}}}v_(c[n+109012>>2]|0);v_(c[124232]|0);c[124232]=0}n=c[126090]|0;if((n|0)!=0){v_(c[n>>2]|0);v_(n)}c[126090]=0;if((c[126266]|0)!=0){n=0;do{cZ(c[504952+(n<<2)>>2]|0);n=n+1|0;}while(n>>>0<(c[126266]|0)>>>0)}c[126266]=0;n=0;do{d=480288+(n*1040|0)|0;if((c[d>>2]|0)!=0){eZ(1,d|0)}d=480808+(n*1040|0)|0;if((c[d>>2]|0)!=0){eZ(1,d|0)}n=n+1|0;}while(n>>>0<16);v3(480288,0,16640);i=b;return}function jk(){return c[(c[124232]|0)+72>>2]|0}function jl(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==0|a[9080]^1){e=0;return e|0}f=c[(c[124232]|0)+76+((b-1|0)*4148|0)+4136>>2]|0;if((f|0)==0){e=0;return e|0}a[d]=(f|0)==1|0;e=1;return e|0}function jm(b){b=b|0;var d=0;if((b|0)==0|a[9080]^1){d=0;return d|0}d=c[(c[124232]|0)+76+((b-1|0)*4148|0)+4140>>2]|0;return d|0}function jn(e,f,h,j,k,l,m,n,o,p,q){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;r=i;i=i+920|0;s=r|0;t=r+512|0;u=r+896|0;v=r+904|0;w=r+912|0;if(!(a[9080]|0)){i=r;return}x=c[191666]|0;if((c[504368+(x<<2)>>2]|0)==0){i=r;return}z=t|0;A=u|0;g[A>>2]=+(e>>>0>>>0);g[u+4>>2]=+(f>>>0>>>0);f=v|0;g[f>>2]=+(k>>>0>>>0);g[v+4>>2]=+(l>>>0>>>0);l=w|0;g[l>>2]=+(h>>>0>>>0);g[w+4>>2]=+(j>>>0>>>0);j=c[496988+(x*460|0)>>2]|0;if((j|0)>-1){a8(j|0,1,A|0)}A=c[496992+(x*460|0)>>2]|0;if((A|0)>-1){a8(A|0,1,f|0)}f=c[496996+(x*460|0)>>2]|0;if((f|0)>-1){a8(f|0,1,l|0)}l=c[497e3+(x*460|0)>>2]|0;f=c[191666]|0;if((l|0)>-1&(f|0)!=0){A=c[(c[124232]|0)+76+((f-1|0)*4148|0)+4144>>2]|0;if((A|0)==0){B=m}else{B=(m>>>0)%(A>>>0)|0}bI(l|0,B|0);C=B}else{C=m}m=c[497008+(x*460|0)>>2]|0;if((m|0)>-1){bI(m|0,((a[756472]&1)!=0?-1:1)|0)}m=c[124232]|0;if((c[m+66444>>2]|0)==0){D=0}else{B=0;l=m;while(1){m=497012+(x*460|0)+(B<<2)|0;if((c[m>>2]|0)>-1){cG(B+33985|0);aY(3553,c[504328+(B<<2)>>2]|0);A=B+1|0;bI(c[m>>2]|0,A|0);E=c[124232]|0;F=A}else{E=l;F=B+1|0}A=c[E+66444>>2]|0;if(F>>>0<A>>>0){B=F;l=E}else{D=A;break}}}E=D+1|0;do{if((c[191666]|0)>>>0>1){l=497044+(x*460|0)|0;if((c[l>>2]|0)>-1){cG(D+33985|0);bI(c[l>>2]|0,E|0);aY(3553,c[n>>2]|0)}l=D+2|0;F=c[497052+(x*460|0)>>2]|0;if((F|0)>-1){a8(F|0,1,n+12|0)}F=c[497048+(x*460|0)>>2]|0;if((F|0)>-1){a8(F|0,1,n+4|0)}F=c[497056+(x*460|0)>>2]|0;if((F|0)>-1){c[t>>2]=F;c[t+4>>2]=2;c[t+8>>2]=0;F=t+12|0;B=s;A=n+20|0;v6(B|0,A|0,32)|0;G=8;H=1;I=F}else{G=0;H=0;I=z}if((q|0)==0){J=I;K=H;L=l;M=G;N=0;break}cG(q+33985+D|0);aY(3553,c[p+((q-1|0)*52|0)>>2]|0);F=I;A=H;B=l;l=0;m=G;while(1){f=c[497060+(x*460|0)+(l<<4)>>2]|0;if((f|0)!=0){bI(f|0,B|0)}f=c[497060+(x*460|0)+(l<<4)+8>>2]|0;if((f|0)>-1){a8(f|0,1,p+(l*52|0)+12|0)}f=c[497060+(x*460|0)+(l<<4)+4>>2]|0;if((f|0)>-1){a8(f|0,1,p+(l*52|0)+4|0)}f=c[497060+(x*460|0)+(l<<4)+12>>2]|0;if((f|0)>-1){c[F>>2]=f;c[F+4>>2]=2;c[F+8>>2]=m<<2;f=A+1|0;j=F+12|0;w=s+(m<<2)|0;h=p+(l*52|0)+20|0;v6(w|0,h|0,32)|0;O=m+8|0;P=f;Q=j}else{O=m;P=A;Q=F}j=l+1|0;if(j>>>0<q>>>0){F=Q;A=P;B=B+1|0;l=j;m=O}else{break}}J=Q;K=P;L=q+2+D|0;M=O;N=0}else{cG(D+33985|0);aY(3553,0);if((c[(c[124232]|0)+72>>2]|0)==0){J=z;K=0;L=E;M=0;N=0;break}m=D+33986|0;l=0;while(1){cG(m+l|0);aY(3553,0);B=l+1|0;if(B>>>0<(c[(c[124232]|0)+72>>2]|0)>>>0){l=B}else{J=z;K=0;L=E;M=0;N=0;break}}}}while(0);while(1){E=497316+(x*460|0)+(N<<4)|0;if((c[E>>2]|0)>-1){cG(L+33984|0);aY(3553,c[o+(N*52|0)>>2]|0);bI(c[E>>2]|0,L|0);R=L+1|0}else{R=L}E=c[497316+(x*460|0)+(N<<4)+8>>2]|0;if((E|0)>-1){a8(E|0,1,o+(N*52|0)+12|0)}E=c[497316+(x*460|0)+(N<<4)+4>>2]|0;if((E|0)>-1){a8(E|0,1,o+(N*52|0)+4|0)}E=c[497316+(x*460|0)+(N<<4)+12>>2]|0;if((E|0)>-1){c[J>>2]=E;c[J+4>>2]=2;c[J+8>>2]=M<<2;E=K+1|0;D=J+12|0;O=s+(M<<2)|0;q=o+(N*52|0)+20|0;v6(O|0,q|0,32)|0;S=M+8|0;T=E;U=D}else{S=M;T=K;U=J}D=N+1|0;if(D>>>0<7){J=U;K=T;L=R+1|0;M=S;N=D}else{break}}if((S|0)!=0){N=c[191666]|0;jt(c[480808+(N*1040|0)>>2]|0,480812+(N*1040|0)|0,481324+(N*1040|0)|0,s|0,S,z,T)}cG(33984);T=c[126090]|0;if((T|0)==0){i=r;return}if((c[191666]|0)==1){z=c[T+4>>2]|0;S=z>>>0<64?z:64;z=c[191560]|0;if((z|0)!=0){s=4;N=0;M=0;R=z;while(1){z=c[200+(s-4<<2)>>2]|0;V=((fb[c[R+8>>2]&15](c[191563]|0,248,0,1,0,z)|0)<<16>>16!=0)<<s|N;W=((fb[c[(c[191560]|0)+8>>2]&15](c[191563]|0,248,1,1,0,z)|0)<<16>>16!=0)<<s|M;z=s+1|0;if(z>>>0>=16){break}s=z;N=V&65535;M=W&65535;R=c[191560]|0}R=T+8|0;y=W<<16|V&65535;b[R>>1]=y&65535;b[R+2>>1]=y>>16}L2192:do{if((S|0)!=0){R=T|0;V=0;while(1){W=c[R>>2]|0;c[504432+(V<<3)>>2]=W+(V*112|0);switch(c[W+(V*112|0)+84>>2]|0){case 3:{M=W+(V*112|0)+104|0;N=(a[W+(V*112|0)+64|0]&1)==0;if(N){X=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{X=b[c[W+(V*112|0)+68>>2]>>1]|0}s=b[W+(V*112|0)+80>>1]|0;z=s&X;L=b[W+(V*112|0)+82>>1]|0;K=L<<16>>16==0;if((c[M>>2]|0)==((K|z<<16>>16==L<<16>>16?z&65535:0)|0)){Y=c[W+(V*112|0)+108>>2]|0}else{if(N){Z=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{Z=b[c[W+(V*112|0)+68>>2]>>1]|0}N=Z&s;c[M>>2]=K|N<<16>>16==L<<16>>16?N&65535:0;N=W+(V*112|0)+108|0;L=(c[N>>2]|0)+1|0;c[N>>2]=L;Y=L}g[504436+(V<<3)>>2]=+(Y|0);break};case 4:{L=W+(V*112|0)+104|0;N=(a[W+(V*112|0)+64|0]&1)==0;if(N){_=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{_=b[c[W+(V*112|0)+68>>2]>>1]|0}K=b[W+(V*112|0)+80>>1]|0;M=K&_;s=b[W+(V*112|0)+82>>1]|0;z=s<<16>>16==0;if((c[L>>2]|0)==((z|M<<16>>16==s<<16>>16?M&65535:0)|0)){$=c[W+(V*112|0)+100>>2]|0}else{if(N){aa=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{aa=b[c[W+(V*112|0)+68>>2]>>1]|0}N=aa&K;c[L>>2]=z|N<<16>>16==s<<16>>16?N&65535:0;N=W+(V*112|0)+96|0;s=c[N>>2]|0;c[W+(V*112|0)+100>>2]=s;c[N>>2]=C;$=s}g[504436+(V<<3)>>2]=+($|0);break};case 0:{if((a[W+(V*112|0)+64|0]&1)==0){ab=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ab=b[c[W+(V*112|0)+68>>2]>>1]|0}s=b[W+(V*112|0)+80>>1]&ab;N=b[W+(V*112|0)+82>>1]|0;g[504436+(V<<3)>>2]=N<<16>>16==0|s<<16>>16==N<<16>>16?+((s&65535)>>>0):0.0;break};case 1:{s=W+(V*112|0)+88|0;N=c[s>>2]|0;z=(a[W+(V*112|0)+64|0]&1)==0;if(z){ac=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ac=b[c[W+(V*112|0)+68>>2]>>1]|0}L=b[W+(V*112|0)+80>>1]|0;K=L&ac;M=b[W+(V*112|0)+82>>1]|0;U=M<<16>>16==0;J=W+(V*112|0)+92|0;if((N|0)==((U|K<<16>>16==M<<16>>16?K&65535:0)|0)){ad=c[J>>2]|0}else{c[J>>2]=N;if(z){ae=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ae=b[c[W+(V*112|0)+68>>2]>>1]|0}z=ae&L;c[s>>2]=U|z<<16>>16==M<<16>>16?z&65535:0;ad=N}g[504436+(V<<3)>>2]=+(ad>>>0>>>0);break};case 2:{N=W+(V*112|0)+104|0;z=(a[W+(V*112|0)+64|0]&1)==0;if(z){af=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{af=b[c[W+(V*112|0)+68>>2]>>1]|0}M=b[W+(V*112|0)+80>>1]|0;U=M&af;s=b[W+(V*112|0)+82>>1]|0;L=s<<16>>16==0;if((c[N>>2]|0)==((L|U<<16>>16==s<<16>>16?U&65535:0)|0)){ag=c[W+(V*112|0)+96>>2]|0}else{if(z){ah=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ah=b[c[W+(V*112|0)+68>>2]>>1]|0}z=ah&M;c[N>>2]=L|z<<16>>16==s<<16>>16?z&65535:0;c[W+(V*112|0)+96>>2]=C;ag=C}g[504436+(V<<3)>>2]=+(ag|0);break};default:{}}V=V+1|0;if(V>>>0>=S>>>0){break L2192}}}}while(0);c[126236]=S;ai=S}else{ai=c[126236]|0}if((ai|0)==0){i=r;return}else{aj=0}do{ai=dz(c[504368+(c[191666]<<2)>>2]|0,c[504432+(aj<<3)>>2]|0)|0;bB(ai|0,+(+g[504436+(aj<<3)>>2]));aj=aj+1|0;}while(aj>>>0<(c[126236]|0)>>>0);i=r;return}function jo(b){b=b|0;var d=0;if(!(a[9080]|0)){return}if((c[126266]|0)!=0){d=0;do{cZ(c[504952+(d<<2)>>2]|0);d=d+1|0;}while(d>>>0<(c[126266]|0)>>>0)}c[126266]=0;c[191666]=b;d0(c[504368+(b<<2)>>2]|0);return}function jp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(!(a[9080]|0)){b=0;return b|0}d=c[(c[124232]|0)+72>>2]|0;if((d|0)==0){b=0;return b|0}else{e=0;f=1}while(1){if((c[497316+(f*460|0)>>2]|0)>-1){g=(e|0)==0?1:e}else{g=e}if((c[497332+(f*460|0)>>2]|0)>-1){h=g>>>0<2?2:g}else{h=g}if((c[497348+(f*460|0)>>2]|0)>-1){i=h>>>0<3?3:h}else{i=h}if((c[497364+(f*460|0)>>2]|0)>-1){j=i>>>0<4?4:i}else{j=i}if((c[497380+(f*460|0)>>2]|0)>-1){k=j>>>0<5?5:j}else{k=j}if((c[497396+(f*460|0)>>2]|0)>-1){l=k>>>0<6?6:k}else{l=k}if((c[497412+(f*460|0)>>2]|0)>-1){m=l>>>0<7?7:l}else{m=l}n=f+1|0;if(n>>>0>d>>>0){b=m;break}else{e=m;f=n}}return b|0}function jq(b,d){b=b|0;d=d|0;var e=0;if((b|0)==0|a[9080]^1){a[d|0]=0;return}else{e=d|0;d=(c[124232]|0)+76+((b-1|0)*4148|0)+4104|0;v6(e|0,d|0,32)|0;return}}function jr(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+560|0;e=d|0;f=d+512|0;if(!(a[9080]|0)){g=0;i=d;return g|0}if((a[(c[124232]|0)+4|0]&1)==0){g=0;i=d;return g|0}h=f|0;j=c[191666]|0;k=c[496972+(j*460|0)>>2]|0;if((k|0)>-1){c[f>>2]=k;c[f+4>>2]=2;c[f+8>>2]=0;k=f+12|0;f=e;l=c[b+8>>2]|0;v6(f|0,l|0,32)|0;m=k;n=1;o=8}else{m=h;n=0;o=0}k=c[496976+(j*460|0)>>2]|0;if((k|0)>-1){c[m>>2]=k;c[m+4>>2]=2;c[m+8>>2]=o<<2;k=n+1|0;l=m+12|0;f=e+(o<<2)|0;p=c[b>>2]|0;v6(f|0,p|0,32)|0;q=l;r=k;s=o+8|0}else{q=m;r=n;s=o}o=c[496980+(j*460|0)>>2]|0;if((o|0)>-1){c[q>>2]=o;c[q+4>>2]=4;c[q+8>>2]=s<<2;o=r+1|0;n=q+12|0;m=e+(s<<2)|0;k=c[b+4>>2]|0;v6(m|0,k|0,64)|0;t=n;u=o;v=s+16|0}else{t=q;u=r;v=s}s=c[496984+(j*460|0)>>2]|0;if((s|0)>-1){c[t>>2]=s;c[t+4>>2]=2;c[t+8>>2]=v<<2;t=u+1|0;s=e+(v<<2)|0;r=c[b+12>>2]|0;v6(s|0,r|0,32)|0;w=t;x=v+8|0}else{w=u;x=v}if((x|0)==0){g=1;i=d;return g|0}jt(c[480288+(j*1040|0)>>2]|0,480292+(j*1040|0)|0,480804+(j*1040|0)|0,e|0,x,h,w);g=1;i=d;return g|0}function js(b){b=b|0;var d=0,e=0;if(!(a[9080]|0)){d=0;return d|0}if((a[(c[124232]|0)+4|0]&1)==0){d=0;return d|0}e=c[496968+((c[191666]|0)*460|0)>>2]|0;if((e|0)<=-1){d=1;return d|0}eN(e|0,1,0,b|0);d=1;return d|0}function jt(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;bV(34962,a|0);if((c[d>>2]|0)==(f|0)){a=e;i=b;j=f<<2;if((wb(a|0,i|0,j|0)|0)!=0){k=i;l=a;m=j;n=1684}}else{k=b;l=e;m=f<<2;n=1684}if((n|0)==1684){v6(k|0,l|0,m)|0;dx(34962,m|0,l|0,35044);c[d>>2]=f}if((h|0)==0){bV(34962,0);return}else{o=0}do{f=c[g+(o*12|0)>>2]|0;dj(f|0);d=c[126266]|0;c[126266]=d+1;c[504952+(d<<2)>>2]=f;bT(f|0,c[g+(o*12|0)+4>>2]|0,5126,0,0,c[g+(o*12|0)+8>>2]|0);o=o+1|0;}while(o>>>0<h>>>0);bV(34962,0);return}function ju(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0;f=i;i=i+88|0;g=f|0;h=f+64|0;j=f+72|0;k=f+80|0;l=ez()|0;if((l|0)==0){m=0;i=f;return m|0}n=(b|0)!=0;do{if(n){if((a[607928]&1)!=0){o=c[191244]|0;p=(o|0)!=0?o:c[q>>2]|0;a3(27280,37,1,p|0)|0;p=c[191244]|0;o=(p|0)!=0?p:c[q>>2]|0;aZ(o|0)|0}o=bG(35633)|0;if(jx(o,26936,b)|0){cg(l|0,o|0);break}o=c[191244]|0;p=(o|0)!=0?o:c[q>>2]|0;eb(p|0,26560,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;p=c[191244]|0;o=(p|0)!=0?p:c[q>>2]|0;aZ(o|0)|0;m=0;i=f;return m|0}}while(0);b=(d|0)!=0;do{if(b){if((a[607928]&1)!=0){o=c[191244]|0;p=(o|0)!=0?o:c[q>>2]|0;a3(26288,39,1,p|0)|0;p=c[191244]|0;o=(p|0)!=0?p:c[q>>2]|0;aZ(o|0)|0}o=bG(35632)|0;if(jx(o,25936,d)|0){cg(l|0,o|0);break}o=c[191244]|0;p=(o|0)!=0?o:c[q>>2]|0;eb(p|0,25504,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;p=c[191244]|0;o=(p|0)!=0?p:c[q>>2]|0;aZ(o|0)|0;m=0;i=f;return m|0}}while(0);if(!(n|b)){m=l;i=f;return m|0}if((a[607928]&1)!=0){b=c[191244]|0;n=(b|0)!=0?b:c[q>>2]|0;a3(24944,33,1,n|0)|0;n=c[191244]|0;b=(n|0)!=0?n:c[q>>2]|0;aZ(b|0)|0}bM(l|0);dG(l|0,35714,k|0);c[h>>2]=0;dG(l|0,35716,j|0);b=c[j>>2]|0;do{if((b|0)!=0){j=vZ(b)|0;if((j|0)==0){break}d2(l|0,b|0,h|0,j|0);do{if((c[h>>2]|0)>0){if((a[607928]&1)==0){break}n=c[191244]|0;d=(n|0)!=0?n:c[q>>2]|0;eb(d|0,24016,(r=i,i=i+8|0,c[r>>2]=j,r)|0)|0;i=r;d=c[191244]|0;n=(d|0)!=0?d:c[q>>2]|0;aZ(n|0)|0}}while(0);v_(j)}}while(0);if((c[k>>2]|0)!=1){k=c[191244]|0;h=(k|0)!=0?k:c[q>>2]|0;eb(h|0,24216,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;e=c[191244]|0;h=(e|0)!=0?e:c[q>>2]|0;aZ(h|0)|0;m=0;i=f;return m|0}d0(l|0);d0(l|0);h=g|0;bN(h|0,64,30560,(r=i,i=i+16|0,c[r>>2]=(c[124232]|0)+5,c[r+8>>2]=30200,r)|0)|0;i=r;g=dz(l|0,h|0)|0;L2395:do{if((g|0)>-1){s=g}else{e=0;while(1){if(e>>>0>=2){s=-1;break L2395}bN(h|0,64,30560,(r=i,i=i+16|0,c[r>>2]=c[9072+(e<<2)>>2],c[r+8>>2]=30200,r)|0)|0;i=r;k=dz(l|0,h|0)|0;if((k|0)>-1){s=k;break}else{e=e+1|0}}}}while(0);bI(s|0,0);d0(0);m=l;i=f;return m|0}function jv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+128|0;f=e+64|0;d0(b|0);g=e|0;bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=(c[124232]|0)+5,c[h+8>>2]=46664,h)|0)|0;i=h;j=dz(b|0,g|0)|0;L2402:do{if((j|0)>-1){k=j}else{l=0;while(1){if(l>>>0>=2){k=-1;break L2402}bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(l<<2)>>2],c[h+8>>2]=46664,h)|0)|0;i=h;m=dz(b|0,g|0)|0;if((m|0)>-1){k=m;break}else{l=l+1|0}}}}while(0);c[d>>2]=k;bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=(c[124232]|0)+5,c[h+8>>2]=45208,h)|0)|0;i=h;k=dz(b|0,g|0)|0;L2407:do{if((k|0)>-1){n=k}else{j=0;while(1){if(j>>>0>=2){n=-1;break L2407}bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(j<<2)>>2],c[h+8>>2]=45208,h)|0)|0;i=h;l=eu(b|0,g|0)|0;if((l|0)>-1){n=l;break}else{j=j+1|0}}}}while(0);c[d+4>>2]=n;bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=(c[124232]|0)+5,c[h+8>>2]=44288,h)|0)|0;i=h;n=dz(b|0,g|0)|0;L2412:do{if((n|0)>-1){o=n}else{k=0;while(1){if(k>>>0>=2){o=-1;break L2412}bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(k<<2)>>2],c[h+8>>2]=44288,h)|0)|0;i=h;j=eu(b|0,g|0)|0;if((j|0)>-1){o=j;break}else{k=k+1|0}}}}while(0);c[d+8>>2]=o;bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=(c[124232]|0)+5,c[h+8>>2]=42928,h)|0)|0;i=h;o=dz(b|0,g|0)|0;L2417:do{if((o|0)>-1){p=o}else{n=0;while(1){if(n>>>0>=2){p=-1;break L2417}bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(n<<2)>>2],c[h+8>>2]=42928,h)|0)|0;i=h;k=eu(b|0,g|0)|0;if((k|0)>-1){p=k;break}else{n=n+1|0}}}}while(0);c[d+12>>2]=p;bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=(c[124232]|0)+5,c[h+8>>2]=41632,h)|0)|0;i=h;p=dz(b|0,g|0)|0;L2422:do{if((p|0)>-1){q=p}else{o=0;while(1){if(o>>>0>=2){q=-1;break L2422}bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(o<<2)>>2],c[h+8>>2]=41632,h)|0)|0;i=h;n=eu(b|0,g|0)|0;if((n|0)>-1){q=n;break}else{o=o+1|0}}}}while(0);c[d+16>>2]=q;bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=(c[124232]|0)+5,c[h+8>>2]=40640,h)|0)|0;i=h;q=dz(b|0,g|0)|0;L2427:do{if((q|0)>-1){r=q}else{p=0;while(1){if(p>>>0>=2){r=-1;break L2427}bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(p<<2)>>2],c[h+8>>2]=40640,h)|0)|0;i=h;o=dz(b|0,g|0)|0;if((o|0)>-1){r=o;break}else{p=p+1|0}}}}while(0);c[d+20>>2]=r;bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=(c[124232]|0)+5,c[h+8>>2]=39592,h)|0)|0;i=h;r=dz(b|0,g|0)|0;L2432:do{if((r|0)>-1){s=r}else{q=0;while(1){if(q>>>0>=2){s=-1;break L2432}bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(q<<2)>>2],c[h+8>>2]=39592,h)|0)|0;i=h;p=dz(b|0,g|0)|0;if((p|0)>-1){s=p;break}else{q=q+1|0}}}}while(0);c[d+24>>2]=s;bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=(c[124232]|0)+5,c[h+8>>2]=38688,h)|0)|0;i=h;s=dz(b|0,g|0)|0;L2437:do{if((s|0)>-1){t=s}else{r=0;while(1){if(r>>>0>=2){t=-1;break L2437}bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(r<<2)>>2],c[h+8>>2]=38688,h)|0)|0;i=h;q=dz(b|0,g|0)|0;if((q|0)>-1){t=q;break}else{r=r+1|0}}}}while(0);c[d+28>>2]=t;bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=(c[124232]|0)+5,c[h+8>>2]=37704,h)|0)|0;i=h;t=dz(b|0,g|0)|0;L2442:do{if((t|0)>-1){u=t}else{s=0;while(1){if(s>>>0>=2){u=-1;break L2442}bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(s<<2)>>2],c[h+8>>2]=37704,h)|0)|0;i=h;r=dz(b|0,g|0)|0;if((r|0)>-1){u=r;break}else{s=s+1|0}}}}while(0);c[d+32>>2]=u;bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=(c[124232]|0)+5,c[h+8>>2]=36432,h)|0)|0;i=h;u=dz(b|0,g|0)|0;L2447:do{if((u|0)>-1){v=u}else{t=0;while(1){if(t>>>0>=2){v=-1;break L2447}bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(t<<2)>>2],c[h+8>>2]=36432,h)|0)|0;i=h;s=dz(b|0,g|0)|0;if((s|0)>-1){v=s;break}else{t=t+1|0}}}}while(0);c[d+40>>2]=v;v=c[124232]|0;if((c[v+66444>>2]|0)!=0){g=0;u=v;do{c[d+44+(g<<2)>>2]=dz(b|0,u+66448+(g*4168|0)|0)|0;g=g+1|0;u=c[124232]|0;}while(g>>>0<(c[u+66444>>2]|0)>>>0)}u=d+76|0;v3(u|0,-1|0,16);jw(b,u,34832);g=f|0;if(a>>>0>1){bN(g|0,64,33496,(h=i,i=i+8|0,c[h>>2]=a,h)|0)|0;i=h;jw(b,u,g);w=0}else{w=0}while(1){u=w+1|0;bN(g|0,64,32456,(h=i,i=i+8|0,c[h>>2]=u,h)|0)|0;i=h;f=d+92+(w<<4)|0;v3(f|0,-1|0,16);jw(b,f,g);if((w|0)!=0&u>>>0<a>>>0){v=a-w|0;bN(g|0,64,33496,(h=i,i=i+8|0,c[h>>2]=v,h)|0)|0;i=h;jw(b,f,g)}if(u>>>0<16){w=u}else{break}}w=d+348|0;v3(w|0,-1|0,16);jw(b,w,31944);bN(g|0,64,31192,(h=i,i=i+8|0,c[h>>2]=1,h)|0)|0;i=h;w=d+364|0;v3(w|0,-1|0,16);jw(b,w,g);bN(g|0,64,31192,(h=i,i=i+8|0,c[h>>2]=2,h)|0)|0;i=h;w=d+380|0;v3(w|0,-1|0,16);jw(b,w,g);bN(g|0,64,31192,(h=i,i=i+8|0,c[h>>2]=3,h)|0)|0;i=h;w=d+396|0;v3(w|0,-1|0,16);jw(b,w,g);bN(g|0,64,31192,(h=i,i=i+8|0,c[h>>2]=4,h)|0)|0;i=h;w=d+412|0;v3(w|0,-1|0,16);jw(b,w,g);bN(g|0,64,31192,(h=i,i=i+8|0,c[h>>2]=5,h)|0)|0;i=h;w=d+428|0;v3(w|0,-1|0,16);jw(b,w,g);bN(g|0,64,31192,(h=i,i=i+8|0,c[h>>2]=6,h)|0)|0;i=h;h=d+444|0;v3(h|0,-1|0,16);jw(b,h,g);d0(0);i=e;return}function jw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+320|0;f=e|0;g=e+64|0;bN(g|0,64,30560,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=30200,h)|0)|0;i=h;j=e+128|0;bN(j|0,64,30560,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=38688,h)|0)|0;i=h;k=e+192|0;bN(k|0,64,30560,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=40640,h)|0)|0;i=h;l=e+256|0;bN(l|0,64,30560,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=45208,h)|0)|0;i=h;d=b|0;if((c[d>>2]|0)<0){m=f|0;n=(c[124232]|0)+5|0;bN(m|0,64,30560,(h=i,i=i+16|0,c[h>>2]=n,c[h+8>>2]=g,h)|0)|0;i=h;n=dz(a|0,m|0)|0;L2467:do{if((n|0)>-1){o=n}else{p=0;while(1){if(p>>>0>=2){o=-1;break L2467}bN(m|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(p<<2)>>2],c[h+8>>2]=g,h)|0)|0;i=h;q=dz(a|0,m|0)|0;if((q|0)>-1){o=q;break}else{p=p+1|0}}}}while(0);c[d>>2]=o}o=b+8|0;if((c[o>>2]|0)<0){d=f|0;m=(c[124232]|0)+5|0;bN(d|0,64,30560,(h=i,i=i+16|0,c[h>>2]=m,c[h+8>>2]=j,h)|0)|0;i=h;m=dz(a|0,d|0)|0;L2475:do{if((m|0)>-1){r=m}else{g=0;while(1){if(g>>>0>=2){r=-1;break L2475}bN(d|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(g<<2)>>2],c[h+8>>2]=j,h)|0)|0;i=h;n=dz(a|0,d|0)|0;if((n|0)>-1){r=n;break}else{g=g+1|0}}}}while(0);c[o>>2]=r}r=b+4|0;if((c[r>>2]|0)<0){o=f|0;d=(c[124232]|0)+5|0;bN(o|0,64,30560,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=k,h)|0)|0;i=h;d=dz(a|0,o|0)|0;L2483:do{if((d|0)>-1){s=d}else{j=0;while(1){if(j>>>0>=2){s=-1;break L2483}bN(o|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(j<<2)>>2],c[h+8>>2]=k,h)|0)|0;i=h;m=dz(a|0,o|0)|0;if((m|0)>-1){s=m;break}else{j=j+1|0}}}}while(0);c[r>>2]=s}s=b+12|0;if((c[s>>2]|0)>=0){i=e;return}b=f|0;bN(b|0,64,30560,(h=i,i=i+16|0,c[h>>2]=(c[124232]|0)+5,c[h+8>>2]=l,h)|0)|0;i=h;f=dz(a|0,b|0)|0;L2492:do{if((f|0)>-1){t=f}else{r=0;while(1){if(r>>>0>=2){t=-1;break L2492}bN(b|0,64,30560,(h=i,i=i+16|0,c[h>>2]=c[9072+(r<<2)>>2],c[h+8>>2]=l,h)|0)|0;i=h;o=eu(a|0,b|0)|0;if((o|0)>-1){t=o;break}else{r=r+1|0}}}}while(0);c[s>>2]=t;i=e;return}function jx(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0;f=i;i=i+72|0;g=f|0;h=f+8|0;j=f+48|0;k=f+64|0;l=f+16|0;v3(l|0,0,32);do{if((a[496960]&1)!=0){if((bu(e|0,23792)|0)!=0){break}m=((c[124234]|0)*10|0)+((c[124236]|0)*100|0)|0;if((m|0)==300){n=130}else if((m|0)==320){n=150}else if((m|0)==310){n=140}else{n=m}bN(l|0,32,23496,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;if((a[607928]&1)==0){break}m=c[191244]|0;p=(m|0)!=0?m:c[q>>2]|0;eb(p|0,23232,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;p=c[191244]|0;m=(p|0)!=0?p:c[q>>2]|0;aZ(m|0)|0}}while(0);n=j|0;c[n>>2]=l;c[j+4>>2]=d;c[j+8>>2]=e;bR(b|0,3,n|0,0);bc(b|0);cP(b|0,35713,k|0);c[g>>2]=0;cP(b|0,35716,h|0);n=c[h>>2]|0;if((n|0)==0){r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}h=vZ(n)|0;if((h|0)==0){r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}d8(b|0,n|0,g|0,h|0);do{if((c[g>>2]|0)>0){if((a[607928]&1)==0){break}n=c[191244]|0;b=(n|0)!=0?n:c[q>>2]|0;eb(b|0,22984,(o=i,i=i+8|0,c[o>>2]=h,o)|0)|0;i=o;b=c[191244]|0;n=(b|0)!=0?b:c[q>>2]|0;aZ(n|0)|0}}while(0);v_(h);r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}function jy(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;j=i;k=e|0;l=e+4|0;m=e+9|0;switch(d[m]|0){case 6:{n=d[e+8|0]<<2;o=((ac(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 0:{n=d[e+8|0]|0;o=((ac(c[k>>2]|0,n)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 3:{n=d[e+8|0]|0;o=((ac(c[k>>2]|0,n)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 4:{n=d[e+8|0]<<1;o=((ac(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 2:{n=(d[e+8|0]|0)*3|0;o=((ac(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};default:{o=0;p=0}}n=o+1|0;if((ac(c[l>>2]|0,n)|0)>>>0>g>>>0){r=0;i=j;return r|0}g=vZ(o)|0;do{if((g|0)!=0){if((c[g-4>>2]&3|0)==0){break}v3(g|0,0,o|0)}}while(0);s=vZ(o)|0;L2535:do{if((s|0)==0){t=c[q>>2]|0;eb(t|0,47208,(u=i,i=i+8|0,c[u>>2]=394,u)|0)|0;i=u;v=0}else{if((c[s-4>>2]&3|0)!=0){v3(s|0,0,o|0)}if((c[l>>2]|0)==0){v=1;break}t=e+8|0;w=(p|0)==0;x=(o|0)==0;y=0;z=f;A=b;L2542:while(1){L2544:do{switch(d[z]|0){case 0:{v6(s|0,z+1|0,o)|0;break};case 1:{if(w){B=0}else{C=0;while(1){D=C+1|0;a[s+C|0]=a[z+D|0]|0;if(D>>>0<p>>>0){C=D}else{B=p;break}}}if(B>>>0<o>>>0){E=B}else{break L2544}while(1){C=E+1|0;a[s+E|0]=(a[z+C|0]|0)+(a[s+(E-B)|0]|0)&255;if(C>>>0<o>>>0){E=C}else{break}}break};case 2:{if(x){break L2544}else{F=0}while(1){C=F+1|0;a[s+F|0]=(a[z+C|0]|0)+(a[g+F|0]|0)&255;if(C>>>0<o>>>0){F=C}else{break}}break};case 3:{if(w){G=0}else{C=0;while(1){D=C+1|0;a[s+C|0]=((d[g+C|0]|0)>>>1)+(a[z+D|0]|0)&255;if(D>>>0<p>>>0){C=D}else{G=p;break}}}if(G>>>0<o>>>0){H=G}else{break L2544}while(1){C=H+1|0;a[s+H|0]=(((d[g+H|0]|0)+(d[s+(H-G)|0]|0)|0)>>>1)+(d[z+C|0]|0)&255;if(C>>>0<o>>>0){H=C}else{break}}break};case 4:{if(w){I=0}else{C=0;while(1){D=C+1|0;a[s+C|0]=(a[z+D|0]|0)+(a[g+C|0]|0)&255;if(D>>>0<p>>>0){C=D}else{I=p;break}}}if(I>>>0<o>>>0){J=I}else{break L2544}while(1){C=J-I|0;D=a[s+C|0]|0;K=D&255;L=a[g+J|0]|0;M=L&255;N=a[g+C|0]|0;C=N&255;O=M+K-C|0;P=O-K|0;K=(P|0)>-1?P:-P|0;P=O-M|0;M=(P|0)>-1?P:-P|0;P=O-C|0;C=(P|0)>-1?P:-P|0;if((K|0)>(M|0)|(K|0)>(C|0)){Q=(M|0)>(C|0)?N:L}else{Q=D}D=J+1|0;a[s+J|0]=(a[z+D|0]|0)+Q&255;if(D>>>0<o>>>0){J=D}else{break}}break};default:{break L2542}}}while(0);L2574:do{switch(a[m]|0){case 0:{D=c[k>>2]|0;L=a[t]|0;N=L&255;if(L<<24>>24==16){if((D|0)==0){break L2574}else{R=0}while(1){c[A+(R<<2)>>2]=(d[s+(R<<1)|0]|0)*65793|0|-16777216;R=R+1|0;if(R>>>0>=D>>>0){break L2574}}}L=(1<<N)-1|0;if((D|0)==0){break L2574}C=8-N|0;M=(c[9608+(N<<2)>>2]|0)*65793|0;K=0;P=0;while(1){c[A+(P<<2)>>2]=ac(M,(d[s+(K>>>3)|0]|0)>>>((C-(K&7)|0)>>>0)&L)|0|-16777216;O=P+1|0;if(O>>>0<D>>>0){K=K+N|0;P=O}else{break}}break};case 3:{P=c[k>>2]|0;N=d[t]|0;K=(1<<N)-1|0;if((P|0)==0){break L2574}D=8-N|0;L=0;C=0;while(1){c[A+(C<<2)>>2]=c[h+(((d[s+(L>>>3)|0]|0)>>>((D-(L&7)|0)>>>0)&K)<<2)>>2];M=C+1|0;if(M>>>0<P>>>0){L=L+N|0;C=M}else{break}}break};case 4:{C=c[k>>2]|0;N=(d[t]|0)>>>3;if((C|0)==0){break L2574}L=N<<1;P=0;K=s;while(1){c[A+(P<<2)>>2]=d[K+N|0]<<24|((d[K]|0)*65793|0);D=P+1|0;if(D>>>0<C>>>0){P=D;K=K+L|0}else{break}}break};case 6:{L=c[k>>2]|0;K=(d[t]|0)>>>3;if((L|0)==0){break L2574}P=K<<1;C=P+K|0;N=C+K|0;D=0;M=s;while(1){c[A+(D<<2)>>2]=d[M+K|0]<<8|d[M]<<16|d[M+P|0]|d[M+C|0]<<24;O=D+1|0;if(O>>>0<L>>>0){D=O;M=M+N|0}else{break}}break};case 2:{N=c[k>>2]|0;M=(d[t]|0)>>>3;if((N|0)==0){break L2574}D=M<<1;L=D+M|0;C=0;P=s;while(1){c[A+(C<<2)>>2]=d[P]<<16|d[P+M|0]<<8|d[P+D|0]|-16777216;K=C+1|0;if(K>>>0<N>>>0){C=K;P=P+L|0}else{break}}break};default:{}}}while(0);v6(g|0,s|0,o)|0;L=y+1|0;if(L>>>0<(c[l>>2]|0)>>>0){y=L;z=z+n|0;A=A+(c[k>>2]<<2)|0}else{v=1;break L2535}}eb(c[q>>2]|0,47208,(u=i,i=i+8|0,c[u>>2]=439,u)|0)|0;i=u;v=0}}while(0);v_(s);v_(g);r=v;i=j;return r|0}function jz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;i=i+16|0;d=b|0;e=b+8|0;if((a|0)==0){f=-2;i=b;return f|0}g=c[a+28>>2]|0;if((g|0)==0){f=-2;i=b;return f|0}h=g;j=(c[h+11008>>2]|0)>0?9:8;k=a+4|0;l=c[k>>2]|0;m=h+11e3|0;n=c[m>>2]|0;c[m>>2]=0;m=h+43780|0;if((c[m>>2]|0)<0){f=-3;i=b;return f|0}o=h+11004|0;c[o>>2]=c[o>>2]|1;if((n|0)!=0){c[d>>2]=c[k>>2];n=a+16|0;c[e>>2]=c[n>>2];o=g;p=a|0;q=a+12|0;r=c[q>>2]|0;s=jA(o,c[p>>2]|0,d,r,r,e,j|4)|0;c[m>>2]=s;r=c[d>>2]|0;c[p>>2]=(c[p>>2]|0)+r;c[k>>2]=(c[k>>2]|0)-r;p=a+8|0;c[p>>2]=(c[p>>2]|0)+r;c[a+40>>2]=c[o+28>>2];o=c[e>>2]|0;c[q>>2]=(c[q>>2]|0)+o;c[n>>2]=(c[n>>2]|0)-o;n=a+20|0;c[n>>2]=(c[n>>2]|0)+o;if((s|0)<0){f=-3;i=b;return f|0}if((s|0)==0){f=1;i=b;return f|0}c[m>>2]=-1;f=-5;i=b;return f|0}s=h+10996|0;o=c[s>>2]|0;if((o|0)!=0){n=a+16|0;q=c[n>>2]|0;r=o>>>0<q>>>0?o:q;q=a+12|0;o=c[q>>2]|0;p=h+10992|0;t=(c[p>>2]|0)+(h+11012)|0;v6(o|0,t|0,r)|0;c[q>>2]=(c[q>>2]|0)+r;c[n>>2]=(c[n>>2]|0)-r;n=a+20|0;c[n>>2]=(c[n>>2]|0)+r;n=c[s>>2]|0;c[s>>2]=n-r;c[p>>2]=(c[p>>2]|0)+r&32767;if((c[m>>2]|0)!=0){f=0;i=b;return f|0}f=(n|0)==(r|0)|0;i=b;return f|0}r=h+10992|0;n=g;g=a|0;p=h+11012|0;q=a+8|0;t=n+28|0;o=a+40|0;u=a+16|0;v=a+12|0;w=a+20|0;a=c[r>>2]|0;L2631:do{if((l|0)==0){x=a;while(1){c[d>>2]=c[k>>2];c[e>>2]=32768-x;y=jA(n,c[g>>2]|0,d,p,h+11012+x|0,e,j)|0;c[m>>2]=y;z=c[d>>2]|0;c[g>>2]=(c[g>>2]|0)+z;c[k>>2]=(c[k>>2]|0)-z;c[q>>2]=(c[q>>2]|0)+z;c[o>>2]=c[t>>2];z=c[e>>2]|0;c[s>>2]=z;A=c[u>>2]|0;B=z>>>0<A>>>0?z:A;A=c[v>>2]|0;z=(c[r>>2]|0)+(h+11012)|0;v6(A|0,z|0,B)|0;c[v>>2]=(c[v>>2]|0)+B;c[u>>2]=(c[u>>2]|0)-B;c[w>>2]=(c[w>>2]|0)+B;z=(c[s>>2]|0)-B|0;c[s>>2]=z;A=(c[r>>2]|0)+B&32767;c[r>>2]=A;if((y|0)<0){f=-3;C=1884;break}if((y|0)==1){f=-5;C=1885;break}else if((y|0)==0){D=z;break L2631}if((c[u>>2]|0)==0){f=-5;C=1886;break}else{x=A}}if((C|0)==1885){i=b;return f|0}else if((C|0)==1886){i=b;return f|0}else if((C|0)==1884){i=b;return f|0}}else{x=a;while(1){c[d>>2]=c[k>>2];c[e>>2]=32768-x;A=jA(n,c[g>>2]|0,d,p,h+11012+x|0,e,j)|0;c[m>>2]=A;z=c[d>>2]|0;c[g>>2]=(c[g>>2]|0)+z;c[k>>2]=(c[k>>2]|0)-z;c[q>>2]=(c[q>>2]|0)+z;c[o>>2]=c[t>>2];z=c[e>>2]|0;c[s>>2]=z;y=c[u>>2]|0;B=z>>>0<y>>>0?z:y;y=c[v>>2]|0;z=(c[r>>2]|0)+(h+11012)|0;v6(y|0,z|0,B)|0;c[v>>2]=(c[v>>2]|0)+B;c[u>>2]=(c[u>>2]|0)-B;c[w>>2]=(c[w>>2]|0)+B;z=(c[s>>2]|0)-B|0;c[s>>2]=z;y=(c[r>>2]|0)+B&32767;c[r>>2]=y;if((A|0)<0){f=-3;C=1887;break}if((A|0)==0){D=z;break L2631}if((c[u>>2]|0)==0){f=-5;C=1888;break}else{x=y}}if((C|0)==1888){i=b;return f|0}else if((C|0)==1887){i=b;return f|0}}}while(0);f=(D|0)!=0?-5:1;i=b;return f|0}function jA(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gg=0,gh=0,gi=0,gj=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0,hB=0,hC=0,hD=0,hE=0,hF=0,hG=0,hH=0,hI=0,hJ=0,hK=0,hL=0,hM=0,hN=0,hO=0,hP=0,hQ=0,hR=0,hS=0,hT=0,hU=0,hV=0,hW=0,hX=0,hY=0,hZ=0,h_=0,h$=0,h0=0,h1=0,h2=0,h3=0,h4=0,h5=0,h6=0,h7=0,h8=0,h9=0,ia=0,ib=0,ic=0,id=0,ie=0,ig=0,ih=0,ii=0,ij=0,ik=0,il=0,im=0,io=0,ip=0,iq=0,ir=0,is=0,it=0,iu=0,iv=0,iw=0,ix=0,iy=0,iz=0,iA=0,iB=0,iC=0,iD=0,iE=0,iF=0,iG=0,iH=0,iI=0,iJ=0,iK=0,iL=0,iM=0,iN=0,iO=0,iP=0,iQ=0,iR=0,iS=0,iT=0,iU=0,iV=0,iW=0,iX=0,iY=0,iZ=0,i_=0,i$=0,i0=0,i1=0,i2=0,i3=0,i4=0,i5=0,i6=0,i7=0,i8=0,i9=0,ja=0,jb=0,jc=0,jd=0,je=0,jf=0,jg=0,jh=0,ji=0,jj=0,jk=0,jl=0,jm=0,jn=0,jo=0,jp=0,jq=0,jr=0,js=0,jt=0,ju=0,jv=0,jw=0,jx=0,jy=0,jz=0,jA=0,jB=0,jC=0,jD=0,jE=0,jF=0,jG=0,jH=0,jI=0,jJ=0,jK=0,jL=0,jM=0,jN=0,jO=0,jP=0,jQ=0,jR=0,jS=0,jT=0,jU=0,jV=0,jW=0,jX=0,jY=0,jZ=0,j_=0,j$=0,j0=0,j1=0,j2=0,j3=0,j4=0,j5=0,j6=0,j7=0,j8=0,j9=0,ka=0,kb=0,kc=0,kd=0,ke=0,kf=0,kg=0,kh=0,ki=0,kj=0,kk=0,kl=0,km=0,kn=0,ko=0,kp=0,kq=0,kr=0,ks=0,kt=0,ku=0,kv=0,kw=0,kx=0,ky=0,kz=0,kA=0,kB=0,kC=0,kD=0,kE=0,kF=0,kG=0,kH=0,kI=0,kJ=0,kK=0,kL=0,kM=0,kN=0,kO=0,kP=0,kQ=0,kR=0,kS=0,kT=0,kU=0,kV=0,kW=0,kX=0,kY=0,kZ=0,k_=0,k$=0,k0=0,k1=0,k2=0,k3=0,k4=0,k5=0,k6=0,k7=0,k8=0,k9=0,la=0,lb=0,lc=0,ld=0,le=0,lf=0,lg=0,lh=0,li=0,lj=0,lk=0,ll=0,lm=0,ln=0,lo=0,lp=0,lq=0,lr=0,ls=0,lt=0,lu=0,lv=0,lw=0,lx=0,ly=0,lz=0,lA=0,lB=0,lC=0,lD=0,lE=0,lF=0,lG=0,lH=0,lI=0,lJ=0,lK=0,lL=0,lM=0,lN=0,lO=0,lP=0,lQ=0,lR=0,lS=0,lT=0,lU=0,lV=0,lW=0,lX=0,lY=0,lZ=0,l_=0,l$=0,l0=0,l1=0,l2=0,l3=0,l4=0,l5=0,l6=0,l7=0,l8=0,l9=0,ma=0,mb=0,mc=0,md=0,me=0,mf=0,mg=0,mh=0,mi=0,mj=0,mk=0,ml=0,mm=0,mn=0,mo=0,mp=0,mq=0,mr=0,ms=0,mt=0,mu=0,mv=0,mw=0,mx=0,my=0,mz=0,mA=0,mB=0,mC=0,mD=0,mE=0,mF=0,mG=0,mH=0,mI=0,mJ=0,mK=0,mL=0,mM=0,mN=0,mO=0,mP=0,mQ=0,mR=0,mS=0,mT=0,mU=0,mV=0,mW=0,mX=0,mY=0,mZ=0,m_=0,m$=0,m0=0,m1=0,m2=0,m3=0,m4=0,m5=0;m=i;i=i+136|0;n=m|0;o=m+72|0;p=c[g>>2]|0;q=f+p|0;r=c[k>>2]|0;s=j+r|0;t=(l&4|0)!=0;if(t){u=-1}else{u=j+~h+r|0}r=u+1|0;if((r&u|0)!=0|j>>>0<h>>>0){c[k>>2]=0;c[g>>2]=0;v=-3;i=m;return v|0}w=e+4|0;x=c[w>>2]|0;z=e+56|0;A=c[z>>2]|0;B=e+32|0;C=c[B>>2]|0;D=e+36|0;E=c[D>>2]|0;F=e+40|0;G=c[F>>2]|0;H=e+60|0;I=c[H>>2]|0;J=e|0;L2657:do{switch(c[J>>2]|0){case 52:{K=x;L=C;M=E;N=G;O=A;P=I;Q=f;R=j;S=1973;break};case 0:{c[e+12>>2]=0;T=e+8|0;c[T>>2]=0;c[e+28>>2]=1;c[e+16>>2]=1;if((l&1|0)==0){U=0;V=0;W=0;X=0;Y=0;Z=I;_=f;$=j;S=1924;break L2657}if((p|0)<1){aa=0;ab=0;ac=0;ad=0;ae=0;S=1903;break L2657}c[T>>2]=d[f]|0;af=0;ag=0;ah=0;ai=0;aj=0;ak=f+1|0;S=1909;break};case 3:{if((p|0)<=0){al=x;am=C;an=E;ao=G;ap=A;aq=I;ar=f;as=j;S=1926;break L2657}at=x;au=C;av=E;aw=G;ax=A;ay=d[f]|0;az=I;aA=f+1|0;aB=j;S=1931;break};case 25:{if((p|0)<=0){aC=x;aD=C;aE=E;aF=G;aG=A;aH=I;aI=f;aJ=j;S=2117;break L2657}aK=d[f]|0;aL=x;aM=C;aN=E;aO=G;aP=A;aQ=I;aR=f+1|0;aS=j;S=2122;break};case 26:{if((p|0)<=0){aT=x;aU=C;aV=E;aW=G;aX=A;aY=I;aZ=f;a_=j;S=2133;break L2657}a$=d[f]|0;a0=x;a1=C;a2=E;a3=G;a4=A;a5=I;a6=f+1|0;a7=j;S=2138;break};case 18:{if((p|0)<=0){a8=x;a9=C;ba=E;bb=G;bc=A;bd=I;be=f;bf=j;S=2060;break L2657}bg=d[f]|0;bh=x;bi=C;bj=E;bk=G;bl=A;bm=I;bn=f+1|0;bo=j;S=2065;break};case 21:{bp=x;bq=C;br=E;bs=G;bt=A;bu=I;bv=f;bw=j;S=2070;break};case 6:{if((p|0)<=0){bx=x;by=C;bz=E;bA=G;bB=A;bC=I;bD=f;bE=j;S=1946;break L2657}bF=x;bG=C;bH=E;bI=G;bJ=A;bK=d[f]|0;bL=I;bM=f+1|0;bN=j;S=1951;break};case 51:{if((p|0)<=0){bO=x;bP=C;bQ=E;bR=G;bS=A;bT=I;bU=f;bV=j;S=1966;break L2657}bW=x;bX=C;bY=E;bZ=G;b_=A;b$=d[f]|0;b0=I;b1=f+1|0;b2=j;S=1971;break};case 2:{if((p|0)<=0){b3=x;b4=C;b5=E;b6=G;b7=A;b8=f;S=1910;break L2657}T=d[f]|0;c[e+12>>2]=T;b9=x;ca=C;cb=G;cc=A;cd=f+1|0;ce=T;S=1916;break};case 27:{if((p|0)<=0){cf=x;cg=C;ch=E;ci=G;cj=A;ck=I;cl=f;cm=j;S=2146;break L2657}cn=d[f]|0;co=x;cp=C;cq=E;cr=G;cs=A;ct=I;cu=f+1|0;cv=j;S=2151;break};case 37:{cw=x;cx=C;cy=E;cz=G;cA=A;cB=I;cC=f;cD=j;S=2154;break};case 53:{cE=x;cF=C;cG=E;cH=G;cI=A;cJ=I;cK=f;cL=j;S=2157;break};case 17:{cM=x;cN=C;cO=E;cP=G;cQ=A;cR=I;cS=f;cT=j;S=2057;break};case 39:{cU=x;cV=C;cW=E;cX=G;cY=A;cZ=I;c_=f;c$=j;S=1962;break};case 16:{if((p|0)<=0){c0=x;c1=C;c2=E;c3=G;c4=A;c5=I;c6=f;c7=j;S=2044;break L2657}c8=d[f]|0;c9=x;da=C;db=E;dc=G;dd=A;de=I;df=f+1|0;dg=j;S=2049;break};case 5:{if((p|0)<=0){dh=x;di=C;dj=E;dk=G;dl=A;dm=I;dn=f;dp=j;S=1935;break L2657}dq=x;dr=C;ds=E;dt=G;du=A;dv=d[f]|0;dw=I;dx=f+1|0;dy=j;S=1940;break};case 1:{if((p|0)<=0){aa=x;ab=C;ac=E;ad=G;ae=A;S=1903;break L2657}c[e+8>>2]=d[f]|0;af=x;ag=C;ah=E;ai=G;aj=A;ak=f+1|0;S=1909;break};case 14:{if((p|0)<=0){dz=x;dA=C;dB=E;dC=G;dD=A;dE=I;dF=f;dG=j;S=1999;break L2657}dH=x;dI=C;dJ=E;dK=d[f]|0;dL=G;dM=A;dN=I;dO=f+1|0;dP=j;S=2004;break};case 36:{dQ=x;dR=C;dS=E;dT=G;dU=A;dV=f;S=1923;break};case 9:{dW=x;dX=C;dY=E;dZ=G;d_=A;d$=I;d0=f;d1=j;S=1977;break};case 38:{d2=x;d3=C;d4=E;d5=G;d6=A;d7=I;d8=f;d9=j;S=1979;break};case 40:{ea=x;eb=C;ec=E;ed=G;ee=A;ef=I;eg=f;eh=j;S=1982;break};case 10:{ei=x;ej=C;ek=E;el=G;em=A;en=I;eo=f;ep=j;S=1984;break};case 32:{if((p|0)<=0){eq=x;er=C;es=E;et=G;eu=A;ev=I;ew=f;ex=j;S=2169;break L2657}ey=d[f]|0;ez=x;eA=C;eB=E;eC=G;eD=A;eE=I;eF=f+1|0;eG=j;S=2174;break};case 41:{if((p|0)<=0){eH=x;eI=C;eJ=E;eK=G;eL=A;eM=I;eN=f;eO=j;S=2180;break L2657}eP=d[f]|0;eQ=x;eR=C;eS=E;eT=G;eU=A;eV=I;eW=f+1|0;eX=j;S=2185;break};case 42:{if((p|0)<=0){eY=x;eZ=C;e_=E;e$=G;e0=A;e1=I;e2=f;e3=j;S=2188;break L2657}e4=d[f]|0;e5=x;e6=C;e7=E;e8=G;e9=A;fa=I;fb=f+1|0;fc=j;S=2193;break};case 34:{fd=x;fe=C;ff=E;fg=G;fh=A;fi=I;fj=f;fk=j;S=2194;break};case 23:{if((p|0)<=0){fl=x;fm=C;fn=E;fo=G;fp=A;fq=I;fr=f;fs=j;S=2083;break L2657}ft=d[f]|0;fu=x;fv=C;fw=E;fx=G;fy=A;fz=I;fA=f+1|0;fB=j;S=2088;break};case 24:{fC=x;fD=C;fE=E;fF=G;fG=A;fH=I;fI=f;fJ=j;S=2094;break};case 35:{fK=x;fL=C;fM=E;fN=G;fO=A;fP=I;fQ=f;fR=j;S=2014;break};case 11:{if((p|0)<=0){fS=x;fT=C;fU=E;fV=G;fW=A;fX=I;fY=f;fZ=j;S=1988;break L2657}f_=x;f$=C;f0=E;f1=G;f2=d[f]|0;f3=A;f4=I;f5=f+1|0;f6=j;S=1993;break};case 7:{if((p|0)<=0){f7=x;f8=C;f9=E;ga=G;gb=A;gc=I;gd=f;ge=j;S=1954;break L2657}a[e+10528+E|0]=a[f]|0;gf=x;gg=C;gh=E;gi=G;gj=A;gk=I;gl=f+1|0;gm=j;S=1960;break};default:{gn=-1;go=x;gp=C;gq=E;gr=G;gs=A;gt=I;gu=f;gv=j;S=2195}}}while(0);do{if((S|0)==1903){if((l&2|0)==0){c[e+8>>2]=0;af=aa;ag=ab;ah=ac;ai=ad;aj=ae;ak=f;S=1909;break}else{c[J>>2]=1;gn=1;go=aa;gp=ab;gq=ac;gr=ad;gs=ae;gt=I;gu=f;gv=j;S=2195;break}}}while(0);do{if((S|0)==1909){if(ak>>>0>=q>>>0){b3=af;b4=ag;b5=ah;b6=ai;b7=aj;b8=ak;S=1910;break}ae=d[ak]|0;c[e+12>>2]=ae;b9=af;ca=ag;cb=ai;cc=aj;cd=ak+1|0;ce=ae;S=1916}}while(0);do{if((S|0)==1910){if((l&2|0)==0){c[e+12>>2]=0;b9=b3;ca=b4;cb=b6;cc=b7;cd=b8;ce=0;S=1916;break}else{c[J>>2]=2;gn=1;go=b3;gp=b4;gq=b5;gr=b6;gs=b7;gt=I;gu=b8;gv=j;S=2195;break}}}while(0);if((S|0)==1916){b8=c[e+8>>2]|0;if((((b8<<8|ce)>>>0)%31|0|ce&32|0)==0){gw=(b8&15|0)!=8|0}else{gw=1}if(t){gx=gw}else{ce=1<<(b8>>>4)+8;if(ce>>>0>32768){gy=1}else{gy=r>>>0<ce>>>0|0}gx=gy|gw}if((gx|0)==0){U=b9;V=ca;W=0;X=cb;Y=cc;Z=I;_=cd;$=j;S=1924}else{dQ=b9;dR=ca;dS=gx;dT=cb;dU=cc;dV=cd;S=1923}}if((S|0)==1923){c[J>>2]=36;gn=-1;go=dQ;gp=dR;gq=dS;gr=dT;gs=dU;gt=I;gu=dV;gv=j;S=2195}L2723:while(1){do{if((S|0)==1973){S=0;if(R>>>0<s>>>0){a[R]=L&255;gz=K;gA=L;gB=M-1|0;gC=N;gD=O;gE=P;gF=Q;gG=R+1|0;S=1963;break}else{c[J>>2]=52;gn=2;go=K;gp=L;gq=M;gr=N;gs=O;gt=P;gu=Q;gv=R;S=2195;continue L2723}}else if((S|0)==1931){S=0;dV=ay<<at|ax;I=at+8|0;if(I>>>0<3){gH=I;gI=au;gJ=av;gK=aw;gL=dV;gM=az;gN=aA;gO=aB;S=1925}else{gP=I;gQ=au;gR=av;gS=aw;gT=dV;gU=az;gV=aA;gW=aB;S=1932}}else if((S|0)==1926){S=0;if((l&2|0)==0){at=al;au=am;av=an;aw=ao;ax=ap;ay=0;az=aq;aA=ar;aB=as;S=1931;continue L2723}c[J>>2]=3;gn=1;go=al;gp=am;gq=an;gr=ao;gs=ap;gt=aq;gu=ar;gv=as;S=2195;continue L2723}else if((S|0)==2117){S=0;if((l&2|0)==0){aK=0;aL=aC;aM=aD;aN=aE;aO=aF;aP=aG;aQ=aH;aR=aI;aS=aJ;S=2122;continue L2723}c[J>>2]=25;gn=1;go=aC;gp=aD;gq=aE;gr=aF;gs=aG;gt=aH;gu=aI;gv=aJ;S=2195;continue L2723}else if((S|0)==2122){S=0;dV=aK<<aL|aP;I=aL+8|0;if(I>>>0<aO>>>0){gX=I;gY=aM;gZ=aN;g_=aO;g$=dV;g0=aQ;g1=aR;g2=aS;S=2116}else{g3=I;g4=aM;g5=aN;g6=aO;g7=dV;g8=aQ;g9=aR;ha=aS;S=2123}}else if((S|0)==2133){S=0;if((l&2|0)==0){a$=0;a0=aT;a1=aU;a2=aV;a3=aW;a4=aX;a5=aY;a6=aZ;a7=a_;S=2138;continue L2723}c[J>>2]=26;gn=1;go=aT;gp=aU;gq=aV;gr=aW;gs=aX;gt=aY;gu=aZ;gv=a_;S=2195;continue L2723}else if((S|0)==2138){S=0;dV=a$<<a0|a4;I=a0+8|0;if(I>>>0<15){hb=I;hc=a1;hd=a2;he=a3;hf=dV;hg=a5;hh=a6;hi=a7;S=2126}else{hj=I;hk=a2;hl=dV;hm=a5;hn=a6;ho=a7;S=2140}}else if((S|0)==2065){S=0;dV=bg<<bh|bl;I=bh+8|0;if(I>>>0<bk>>>0){hp=I;hq=bi;hr=bj;hs=bk;ht=dV;hu=bm;hv=bn;hw=bo;S=2059}else{hx=I;hy=bi;hz=bj;hA=bk;hB=dV;hC=bm;hD=bn;hE=bo;S=2066}}else if((S|0)==2070){S=0;c[J>>2]=21;gn=-1;go=bp;gp=bq;gq=br;gr=bs;gs=bt;gt=bu;gu=bv;gv=bw;S=2195;continue L2723}else if((S|0)==1946){S=0;if((l&2|0)==0){bF=bx;bG=by;bH=bz;bI=bA;bJ=bB;bK=0;bL=bC;bM=bD;bN=bE;S=1951;continue L2723}c[J>>2]=6;gn=1;go=bx;gp=by;gq=bz;gr=bA;gs=bB;gt=bC;gu=bD;gv=bE;S=2195;continue L2723}else if((S|0)==1966){S=0;if((l&2|0)==0){bW=bO;bX=bP;bY=bQ;bZ=bR;b_=bS;b$=0;b0=bT;b1=bU;b2=bV;S=1971;continue L2723}c[J>>2]=51;gn=1;go=bO;gp=bP;gq=bQ;gr=bR;gs=bS;gt=bT;gu=bU;gv=bV;S=2195;continue L2723}else if((S|0)==1971){S=0;dV=b$<<bW|b_;I=bW+8|0;if(bW>>>0>4294967287){hF=I;hG=bX;hH=bY;hI=bZ;hJ=dV;hK=b0;hL=b1;hM=b2;S=1965}else{hN=I;hO=bY;hP=bZ;hQ=dV;hR=b0;hS=b1;hT=b2;S=1972}}else if((S|0)==2146){S=0;if((l&2|0)==0){cn=0;co=cf;cp=cg;cq=ch;cr=ci;cs=cj;ct=ck;cu=cl;cv=cm;S=2151;continue L2723}c[J>>2]=27;gn=1;go=cf;gp=cg;gq=ch;gr=ci;gs=cj;gt=ck;gu=cl;gv=cm;S=2195;continue L2723}else if((S|0)==2151){S=0;dV=cn<<co|cs;I=co+8|0;if(I>>>0<cr>>>0){hU=I;hV=cp;hW=cq;hX=cr;hY=dV;hZ=ct;h_=cu;h$=cv;S=2145}else{h0=I;h1=cp;h2=cq;h3=cr;h4=dV;h5=cu;h6=cv;S=2152}}else if((S|0)==2154){S=0;c[J>>2]=37;gn=-1;go=cw;gp=cx;gq=cy;gr=cz;gs=cA;gt=cB;gu=cC;gv=cD;S=2195;continue L2723}else if((S|0)==2157){S=0;if(cL>>>0<s>>>0){a[cL]=a[h+(cJ-cF&u)|0]|0;h7=cE;h8=cF;h9=cG;ia=cH;ib=cI;ic=cJ+1|0;id=cK;ie=cL+1|0;S=2156;break}else{c[J>>2]=53;gn=2;go=cE;gp=cF;gq=cG;gr=cH;gs=cI;gt=cJ;gu=cK;gv=cL;S=2195;continue L2723}}else if((S|0)==2057){S=0;c[J>>2]=17;gn=-1;go=cM;gp=cN;gq=cO;gr=cP;gs=cQ;gt=cR;gu=cS;gv=cT;S=2195;continue L2723}else if((S|0)==2060){S=0;if((l&2|0)==0){bg=0;bh=a8;bi=a9;bj=ba;bk=bb;bl=bc;bm=bd;bn=be;bo=bf;S=2065;continue L2723}c[J>>2]=18;gn=1;go=a8;gp=a9;gq=ba;gr=bb;gs=bc;gt=bd;gu=be;gv=bf;S=2195;continue L2723}else if((S|0)==1951){S=0;dV=bK<<bF|bJ;I=bF+8|0;if(bF>>>0>4294967287){ig=I;ih=bG;ii=bH;ij=bI;ik=dV;il=bL;im=bM;io=bN;S=1945}else{ip=I;iq=bG;ir=bH;is=bI;it=dV;iu=bL;iv=bM;iw=bN;S=1952}}else if((S|0)==1960){S=0;ix=gf;iy=gg;iz=gh+1|0;iA=gi;iB=gj;iC=gk;iD=gl;iE=gm;S=1942}else if((S|0)==1962){S=0;c[J>>2]=39;gn=-1;go=cU;gp=cV;gq=cW;gr=cX;gs=cY;gt=cZ;gu=c_;gv=c$;S=2195;continue L2723}else if((S|0)==2044){S=0;if((l&2|0)==0){c8=0;c9=c0;da=c1;db=c2;dc=c3;dd=c4;de=c5;df=c6;dg=c7;S=2049;continue L2723}c[J>>2]=16;gn=1;go=c0;gp=c1;gq=c2;gr=c3;gs=c4;gt=c5;gu=c6;gv=c7;S=2195;continue L2723}else if((S|0)==2049){S=0;dV=c8<<c9|dd;I=c9+8|0;if(I>>>0<15){iF=I;iG=da;iH=db;iI=dc;iJ=dV;iK=de;iL=df;iM=dg;S=2037}else{iN=I;iO=db;iP=dc;iQ=dV;iR=de;iS=df;iT=dg;S=2051}}else if((S|0)==1935){S=0;if((l&2|0)==0){dq=dh;dr=di;ds=dj;dt=dk;du=dl;dv=0;dw=dm;dx=dn;dy=dp;S=1940;continue L2723}c[J>>2]=5;gn=1;go=dh;gp=di;gq=dj;gr=dk;gs=dl;gt=dm;gu=dn;gv=dp;S=2195;continue L2723}else if((S|0)==1999){S=0;if((l&2|0)==0){dH=dz;dI=dA;dJ=dB;dK=0;dL=dC;dM=dD;dN=dE;dO=dF;dP=dG;S=2004;continue L2723}c[J>>2]=14;gn=1;go=dz;gp=dA;gq=dB;gr=dC;gs=dD;gt=dE;gu=dF;gv=dG;S=2195;continue L2723}else if((S|0)==2004){S=0;dV=dK<<dH|dM;I=dH+8|0;if(I>>>0<3){iU=I;iV=dI;iW=dJ;iX=dL;iY=dV;iZ=dN;i_=dO;i$=dP;S=1998}else{i0=I;i1=dI;i2=dJ;i3=dL;i4=dV;i5=dN;i6=dO;i7=dP;S=2005}}else if((S|0)==1924){S=0;if(U>>>0<3){gH=U;gI=V;gJ=W;gK=X;gL=Y;gM=Z;gN=_;gO=$;S=1925}else{gP=U;gQ=V;gR=W;gS=X;gT=Y;gU=Z;gV=_;gW=$;S=1932}}else if((S|0)==1977){S=0;if(d1>>>0<s>>>0){d2=dW;d3=dX;d4=dY;d5=dZ;d6=d_;d7=d$;d8=d0;d9=d1;S=1979;continue L2723}c[J>>2]=9;gn=2;go=dW;gp=dX;gq=dY;gr=dZ;gs=d_;gt=d$;gu=d0;gv=d1;S=2195;continue L2723}else if((S|0)==1979){S=0;if(d8>>>0<q>>>0){dV=s-d9|0;I=q-d8|0;dU=dV>>>0<I>>>0?dV:I;I=dU>>>0<d4>>>0?dU:d4;v6(d9|0,d8|0,I)|0;i8=d2;i9=d3;ja=d4-I|0;jb=d5;jc=d6;jd=d7;je=d8+I|0;jf=d9+I|0;S=1976;break}if((l&2|0)==0){ea=d2;eb=d3;ec=d4;ed=d5;ee=d6;ef=d7;eg=d8;eh=d9;S=1982;continue L2723}c[J>>2]=38;gn=1;go=d2;gp=d3;gq=d4;gr=d5;gs=d6;gt=d7;gu=d8;gv=d9;S=2195;continue L2723}else if((S|0)==1982){S=0;c[J>>2]=40;gn=-1;go=ea;gp=eb;gq=ec;gr=ed;gs=ee;gt=ef;gu=eg;gv=eh;S=2195;continue L2723}else if((S|0)==1984){S=0;c[J>>2]=10;gn=-1;go=ei;gp=ej;gq=ek;gr=el;gs=em;gt=en;gu=eo;gv=ep;S=2195;continue L2723}else if((S|0)==2169){S=0;if((l&2|0)==0){ey=0;ez=eq;eA=er;eB=es;eC=et;eD=eu;eE=ev;eF=ew;eG=ex;S=2174;continue L2723}c[J>>2]=32;gn=1;go=eq;gp=er;gq=es;gr=et;gs=eu;gt=ev;gu=ew;gv=ex;S=2195;continue L2723}else if((S|0)==2174){S=0;I=ey<<ez|eD;dU=ez+8|0;if(dU>>>0<(dU&7)>>>0){jg=dU;jh=eA;ji=eB;jj=eC;jk=I;jl=eE;jm=eF;jn=eG;S=2168}else{jo=dU;jp=eA;jq=eC;jr=I;js=eE;jt=eF;ju=eG;S=2175}}else if((S|0)==2180){S=0;if((l&2|0)==0){eP=0;eQ=eH;eR=eI;eS=eJ;eT=eK;eU=eL;eV=eM;eW=eN;eX=eO;S=2185;continue L2723}c[J>>2]=41;gn=1;go=eH;gp=eI;gq=eJ;gr=eK;gs=eL;gt=eM;gu=eN;gv=eO;S=2195;continue L2723}else if((S|0)==2185){S=0;I=eP<<eQ|eU;dU=eQ+8|0;if(eQ>>>0>4294967287){jv=dU;jw=eR;jx=eS;jy=eT;jz=I;jA=eV;jB=eW;jC=eX;S=2179}else{jD=dU;jE=eR;jF=eS;jG=eT;jH=I;jI=eV;jJ=eW;jK=eX;S=2186}}else if((S|0)==2188){S=0;if((l&2|0)==0){e4=0;e5=eY;e6=eZ;e7=e_;e8=e$;e9=e0;fa=e1;fb=e2;fc=e3;S=2193;continue L2723}c[J>>2]=42;gn=1;go=eY;gp=eZ;gq=e_;gr=e$;gs=e0;gt=e1;gu=e2;gv=e3;S=2195;continue L2723}else if((S|0)==2193){S=0;I=e+16|0;c[I>>2]=c[I>>2]<<8|e4;jL=e5;jM=e6;jN=e7+1|0;jO=e8;jP=e9;jQ=fa;jR=fb;jS=fc;S=2176}else if((S|0)==2194){S=0;c[J>>2]=34;gn=0;go=fd;gp=fe;gq=ff;gr=fg;gs=fh;gt=fi;gu=fj;gv=fk;S=2195;continue L2723}else if((S|0)==2195){S=0;c[w>>2]=go;c[z>>2]=gs;c[B>>2]=gp;c[D>>2]=gq;c[F>>2]=gr;c[H>>2]=gt;c[g>>2]=gu-f;jT=gv-j|0;c[k>>2]=jT;if((l&9|0)!=0&(gn|0)>-1){break L2723}else{v=gn;S=2211;break L2723}}else if((S|0)==2083){S=0;if((l&2|0)==0){ft=0;fu=fl;fv=fm;fw=fn;fx=fo;fy=fp;fz=fq;fA=fr;fB=fs;S=2088;continue L2723}c[J>>2]=23;gn=1;go=fl;gp=fm;gq=fn;gr=fo;gs=fp;gt=fq;gu=fr;gv=fs;S=2195;continue L2723}else if((S|0)==2088){S=0;I=ft<<fu|fy;dU=fu+8|0;if(dU>>>0<15){jU=dU;jV=fv;jW=fw;jX=fx;jY=I;jZ=fz;j_=fA;j$=fB;S=2076}else{j0=dU;j1=fv;j2=fx;j3=I;j4=fz;j5=fA;j6=fB;S=2090}}else if((S|0)==2094){S=0;if(fJ>>>0<s>>>0){a[fJ]=fE&255;j7=fC;j8=fD;j9=fE;ka=fF;kb=fG;kc=fH;kd=fI;ke=fJ+1|0;S=2097;break}else{c[J>>2]=24;gn=2;go=fC;gp=fD;gq=fE;gr=fF;gs=fG;gt=fH;gu=fI;gv=fJ;S=2195;continue L2723}}else if((S|0)==2014){S=0;c[J>>2]=35;gn=-1;go=fK;gp=fL;gq=fM;gr=fN;gs=fO;gt=fP;gu=fQ;gv=fR;S=2195;continue L2723}else if((S|0)==1988){S=0;if((l&2|0)==0){f_=fS;f$=fT;f0=fU;f1=fV;f2=0;f3=fW;f4=fX;f5=fY;f6=fZ;S=1993;continue L2723}c[J>>2]=11;gn=1;go=fS;gp=fT;gq=fU;gr=fV;gs=fW;gt=fX;gu=fY;gv=fZ;S=2195;continue L2723}else if((S|0)==1993){S=0;I=f2<<f_|f3;dU=f_+8|0;dV=a[48600+f0|0]|0;if(dU>>>0<dV<<24>>24>>>0){kf=dU;kg=f$;kh=f0;ki=f1;kj=I;kk=f4;kl=f5;km=f6;S=1987}else{kn=dU;ko=f$;kp=f0;kq=f1;kr=I;ks=f4;kt=f5;ku=f6;kv=dV;S=1994}}else if((S|0)==1940){S=0;dV=dv<<dq|du;I=dq+8|0;if(I>>>0<(I&7)>>>0){kw=I;kx=dr;ky=ds;kz=dt;kA=dV;kB=dw;kC=dx;kD=dy;S=1934}else{kE=I;kF=dr;kG=dt;kH=dV;kI=dw;kJ=dx;kK=dy;S=1941}}else if((S|0)==1954){S=0;if((l&2|0)==0){a[e+10528+f9|0]=0;gf=f7;gg=f8;gh=f9;gi=ga;gj=gb;gk=gc;gl=gd;gm=ge;S=1960;continue L2723}else{c[J>>2]=7;gn=1;go=f7;gp=f8;gq=f9;gr=ga;gs=gb;gt=gc;gu=gd;gv=ge;S=2195;continue L2723}}}while(0);if((S|0)==1925){S=0;if(gN>>>0>=q>>>0){al=gH;am=gI;an=gJ;ao=gK;ap=gL;aq=gM;ar=gN;as=gO;S=1926;continue}at=gH;au=gI;av=gJ;aw=gK;ax=gL;ay=d[gN]|0;az=gM;aA=gN+1|0;aB=gO;S=1931;continue}do{if((S|0)==1932){S=0;dV=gT&7;c[e+20>>2]=dV;I=gT>>>3;dU=gP-3|0;dT=dV>>>1;dV=e+24|0;c[dV>>2]=dT;if((dT|0)==3){ei=dU;ej=gQ;ek=gR;el=gS;em=I;en=gU;eo=gV;ep=gW;S=1984;continue L2723}else if((dT|0)==0){if(dU>>>0<(dU&7)>>>0){kw=dU;kx=gQ;ky=gR;kz=gS;kA=I;kB=gU;kC=gV;kD=gW;S=1934;break}else{kE=dU;kF=gQ;kG=gS;kH=I;kI=gU;kJ=gV;kK=gW;S=1941;break}}else if((dT|0)==1){c[e+44>>2]=288;c[e+48>>2]=32;v3(e+3552|0,5,32);v3(e+64|0,8,144);v3(e+208|0,9,112);v3(e+320|0,7,24);dT=e+344|0;dS=dT|0;y=134744072;a[dS]=y&255;y=y>>8;a[dS+1|0]=y&255;y=y>>8;a[dS+2|0]=y&255;y=y>>8;a[dS+3|0]=y&255;dS=dT+4|0;y=134744072;a[dS]=y&255;y=y>>8;a[dS+1|0]=y&255;y=y>>8;a[dS+2|0]=y&255;y=y>>8;a[dS+3|0]=y&255;kL=dU;kM=gQ;kN=gR;kO=gS;kP=I;kQ=gU;kR=gV;kS=gW;kT=dV;kU=1;S=2008;break}else{kV=dU;kW=gQ;kX=0;kY=gS;kZ=I;k_=gU;k$=gV;k0=gW;S=1985;break}}}while(0);if((S|0)==1941){S=0;I=kE&7;ix=kE-I|0;iy=kF;iz=0;iA=kG;iB=kH>>>(I>>>0);iC=kI;iD=kJ;iE=kK;S=1942}else if((S|0)==1934){S=0;if(kC>>>0>=q>>>0){dh=kw;di=kx;dj=ky;dk=kz;dl=kA;dm=kB;dn=kC;dp=kD;S=1935;continue}dq=kw;dr=kx;ds=ky;dt=kz;du=kA;dv=d[kC]|0;dw=kB;dx=kC+1|0;dy=kD;S=1940;continue}do{if((S|0)==1942){S=0;if(iz>>>0>=4){I=d[e+10529|0]<<8|d[e+10528|0];if((I|0)==((d[e+10531|0]<<8|d[e+10530|0])^65535|0)){gz=ix;gA=iy;gB=I;gC=iA;gD=iB;gE=iC;gF=iD;gG=iE;S=1963;break}else{cU=ix;cV=iy;cW=I;cX=iA;cY=iB;cZ=iC;c_=iD;c$=iE;S=1962;continue L2723}}if((ix|0)!=0){if(ix>>>0<8){ig=ix;ih=iy;ii=iz;ij=iA;ik=iB;il=iC;im=iD;io=iE;S=1945;break}else{ip=ix;iq=iy;ir=iz;is=iA;it=iB;iu=iC;iv=iD;iw=iE;S=1952;break}}if(iD>>>0>=q>>>0){f7=0;f8=iy;f9=iz;ga=iA;gb=iB;gc=iC;gd=iD;ge=iE;S=1954;continue L2723}a[e+10528+iz|0]=a[iD]|0;gf=0;gg=iy;gh=iz;gi=iA;gj=iB;gk=iC;gl=iD+1|0;gm=iE;S=1960;continue L2723}}while(0);do{if((S|0)==1945){S=0;if(im>>>0>=q>>>0){bx=ig;by=ih;bz=ii;bA=ij;bB=ik;bC=il;bD=im;bE=io;S=1946;continue L2723}bF=ig;bG=ih;bH=ii;bI=ij;bJ=ik;bK=d[im]|0;bL=il;bM=im+1|0;bN=io;S=1951;continue L2723}else if((S|0)==1963){S=0;if((gB|0)==0|(gz|0)==0){i8=gz;i9=gA;ja=gB;jb=gC;jc=gD;jd=gE;je=gF;jf=gG;S=1976;break}if(gz>>>0<8){hF=gz;hG=gA;hH=gB;hI=gC;hJ=gD;hK=gE;hL=gF;hM=gG;S=1965}else{hN=gz;hO=gB;hP=gC;hQ=gD;hR=gE;hS=gF;hT=gG;S=1972}}else if((S|0)==1952){S=0;a[e+10528+ir|0]=it&255;gf=ip-8|0;gg=iq;gh=ir;gi=is;gj=it>>>8;gk=iu;gl=iv;gm=iw;S=1960;continue L2723}}while(0);if((S|0)==1972){S=0;K=hN-8|0;L=hQ&255;M=hO;N=hP;O=hQ>>>8;P=hR;Q=hS;R=hT;S=1973;continue}else if((S|0)==1976){S=0;if((ja|0)==0){k1=i8;k2=i9;k3=0;k4=jb;k5=jc;k6=jd;k7=je;k8=jf;S=2165}else{dW=i8;dX=i9;dY=ja;dZ=jb;d_=jc;d$=jd;d0=je;d1=jf;S=1977;continue}}else if((S|0)==1965){S=0;if(hL>>>0>=q>>>0){bO=hF;bP=hG;bQ=hH;bR=hI;bS=hJ;bT=hK;bU=hL;bV=hM;S=1966;continue}bW=hF;bX=hG;bY=hH;bZ=hI;b_=hJ;b$=d[hL]|0;b0=hK;b1=hL+1|0;b2=hM;S=1971;continue}L2836:while(1){L2837:do{if((S|0)==1987){S=0;if(kl>>>0<q>>>0){S=1992;break L2836}else{fS=kf;fT=kg;fU=kh;fV=ki;fW=kj;fX=kk;fY=kl;fZ=km;S=1988;continue L2723}}else if((S|0)==1994){S=0;I=kv<<24>>24;c[e+44+(kp<<2)>>2]=(c[256+(kp<<2)>>2]|0)+(kr&(1<<I)-1);kV=kn-I|0;kW=ko;kX=kp+1|0;kY=kq;kZ=kr>>>(I>>>0);k_=ks;k$=kt;k0=ku;S=1985;continue L2836}else if((S|0)==1998){S=0;if(i_>>>0<q>>>0){S=2003;break L2836}else{dz=iU;dA=iV;dB=iW;dC=iX;dD=iY;dE=iZ;dF=i_;dG=i$;S=1999;continue L2723}}else if((S|0)==2116){S=0;if(g1>>>0<q>>>0){S=2121;break L2836}else{aC=gX;aD=gY;aE=gZ;aF=g_;aG=g$;aH=g0;aI=g1;aJ=g2;S=2117;continue L2723}}else if((S|0)==2123){S=0;k9=g3-g6|0;la=g4;lb=((1<<g6)-1&g7)+g5|0;lc=g6;ld=g7>>>(g6>>>0);le=g8;lf=g9;lg=ha}else if((S|0)==2126){S=0;I=b[e+3840+((hf&1023)<<1)>>1]|0;dU=I<<16>>16;if(I<<16>>16>-1){I=dU>>9;if((I|0)==0|hb>>>0<I>>>0){S=2132;break L2836}else{hj=hb;hk=hd;hl=hf;hm=hg;hn=hh;ho=hi;S=2140;continue L2836}}if(hb>>>0>10){lh=10;li=dU}else{S=2132;break L2836}while(1){lj=b[e+5888+((hf>>>(lh>>>0)&1)+~li<<1)>>1]|0;if(lj<<16>>16>=0){hj=hb;hk=hd;hl=hf;hm=hg;hn=hh;ho=hi;S=2140;continue L2836}if(hb>>>0<(lh+2|0)>>>0){break}else{lh=lh+1|0;li=lj<<16>>16}}if(lj<<16>>16>-1){hj=hb;hk=hd;hl=hf;hm=hg;hn=hh;ho=hi;S=2140;continue L2836}else{S=2132;break L2836}}else if((S|0)==2140){S=0;dU=b[e+3840+((hl&1023)<<1)>>1]|0;I=dU<<16>>16;if(dU<<16>>16>-1){lk=I>>9;ll=I&511}else{dU=10;dV=I;while(1){I=dU+1|0;dS=b[e+5888+((hl>>>(dU>>>0)&1)+~dV<<1)>>1]|0;dT=dS<<16>>16;if(dS<<16>>16<0){dU=I;dV=dT}else{lk=I;ll=dT;break}}}dV=hl>>>(lk>>>0);dU=hj-lk|0;dT=c[552+(ll<<2)>>2]|0;I=c[680+(ll<<2)>>2]|0;if((ll-4|0)>>>0>=26){lm=dU;ln=I;lo=hk;lp=dT;lq=dV;lr=hn;ls=ho;S=2153;break}if(dU>>>0<dT>>>0){hU=dU;hV=I;hW=hk;hX=dT;hY=dV;hZ=hm;h_=hn;h$=ho;S=2145;continue L2836}else{h0=dU;h1=I;h2=hk;h3=dT;h4=dV;h5=hn;h6=ho;S=2152;continue L2836}}else if((S|0)==2066){S=0;dV=(a[45176+(hy-16)|0]|0)+((1<<hA)-1&hB)|0;if((hy|0)==16){lt=a[hz-1+(e+10532)|0]|0}else{lt=0}v3(e+10532+hz|0,lt|0,dV|0);lu=hx-hA|0;lv=hy;lw=dV+hz|0;lx=hA;ly=hB>>>(hA>>>0);lz=hC;lA=hD;lB=hE;S=2034}else if((S|0)==2076){S=0;dV=b[e+352+((jY&1023)<<1)>>1]|0;dT=dV<<16>>16;if(dV<<16>>16>-1){dV=dT>>9;if((dV|0)==0|jU>>>0<dV>>>0){S=2082;break L2836}else{j0=jU;j1=jV;j2=jX;j3=jY;j4=jZ;j5=j_;j6=j$;S=2090;continue L2836}}if(jU>>>0>10){lC=10;lD=dT}else{S=2082;break L2836}while(1){lE=b[e+2400+((jY>>>(lC>>>0)&1)+~lD<<1)>>1]|0;if(lE<<16>>16>=0){j0=jU;j1=jV;j2=jX;j3=jY;j4=jZ;j5=j_;j6=j$;S=2090;continue L2836}if(jU>>>0<(lC+2|0)>>>0){break}else{lC=lC+1|0;lD=lE<<16>>16}}if(lE<<16>>16>-1){j0=jU;j1=jV;j2=jX;j3=jY;j4=jZ;j5=j_;j6=j$;S=2090;continue L2836}else{S=2082;break L2836}}else if((S|0)==2145){S=0;if(h_>>>0<q>>>0){S=2150;break L2836}else{cf=hU;cg=hV;ch=hW;ci=hX;cj=hY;ck=hZ;cl=h_;cm=h$;S=2146;continue L2723}}else if((S|0)==2152){S=0;lm=h0-h3|0;ln=((1<<h3)-1&h4)+h1|0;lo=h2;lp=h3;lq=h4>>>(h3>>>0);lr=h5;ls=h6;S=2153}else if((S|0)==2156){S=0;dT=h9-1|0;if((h9|0)==0){j7=h7;j8=h8;j9=dT;ka=ia;kb=ib;kc=ic;kd=id;ke=ie;S=2097;continue L2836}else{cE=h7;cF=h8;cG=dT;cH=ia;cI=ib;cJ=ic;cK=id;cL=ie;S=2157;continue L2723}}else if((S|0)==2051){S=0;dT=b[e+7328+((iQ&1023)<<1)>>1]|0;dV=dT<<16>>16;if(dT<<16>>16>-1){lF=dV>>9;lG=dV&511}else{dT=10;I=dV;while(1){dV=dT+1|0;dU=b[e+9376+((iQ>>>(dT>>>0)&1)+~I<<1)>>1]|0;dS=dU<<16>>16;if(dU<<16>>16<0){dT=dV;I=dS}else{lF=dV;lG=dS;break}}}I=iQ>>>(lF>>>0);dT=iN-lF|0;if(lG>>>0<16){a[e+10532+iO|0]=lG&255;lu=dT;lv=lG;lw=iO+1|0;lx=iP;ly=I;lz=iR;lA=iS;lB=iT;S=2034;break}if((lG|0)==16&(iO|0)==0){cM=dT;cN=16;cO=0;cP=iP;cQ=I;cR=iR;cS=iS;cT=iT;S=2057;continue L2723}dS=a[46624+(lG-16)|0]|0;if(dT>>>0<dS>>>0){hp=dT;hq=lG;hr=iO;hs=dS;ht=I;hu=iR;hv=iS;hw=iT;S=2059;continue L2836}else{hx=dT;hy=lG;hz=iO;hA=dS;hB=I;hC=iR;hD=iS;hE=iT;S=2066;continue L2836}}else if((S|0)==2059){S=0;if(hv>>>0<q>>>0){S=2064;break L2836}else{a8=hp;a9=hq;ba=hr;bb=hs;bc=ht;bd=hu;be=hv;bf=hw;S=2060;continue L2723}}else if((S|0)==2037){S=0;I=b[e+7328+((iJ&1023)<<1)>>1]|0;dS=I<<16>>16;if(I<<16>>16>-1){I=dS>>9;if((I|0)==0|iF>>>0<I>>>0){S=2043;break L2836}else{iN=iF;iO=iH;iP=iI;iQ=iJ;iR=iK;iS=iL;iT=iM;S=2051;continue L2836}}if(iF>>>0>10){lH=10;lI=dS}else{S=2043;break L2836}while(1){lJ=b[e+9376+((iJ>>>(lH>>>0)&1)+~lI<<1)>>1]|0;if(lJ<<16>>16>=0){iN=iF;iO=iH;iP=iI;iQ=iJ;iR=iK;iS=iL;iT=iM;S=2051;continue L2836}if(iF>>>0<(lH+2|0)>>>0){break}else{lH=lH+1|0;lI=lJ<<16>>16}}if(lJ<<16>>16>-1){iN=iF;iO=iH;iP=iI;iQ=iJ;iR=iK;iS=iL;iT=iM;S=2051;continue L2836}else{S=2043;break L2836}}else if((S|0)==2005){S=0;a[(d[400+i2|0]|0)+(e+7040)|0]=i4&7;lK=i0-3|0;lL=i1;lM=i2+1|0;lN=i3;lO=i4>>>3;lP=i5;lQ=i6;lR=i7;S=1996}else if((S|0)==2097){S=0;dS=q;I=dS-kd|0;L2894:do{if((I|0)<4){lS=ke;lT=kd;lU=kb;lV=j9;lW=j7;lX=I}else{dT=s;dV=ke;dU=kd;dR=kb;dQ=j9;cd=j7;cc=I;while(1){if((dT-dV|0)<2){lS=dV;lT=dU;lU=dR;lV=dQ;lW=cd;lX=cc;break L2894}if(cd>>>0<15){lY=cd+16|0;lZ=(d[dU+1|0]<<8|d[dU])<<cd|dR;l_=dU+2|0}else{lY=cd;lZ=dR;l_=dU}cb=b[e+352+((lZ&1023)<<1)>>1]|0;gx=cb<<16>>16;if(cb<<16>>16>-1){l$=gx>>9;l0=gx}else{cb=10;ca=gx;while(1){gx=cb+1|0;b9=b[e+2400+((lZ>>>(cb>>>0)&1)+~ca<<1)>>1]|0;gw=b9<<16>>16;if(b9<<16>>16<0){cb=gx;ca=gw}else{l$=gx;l0=gw;break}}}ca=lZ>>>(l$>>>0);cb=lY-l$|0;if((l0&256|0)!=0){l1=cb;l2=j8;l3=l0;l4=ka;l5=ca;l6=kc;l7=l_;l8=dV;S=2113;break L2837}if(cb>>>0<15){l9=cb+16|0;ma=(d[l_+1|0]<<8|d[l_])<<cb|ca;mb=l_+2|0}else{l9=cb;ma=ca;mb=l_}ca=b[e+352+((ma&1023)<<1)>>1]|0;cb=ca<<16>>16;if(ca<<16>>16>-1){mc=cb>>9;md=cb}else{ca=10;gw=cb;while(1){cb=ca+1|0;gx=b[e+2400+((ma>>>(ca>>>0)&1)+~gw<<1)>>1]|0;b9=gx<<16>>16;if(gx<<16>>16<0){ca=cb;gw=b9}else{mc=cb;md=b9;break}}}me=ma>>>(mc>>>0);mf=l9-mc|0;a[dV]=l0&255;if((md&256|0)!=0){break}a[dV+1|0]=md&255;gw=dV+2|0;ca=dS-mb|0;if((ca|0)<4){lS=gw;lT=mb;lU=me;lV=l0;lW=mf;lX=ca;break L2894}else{dV=gw;dU=mb;dR=me;dQ=l0;cd=mf;cc=ca}}l1=mf;l2=j8;l3=md;l4=ka;l5=me;l6=kc;l7=mb;l8=dV+1|0;S=2113;break L2837}}while(0);if(lW>>>0>=15){j0=lW;j1=j8;j2=ka;j3=lU;j4=kc;j5=lT;j6=lS;S=2090;continue L2836}if((lX|0)<2){jU=lW;jV=j8;jW=lV;jX=ka;jY=lU;jZ=kc;j_=lT;j$=lS;S=2076;continue L2836}j0=lW+16|0;j1=j8;j2=ka;j3=d[lT]<<lW|lU|d[lT+1|0]<<lW+8;j4=kc;j5=lT+2|0;j6=lS;S=2090;continue L2836}else if((S|0)==1985){S=0;if(kX>>>0<3){dS=a[48600+kX|0]|0;if(kV>>>0<dS<<24>>24>>>0){kf=kV;kg=kW;kh=kX;ki=kY;kj=kZ;kk=k_;kl=k$;km=k0;S=1987;continue L2836}else{kn=kV;ko=kW;kp=kX;kq=kY;kr=kZ;ks=k_;kt=k$;ku=k0;kv=dS;S=1994;continue L2836}}else{v3(e+7040|0,0,288);lK=kV;lL=kW;lM=0;lN=kY;lO=kZ;lP=k_;lQ=k$;lR=k0;S=1996;break}}else if((S|0)==2165){S=0;if((c[e+20>>2]&1|0)==0){U=k1;V=k2;W=k3;X=k4;Y=k5;Z=k6;_=k7;$=k8;S=1924;continue L2723}if((l&1|0)==0){fd=k1;fe=k2;ff=k3;fg=k4;fh=k5;fi=k6;fj=k7;fk=k8;S=2194;continue L2723}if(k1>>>0<(k1&7)>>>0){jg=k1;jh=k2;ji=k3;jj=k4;jk=k5;jl=k6;jm=k7;jn=k8;S=2168;continue L2836}else{jo=k1;jp=k2;jq=k4;jr=k5;js=k6;jt=k7;ju=k8;S=2175;continue L2836}}else if((S|0)==2168){S=0;if(jm>>>0<q>>>0){S=2173;break L2836}else{eq=jg;er=jh;es=ji;et=jj;eu=jk;ev=jl;ew=jm;ex=jn;S=2169;continue L2723}}else if((S|0)==2175){S=0;dS=jo&7;jL=jo-dS|0;jM=jp;jN=0;jO=jq;jP=jr>>>(dS>>>0);jQ=js;jR=jt;jS=ju;S=2176;continue L2836}else if((S|0)==2176){S=0;if(jN>>>0>=4){fd=jL;fe=jM;ff=jN;fg=jO;fh=jP;fi=jQ;fj=jR;fk=jS;S=2194;continue L2723}if((jL|0)==0){S=2187;break L2836}if(jL>>>0<8){jv=jL;jw=jM;jx=jN;jy=jO;jz=jP;jA=jQ;jB=jR;jC=jS;S=2179;continue L2836}else{jD=jL;jE=jM;jF=jN;jG=jO;jH=jP;jI=jQ;jJ=jR;jK=jS;S=2186;continue L2836}}else if((S|0)==2179){S=0;if(jB>>>0<q>>>0){S=2184;break L2836}else{eH=jv;eI=jw;eJ=jx;eK=jy;eL=jz;eM=jA;eN=jB;eO=jC;S=2180;continue L2723}}else if((S|0)==2186){S=0;e4=jH&255;e5=jD-8|0;e6=jE;e7=jF;e8=jG;e9=jH>>>8;fa=jI;fb=jJ;fc=jK;S=2193;continue L2723}else if((S|0)==2090){S=0;dS=b[e+352+((j3&1023)<<1)>>1]|0;I=dS<<16>>16;if(dS<<16>>16>-1){mg=I>>9;mh=I&511}else{dS=10;cc=I;while(1){I=dS+1|0;cd=b[e+2400+((j3>>>(dS>>>0)&1)+~cc<<1)>>1]|0;dQ=cd<<16>>16;if(cd<<16>>16<0){dS=I;cc=dQ}else{mg=I;mh=dQ;break}}}cc=j3>>>(mg>>>0);dS=j0-mg|0;if(mh>>>0>255){l1=dS;l2=j1;l3=mh;l4=j2;l5=cc;l6=j4;l7=j5;l8=j6;S=2113}else{fC=dS;fD=j1;fE=mh;fF=j2;fG=cc;fH=j4;fI=j5;fJ=j6;S=2094;continue L2723}}else if((S|0)==2008){S=0;if((kU|0)<=-1){j7=kL;j8=kM;j9=kN;ka=kO;kb=kP;kc=kQ;kd=kR;ke=kS;S=2097;continue L2836}v3(o|0,0,64);v3(e+64+(kU*3488|0)+288|0,0,3200);cc=c[kT>>2]|0;dS=c[e+44+(cc<<2)>>2]|0;if((dS|0)==0){mi=0;mj=0;mk=0;ml=0;mm=0;mn=0;mo=0;mp=0;mq=0;mr=0;ms=0;mt=0;mu=0;mv=0;mw=0;mx=0}else{dQ=0;do{I=o+(d[e+64+(kU*3488|0)+dQ|0]<<2)|0;c[I>>2]=(c[I>>2]|0)+1;dQ=dQ+1|0;}while(dQ>>>0<dS>>>0);mi=c[o+4>>2]|0;mj=c[o+8>>2]|0;mk=c[o+12>>2]|0;ml=c[o+16>>2]|0;mm=c[o+20>>2]|0;mn=c[o+24>>2]|0;mo=c[o+28>>2]|0;mp=c[o+32>>2]|0;mq=c[o+36>>2]|0;mr=c[o+40>>2]|0;ms=c[o+44>>2]|0;mt=c[o+48>>2]|0;mu=c[o+52>>2]|0;mv=c[o+56>>2]|0;mw=c[o+60>>2]|0;mx=dS}c[n+4>>2]=0;c[n>>2]=0;dQ=mi<<1;c[n+8>>2]=dQ;I=dQ+mj<<1;c[n+12>>2]=I;dQ=I+mk<<1;c[n+16>>2]=dQ;I=dQ+ml<<1;c[n+20>>2]=I;dQ=I+mm<<1;c[n+24>>2]=dQ;I=dQ+mn<<1;c[n+28>>2]=I;dQ=I+mo<<1;c[n+32>>2]=dQ;I=dQ+mp<<1;c[n+36>>2]=I;dQ=I+mq<<1;c[n+40>>2]=dQ;I=dQ+mr<<1;c[n+44>>2]=I;dQ=I+ms<<1;c[n+48>>2]=dQ;I=dQ+mt<<1;c[n+52>>2]=I;dQ=I+mu<<1;c[n+56>>2]=dQ;I=dQ+mv<<1;c[n+60>>2]=I;dQ=I+mw<<1;c[n+64>>2]=dQ;if((dQ|0)!=65536&(mv+mw+mu+mt+ms+mr+mq+mp+mo+mn+mm+ml+mk+mj+mi|0)>>>0>1){fK=kL;fL=kM;fM=kN;fN=kO;fO=kP;fP=kQ;fQ=kR;fR=kS;S=2014;continue L2723}if((mx|0)==0){my=cc}else{dQ=-1;I=0;while(1){cd=a[e+64+(kU*3488|0)+I|0]|0;dR=cd&255;L2952:do{if(cd<<24>>24==0){mz=dQ}else{dU=n+(dR<<2)|0;dT=c[dU>>2]|0;c[dU>>2]=dT+1;dU=0;ca=dR;gw=dT;while(1){mA=dU<<1|gw&1;dT=ca-1|0;if((dT|0)==0){break}else{dU=mA;ca=dT;gw=gw>>>1}}if((cd&255)<11){gw=(dR<<9|I)&65535;if(mA>>>0>=1024){mz=dQ;break}ca=1<<dR;dT=mA;while(1){b[e+64+(kU*3488|0)+288+(dT<<1)>>1]=gw;b9=dT+ca|0;if(b9>>>0<1024){dT=b9}else{mz=dQ;break L2952}}}dT=e+64+(kU*3488|0)+288+((mA&1023)<<1)|0;ca=b[dT>>1]|0;if(ca<<16>>16==0){b[dT>>1]=dQ&65535;mB=dQ;mC=dQ-2|0}else{mB=ca<<16>>16;mC=dQ}ca=dU>>>9;dT=mB-(ca&1)|0;if((cd&255)>11){gw=mC;b9=dR;cb=ca&4194303;ca=dT;while(1){gx=e+64+(kU*3488|0)+2336+(~ca<<1)|0;gy=b[gx>>1]|0;if(gy<<16>>16==0){b[gx>>1]=gw&65535;mD=gw;mE=gw-2|0}else{mD=gy<<16>>16;mE=gw}gy=b9-1|0;gx=cb>>>1;ce=mD-(gx&1)|0;if(gy>>>0>11){gw=mE;b9=gy;cb=gx;ca=ce}else{mF=mE;mG=ce;break}}}else{mF=mC;mG=dT}b[e+64+(kU*3488|0)+2336+(~mG<<1)>>1]=I&65535;mz=mF}}while(0);dR=I+1|0;cd=c[kT>>2]|0;if(dR>>>0<(c[e+44+(cd<<2)>>2]|0)>>>0){dQ=mz;I=dR}else{my=cd;break}}}if((my|0)==2){lu=kL;lv=kM;lw=0;lx=kO;ly=kP;lz=kQ;lA=kR;lB=kS;S=2034;break}mH=kL;mI=kM;mJ=kN;mK=kO;mL=kP;mM=kQ;mN=kR;mO=kS;mP=my;mQ=e+24|0;S=2072}}while(0);do{if((S|0)==1996){S=0;I=e+52|0;if(lM>>>0<(c[I>>2]|0)>>>0){if(lK>>>0<3){iU=lK;iV=lL;iW=lM;iX=lN;iY=lO;iZ=lP;i_=lQ;i$=lR;S=1998;continue L2836}else{i0=lK;i1=lL;i2=lM;i3=lN;i4=lO;i5=lP;i6=lQ;i7=lR;S=2005;continue L2836}}else{c[I>>2]=19;I=e+24|0;kL=lK;kM=lL;kN=lM;kO=lN;kP=lO;kQ=lP;kR=lQ;kS=lR;kT=I;kU=c[I>>2]|0;S=2008;continue L2836}}else if((S|0)==2153){S=0;I=ls-h|0;if(!(ln>>>0<=I>>>0|t^1)){cw=lm;cx=ln;cy=lo;cz=lp;cA=lq;cB=I;cC=lr;cD=ls;S=2154;continue L2723}dQ=h+(I-ln&u)|0;if(((ls>>>0>dQ>>>0?ls:dQ)+lo|0)>>>0>s>>>0){h7=lm;h8=ln;h9=lo;ia=lp;ib=lq;ic=I;id=lr;ie=ls;S=2156;continue L2836}else{mR=dQ;mS=lo;mT=ls}while(1){a[mT]=a[mR]|0;a[mT+1|0]=a[mR+1|0]|0;a[mT+2|0]=a[mR+2|0]|0;mU=mT+3|0;mV=mR+3|0;mW=mS-3|0;if((mW|0)>2){mR=mV;mS=mW;mT=mU}else{break}}if((mW|0)<=0){j7=lm;j8=ln;j9=mW;ka=lp;kb=lq;kc=I;kd=lr;ke=mU;S=2097;continue L2836}a[mU]=a[mV]|0;if((mW|0)>1){a[mT+4|0]=a[mR+4|0]|0}j7=lm;j8=ln;j9=mW;ka=lp;kb=lq;kc=I;kd=lr;ke=mT+mS|0;S=2097;continue L2836}else if((S|0)==2034){S=0;dQ=c[e+44>>2]|0;cc=c[e+48>>2]|0;dS=cc+dQ|0;if(lw>>>0>=dS>>>0){if((dS|0)!=(lw|0)){bp=lu;bq=lv;br=lw;bs=lx;bt=ly;bu=lz;bv=lA;bw=lB;S=2070;continue L2723}dS=e+64|0;cd=e+10532|0;v6(dS|0,cd|0,dQ)|0;cd=e+3552|0;dS=e+10532+dQ|0;v6(cd|0,dS|0,cc)|0;cc=e+24|0;mH=lu;mI=lv;mJ=lw;mK=lx;mL=ly;mM=lz;mN=lA;mO=lB;mP=c[cc>>2]|0;mQ=cc;S=2072;break}if(lu>>>0>=15){iN=lu;iO=lw;iP=lx;iQ=ly;iR=lz;iS=lA;iT=lB;S=2051;continue L2836}if((q-lA|0)<2){iF=lu;iG=lv;iH=lw;iI=lx;iJ=ly;iK=lz;iL=lA;iM=lB;S=2037;continue L2836}iN=lu+16|0;iO=lw;iP=lx;iQ=d[lA]<<lu|ly|d[lA+1|0]<<lu+8;iR=lz;iS=lA+2|0;iT=lB;S=2051;continue L2836}else if((S|0)==2113){S=0;cc=l3&511;if((cc|0)==256){k1=l1;k2=l2;k3=256;k4=l4;k5=l5;k6=l6;k7=l7;k8=l8;S=2165;continue L2836}dS=cc-257|0;cd=c[272+(dS<<2)>>2]|0;dQ=c[424+(dS<<2)>>2]|0;if((cc-265|0)>>>0>=20){k9=l1;la=l2;lb=dQ;lc=cd;ld=l5;le=l6;lf=l7;lg=l8;break}if(l1>>>0<cd>>>0){gX=l1;gY=l2;gZ=dQ;g_=cd;g$=l5;g0=l6;g1=l7;g2=l8;S=2116;continue L2836}else{g3=l1;g4=l2;g5=dQ;g6=cd;g7=l5;g8=l6;g9=l7;ha=l8;S=2123;continue L2836}}}while(0);if((S|0)==2072){S=0;cd=mP-1|0;c[mQ>>2]=cd;kL=mH;kM=mI;kN=mJ;kO=mK;kP=mL;kQ=mM;kR=mN;kS=mO;kT=mQ;kU=cd;S=2008;continue}if(k9>>>0>=15){hj=k9;hk=lb;hl=ld;hm=le;hn=lf;ho=lg;S=2140;continue}if((q-lf|0)<2){hb=k9;hc=la;hd=lb;he=lc;hf=ld;hg=le;hh=lf;hi=lg;S=2126;continue}hj=k9+16|0;hk=lb;hl=d[lf]<<k9|ld|d[lf+1|0]<<k9+8;hm=le;hn=lf+2|0;ho=lg;S=2140}if((S|0)==2121){S=0;aK=d[g1]|0;aL=gX;aM=gY;aN=gZ;aO=g_;aP=g$;aQ=g0;aR=g1+1|0;aS=g2;S=2122;continue}else if((S|0)==2132){S=0;if(hh>>>0>=q>>>0){aT=hb;aU=hc;aV=hd;aW=he;aX=hf;aY=hg;aZ=hh;a_=hi;S=2133;continue}a$=d[hh]|0;a0=hb;a1=hc;a2=hd;a3=he;a4=hf;a5=hg;a6=hh+1|0;a7=hi;S=2138;continue}else if((S|0)==2064){S=0;bg=d[hv]|0;bh=hp;bi=hq;bj=hr;bk=hs;bl=ht;bm=hu;bn=hv+1|0;bo=hw;S=2065;continue}else if((S|0)==2150){S=0;cn=d[h_]|0;co=hU;cp=hV;cq=hW;cr=hX;cs=hY;ct=hZ;cu=h_+1|0;cv=h$;S=2151;continue}else if((S|0)==2043){S=0;if(iL>>>0>=q>>>0){c0=iF;c1=iG;c2=iH;c3=iI;c4=iJ;c5=iK;c6=iL;c7=iM;S=2044;continue}c8=d[iL]|0;c9=iF;da=iG;db=iH;dc=iI;dd=iJ;de=iK;df=iL+1|0;dg=iM;S=2049;continue}else if((S|0)==2003){S=0;dH=iU;dI=iV;dJ=iW;dK=d[i_]|0;dL=iX;dM=iY;dN=iZ;dO=i_+1|0;dP=i$;S=2004;continue}else if((S|0)==2173){S=0;ey=d[jm]|0;ez=jg;eA=jh;eB=ji;eC=jj;eD=jk;eE=jl;eF=jm+1|0;eG=jn;S=2174;continue}else if((S|0)==2184){S=0;eP=d[jB]|0;eQ=jv;eR=jw;eS=jx;eT=jy;eU=jz;eV=jA;eW=jB+1|0;eX=jC;S=2185;continue}else if((S|0)==2187){S=0;if(jR>>>0>=q>>>0){eY=0;eZ=jM;e_=jN;e$=jO;e0=jP;e1=jQ;e2=jR;e3=jS;S=2188;continue}e4=d[jR]|0;e5=0;e6=jM;e7=jN;e8=jO;e9=jP;fa=jQ;fb=jR+1|0;fc=jS;S=2193;continue}else if((S|0)==2082){S=0;if(j_>>>0>=q>>>0){fl=jU;fm=jV;fn=jW;fo=jX;fp=jY;fq=jZ;fr=j_;fs=j$;S=2083;continue}ft=d[j_]|0;fu=jU;fv=jV;fw=jW;fx=jX;fy=jY;fz=jZ;fA=j_+1|0;fB=j$;S=2088;continue}else if((S|0)==1992){S=0;f_=kf;f$=kg;f0=kh;f1=ki;f2=d[kl]|0;f3=kj;f4=kk;f5=kl+1|0;f6=km;S=1993;continue}}if((S|0)==2211){i=m;return v|0}S=e+28|0;km=c[S>>2]|0;f6=km&65535;kl=km>>>16;if((gv|0)==(j|0)){mX=f6;mY=kl}else{gv=j;j=jT;km=f6;f6=kl;kl=(jT>>>0)%5552|0;while(1){if(kl>>>0>7){jT=gv;f5=0;kk=km;f4=f6;while(1){kj=(d[jT]|0)+kk|0;f3=kj+(d[jT+1|0]|0)|0;f2=f3+(d[jT+2|0]|0)|0;ki=f2+(d[jT+3|0]|0)|0;f1=ki+(d[jT+4|0]|0)|0;kh=f1+(d[jT+5|0]|0)|0;f0=kh+(d[jT+6|0]|0)|0;kg=f0+(d[jT+7|0]|0)|0;f$=kj+f4+f3+f2+ki+f1+kh+f0+kg|0;f0=f5+8|0;kh=jT+8|0;if((f0|7)>>>0<kl>>>0){jT=kh;f5=f0;kk=kg;f4=f$}else{mZ=kh;m_=f0;m$=kg;m0=f$;break}}}else{mZ=gv;m_=0;m$=km;m0=f6}if(m_>>>0<kl>>>0){f4=mZ;kk=m_;f5=m$;jT=m0;while(1){m1=(d[f4]|0)+f5|0;m2=m1+jT|0;f$=kk+1|0;if(f$>>>0<kl>>>0){f4=f4+1|0;kk=f$;f5=m1;jT=m2}else{break}}m3=mZ+(kl-m_)|0;m4=m1;m5=m2}else{m3=mZ;m4=m$;m5=m0}jT=(m4>>>0)%65521|0;f5=(m5>>>0)%65521|0;if((j|0)==(kl|0)){mX=jT;mY=f5;break}else{gv=m3;j=j-kl|0;km=jT;f6=f5;kl=5552}}}kl=mY<<16|mX;c[S>>2]=kl;if((gn|0)!=0){v=gn;i=m;return v|0}if((l&1|0)==0){v=0;i=m;return v|0}else{i=m;return((kl|0)==(c[e+16>>2]|0)?0:-2)|0}return 0}function jB(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((f|0)==4){i=c[b+20>>2]|0;j=d[i+4|0]|0;k=(e&1|0)!=0;do{if(k){if((g&64|0)!=0){break}l=b+48|0;m=c[l>>2]|0;if((m|0)==0){break}if((j&64|0)==0){break}c[l>>2]=m-1}}while(0);if((j&128|0)==0){if((c[b+48>>2]|0)!=0){n=0;return n|0}a[b+56|0]=0;n=0;return n|0}m=b+56|0;a[m]=1;l=b+48|0;do{if((c[l>>2]|0)==0){c[l>>2]=64;if(!k){break}if((j&64|0)==0){break}c[l>>2]=63}}while(0);l=i+2|0;c[b+64>>2]=(d[l]|0)>>>4;i=a[l]&7;j=(i|0)!=0?i:8;i=b+60|0;c[i>>2]=j;a[b+68|0]=1;if((e|0)==7){c[i>>2]=j+1}if((d[l]|0)>7){n=1;return n|0}a[m]=0;n=1;return n|0}else if((f|0)==2){m=(c[b+20>>2]|0)+2|0;if((d[m]|0)<=7){a[b+56|0]=0}l=b+64|0;j=c[l>>2]|0;if(((h^g)&8|0)==0){o=j+((g&15|0)==8)|0}else{if((g&8|0)==0){p=j+((g&7|0)==0?1:2)|0}else{p=j}o=16-p|0}p=o&15;c[l>>2]=p;if((h&7|0)==0){n=0;return n|0}o=b+60|0;if((c[o>>2]|0)!=8){n=0;return n|0}c[o>>2]=1;j=b+68|0;if((a[j]&1)==0){n=0;return n|0}c[o>>2]=0;g=a[m]&7;c[o>>2]=(g|0)!=0?g:8;if((g|0)==0){n=0;return n|0}g=((a[m]&8)!=0?1:-1)+p|0;if(g>>>0<16){c[l>>2]=g;n=0;return n|0}else{a[j]=0;n=0;return n|0}}else if((f|0)==1){c[b+48>>2]=64-(h&63);n=0;return n|0}else{n=0;return n|0}return 0}function jC(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=b+20|0;h=c[g>>2]|0;i=(d[h+1|0]|0)>>>6;j=d[51648+i|0]|0;k=(d[51656+i|0]|0)-j|0;i=8-j|0;j=b+52|0;l=k+(c[j>>2]|0)&7;m=c[b+16>>2]|0;do{if((m|0)==0){n=0}else{o=c[b+28>>2]|0;do{if((d[h+2|0]|0)>7){if((a[b+56|0]&1)==0){p=0}else{p=c[b+64>>2]|0}q=p>>1;r=-q|0;do{if(((d[h+4|0]|0)<<8&1792|(d[h+3|0]|0))>>>0>2041){if((c[b+44>>2]|0)>=128){s=r;t=p;break}s=((ac(p,i)|0)>>3)-q|0;t=0}else{s=r;t=p}}while(0);if((l|0)>=(i|0)){u=s;v=t;break}u=s+t|0;v=-t|0}else{u=o;v=0}}while(0);o=b+32|0;r=c[o>>2]|0;if((r|0)==(u|0)){n=v;break}c[o>>2]=u;o=c[b+40>>2]|0;q=ac(c[m+12>>2]|0,e)|0;w=q+(c[m+16>>2]|0)|0;q=ac(c[o+4>>2]|0,u-r|0)|0;r=c[m+20>>2]|0;o=w>>>16;x=r+(o<<2)|0;y=(c[x>>2]|0)+q|0;z=ac(q>>8,w>>>8&255)|0;w=r+(o+1<<2)|0;o=z+(c[w>>2]|0)|0;c[x>>2]=y-z;c[w>>2]=o;n=v}}while(0);v=b+44|0;u=(c[v>>2]|0)+e|0;if((u|0)>=(f|0)){A=u;B=A-f|0;c[v>>2]=B;return}e=c[g>>2]|0;g=2048-((d[e+4|0]|0)<<8&1792|(d[e+3|0]|0))<<4;do{if((n|0)==0){e=(f-1-u+g|0)/(g|0)|0;C=(ac(e,g)|0)+u|0;D=e+l|0}else{e=b+36|0;t=m+12|0;s=m+16|0;p=m+20|0;h=n;o=u;w=l;while(1){E=w+1&7;if((E|0)==0|(E|0)==(i|0)){z=c[e>>2]|0;y=ac(c[t>>2]|0,o)|0;x=y+(c[s>>2]|0)|0;y=ac(c[z+4>>2]|0,h)|0;z=c[p>>2]|0;r=x>>>16;q=z+(r<<2)|0;F=(c[q>>2]|0)+y|0;G=ac(y>>8,x>>>8&255)|0;x=z+(r+1<<2)|0;r=G+(c[x>>2]|0)|0;c[q>>2]=F-G;c[x>>2]=r;H=-h|0}else{H=h}I=o+g|0;if((I|0)<(f|0)){h=H;o=I;w=E}else{break}}if((H|0)==(n|0)){C=I;D=E;break}w=b+32|0;c[w>>2]=(c[w>>2]|0)-H;C=I;D=E}}while(0);c[j>>2]=D-k&7;A=C;B=A-f|0;c[v>>2]=B;return}function jD(a){a=a|0;v_(c[203425]|0);v_(c[203417]|0);v_(c[203409]|0);return}function jE(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=c[120068]|0;h=167772-(c[322]|0)|0;i=g+130|0;j=g+132|0;k=g+131|0;l=a[51760]|0?-2768240:0;m=0;do{n=f+m|0;o=e+(m<<2)|0;a[g+(c[o>>2]|0)|0]=a[n]|0;jF(h,c[b+(m<<2)>>2]|0,d[n]|0);do{if((c[o>>2]|0)==132){c[193613]=(d[i]|0)>>>2&1^1;do{if((a[j]|0)<0){n=a[k]&3;if((n|0)==1){p=813648;break}else if((n|0)==2){p=813616;break}else if((n|0)==3){p=813680;break}else{p=0;break}}else{p=0}}while(0);n=c[193614]|0;if((n|0)!=(p|0)){if((n|0)!=0){q=-(c[193611]|0)|0;r=ac(c[n+12>>2]|0,h)|0;s=r+(c[n+16>>2]|0)|0;r=ac(l,q)|0;q=c[n+20>>2]|0;n=s>>>16;t=q+(n<<2)|0;u=(c[t>>2]|0)+r|0;v=ac(r>>8,s>>>8&255)|0;s=q+(n+1<<2)|0;n=v+(c[s>>2]|0)|0;c[t>>2]=u-v;c[s>>2]=n}c[193611]=0;c[193614]=p}c[193632]=(d[i]|0)>>>3&1^1;do{if((a[j]|0)<0){n=(d[k]|0)>>>4&3;if((n|0)==2){w=813616;break}else if((n|0)==1){w=813648;break}else if((n|0)==3){w=813680;break}else{w=0;break}}else{w=0}}while(0);n=c[193633]|0;if((n|0)==(w|0)){break}if((n|0)!=0){s=-(c[193630]|0)|0;v=ac(c[n+12>>2]|0,h)|0;u=v+(c[n+16>>2]|0)|0;v=ac(l,s)|0;s=c[n+20>>2]|0;n=u>>>16;t=s+(n<<2)|0;q=(c[t>>2]|0)+v|0;r=ac(v>>8,u>>>8&255)|0;u=s+(n+1<<2)|0;n=r+(c[u>>2]|0)|0;c[t>>2]=q-r;c[u>>2]=n}c[193630]=0;c[193633]=w}}while(0);m=m+1|0;}while(m>>>0<2);return}function jF(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=e-65296|0;if(g>>>0>47){return}if(!(e>>>0>65317|(a[505111]|0)<0)){return}if((c[126289]|0)<(b|0)){jJ(b)}if(e>>>0>65327){if((a[505412]&1)==0){i=e}else{i=(c[126352]|0)>>>1}a[(c[126356]|0)+(((d[c[126344]|0]|0)>>>2&16^16)&c[126355]|i&15)|0]=f&255;return}i=505089+g|0;b=d[i]|0;j=f&255;a[i]=j;if(e>>>0>=65316){if(!((e|0)!=65316|(b|0)==(f|0))){i=c[126299]|0;k=i+32|0;l=c[k>>2]|0;m=-l|0;do{if((l|0)!=0){c[k>>2]=0;n=c[i+16>>2]|0;if((n|0)==0){break}o=ac(c[n+12>>2]|0,c[126289]|0)|0;p=o+(c[n+16>>2]|0)|0;o=ac(c[126379]|0,m)|0;q=c[n+20>>2]|0;n=p>>>16;r=q+(n<<2)|0;s=(c[r>>2]|0)+o|0;t=ac(o>>8,p>>>8&255)|0;p=q+(n+1<<2)|0;n=t+(c[p>>2]|0)|0;c[r>>2]=s-t;c[p>>2]=n}}while(0);m=c[126298]|0;i=m+32|0;k=c[i>>2]|0;l=-k|0;do{if((k|0)!=0){c[i>>2]=0;n=c[m+16>>2]|0;if((n|0)==0){break}p=ac(c[n+12>>2]|0,c[126289]|0)|0;t=p+(c[n+16>>2]|0)|0;p=ac(c[126379]|0,l)|0;s=c[n+20>>2]|0;n=t>>>16;r=s+(n<<2)|0;q=(c[r>>2]|0)+p|0;o=ac(p>>8,t>>>8&255)|0;t=s+(n+1<<2)|0;n=o+(c[t>>2]|0)|0;c[r>>2]=q-o;c[t>>2]=n}}while(0);l=c[126297]|0;m=l+32|0;i=c[m>>2]|0;k=-i|0;do{if((i|0)!=0){c[m>>2]=0;n=c[l+16>>2]|0;if((n|0)==0){break}t=ac(c[n+12>>2]|0,c[126289]|0)|0;o=t+(c[n+16>>2]|0)|0;t=ac(c[126379]|0,k)|0;q=c[n+20>>2]|0;n=o>>>16;r=q+(n<<2)|0;s=(c[r>>2]|0)+t|0;p=ac(t>>8,o>>>8&255)|0;o=q+(n+1<<2)|0;n=p+(c[o>>2]|0)|0;c[r>>2]=s-p;c[o>>2]=n}}while(0);k=c[126296]|0;l=k+32|0;m=c[l>>2]|0;i=-m|0;do{if((m|0)!=0){c[l>>2]=0;n=c[k+16>>2]|0;if((n|0)==0){break}o=ac(c[n+12>>2]|0,c[126289]|0)|0;p=o+(c[n+16>>2]|0)|0;o=ac(c[126379]|0,i)|0;s=c[n+20>>2]|0;n=p>>>16;r=s+(n<<2)|0;q=(c[r>>2]|0)+o|0;t=ac(o>>8,p>>>8&255)|0;p=s+(n+1<<2)|0;n=t+(c[p>>2]|0)|0;c[r>>2]=q-t;c[p>>2]=n}}while(0);i=d[505109]|0;k=i>>>4&7;l=i&7;i=~~(+h[63147]*.6*.25/15.0*.125*+((k>>>0<l>>>0?l:k)+1|0)*1073741824.0+.5);c[126377]=i;c[126379]=i;return}if((e|0)==65318){if(((b^f)&128|0)==0){return}c[126292]=0;i=c[126299]|0;k=i+32|0;l=c[k>>2]|0;m=-l|0;do{if((l|0)!=0){c[k>>2]=0;n=c[i+16>>2]|0;if((n|0)==0){break}p=ac(c[n+12>>2]|0,c[126289]|0)|0;t=p+(c[n+16>>2]|0)|0;p=ac(c[126379]|0,m)|0;q=c[n+20>>2]|0;n=t>>>16;r=q+(n<<2)|0;s=(c[r>>2]|0)+p|0;o=ac(p>>8,t>>>8&255)|0;t=q+(n+1<<2)|0;n=o+(c[t>>2]|0)|0;c[r>>2]=s-o;c[t>>2]=n}}while(0);m=c[126298]|0;i=m+32|0;k=c[i>>2]|0;l=-k|0;do{if((k|0)!=0){c[i>>2]=0;n=c[m+16>>2]|0;if((n|0)==0){break}t=ac(c[n+12>>2]|0,c[126289]|0)|0;o=t+(c[n+16>>2]|0)|0;t=ac(c[126379]|0,l)|0;s=c[n+20>>2]|0;n=o>>>16;r=s+(n<<2)|0;q=(c[r>>2]|0)+t|0;p=ac(t>>8,o>>>8&255)|0;o=s+(n+1<<2)|0;n=p+(c[o>>2]|0)|0;c[r>>2]=q-p;c[o>>2]=n}}while(0);l=c[126297]|0;m=l+32|0;i=c[m>>2]|0;k=-i|0;do{if((i|0)!=0){c[m>>2]=0;n=c[l+16>>2]|0;if((n|0)==0){break}o=ac(c[n+12>>2]|0,c[126289]|0)|0;p=o+(c[n+16>>2]|0)|0;o=ac(c[126379]|0,k)|0;q=c[n+20>>2]|0;n=p>>>16;r=q+(n<<2)|0;s=(c[r>>2]|0)+o|0;t=ac(o>>8,p>>>8&255)|0;p=q+(n+1<<2)|0;n=t+(c[p>>2]|0)|0;c[r>>2]=s-t;c[p>>2]=n}}while(0);k=c[126296]|0;l=k+32|0;m=c[l>>2]|0;i=-m|0;do{if((m|0)!=0){c[l>>2]=0;n=c[k+16>>2]|0;if((n|0)==0){break}p=ac(c[n+12>>2]|0,c[126289]|0)|0;t=p+(c[n+16>>2]|0)|0;p=ac(c[126379]|0,i)|0;s=c[n+20>>2]|0;n=t>>>16;r=s+(n<<2)|0;q=(c[r>>2]|0)+p|0;o=ac(p>>8,t>>>8&255)|0;t=s+(n+1<<2)|0;n=o+(c[t>>2]|0)|0;c[r>>2]=q-o;c[t>>2]=n}}while(0);v3(505089,0,32);c[126315]=0;c[126316]=0;c[126304]=0;c[126308]=0;c[126313]=0;a[505256]=0;v3(505272,0,10);c[126311]=1073741824;c[126336]=0;c[126337]=0;c[126325]=0;c[126329]=0;c[126334]=0;a[505340]=0;c[126332]=1073741824;c[126354]=0;c[126343]=0;c[126347]=0;c[126350]=0;c[126352]=0;a[505412]=0;c[126375]=0;c[126372]=0;c[126373]=0;c[126361]=0;c[126365]=0;c[126370]=0;a[505484]=0;c[126368]=16;i=~~(+h[63147]*.6*.25/15.0*.125*1073741824.0+.5);c[126377]=i;c[126379]=i;c[126312]=64;c[126333]=64;c[126351]=256;c[126369]=64;a[505111]=j;return}else if((e|0)==65317){e=3;while(1){j=c[505184+(e<<2)>>2]|0;i=(d[505110]|0)>>>(e>>>0);k=c[j+((i>>>3&2|i&1)<<2)>>2]|0;i=j+16|0;l=c[i>>2]|0;if((l|0)!=(k|0)){m=j+32|0;j=c[m>>2]|0;n=-j|0;do{if((j|0)!=0){c[m>>2]=0;if((l|0)==0){break}t=ac(c[l+12>>2]|0,c[126289]|0)|0;o=t+(c[l+16>>2]|0)|0;t=ac(c[126379]|0,n)|0;q=c[l+20>>2]|0;r=o>>>16;s=q+(r<<2)|0;p=(c[s>>2]|0)+t|0;u=ac(t>>8,o>>>8&255)|0;o=q+(r+1<<2)|0;r=u+(c[o>>2]|0)|0;c[s>>2]=p-u;c[o>>2]=r}}while(0);c[i>>2]=k}if((e|0)<=0){break}e=e-1|0}return}else{return}}e=(g|0)/5|0;l=(e*-5|0)+g|0;if((e|0)==2){if((l|0)==1){c[126351]=256-f;return}else if((l|0)==4){g=c[126344]|0;n=g+4|0;m=d[n]|0;j=(c[126292]&1|0)!=0;do{if(j){if((b&64|0)!=0){break}r=c[126351]|0;if((r|0)==0){break}if((m&64|0)==0){break}c[126351]=r-1}}while(0);if((m&128|0)==0){if((c[126351]|0)!=0){return}a[505412]=0;return}a[505412]=1;do{if((c[126351]|0)==0){c[126351]=256;if(!j){break}if((m&64|0)==0){break}c[126351]=255}}while(0);if((a[g]|0)>=0){a[505412]=0}c[126352]=0;c[126350]=(2048-(d[n]<<8&1792|d[g+3|0])<<3)+24;return}else if((l|0)==0){if((a[c[126344]|0]|0)<0){return}a[505412]=0;return}else{return}}else if((e|0)==3){if(!(jB(505428,c[126292]|0,l,b,f)|0)){return}c[126370]=32767;c[126368]=(c[126368]|0)+32;return}else if((e|0)==0){g=c[126292]|0;do{if((l|0)==0){if((a[505280]&1)==0){break}if((a[505281]&1)==0){break}if((f&8|0)!=0){break}a[505256]=0}}while(0);if(!(jB(505200,g,l,b,f)|0)){return}g=c[126305]|0;n=g+4|0;m=g+3|0;c[126311]=2048-(d[n]<<8&1792|d[m])<<4|c[126311]&15;j=d[n]<<8&1792|d[m];c[126318]=j;a[505281]=0;m=(d[g]|0)>>>4&7;c[126319]=(m|0)==0?8:m;a[505280]=(a[g]&119)!=0|0;m=a[g]|0;if((m&7)==0){return}g=j>>>((m&7)>>>0);n=(m&255)>>>3&1;a[505281]=n;if(((n<<24>>24!=0?-g|0:g)+j|0)<=2047){return}a[505256]=0;return}else if((e|0)==1){if(!(jB(505284,c[126292]|0,l,b,f)|0)){return}f=c[126326]|0;c[126332]=2048-(d[f+4|0]<<8&1792|d[f+3|0])<<4|c[126332]&15;return}else{return}}function jG(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=c[120068]|0;a[g+e|0]=f;h=167772-(c[322]|0)|0;jF(h,b,f&255);if((e|0)!=132){return}e=g+130|0;c[193613]=(d[e]|0)>>>2&1^1;f=g+132|0;do{if((a[f]|0)<0){b=a[g+131|0]&3;if((b|0)==1){i=813648;break}else if((b|0)==2){i=813616;break}else if((b|0)==3){i=813680;break}else{i=0;break}}else{i=0}}while(0);b=c[193614]|0;if((b|0)!=(i|0)){if((b|0)!=0){j=-(c[193611]|0)|0;k=ac(c[b+12>>2]|0,h)|0;l=k+(c[b+16>>2]|0)|0;k=ac(a[51760]|0?-2768240:0,j)|0;j=c[b+20>>2]|0;b=l>>>16;m=j+(b<<2)|0;n=(c[m>>2]|0)+k|0;o=ac(k>>8,l>>>8&255)|0;l=j+(b+1<<2)|0;b=o+(c[l>>2]|0)|0;c[m>>2]=n-o;c[l>>2]=b}c[193611]=0;c[193614]=i}c[193632]=(d[e]|0)>>>3&1^1;do{if((a[f]|0)<0){e=(d[g+131|0]|0)>>>4&3;if((e|0)==1){p=813648;break}else if((e|0)==2){p=813616;break}else if((e|0)==3){p=813680;break}else{p=0;break}}else{p=0}}while(0);g=c[193633]|0;if((g|0)==(p|0)){return}if((g|0)!=0){f=-(c[193630]|0)|0;e=ac(c[g+12>>2]|0,h)|0;h=e+(c[g+16>>2]|0)|0;e=ac(a[51760]|0?-2768240:0,f)|0;f=c[g+20>>2]|0;g=h>>>16;i=f+(g<<2)|0;b=(c[i>>2]|0)+e|0;l=ac(e>>8,h>>>8&255)|0;h=f+(g+1<<2)|0;g=l+(c[h>>2]|0)|0;c[i>>2]=b-l;c[h>>2]=g}c[193630]=0;c[193633]=p;return}function jH(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a[774384]=(b&768|0)!=0|0;c[193610]=b>>>10&1;if((b&2048|0)!=0){v3(774385,0,32);v3(774420,0,16)}b=c[193609]|0;f=c[120068]|0;g=f+130|0;c[193613]=~d[g]>>>((b+2|0)>>>0)&1;h=f+132|0;do{if((a[h]|0)<0){i=(d[f+131|0]|0)>>>(b<<2>>>0)&3;if((i|0)==3){j=813680;break}else if((i|0)==2){j=813616;break}else if((i|0)==1){j=813648;break}else{j=0;break}}else{j=0}}while(0);b=c[193614]|0;if((b|0)!=(j|0)){if((b|0)!=0){i=-(c[193611]|0)|0;k=ac(c[b+12>>2]|0,167772-(c[322]|0)|0)|0;l=k+(c[b+16>>2]|0)|0;k=ac(a[51760]|0?-2768240:0,i)|0;i=c[b+20>>2]|0;b=l>>>16;m=i+(b<<2)|0;n=(c[m>>2]|0)+k|0;o=ac(k>>8,l>>>8&255)|0;l=i+(b+1<<2)|0;b=o+(c[l>>2]|0)|0;c[m>>2]=n-o;c[l>>2]=b}c[193611]=0;c[193614]=j}if((j|0)!=0){b=167772-(c[322]|0)|0;l=c[193606]<<24>>24>>c[193613];c[193606]=l;o=c[193611]|0;if((l|0)!=(o|0)){c[193611]=l;n=ac(c[j+12>>2]|0,b)|0;m=n+(c[j+16>>2]|0)|0;n=ac(a[51760]|0?-2768240:0,l-o|0)|0;o=c[j+20>>2]|0;j=m>>>16;l=o+(j<<2)|0;i=(c[l>>2]|0)+n|0;k=ac(n>>8,m>>>8&255)|0;m=o+(j+1<<2)|0;j=k+(c[m>>2]|0)|0;c[l>>2]=i-k;c[m>>2]=j}c[193612]=b}a[774460]=(e&768|0)!=0|0;c[193629]=e>>>10&1;if((e&2048|0)!=0){v3(774461,0,32);v3(774496,0,16)}e=c[193628]|0;c[193632]=~d[g]>>>((e+2|0)>>>0)&1;do{if((a[h]|0)<0){g=(d[f+131|0]|0)>>>(e<<2>>>0)&3;if((g|0)==1){p=813648;break}else if((g|0)==3){p=813680;break}else if((g|0)==2){p=813616;break}else{p=0;break}}else{p=0}}while(0);e=c[193633]|0;if((e|0)!=(p|0)){if((e|0)!=0){f=-(c[193630]|0)|0;h=ac(c[e+12>>2]|0,167772-(c[322]|0)|0)|0;g=h+(c[e+16>>2]|0)|0;h=ac(a[51760]|0?-2768240:0,f)|0;f=c[e+20>>2]|0;e=g>>>16;b=f+(e<<2)|0;j=(c[b>>2]|0)+h|0;m=ac(h>>8,g>>>8&255)|0;g=f+(e+1<<2)|0;e=m+(c[g>>2]|0)|0;c[b>>2]=j-m;c[g>>2]=e}c[193630]=0;c[193633]=p}if((p|0)==0){return}e=167772-(c[322]|0)|0;g=c[193625]<<24>>24>>c[193632];c[193625]=g;m=c[193630]|0;if((g|0)!=(m|0)){c[193630]=g;j=ac(c[p+12>>2]|0,e)|0;b=j+(c[p+16>>2]|0)|0;j=ac(a[51760]|0?-2768240:0,g-m|0)|0;m=c[p+20>>2]|0;p=b>>>16;g=m+(p<<2)|0;f=(c[g>>2]|0)+j|0;h=ac(j>>8,b>>>8&255)|0;b=m+(p+1<<2)|0;p=h+(c[b>>2]|0)|0;c[g>>2]=f-h;c[b>>2]=p}c[193631]=e;return}function jI(e){e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0;f=i;i=i+56|0;j=f|0;k=f+8|0;l=f+16|0;m=f+24|0;n=774420+(e*76|0)|0;o=c[n>>2]|0;do{if((o|0)<17){p=774436+(e*76|0)|0;kj(3,(c[p>>2]|0)!=0?4:2);q=c[n>>2]|0;if((q|0)>=17){r=q;break}q=(c[p>>2]|0)!=0?164:160;c[m>>2]=q;p=q|2;c[m+4>>2]=p;c[m+8>>2]=q;c[m+12>>2]=p;c[m+16>>2]=q;c[m+20>>2]=p;c[m+24>>2]=q;c[m+28>>2]=p;p=l;s=j|0;t=j+4|0;u=k|0;v=k+4|0;w=1;x=q;while(1){L3387:do{switch(x|0){case 164:case 166:{a[774461+(c[193627]|0)|0]=0;a[(c[193627]|0)+774462|0]=0;c[193624]=(c[193624]|0)+2;c[193627]=(c[193627]|0)+2&31;b[(c[120068]|0)+x>>1]=0;break};case 130:{q=(c[120068]|0)+130|0;b[q>>1]=0;jH(0,0);y=+g[52048+((a[q]&3)<<2)>>2];if(+h[63147]==y){break L3387}h[63147]=y;q=d[505109]|0;z=q>>>4&7;A=q&7;q=~~(y*.6*.25/15.0*.125*+((z>>>0<A>>>0?A:z)+1|0)*1073741824.0+.5);c[126377]=q;c[126379]=q;break};case 136:{b[(c[120068]|0)+136>>1]=0;break};case 160:case 162:{a[774385+(c[193608]|0)|0]=0;a[(c[193608]|0)+774386|0]=0;c[193605]=(c[193605]|0)+2;c[193608]=(c[193608]|0)+2&31;b[(c[120068]|0)+x>>1]=0;break};default:{q=x&-2;z=x|1;c[u>>2]=q;c[v>>2]=z;b[l>>1]=0;c[s>>2]=c[124824+(q-96<<2)>>2];c[t>>2]=c[124824+(z-96<<2)>>2];jE(s,u,p)}}}while(0);if((w|0)>=8){break}z=c[m+(w<<2)>>2]|0;w=w+1|0;x=z}r=c[n>>2]|0}else{r=o}}while(0);c[n>>2]=r-1;r=774428+(e*76|0)|0;n=c[r>>2]|0;o=a[774385+(e*76|0)+n|0]|0;m=774424+(e*76|0)|0;c[m>>2]=o&255;c[r>>2]=n+1&31;n=c[774456+(e*76|0)>>2]|0;if((n|0)==0){i=f;return}r=167772-(c[322]|0)|0;l=o<<24>>24>>c[774452+(e*76|0)>>2];c[m>>2]=l;m=774444+(e*76|0)|0;o=c[m>>2]|0;if((l|0)!=(o|0)){c[m>>2]=l;m=ac(c[n+12>>2]|0,r)|0;k=m+(c[n+16>>2]|0)|0;m=ac(a[51760]|0?-2768240:0,l-o|0)|0;o=c[n+20>>2]|0;n=k>>>16;l=o+(n<<2)|0;j=(c[l>>2]|0)+m|0;x=ac(m>>8,k>>>8&255)|0;k=o+(n+1<<2)|0;n=x+(c[k>>2]|0)|0;c[l>>2]=j-x;c[k>>2]=n}c[774448+(e*76|0)>>2]=r;i=f;return}function jJ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0;L3406:while(1){e=c[126290]|0;f=(e|0)<(b|0)?e:b;jC(505200,c[126289]|0,f);jC(505284,c[126289]|0,f);e=c[126289]|0;g=c[126344]|0;h=(d[g+2|0]|0)>>>5&(c[126355]|3);i=d[51672+h|0]|0;j=c[126343]|0;do{if((j|0)==0){k=0}else{l=c[126346]|0;if((a[g]|0)<0){if((d[g+4|0]<<8&1792|d[g+3|0])>>>0<2044|(c[126350]|0)>60){if((h|0)==0){m=0}else{m=a[505412]&1}n=m;o=-m&240&c[126354]<<(c[126352]<<2&4)}else{n=0;o=128}p=n;q=((ac(o,i)|0)>>6)-7|0}else{p=0;q=l}l=c[126347]|0;if((l|0)==(q|0)){k=p;break}c[126347]=q;r=c[126349]|0;s=ac(c[j+12>>2]|0,e)|0;t=s+(c[j+16>>2]|0)|0;s=ac(c[r+4>>2]|0,q-l|0)|0;l=c[j+20>>2]|0;r=t>>>16;u=l+(r<<2)|0;v=(c[u>>2]|0)+s|0;w=ac(s>>8,t>>>8&255)|0;t=l+(r+1<<2)|0;r=w+(c[t>>2]|0)|0;c[u>>2]=v-w;c[t>>2]=r;k=p}}while(0);h=(c[126350]|0)+e|0;if((h|0)<(f|0)){g=c[126356]|0;r=c[126344]|0;t=d[r]&c[126355];w=t&32;v=w|31;if((t&64|0)==0){x=g;y=0}else{x=g+(16-(w>>>1))|0;y=w}w=(c[126352]^y)+1&v;g=2048-(d[r+4|0]<<8&1792|d[r+3|0])<<3;if((k|0)==0){r=(f-1-h+g|0)/(g|0)|0;z=(ac(r,g)|0)+h|0;A=r+w|0}else{r=j+12|0;t=j+16|0;u=j+20|0;l=h;s=(c[126347]|0)+7|0;B=w;while(1){C=B+1&v;w=(ac(d[x+(B>>1)|0]<<(B<<2&4)&240,i)|0)>>>6;if((w|0)==(s|0)){D=s}else{E=c[126349]|0;F=ac(c[r>>2]|0,l)|0;G=F+(c[t>>2]|0)|0;F=ac(c[E+4>>2]|0,w-s|0)|0;E=c[u>>2]|0;H=G>>>16;I=E+(H<<2)|0;J=(c[I>>2]|0)+F|0;K=ac(F>>8,G>>>8&255)|0;G=E+(H+1<<2)|0;H=K+(c[G>>2]|0)|0;c[I>>2]=J-K;c[G>>2]=H;D=w}L=l+g|0;if((L|0)<(f|0)){l=L;s=D;B=C}else{break}}c[126347]=D-7;z=L;A=C}B=A+63&v;if((a[505412]&1)!=0){c[126354]=d[x+(B>>>1)|0]|0}c[126352]=B^y;M=z}else{M=h}c[126350]=M-f;B=c[126289]|0;s=c[126361]|0;do{if((s|0)==0){N=0}else{l=c[126364]|0;do{if((d[(c[126362]|0)+2|0]|0)>7){g=(a[505484]&1)==0?0:c[126373]|0;u=g>>1;if((c[126370]&1|0)!=0){O=g;P=-u|0;break}O=-g|0;P=g-u|0}else{O=0;P=l}}while(0);l=-O|0;u=-P|0;g=c[126365]|0;if((g|0)==(u|0)){N=l;break}c[126365]=u;t=c[126367]|0;r=ac(c[s+12>>2]|0,B)|0;i=r+(c[s+16>>2]|0)|0;r=ac(c[t+4>>2]|0,u-g|0)|0;g=c[s+20>>2]|0;u=i>>>16;t=g+(u<<2)|0;j=(c[t>>2]|0)+r|0;e=ac(r>>8,i>>>8&255)|0;i=g+(u+1<<2)|0;u=e+(c[i>>2]|0)|0;c[t>>2]=j-e;c[i>>2]=u;N=l}}while(0);h=(c[126362]|0)+3|0;v=d[h]|0;l=d[51664+(v&7)|0]|0;u=l<<2;i=c[126368]|0;e=f-B-i|0;j=8<<(v>>>4);v=c[126375]|0;t=i+B+(ac((j>>1^v)&j-1,u)|0)|0;if((e|0)<0){Q=0}else{Q=(u-1+e|0)/(u|0)|0}c[126375]=v-Q&131071;c[126368]=(ac(Q,u)|0)-e;if((t|0)<(f|0)){e=a[h]|0;h=e&255;u=h<<3|-16449;v=u^64;j=c[126370]|0;i=l<<5<<(h>>>4);L3453:do{if((e&255)>223){R=j}else{if((N|0)!=0){h=u^-65;l=s+12|0;g=s+16|0;r=s+20|0;w=t;H=-N|0;G=j;while(1){K=G>>>1&v;if((G+1&2|0)==0){S=H;T=K}else{J=-H|0;I=c[126367]|0;E=ac(c[l>>2]|0,w)|0;F=E+(c[g>>2]|0)|0;E=ac(c[I+4>>2]|0,J)|0;I=c[r>>2]|0;U=F>>>16;V=I+(U<<2)|0;W=(c[V>>2]|0)+E|0;X=ac(E>>8,F>>>8&255)|0;F=I+(U+1<<2)|0;U=X+(c[F>>2]|0)|0;c[V>>2]=W-X;c[F>>2]=U;S=J;T=K|h}K=w+i|0;if((K|0)<(f|0)){w=K;H=S;G=T}else{break}}if((S|0)!=(N|0)){R=T;break}c[126365]=(c[126365]|0)+N;R=T;break}G=(f-1-t+i|0)/(i|0)|0;H=u^-65;if((u|0)==-16449){if((G|0)>32766){Y=(G|0)%32767|0}else{Y=G}w=j<<15&32768^j;h=Y-255|0;if((h|0)>0){r=w;g=h;do{h=r&14;r=r>>>3^r^h<<11^h<<12;g=g-255|0;}while((g|0)>0);Z=r;_=(((Y-256|0)>>>0)%255|0)+1|0}else{Z=w;_=Y}g=_-15|0;if((g|0)>0){h=Z;l=g;do{h=h>>>1^h^((h&2)*24576|0);l=l-15|0;}while((l|0)>0);$=(((_-16|0)>>>0)%15|0)+1|0;aa=h}else{$=_;aa=Z}while(1){ab=((aa&2)*24576|0)^aa>>>1;if(($|0)>0){$=$-1|0;aa=ab}else{break}}R=ab&32767;break}else{if((G|0)<8){h=G;l=j;while(1){w=H&-(l+3&2)^(l>>>1|H);if((h|0)>0){h=h-1|0;l=w}else{R=w;break L3453}}}if((G|0)>127){l=(G|0)%127|0;ad=(l|0)==0?127:l}else{ad=G}l=j<<1&254|j<<8&256;h=ad-7|0;if((h|0)>0){H=l;w=h;do{H=H>>>1^H^((H&4)*96|0);w=w-7|0;}while((w|0)>0);ae=H;af=(((ad-8|0)>>>0)%7|0)+1|0}else{ae=l;af=ad}if((af|0)>0){w=ae;G=af;while(1){h=G-1|0;r=((w&4)*96|0)^w>>>1;if((h|0)>0){w=r;G=h}else{ag=r;break}}}else{ag=ae}R=ag<<7&32640|ag>>>1&127;break}}}while(0);c[126370]=R}c[126289]=f;if((f|0)==(b|0)){break}c[126290]=(c[126290]|0)+(c[126291]<<2);j=c[126292]|0;c[126292]=j+1;L3502:do{switch(j|0){case 2:case 6:{u=(c[126319]|0)-1|0;c[126319]=u;if((u|0)>=1){break L3502}u=c[126305]|0;i=(d[u]|0)>>>4&7;c[126319]=(i|0)==0?8:i;if((a[505280]&1)==0){break L3502}i=a[u]|0;if((i&112)==0){break L3502}t=i&7;v=c[126318]|0;s=v>>t;e=(i&255)>>>3&1;a[505281]=e;i=(e<<24>>24!=0?-s|0:s)+v|0;do{if((i|0)>2047){a[505256]=0;ah=u;ai=v}else{if((t|0)==0){ah=u;ai=v;break}c[126318]=i;a[u+3|0]=i&255;s=(c[126305]|0)+4|0;a[s]=(a[s]&248|i>>>8&7)&255;ah=c[126305]|0;ai=c[126318]|0}}while(0);i=a[ah]|0;u=ai>>(i&7);v=(i&255)>>>3&1;a[505281]=v;if(((v<<24>>24!=0?-u|0:u)+ai|0)<=2047){break L3502}a[505256]=0;break};case 0:case 4:{break};case 7:{c[126292]=0;do{if((a[505268]&1)!=0){u=(c[126315]|0)-1|0;c[126315]=u;if((u|0)>=1){break}u=(c[126305]|0)+2|0;v=a[u]&7;c[126315]=(v|0)!=0?v:8;if((v|0)==0){break}v=((a[u]&8)!=0?1:-1)+(c[126316]|0)|0;if(v>>>0<16){c[126316]=v;break}else{a[505268]=0;break}}}while(0);do{if((a[505352]&1)!=0){v=(c[126336]|0)-1|0;c[126336]=v;if((v|0)>=1){break}v=(c[126326]|0)+2|0;u=a[v]&7;c[126336]=(u|0)!=0?u:8;if((u|0)==0){break}u=((a[v]&8)!=0?1:-1)+(c[126337]|0)|0;if(u>>>0<16){c[126337]=u;break}else{a[505352]=0;break}}}while(0);if((a[505496]&1)==0){continue L3406}u=(c[126372]|0)-1|0;c[126372]=u;if((u|0)>=1){continue L3406}u=(c[126362]|0)+2|0;v=a[u]&7;c[126372]=(v|0)!=0?v:8;if((v|0)==0){continue L3406}v=((a[u]&8)!=0?1:-1)+(c[126373]|0)|0;if(v>>>0<16){c[126373]=v;continue L3406}else{a[505496]=0;continue L3406}break};default:{continue L3406}}}while(0);do{if((a[(c[126305]|0)+4|0]&64)!=0){j=c[126312]|0;if((j|0)==0){break}f=j-1|0;c[126312]=f;if((f|0)>=1){break}a[505256]=0}}while(0);do{if((a[(c[126326]|0)+4|0]&64)!=0){f=c[126333]|0;if((f|0)==0){break}j=f-1|0;c[126333]=j;if((j|0)>=1){break}a[505340]=0}}while(0);do{if((a[(c[126344]|0)+4|0]&64)!=0){j=c[126351]|0;if((j|0)==0){break}f=j-1|0;c[126351]=f;if((f|0)>=1){break}a[505412]=0}}while(0);if((a[(c[126362]|0)+4|0]&64)==0){continue}f=c[126369]|0;if((f|0)==0){continue}j=f-1|0;c[126369]=j;if((j|0)>=1){continue}a[505484]=0}return}function jK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;jL();jM();c[194196]=0;c[203424]=0;c[203427]=0;b=c[203425]|0;if((b|0)!=0){v3(b|0,0,(c[203426]<<2)+72|0)}c[203416]=0;c[203419]=0;b=c[203417]|0;if((b|0)!=0){v3(b|0,0,(c[203418]<<2)+72|0)}c[203408]=0;c[203411]=0;b=c[203409]|0;if((b|0)!=0){v3(b|0,0,(c[203410]<<2)+72|0)}c[322]=167772;b=c[120068]|0;e=b+132|0;a[e]=-128;jF(0,65318,128);f=b+130|0;c[193613]=(d[f]|0)>>>2&1^1;do{if((a[e]|0)<0){g=a[b+131|0]&3;if((g|0)==1){h=813648;break}else if((g|0)==2){h=813616;break}else if((g|0)==3){h=813680;break}else{h=0;break}}else{h=0}}while(0);g=c[193614]|0;if((g|0)!=(h|0)){if((g|0)!=0){i=c[g+16>>2]|0;j=ac(a[51760]|0?-2768240:0,-(c[193611]|0)|0)|0;k=c[g+20>>2]|0;g=i>>>16;l=k+(g<<2)|0;m=(c[l>>2]|0)+j|0;n=ac(j>>8,i>>>8&255)|0;i=k+(g+1<<2)|0;g=n+(c[i>>2]|0)|0;c[l>>2]=m-n;c[i>>2]=g}c[193611]=0;c[193614]=h}c[193632]=(d[f]|0)>>>3&1^1;do{if((a[e]|0)<0){f=(d[b+131|0]|0)>>>4&3;if((f|0)==1){o=813648;break}else if((f|0)==2){o=813616;break}else if((f|0)==3){o=813680;break}else{o=0;break}}else{o=0}}while(0);b=c[193633]|0;if((b|0)==(o|0)){return}if((b|0)!=0){e=c[b+16>>2]|0;f=ac(a[51760]|0?-2768240:0,-(c[193630]|0)|0)|0;h=c[b+20>>2]|0;b=e>>>16;g=h+(b<<2)|0;i=(c[g>>2]|0)+f|0;n=ac(f>>8,e>>>8&255)|0;e=h+(b+1<<2)|0;b=n+(c[e>>2]|0)|0;c[g>>2]=i-n;c[e>>2]=b}c[193630]=0;c[193633]=o;return}function jL(){var b=0,e=0,f=0.0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[120068]|0)==0){return}v3(774444,0,16);v3(774520,0,16);b=a[1296]|0?32e3:22050;c[194196]=0;e=(((b*251|0)+999|0)>>>0)/1e3|0;f=+(b|0);i=e*1e3|0;j=(e<<2)+72|0;do{if((c[203426]|0)==(e|0)){k=2622}else{l=v$(c[203425]|0,j)|0;if((l|0)==0){break}c[203425]=l;k=2622}}while(0);do{if((k|0)==2622){c[203426]=e;c[203422]=b;l=((i>>>0)/(b>>>0)|0)-1|0;c[203421]=l;m=c[203420]|0;if((m|0)!=0){c[203423]=~~+Q(+(f/+(m|0)*65536.0+.5))}c[203424]=0;c[203427]=0;m=c[203425]|0;if((m|0)!=0){v3(m|0,0,j|0)}if((c[203418]|0)!=(e|0)){m=v$(c[203417]|0,j)|0;if((m|0)==0){break}c[203417]=m}c[203418]=e;c[203414]=b;c[203413]=l;m=c[203412]|0;if((m|0)!=0){c[203415]=~~+Q(+(f/+(m|0)*65536.0+.5))}c[203416]=0;c[203419]=0;m=c[203417]|0;if((m|0)!=0){v3(m|0,0,j|0)}if((c[203410]|0)!=(e|0)){m=v$(c[203409]|0,j)|0;if((m|0)==0){break}c[203409]=m}c[203410]=e;c[203406]=b;c[203405]=l;l=c[203404]|0;if((l|0)!=0){c[203407]=~~+Q(+(f/+(l|0)*65536.0+.5))}c[203408]=0;c[203411]=0;l=c[203409]|0;if((l|0)==0){break}v3(l|0,0,j|0)}}while(0);c[203423]=~~+Q(+(+(c[203422]|0)*5.960464477539063e-8*65536.0+.5));c[203415]=~~+Q(+(+(c[203414]|0)*5.960464477539063e-8*65536.0+.5));c[203407]=~~+Q(+(+(c[203406]|0)*5.960464477539063e-8*65536.0+.5));c[193609]=0;c[193628]=1;c[126356]=505121;c[126296]=505200;c[126297]=505284;c[126298]=505356;c[126299]=505428;c[126362]=505104;v3(505428,0,20);c[126366]=505504;c[126367]=505512;c[126344]=505099;v3(505356,0,20);c[126348]=505504;c[126349]=505512;c[126326]=505094;v3(505284,0,20);c[126330]=505504;c[126331]=505512;c[126305]=505089;v3(505200,0,20);c[126309]=505504;c[126310]=505512;a[505088]=0;c[126291]=8192;h[63147]=1.0;jM();jM();c[194196]=0;c[203424]=0;c[203427]=0;j=c[203425]|0;if((j|0)!=0){v3(j|0,0,(c[203426]<<2)+72|0)}c[203416]=0;c[203419]=0;j=c[203417]|0;if((j|0)!=0){v3(j|0,0,(c[203418]<<2)+72|0)}c[203408]=0;c[203411]=0;j=c[203409]|0;if((j|0)!=0){v3(j|0,0,(c[203410]<<2)+72|0)}c[322]=167772;j=c[120068]|0;b=j+130|0;c[193632]=(d[b]|0)>>>2&1^1;e=j+132|0;do{if((a[e]|0)<0){i=a[j+131|0]&3;if((i|0)==3){n=813680;break}else if((i|0)==2){n=813616;break}else if((i|0)==1){n=813648;break}else{n=0;break}}else{n=0}}while(0);i=c[193633]|0;if((i|0)!=(n|0)){if((i|0)!=0){k=c[i+16>>2]|0;l=ac(a[51760]|0?-2768240:0,-(c[193630]|0)|0)|0;m=c[i+20>>2]|0;i=k>>>16;o=m+(i<<2)|0;p=(c[o>>2]|0)+l|0;q=ac(l>>8,k>>>8&255)|0;k=m+(i+1<<2)|0;i=q+(c[k>>2]|0)|0;c[o>>2]=p-q;c[k>>2]=i}c[193630]=0;c[193633]=n}c[193632]=(d[b]|0)>>>3&1^1;do{if((a[e]|0)<0){i=(d[j+131|0]|0)>>>4&3;if((i|0)==1){r=813648;break}else if((i|0)==2){r=813616;break}else if((i|0)==3){r=813680;break}else{r=0;break}}else{r=0}}while(0);if((n|0)!=(r|0)){if((n|0)!=0){j=c[n+16>>2]|0;e=ac(a[51760]|0?-2768240:0,-(c[193630]|0)|0)|0;i=c[n+20>>2]|0;n=j>>>16;k=i+(n<<2)|0;q=(c[k>>2]|0)+e|0;p=ac(e>>8,j>>>8&255)|0;j=i+(n+1<<2)|0;n=p+(c[j>>2]|0)|0;c[k>>2]=q-p;c[j>>2]=n}c[193630]=0;c[193633]=r}r=c[126296]|0;c[r+4>>2]=813648;c[r+8>>2]=813616;c[r+12>>2]=813680;n=d[505110]|0;c[r+16>>2]=c[r+((n>>>3&2|n&1)<<2)>>2];n=c[126297]|0;c[n+4>>2]=813648;c[n+8>>2]=813616;c[n+12>>2]=813680;r=d[505110]|0;c[n+16>>2]=c[n+((r>>>4&2|r>>>1&1)<<2)>>2];r=c[126298]|0;c[r+4>>2]=813648;c[r+8>>2]=813616;c[r+12>>2]=813680;n=d[505110]|0;c[r+16>>2]=c[r+((n>>>5&2|n>>>2&1)<<2)>>2];n=c[126299]|0;c[n+4>>2]=813648;c[n+8>>2]=813616;c[n+12>>2]=813680;r=d[505110]|0;c[n+16>>2]=c[n+((r>>>6&2|r>>>3&1)<<2)>>2];f=+g[52048+((a[b]&3)<<2)>>2];if(+h[63147]!=f){h[63147]=f;b=d[505109]|0;r=b>>>4&7;n=b&7;b=~~(f*.6*.25/15.0*.125*+((r>>>0<n>>>0?n:r)+1|0)*1073741824.0+.5);c[126377]=b;c[126379]=b}a[51760]=1;return}function jM(){var b=0,e=0;c[126355]=255;c[(c[126296]|0)+24>>2]=2;c[(c[126297]|0)+24>>2]=2;c[(c[126298]|0)+24>>2]=2;c[(c[126299]|0)+24>>2]=2;a[505088]=a[505088]&1;c[(c[126296]|0)+28>>2]=0;c[(c[126297]|0)+28>>2]=0;c[(c[126298]|0)+28>>2]=0;c[(c[126299]|0)+28>>2]=0;c[126346]=-7;c[126290]=0;c[126289]=0;c[126292]=0;v3(505089,0,32);c[126315]=0;c[126316]=0;c[126304]=0;c[126308]=0;c[126313]=0;a[505256]=0;v3(505272,0,10);c[126311]=1073741824;c[126336]=0;c[126337]=0;c[126325]=0;c[126329]=0;c[126334]=0;a[505340]=0;c[126332]=1073741824;c[126354]=0;c[126343]=0;c[126347]=0;c[126350]=0;c[126352]=0;a[505412]=0;c[126375]=0;c[126372]=0;c[126373]=0;c[126361]=0;c[126365]=0;c[126370]=0;a[505484]=0;c[126368]=16;b=~~(+h[63147]*.6*.25/15.0*.125*1073741824.0+.5);c[126377]=b;c[126379]=b;c[126312]=64;c[126333]=64;c[126351]=256;c[126369]=64;b=0;do{jF(0,b+65328|0,d[51712+b|0]|0);b=b+1|0;}while(b>>>0<16);do{if((a[505111]|0)<0){if((c[126289]|0)<0){jJ(0)}a[505099]=0;if((a[c[126344]|0]|0)<0){e=0;break}a[505412]=0;e=0}else{e=0}}while(0);do{jF(0,e+65328|0,d[51712+e|0]|0);e=e+1|0;}while(e>>>0<16);return}function jN(){var b=0,d=0,e=0;c[192084]=1346454087;c[192085]=0;v6(768344,505089,64)|0;c[192102]=c[126290];c[192103]=c[126292];c[192104]=c[126318];c[192105]=c[126319];c[192106]=a[505280]&1;c[192107]=a[505281]&1;c[192108]=c[126375];c[192109]=c[126354];b=3;while(1){d=c[505184+(b<<2)>>2]|0;c[768440+(b<<2)>>2]=c[d+44>>2];c[768456+(b<<2)>>2]=c[d+48>>2];c[768472+(b<<2)>>2]=c[d+52>>2];c[768488+(b<<2)>>2]=a[d+56|0]&1;if((b|0)==2){b=1;continue}e=(b|0)>2?2:b;c[768504+(e<<2)>>2]=c[d+60>>2];c[768516+(e<<2)>>2]=c[d+64>>2];c[768528+(e<<2)>>2]=a[d+68|0]&1;if((b|0)>0){b=b-1|0}else{break}}return}function jO(){a[51760]=0;c[203407]=2147483647;c[203406]=0;c[203404]=0;c[203405]=0;v3(813632,0,16);c[203415]=2147483647;c[203414]=0;c[203412]=0;c[203413]=0;v3(813664,0,16);c[203423]=2147483647;c[203422]=0;c[203420]=0;c[203421]=0;v3(813696,0,16);dP(1184,0,p|0)|0;v3(505504,0,16);return}function jP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(a|0)==234902869;e=d?104:48;c[36854]=d?2:1;c[2396]=e;fa[e&127](a,b);return}function jQ(b,c){b=b|0;c=c|0;a[341e3+(b&65535)|0]=c;return}function jR(b){b=b|0;var e=0,f=0,g=0,h=0;e=c[191614]|0;if((e|0)==0){return}f=b&1;switch(c[191532]|0){case 4:{b=c[191536]|0;g=766152+b|0;a[g]=(a[g]<<1&255|f)&255;g=c[191542]|0;h=g+1|0;c[191542]=h;if((h&7|0)==0){c[191536]=b+1}if((g|0)==64){c[191532]=0;c[191536]=0;c[191542]=0;return}else if((g|0)==63){a[766136]=1;g=c[2374]|0;a[g+(c[191544]<<3)|0]=a[766152]|0;a[g+(c[191544]<<3|1)|0]=a[766153]|0;a[g+(c[191544]<<3|2)|0]=a[766154]|0;a[g+(c[191544]<<3|3)|0]=a[766155]|0;a[g+(c[191544]<<3|4)|0]=a[766156]|0;a[g+(c[191544]<<3|5)|0]=a[766157]|0;a[g+(c[191544]<<3|6)|0]=a[766158]|0;a[g+(c[191544]<<3|7)|0]=a[766159]|0;return}else{return}break};case 1:{g=c[191536]|0;b=766152+g|0;a[b]=(a[b]<<1&255|f)&255;b=(c[191542]|0)+1|0;c[191542]=b;if((b&7|0)==0){c[191536]=g+1}if((e|0)==81|(e|0)==17){if((b|0)!=17){return}a[766136]=1;c[2356]=8192;e=a[766152]|0;c[191544]=(e&255)<<8&16128|(d[766153]|0);if((e&64)==0){a[766152]=f&255;c[191542]=1;c[191536]=0;c[191532]=4;return}else{c[191532]=2;c[191536]=0;c[191542]=0;return}}else{if((b|0)!=9){return}a[766136]=1;b=a[766152]|0;c[191544]=b&63;if((b&64)==0){a[766152]=f&255;c[191542]=1;c[191536]=0;c[191532]=4;return}else{c[191532]=2;c[191536]=0;c[191542]=0;return}}break};case 2:case 3:{c[191532]=0;return};case 0:{c[191536]=0;c[191542]=1;a[766152]=f&255;c[191532]=1;return};default:{return}}}function jS(b,d){b=b|0;d=d|0;c[36854]=1;c[2396]=48;a[341e3+(b&65535)|0]=d;return}function jT(b,d){b=b|0;d=d|0;var e=0;e=b&65535;switch(c[191524]|0){case 9:{if((e|0)==0){c[191528]=d&1}c[191524]=0;c[191526]=0;return};case 1:{if((e|0)==10922&d<<24>>24==85){c[191524]=2;return}else{c[191524]=0;return}break};case 4:{if((e|0)==21845&d<<24>>24==-86){c[191524]=5;return}else{c[191524]=0;c[191526]=0;return}break};case 8:{a[341e3+(c[191528]<<16|e)|0]=d;c[191524]=0;c[191526]=0;return};case 0:{if(!((e|0)==21845&d<<24>>24==-86)){return}c[191524]=1;return};case 5:{if((e|0)==10922&d<<24>>24==85){c[191524]=6;return}else{c[191524]=0;c[191526]=0;return}break};case 2:{if((e|0)!=21845){c[191524]=0;c[191526]=0;return}if((d<<24>>24|0)==(-112|0)){c[191524]=3;c[191526]=3;return}else if((d<<24>>24|0)==(-16|0)){c[191524]=0;c[191526]=0;return}else if((d<<24>>24|0)==(-96|0)){c[191524]=8;return}else if((d<<24>>24|0)==(-128|0)){c[191524]=4;return}else{if(d<<24>>24==-80&(c[2346]|0)==131072){c[191524]=9;return}else{c[191524]=0;c[191526]=0;return}}break};case 6:{if((d<<24>>24|0)==16){v3(341e3,0,c[2346]|0);c[191526]=7;return}else if((d<<24>>24|0)==48){v3(341e3+(c[191528]<<16|b&61440)|0,0,4096);c[191526]=7;return}else{c[191524]=0;c[191526]=0;return}break};case 3:{if(d<<24>>24==-16){c[191524]=0;c[191526]=0;return}if((e|0)==21845&d<<24>>24==-86){c[191524]=1;return}else{c[191524]=0;c[191526]=0;return}break};default:{return}}}function jU(a,b){a=a|0;b=b|0;c[36854]=2;c[2396]=104;jT(a,b);return}function jV(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b;y=10;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=b+4|0;e=(c[36856]|0)+160|0;v6(d|0,e|0,16)|0;e=b+20|0;y=0;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;e=b+24|0;v6(e|0,776584,180)|0;e=129408;d=780688;f=b+204|0;while(1){g=c[e+4>>2]|0;v6(f|0,d|0,g)|0;h=f+g|0;i=e+8|0;j=c[i>>2]|0;if((j|0)==0){break}else{e=i;d=j;f=h}}d=h;y=a[767376]&1;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=f+(g+4)|0;y=c[191996]|0;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=f+(g+8)|0;h=c[120070]|0;v6(d|0,h|0,32768)|0;h=f+(g+32776)|0;d=c[191862]|0;v6(h|0,d|0,1024)|0;d=f+(g+33800)|0;h=c[36848]|0;v6(d|0,h|0,262144)|0;h=f+(g+295944)|0;d=c[36850]|0;v6(h|0,d|0,131072)|0;d=f+(g+427016)|0;h=c[37240]|0;v6(d|0,h|0,1024)|0;h=f+(g+428040)|0;d=c[37236]|0;v6(h|0,d|0,163840)|0;d=f+(g+591880)|0;h=c[120068]|0;v6(d|0,h|0,1024)|0;h=9432;d=766128;e=f+(g+592904)|0;while(1){k=c[h+4>>2]|0;v6(e|0,d|0,k)|0;l=e+k|0;g=h+8|0;f=c[g>>2]|0;if((f|0)==0){break}else{h=g;d=f;e=l}}d=l;y=c[2356]|0;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=e+(k+4)|0;l=c[2374]|0;v6(d|0,l|0,8192)|0;l=e+(k+8196)|0;y=c[191524]|0;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;l=e+(k+8200)|0;y=c[191526]|0;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;l=e+(k+8204)|0;y=c[2346]|0;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;l=e+(k+8208)|0;y=c[191528]|0;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;l=e+(k+8212)|0;v6(l|0,341e3,131072)|0;jN();v3(813536,0,64);l=51776;d=774428;h=e+(k+139284)|0;while(1){m=c[l+4>>2]|0;v6(h|0,d|0,m)|0;n=h+m|0;k=l+8|0;e=c[k>>2]|0;if((e|0)==0){break}else{l=k;d=e;h=n}}v6(n|0,780640,48)|0;return h+(m+48)-b|0}function jW(){var a=0;a=c[36856]|0;if((a|0)!=0){v_(a);c[36856]=0}a=c[36850]|0;if((a|0)!=0){v_(a);c[36850]=0}a=c[191862]|0;if((a|0)!=0){v_(a);c[191862]=0}a=c[120070]|0;if((a|0)!=0){v_(a);c[120070]=0}a=c[36848]|0;if((a|0)!=0){v_(a);c[36848]=0}a=c[191664]|0;if((a|0)!=0){v_(a);c[191664]=0}a=c[37236]|0;if((a|0)!=0){v_(a);c[37236]=0}a=c[37240]|0;if((a|0)!=0){v_(a);c[37240]=0}a=c[120068]|0;if((a|0)==0){return}v_(a);c[120068]=0;return}function jX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;g=c[191863]|0;h=(g&256|0)!=0;i=g>>>11;j=g>>>9&1;k=g>>>10&1;do{if((j|0)==0&(h^1)){if((k|0)!=0){l=0;m=k;n=2814;break}if((i&1|0)!=0){l=0;m=0;n=2814}}else{l=(j|0)!=0;m=k;n=2814}}while(0);if((n|0)==2814){vI(h,l,(m|0)!=0,(i&1|0)!=0)}i=e[f>>1]|0|805306368;f=0;do{m=c[768608+(f<<2)>>2]|0;l=m>>>0<i>>>0?m:i;h=c[769568+(f<<2)>>2]|0;n=h>>>24;k=n>>>0<l>>>24>>>0?h:l;l=c[770528+(f<<2)>>2]|0;j=l>>>24;g=j>>>0<k>>>24>>>0?l:k;k=c[771488+(f<<2)>>2]|0;o=k>>>24;p=o>>>0<g>>>24>>>0?k:g;g=c[772448+(f<<2)>>2]|0;do{if(g>>>24>>>0<p>>>24>>>0){if((g&65536|0)==0){q=g;break}r=m>>>0<805306368;s=r?m:i;t=n>>>0<s>>>24>>>0;u=t?h:s;s=j>>>0<u>>>24>>>0;v=s?l:u;u=o>>>0<v>>>24>>>0;w=u?k:v;v=e[384132]|0;if((v>>>8&(u?8:s?4:t?2:r?1:32)|0)==0){q=g;break}if((g|0)>-1){r=e[384300]|0;t=c[125080+((r&31)<<2)>>2]|0;s=(ac(t,g&31)|0)>>>4;u=c[125080+((r>>>8&31)<<2)>>2]|0;r=c[130360+(((ac(u,w&31)|0)>>>4)+s<<2)>>2]|0;s=(ac(t,g>>>5&31)|0)>>>4;x=c[130360+(((ac(u,w>>>5&31)|0)>>>4)+s<<2)>>2]|0;s=(ac(t,g>>>10&31)|0)>>>4;q=r|g&-65536|x<<5|c[130360+(((ac(u,w>>>10&31)|0)>>>4)+s<<2)>>2]<<10;break}if((v&16|0)==0){q=g;break}s=v>>>6&3;if((s|0)==3){v=g<<16&65011712|g&31775;w=v-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,v)|0)>>>4&65043487)|0;q=w>>>16|w;break}else if((s|0)==2){s=g<<16&65011712|g&31775;w=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-s|0)|0)>>>4&65043487)+s|0;q=w>>>16|w;break}else{q=g;break}}else{q=p}}while(0);b[a+(f+d<<1)>>1]=(q<<1&1984|q<<11|q>>>4&32|q>>>10&31)&65535;f=f+1|0;}while((f|0)<240);return}function jY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;g=c[191863]|0;h=(g&256|0)!=0;i=g>>>11;j=g>>>9&1;k=g>>>10&1;do{if((j|0)==0&(h^1)){if((k|0)!=0){l=0;m=k;n=2831;break}if((i&1|0)!=0){l=0;m=0;n=2831}}else{l=(j|0)!=0;m=k;n=2831}}while(0);if((n|0)==2831){vI(h,l,(m|0)!=0,(i&1|0)!=0)}i=e[f>>1]|0|805306368;f=(e[384132]|0)>>>6&3;m=0;do{l=c[768608+(m<<2)>>2]|0;h=l>>>0<i>>>0;n=h?l:i;k=c[769568+(m<<2)>>2]|0;j=k>>>0<(n&-16777216)>>>0;g=j?k:n;n=c[770528+(m<<2)>>2]|0;o=n>>>0<(g&-16777216)>>>0;p=o?n:g;g=c[771488+(m<<2)>>2]|0;q=g>>>0<(p&-16777216)>>>0;r=q?8:o?4:j?2:h?1:32;h=q?g:p;p=c[772448+(m<<2)>>2]|0;q=p>>>0<(h&-16777216)>>>0;j=q?16:r;o=q?p:h;do{if((o&65536|0)==0){if((f|0)==2){if(((e[384132]|0)&(j&255)|0)==0){s=o;break}q=o<<16&65011712|o&31775;t=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-q|0)|0)>>>4&65043487)+q|0;s=t>>>16|t;break}else if((f|0)==3){if(((e[384132]|0)&(j&255)|0)==0){s=o;break}t=o<<16&65011712|o&31775;q=t-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,t)|0)>>>4&65043487)|0;s=q>>>16|q;break}else if((f|0)==1){q=e[384132]|0;if((q&(j&255)|0)==0){s=o;break}t=l>>>0>=i>>>0|j<<24>>24==1;u=t?i:l;v=k>>>0>=(u&-16777216)>>>0|j<<24>>24==2;w=v?u:k;u=n>>>0>=(w&-16777216)>>>0|j<<24>>24==4;x=u?w:n;w=g>>>0>=(x&-16777216)>>>0|j<<24>>24==8;y=w?x:g;x=p>>>0>=(y&-16777216)>>>0|j<<24>>24==16;z=x?y:p;if(!((q>>>8&(x?w?u?v?t?32:1:2:4:8:16)|0)!=0&(o|0)>-1)){s=o;break}t=e[384300]|0;v=c[125080+((t&31)<<2)>>2]|0;u=(ac(v,o&31)|0)>>>4;w=c[125080+((t>>>8&31)<<2)>>2]|0;t=c[130360+(((ac(w,z&31)|0)>>>4)+u<<2)>>2]|0;u=(ac(v,o>>>5&31)|0)>>>4;x=c[130360+(((ac(w,z>>>5&31)|0)>>>4)+u<<2)>>2]|0;u=(ac(v,o>>>10&31)|0)>>>4;s=t|o&-65536|x<<5|c[130360+(((ac(w,z>>>10&31)|0)>>>4)+u<<2)>>2]<<10;break}else{s=o;break}}else{u=e[384132]|0;if((u>>>8&(r&255)|0)==0){s=o;break}if((o|0)>-1){z=e[384300]|0;w=c[125080+((z&31)<<2)>>2]|0;x=(ac(w,o&31)|0)>>>4;t=c[125080+((z>>>8&31)<<2)>>2]|0;z=c[130360+(((ac(t,h&31)|0)>>>4)+x<<2)>>2]|0;x=(ac(w,o>>>5&31)|0)>>>4;v=c[130360+(((ac(t,h>>>5&31)|0)>>>4)+x<<2)>>2]|0;x=(ac(w,o>>>10&31)|0)>>>4;s=z|o&-65536|v<<5|c[130360+(((ac(t,h>>>10&31)|0)>>>4)+x<<2)>>2]<<10;break}if((u&(j&255)|0)==0){s=o;break}x=u>>>6&3;if((x|0)==2){u=o<<16&65011712|o&31775;t=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-u|0)|0)>>>4&65043487)+u|0;s=t>>>16|t;break}else if((x|0)==3){x=o<<16&65011712|o&31775;t=x-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,x)|0)>>>4&65043487)|0;s=t>>>16|t;break}else{s=o;break}}}while(0);b[a+(m+d<<1)>>1]=(s<<1&1984|s<<11|s>>>4&32|s>>>10&31)&65535;m=m+1|0;}while((m|0)<240);return}function jZ(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;a=c[37236]|0;f=b[390347]|0;g=(f&65535)<<8;h=c[191862]|0;i=c[191863]|0;do{if((i&8192|0)==0){j=0}else{k=b[390378]|0;l=(k&65535)>>>8;m=k&255;if(l<<16>>16==m<<16>>16){n=(k&65535)>59391|0}else{n=0}k=(f&65535)>=(l&65535);if((m&65535)<(l&65535)){if(k){o=1}else{o=(f&65535)<(m&65535)|0}j=(o|n|0)!=0;break}else{if(k){p=(f&65535)<(m&65535)|0}else{p=0}j=(p|n|0)!=0;break}}}while(0);do{if((i&16384|0)==0){q=0}else{n=b[390379]|0;p=(n&65535)>>>8;o=n&255;if(p<<16>>16==o<<16>>16){r=(n&65535)>59391|0}else{r=0}n=(f&65535)>=(p&65535);if((o&65535)<(p&65535)){if(n){s=1}else{s=(f&65535)<(o&65535)|0}q=(s|r|0)!=0;break}else{if(n){t=(f&65535)<(o&65535)|0}else{t=0}q=(t|r|0)!=0;break}}}while(0);r=(i&256|0)!=0;t=i>>>11;f=i>>>9&1;s=i>>>10&1;do{if((f|0)==0&(r^1)){if((s|0)!=0){u=0;v=s;w=2875;break}if((t&1|0)!=0){u=0;v=0;w=2875}}else{u=(f|0)!=0;v=s;w=2875}}while(0);if((w|0)==2875){vI(r,u,(v|0)!=0,(t&1|0)!=0)}t=e[h>>1]|0|805306368;h=b[390380]|0;v=b[390381]&255;u=q&1;q=j&1;j=(h&65535)>>>8&65535;r=h&255;h=0;do{if((c[773408+(h<<2)>>2]|0)<0){x=v}else{x=(e[390381]|0)>>>8&255}w=(d[767464+h|0]|0)&u;s=(d[767704+h|0]|0)&q;f=(w+255&(x&255)|j&-w)&s+255|r&-s;s=(f&1|0)!=0;if(s){w=c[768608+(h<<2)>>2]|0;i=w>>>0<t>>>0;y=i?w:t;z=i?1:32}else{y=t;z=32}i=(f&2|0)!=0;if(i){w=c[769568+(h<<2)>>2]|0;o=w>>>24>>>0<y>>>24>>>0;A=o?w:y;B=o?2:z}else{A=y;B=z}o=(f&4|0)!=0;if(o){w=c[770528+(h<<2)>>2]|0;n=w>>>24>>>0<A>>>24>>>0;C=n?w:A;D=n?4:B}else{C=A;D=B}n=(f&8|0)!=0;if(n){w=c[771488+(h<<2)>>2]|0;p=w>>>24>>>0<C>>>24>>>0;E=p?w:C;F=p?8:D}else{E=C;F=D}p=(f&16|0)!=0;if(p){w=c[772448+(h<<2)>>2]|0;m=w>>>24>>>0<E>>>24>>>0;G=m?w:E;H=m?16:F}else{G=E;H=F}do{if((G&65536|0)==0){if((f&32|0)==0){I=G;break}m=e[384132]|0;if((m&(H&255)|0)==0){I=G;break}w=m>>>6&3;if((w|0)==2){k=G<<16&65011712|G&31775;l=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-k|0)|0)>>>4&65043487)+k|0;I=l>>>16|l;break}else if((w|0)==3){l=G<<16&65011712|G&31775;k=l-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,l)|0)>>>4&65043487)|0;I=k>>>16|k;break}else if((w|0)==1){if(s){w=c[768608+(h<<2)>>2]|0;k=w>>>0>805306367|H<<24>>24==1;J=k?32:1;K=k?t:w}else{J=32;K=t}if(i){w=c[769568+(h<<2)>>2]|0;k=w>>>24>>>0>=K>>>24>>>0|H<<24>>24==2;L=k?J:2;M=k?K:w}else{L=J;M=K}if(o){w=c[770528+(h<<2)>>2]|0;k=w>>>24>>>0>=M>>>24>>>0|H<<24>>24==4;N=k?L:4;O=k?M:w}else{N=L;O=M}if(n){w=c[771488+(h<<2)>>2]|0;k=w>>>24>>>0>=O>>>24>>>0|H<<24>>24==8;P=k?N:8;Q=k?O:w}else{P=N;Q=O}if(p){w=c[772448+(h<<2)>>2]|0;k=w>>>24>>>0>=Q>>>24>>>0|H<<24>>24==16;R=k?P:16;S=k?Q:w}else{R=P;S=Q}if(!((R&255&m>>>8|0)!=0&(G|0)>-1)){I=G;break}m=e[384300]|0;w=c[125080+((m&31)<<2)>>2]|0;k=(ac(w,G&31)|0)>>>4;l=c[125080+((m>>>8&31)<<2)>>2]|0;m=c[130360+(((ac(l,S&31)|0)>>>4)+k<<2)>>2]|0;k=(ac(w,G>>>5&31)|0)>>>4;T=c[130360+(((ac(l,S>>>5&31)|0)>>>4)+k<<2)>>2]|0;k=(ac(w,G>>>10&31)|0)>>>4;I=m|G&-65536|T<<5|c[130360+(((ac(l,S>>>10&31)|0)>>>4)+k<<2)>>2]<<10;break}else{I=G;break}}else{if(s){k=c[768608+(h<<2)>>2]|0;l=k>>>0<805306368;U=l?1:32;V=l?k:t}else{U=32;V=t}if(i){k=c[769568+(h<<2)>>2]|0;l=k>>>24>>>0<V>>>24>>>0;W=l?2:U;X=l?k:V}else{W=U;X=V}if(o){k=c[770528+(h<<2)>>2]|0;l=k>>>24>>>0<X>>>24>>>0;Y=l?4:W;Z=l?k:X}else{Y=W;Z=X}if(n){k=c[771488+(h<<2)>>2]|0;l=k>>>24>>>0<Z>>>24>>>0;_=l?8:Y;$=l?k:Z}else{_=Y;$=Z}k=e[384132]|0;if((k>>>8&(_&255)|0)==0){I=G;break}if((G|0)>-1){l=e[384300]|0;T=c[125080+((l&31)<<2)>>2]|0;m=(ac(T,G&31)|0)>>>4;w=c[125080+((l>>>8&31)<<2)>>2]|0;l=c[130360+(((ac(w,$&31)|0)>>>4)+m<<2)>>2]|0;m=(ac(T,G>>>5&31)|0)>>>4;aa=c[130360+(((ac(w,$>>>5&31)|0)>>>4)+m<<2)>>2]|0;m=(ac(T,G>>>10&31)|0)>>>4;I=l|G&-65536|aa<<5|c[130360+(((ac(w,$>>>10&31)|0)>>>4)+m<<2)>>2]<<10;break}if((k&(H&255)|0)==0){I=G;break}m=k>>>6&3;if((m|0)==2){k=G<<16&65011712|G&31775;w=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-k|0)|0)>>>4&65043487)+k|0;I=w>>>16|w;break}else if((m|0)==3){m=G<<16&65011712|G&31775;w=m-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,m)|0)>>>4&65043487)|0;I=w>>>16|w;break}else{I=G;break}}}while(0);b[a+(h+g<<1)>>1]=(I<<1&1984|I<<11|I>>>4&32|I>>>10&31)&65535;h=h+1|0;}while((h|0)<240);return}function j_(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;g=c[191863]|0;h=(g&256|0)!=0;i=g>>>9&1;if((i|0)==0&(h^1)){j=g}else{vI(h,(i|0)!=0,0,0);j=c[191863]|0}if((j&1024|0)!=0){vL(b[390350]|0,b[384160]|0,b[384164]|0,b[384152]|0,b[384156]|0,b[390360]|0,b[390361]|0,b[390362]|0,b[390363]|0,768216,768208,c[195146]|0,770528)}j=e[f>>1]|0|805306368;f=0;do{i=c[769568+(f<<2)>>2]|0;h=i>>>24;g=c[770528+(f<<2)>>2]|0;k=g>>>24;l=c[772448+(f<<2)>>2]|0;m=l>>>24;n=k>>>0<h>>>0?k:h;o=m>>>0<n>>>0?m:n;n=c[768608+(f<<2)>>2]|0;p=n>>>0<j>>>0?n:j;do{if(o>>>0<p>>>24>>>0){if((o|0)==(h|0)){q=i;break}if((o|0)==(k|0)){q=g;break}if((o|0)!=(m|0)){q=p;break}if((l&65536|0)==0){q=l;break}r=n>>>24;s=h>>>0<r>>>0?h:r;t=k>>>0<s>>>0?k:s;do{if((t&255)<48){if((t|0)==(r|0)){u=n;v=1;break}if((t|0)==(h|0)){u=i;v=2;break}s=(t|0)==(k|0);u=s?g:j;v=s?4:32}else{u=j;v=32}}while(0);t=e[384132]|0;if((t>>>8&v|0)==0){q=l;break}if((l|0)>-1){r=e[384300]|0;s=c[125080+((r&31)<<2)>>2]|0;w=(ac(s,l&31)|0)>>>4;x=c[125080+((r>>>8&31)<<2)>>2]|0;r=c[130360+(((ac(x,u&31)|0)>>>4)+w<<2)>>2]|0;w=(ac(s,l>>>5&31)|0)>>>4;y=c[130360+(((ac(x,u>>>5&31)|0)>>>4)+w<<2)>>2]|0;w=(ac(s,l>>>10&31)|0)>>>4;q=r|l&-65536|y<<5|c[130360+(((ac(x,u>>>10&31)|0)>>>4)+w<<2)>>2]<<10;break}if((t&16|0)==0){q=l;break}w=t>>>6&3;if((w|0)==2){t=l<<16&65011712|l&31775;x=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-t|0)|0)>>>4&65043487)+t|0;q=x>>>16|x;break}else if((w|0)==3){w=l<<16&65011712|l&31775;x=w-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,w)|0)>>>4&65043487)|0;q=x>>>16|x;break}else{q=l;break}}else{q=p}}while(0);b[a+(f+d<<1)>>1]=(q<<1&1984|q<<11|q>>>4&32|q>>>10&31)&65535;f=f+1|0;}while(f>>>0<240);c[195146]=0;return}function j$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;g=c[191863]|0;h=(g&256|0)!=0;i=g>>>9&1;if((i|0)==0&(h^1)){j=g}else{vI(h,(i|0)!=0,0,0);j=c[191863]|0}if((j&1024|0)!=0){vL(b[390350]|0,b[384160]|0,b[384164]|0,b[384152]|0,b[384156]|0,b[390360]|0,b[390361]|0,b[390362]|0,b[390363]|0,768216,768208,c[195146]|0,770528)}j=e[f>>1]|0|805306368;f=0;do{i=c[769568+(f<<2)>>2]|0;h=i>>>24;g=c[770528+(f<<2)>>2]|0;k=g>>>24;l=c[772448+(f<<2)>>2]|0;m=l>>>24;n=k>>>0<h>>>0?k:h;o=m>>>0<n>>>0?m:n;n=c[768608+(f<<2)>>2]|0;p=n>>>0<j>>>0;q=p?1:32;r=p?n:j;do{if(o>>>0<r>>>24>>>0){if((o|0)==(h|0)){s=i;t=2;break}if((o|0)==(k|0)){s=g;t=4;break}p=(o|0)==(m|0);s=p?l:r;t=p?16:q}else{s=r;t=q}}while(0);do{if((s&65536|0)==0){q=e[384132]|0;r=q>>>6&3;if((r|0)==1){if((q&(t&255)|0)==0){u=s;break}do{if(t<<24>>24==1){o=i>>>0<805306368;v=o?2:32;w=o?i:j;x=2963}else{o=n>>>0<805306368;p=o?1:32;y=o?n:j;if(t<<24>>24==2){v=p;w=y;x=2963;break}o=h>>>0<y>>>24>>>0;z=o?2:p;p=o?i:y;if(t<<24>>24==4){A=z;B=p;x=2965;break}y=k>>>0<p>>>24>>>0;o=y?4:z;z=y?g:p;if(t<<24>>24==16){C=z;D=o}else{A=o;B=z;x=2965}}}while(0);if((x|0)==2963){x=0;z=k>>>0<w>>>24>>>0;A=z?4:v;B=z?g:w;x=2965}if((x|0)==2965){x=0;z=m>>>0<B>>>24>>>0;C=z?l:B;D=z?16:A}if(!((D&255&q>>>8|0)!=0&(s|0)>-1)){u=s;break}z=e[384300]|0;o=c[125080+((z&31)<<2)>>2]|0;p=(ac(o,s&31)|0)>>>4;y=c[125080+((z>>>8&31)<<2)>>2]|0;z=c[130360+(((ac(y,C&31)|0)>>>4)+p<<2)>>2]|0;p=(ac(o,s>>>5&31)|0)>>>4;E=c[130360+(((ac(y,C>>>5&31)|0)>>>4)+p<<2)>>2]|0;p=(ac(o,s>>>10&31)|0)>>>4;u=z|s&-65536|E<<5|c[130360+(((ac(y,C>>>10&31)|0)>>>4)+p<<2)>>2]<<10;break}else if((r|0)==3){if((q&(t&255)|0)==0){u=s;break}p=s<<16&65011712|s&31775;y=p-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,p)|0)>>>4&65043487)|0;u=y>>>16|y;break}else if((r|0)==2){if((q&(t&255)|0)==0){u=s;break}y=s<<16&65011712|s&31775;p=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-y|0)|0)>>>4&65043487)+y|0;u=p>>>16|p;break}else{u=s;break}}else{p=n>>>24;y=h>>>0<p>>>0?h:p;E=k>>>0<y>>>0?k:y;do{if((E&255)<48){if((E|0)==(p|0)){F=1;G=n;break}if((E|0)==(h|0)){F=2;G=i;break}y=(E|0)==(k|0);F=y?4:32;G=y?g:j}else{F=32;G=j}}while(0);E=e[384132]|0;if((E>>>8&F|0)==0){u=s;break}if((s|0)>-1){p=e[384300]|0;q=c[125080+((p&31)<<2)>>2]|0;r=(ac(q,s&31)|0)>>>4;y=c[125080+((p>>>8&31)<<2)>>2]|0;p=c[130360+(((ac(y,G&31)|0)>>>4)+r<<2)>>2]|0;r=(ac(q,s>>>5&31)|0)>>>4;z=c[130360+(((ac(y,G>>>5&31)|0)>>>4)+r<<2)>>2]|0;r=(ac(q,s>>>10&31)|0)>>>4;u=p|s&-65536|z<<5|c[130360+(((ac(y,G>>>10&31)|0)>>>4)+r<<2)>>2]<<10;break}if((E&(t&255)|0)==0){u=s;break}r=E>>>6&3;if((r|0)==2){E=s<<16&65011712|s&31775;y=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-E|0)|0)>>>4&65043487)+E|0;u=y>>>16|y;break}else if((r|0)==3){r=s<<16&65011712|s&31775;y=r-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,r)|0)>>>4&65043487)|0;u=y>>>16|y;break}else{u=s;break}}}while(0);b[a+(f+d<<1)>>1]=(u<<1&1984|u<<11|u>>>4&32|u>>>10&31)&65535;f=f+1|0;}while((f|0)<240);c[195146]=0;return}function j0(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;d=c[37236]|0;f=b[390347]|0;g=(f&65535)<<8;h=c[191862]|0;i=c[191863]|0;if((i&8192|0)==0){j=0}else{k=b[390378]|0;l=(k&65535)>>>8;m=k&255;if(l<<16>>16==m<<16>>16){n=(k&65535)>59391|0}else{n=0}k=(-((m&65535)>=(l&65535)|0)|0)>>>31;o=(f&65535)<(l&65535);l=(f&65535)<(m&65535)|0;j=(n|(o?l:1))&~k|(n|(o?0:l))&k}if((i&16384|0)==0){p=0}else{k=b[390379]|0;l=(k&65535)>>>8;o=k&255;if(l<<16>>16==o<<16>>16){q=(k&65535)>59391|0}else{q=0}k=(-((o&65535)>=(l&65535)|0)|0)>>>31;n=(f&65535)<(l&65535);l=(f&65535)<(o&65535)|0;p=(q|(n?l:1))&~k|(q|(n?0:l))&k}k=(i&256|0)!=0;l=i>>>9&1;if((l|0)==0&(k^1)){r=i}else{vI(k,(l|0)!=0,0,0);r=c[191863]|0}if((r&1024|0)!=0){vL(b[390350]|0,b[384160]|0,b[384164]|0,b[384152]|0,b[384156]|0,b[390360]|0,b[390361]|0,b[390362]|0,b[390363]|0,768216,768208,c[195146]|0,770528)}r=e[h>>1]|0|805306368;h=b[390380]|0;l=b[390381]&255;k=(h&65535)>>>8&65535;i=h&255;h=0;do{if((c[773408+(h<<2)>>2]|0)<0){s=l}else{s=(e[390381]|0)>>>8&255}n=a[767464+h|0]&1&p;q=a[767704+h|0]&1&j;o=(n+255&(s&255)|k&-n)&q+255|i&-q;q=(o&1|0)!=0;if(q){n=c[768608+(h<<2)>>2]|0;f=n>>>0<r>>>0;t=f?n:r;u=f?1:32}else{t=r;u=32}f=(o&2|0)!=0;if(f){n=c[769568+(h<<2)>>2]|0;m=n>>>24>>>0<t>>>24>>>0;v=m?n:t;w=m?2:u}else{v=t;w=u}m=(o&4|0)!=0;if(m){n=c[770528+(h<<2)>>2]|0;x=n>>>24>>>0<v>>>24>>>0;y=x?n:v;z=x?4:w}else{y=v;z=w}x=(o&16|0)!=0;if(x){n=c[772448+(h<<2)>>2]|0;A=n>>>24>>>0<y>>>24>>>0;B=A?n:y;C=A?16:z}else{B=y;C=z}do{if((B&65536|0)==0){if((o&32|0)==0){D=B;break}A=e[384132]|0;n=A>>>6&3;if((n|0)==1){if((A&(C&255)|0)==0){D=B;break}if(C<<24>>24==1|q^1){E=32;F=r}else{G=c[768608+(h<<2)>>2]|0;H=G>>>0<805306368;E=H?1:32;F=H?G:r}if(C<<24>>24==2|f^1){I=E;J=F}else{G=c[769568+(h<<2)>>2]|0;H=G>>>24>>>0<F>>>24>>>0;I=H?2:E;J=H?G:F}if(C<<24>>24==4|m^1){K=I;L=J}else{G=c[770528+(h<<2)>>2]|0;H=G>>>24>>>0<J>>>24>>>0;K=H?4:I;L=H?G:J}if(C<<24>>24==16|x^1){M=K;N=L}else{G=c[772448+(h<<2)>>2]|0;H=G>>>24>>>0<L>>>24>>>0;M=H?16:K;N=H?G:L}if(!((M&255&A>>>8|0)!=0&(B|0)>-1)){D=B;break}G=e[384300]|0;H=c[125080+((G&31)<<2)>>2]|0;O=(ac(H,B&31)|0)>>>4;P=c[125080+((G>>>8&31)<<2)>>2]|0;G=c[130360+(((ac(P,N&31)|0)>>>4)+O<<2)>>2]|0;O=(ac(H,B>>>5&31)|0)>>>4;Q=c[130360+(((ac(P,N>>>5&31)|0)>>>4)+O<<2)>>2]|0;O=(ac(H,B>>>10&31)|0)>>>4;D=G|B&-65536|Q<<5|c[130360+(((ac(P,N>>>10&31)|0)>>>4)+O<<2)>>2]<<10;break}else if((n|0)==2){if((A&(C&255)|0)==0){D=B;break}O=B<<16&65011712|B&31775;P=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-O|0)|0)>>>4&65043487)+O|0;D=P>>>16|P;break}else if((n|0)==3){if((A&(C&255)|0)==0){D=B;break}A=B<<16&65011712|B&31775;n=A-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,A)|0)>>>4&65043487)|0;D=n>>>16|n;break}else{D=B;break}}else{if(q){n=c[768608+(h<<2)>>2]|0;A=n>>>0<805306368;R=A?1:32;S=A?n:r}else{R=32;S=r}if(f){n=c[769568+(h<<2)>>2]|0;A=n>>>24>>>0<S>>>24>>>0;T=A?2:R;U=A?n:S}else{T=R;U=S}if(m){n=c[770528+(h<<2)>>2]|0;A=n>>>24>>>0<U>>>24>>>0;V=A?4:T;W=A?n:U}else{V=T;W=U}n=e[384132]|0;if((n>>>8&(V&255)|0)==0){D=B;break}if((B|0)>-1){A=e[384300]|0;P=c[125080+((A&31)<<2)>>2]|0;O=(ac(P,B&31)|0)>>>4;Q=c[125080+((A>>>8&31)<<2)>>2]|0;A=c[130360+(((ac(Q,W&31)|0)>>>4)+O<<2)>>2]|0;O=(ac(P,B>>>5&31)|0)>>>4;G=c[130360+(((ac(Q,W>>>5&31)|0)>>>4)+O<<2)>>2]|0;O=(ac(P,B>>>10&31)|0)>>>4;D=A|B&-65536|G<<5|c[130360+(((ac(Q,W>>>10&31)|0)>>>4)+O<<2)>>2]<<10;break}if((n&(C&255)|0)==0){D=B;break}O=n>>>6&3;if((O|0)==3){n=B<<16&65011712|B&31775;Q=n-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,n)|0)>>>4&65043487)|0;D=Q>>>16|Q;break}else if((O|0)==2){O=B<<16&65011712|B&31775;Q=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-O|0)|0)>>>4&65043487)+O|0;D=Q>>>16|Q;break}else{D=B;break}}}while(0);b[d+(h+g<<1)>>1]=(D<<1&1984|D<<11|D>>>4&32|D>>>10&31)&65535;h=h+1|0;}while((h|0)<240);c[195146]=0;return}function j1(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;g=c[191863]|0;if((g&1024|0)==0){h=g}else{vL(b[390350]|0,b[384160]|0,b[384164]|0,b[384152]|0,b[384156]|0,b[390360]|0,b[390361]|0,b[390362]|0,b[390363]|0,768216,768208,c[195146]|0,770528);h=c[191863]|0}if((h&2048|0)!=0){vL(b[390351]|0,b[384144]|0,b[384148]|0,b[384136]|0,b[384140]|0,b[390368]|0,b[390369]|0,b[390370]|0,b[390371]|0,768200,768192,c[195144]|0,771488)}h=e[f>>1]|0|805306368;f=0;do{g=c[770528+(f<<2)>>2]|0;i=g>>>24;j=c[771488+(f<<2)>>2]|0;k=j>>>24;l=c[772448+(f<<2)>>2]|0;m=l>>>24;n=k>>>0<i>>>0?k:i;o=m>>>0<n>>>0?m:n;do{if((o&255)<48){if((o|0)==(i|0)){p=g;break}if((o|0)==(k|0)){p=j;break}if((o|0)!=(m|0)){p=h;break}if((l&65536|0)==0){p=l;break}do{if(n>>>0<48){if((n|0)==(i|0)){q=g;r=4;break}s=(n|0)==(k|0);q=s?j:h;r=s?8:32}else{q=h;r=32}}while(0);s=e[384132]|0;if((s>>>8&r|0)==0){p=l;break}if((l|0)>-1){t=e[384300]|0;u=c[125080+((t&31)<<2)>>2]|0;v=(ac(u,l&31)|0)>>>4;w=c[125080+((t>>>8&31)<<2)>>2]|0;t=c[130360+(((ac(w,q&31)|0)>>>4)+v<<2)>>2]|0;v=(ac(u,l>>>5&31)|0)>>>4;x=c[130360+(((ac(w,q>>>5&31)|0)>>>4)+v<<2)>>2]|0;v=(ac(u,l>>>10&31)|0)>>>4;p=t|l&-65536|x<<5|c[130360+(((ac(w,q>>>10&31)|0)>>>4)+v<<2)>>2]<<10;break}if((s&16|0)==0){p=l;break}v=s>>>6&3;if((v|0)==2){s=l<<16&65011712|l&31775;w=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-s|0)|0)>>>4&65043487)+s|0;p=w>>>16|w;break}else if((v|0)==3){v=l<<16&65011712|l&31775;w=v-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,v)|0)>>>4&65043487)|0;p=w>>>16|w;break}else{p=l;break}}else{p=h}}while(0);b[a+(f+d<<1)>>1]=(p<<1&1984|p<<11|p>>>4&32|p>>>10&31)&65535;f=f+1|0;}while((f|0)<240);c[195146]=0;c[195144]=0;return}function j2(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;g=c[191863]|0;if((g&1024|0)==0){h=g}else{vL(b[390350]|0,b[384160]|0,b[384164]|0,b[384152]|0,b[384156]|0,b[390360]|0,b[390361]|0,b[390362]|0,b[390363]|0,768216,768208,c[195146]|0,770528);h=c[191863]|0}if((h&2048|0)!=0){vL(b[390351]|0,b[384144]|0,b[384148]|0,b[384136]|0,b[384140]|0,b[390368]|0,b[390369]|0,b[390370]|0,b[390371]|0,768200,768192,c[195144]|0,771488)}h=e[f>>1]|0|805306368;f=0;do{g=c[770528+(f<<2)>>2]|0;i=g>>>24;j=c[771488+(f<<2)>>2]|0;k=j>>>24;l=c[772448+(f<<2)>>2]|0;m=l>>>24;n=k>>>0<i>>>0?k:i;o=m>>>0<n>>>0?m:n;do{if((o&255)<48){if((o|0)==(i|0)){p=g;q=4;break}if((o|0)==(k|0)){p=j;q=8;break}r=(o|0)==(m|0);p=r?l:h;q=r?16:32}else{p=h;q=32}}while(0);do{if((p&65536|0)==0){o=e[384132]|0;r=o>>>6&3;if((r|0)==2){if((o&q|0)==0){s=p;break}t=p<<16&65011712|p&31775;u=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-t|0)|0)>>>4&65043487)+t|0;s=u>>>16|u;break}else if((r|0)==3){if((o&q|0)==0){s=p;break}u=p<<16&65011712|p&31775;t=u-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,u)|0)>>>4&65043487)|0;s=t>>>16|t;break}else if((r|0)==1){if((o&q|0)==0){s=p;break}do{if((q|0)==4){r=j>>>0<805306368;v=r?8:32;w=r?j:h;x=3079}else{r=g>>>0<805306368;t=r?4:32;u=r?g:h;if((q|0)==8){v=t;w=u;x=3079;break}r=k>>>0<u>>>24>>>0;y=r?8:t;t=r?j:u;if((q|0)==16){z=t;A=y}else{v=y;w=t;x=3079}}}while(0);if((x|0)==3079){x=0;t=m>>>0<w>>>24>>>0;z=t?l:w;A=t?16:v}if(!((A&255&o>>>8|0)!=0&(p|0)>-1)){s=p;break}t=e[384300]|0;y=c[125080+((t&31)<<2)>>2]|0;u=(ac(y,p&31)|0)>>>4;r=c[125080+((t>>>8&31)<<2)>>2]|0;t=c[130360+(((ac(r,z&31)|0)>>>4)+u<<2)>>2]|0;u=(ac(y,p>>>5&31)|0)>>>4;B=c[130360+(((ac(r,z>>>5&31)|0)>>>4)+u<<2)>>2]|0;u=(ac(y,p>>>10&31)|0)>>>4;s=t|p&-65536|B<<5|c[130360+(((ac(r,z>>>10&31)|0)>>>4)+u<<2)>>2]<<10;break}else{s=p;break}}else{do{if(n>>>0<48){if((n|0)==(i|0)){C=4;D=g;break}u=(n|0)==(k|0);C=u?8:32;D=u?j:h}else{C=32;D=h}}while(0);o=e[384132]|0;if((o>>>8&C|0)==0){s=p;break}if((p|0)>-1){u=e[384300]|0;r=c[125080+((u&31)<<2)>>2]|0;B=(ac(r,p&31)|0)>>>4;t=c[125080+((u>>>8&31)<<2)>>2]|0;u=c[130360+(((ac(t,D&31)|0)>>>4)+B<<2)>>2]|0;B=(ac(r,p>>>5&31)|0)>>>4;y=c[130360+(((ac(t,D>>>5&31)|0)>>>4)+B<<2)>>2]|0;B=(ac(r,p>>>10&31)|0)>>>4;s=u|p&-65536|y<<5|c[130360+(((ac(t,D>>>10&31)|0)>>>4)+B<<2)>>2]<<10;break}if((o&q|0)==0){s=p;break}B=o>>>6&3;if((B|0)==3){o=p<<16&65011712|p&31775;t=o-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,o)|0)>>>4&65043487)|0;s=t>>>16|t;break}else if((B|0)==2){B=p<<16&65011712|p&31775;t=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-B|0)|0)>>>4&65043487)+B|0;s=t>>>16|t;break}else{s=p;break}}}while(0);b[a+(f+d<<1)>>1]=(s<<1&1984|s<<11|s>>>4&32|s>>>10&31)&65535;f=f+1|0;}while((f|0)<240);c[195146]=0;c[195144]=0;return}function j3(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;d=c[37236]|0;f=b[390347]|0;g=(f&65535)<<8;h=c[191862]|0;i=c[191863]|0;if((i&8192|0)==0){j=0}else{k=b[390378]|0;l=(k&65535)>>>8;m=k&255;if(l<<16>>16==m<<16>>16){n=(k&65535)>59391|0}else{n=0}k=(-((m&65535)>=(l&65535)|0)|0)>>>31;o=(f&65535)<(l&65535);l=(f&65535)<(m&65535)|0;j=(n|(o?l:1))&~k|(n|(o?0:l))&k}if((i&16384|0)==0){p=0}else{k=b[390379]|0;l=(k&65535)>>>8;o=k&255;if(l<<16>>16==o<<16>>16){q=(k&65535)>59391|0}else{q=0}k=(-((o&65535)>=(l&65535)|0)|0)>>>31;n=(f&65535)<(l&65535);l=(f&65535)<(o&65535)|0;p=(q|(n?l:1))&~k|(q|(n?0:l))&k}if((i&1024|0)==0){r=i}else{vL(b[390350]|0,b[384160]|0,b[384164]|0,b[384152]|0,b[384156]|0,b[390360]|0,b[390361]|0,b[390362]|0,b[390363]|0,768216,768208,c[195146]|0,770528);r=c[191863]|0}if((r&2048|0)!=0){vL(b[390351]|0,b[384144]|0,b[384148]|0,b[384136]|0,b[384140]|0,b[390368]|0,b[390369]|0,b[390370]|0,b[390371]|0,768200,768192,c[195144]|0,771488)}r=e[h>>1]|0|805306368;h=b[390380]|0;i=b[390381]&255;k=(h&65535)>>>8&65535;l=h&255;h=0;do{if((c[773408+(h<<2)>>2]|0)<0){s=i}else{s=(e[390381]|0)>>>8&255}n=a[767464+h|0]&1&p;q=a[767704+h|0]&1&j;o=(n+255&(s&255)|k&-n)&q+255|l&-q;q=(o&4|0)!=0;if(q){n=c[770528+(h<<2)>>2]|0;f=n>>>0<r>>>0;t=f?n:r;u=f?4:32}else{t=r;u=32}f=(o&8|0)!=0;if(f){n=c[771488+(h<<2)>>2]|0;m=n>>>24>>>0<t>>>24>>>0;v=m?n:t;w=m?8:u}else{v=t;w=u}m=(o&16|0)!=0;if(m){n=c[772448+(h<<2)>>2]|0;x=n>>>24>>>0<v>>>24>>>0;y=x?n:v;z=x?16:w}else{y=v;z=w}do{if((y&65536|0)==0){if((o&32|0)==0){A=y;break}x=e[384132]|0;n=x>>>6&3;if((n|0)==2){if((x&(z&255)|0)==0){A=y;break}B=y<<16&65011712|y&31775;C=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-B|0)|0)>>>4&65043487)+B|0;A=C>>>16|C;break}else if((n|0)==1){if((x&(z&255)|0)==0){A=y;break}if(z<<24>>24==4|q^1){D=32;E=r}else{C=c[770528+(h<<2)>>2]|0;B=C>>>0<r>>>0;D=B?4:32;E=B?C:r}if(z<<24>>24==8|f^1){F=D;G=E}else{C=c[771488+(h<<2)>>2]|0;B=C>>>24>>>0<E>>>24>>>0;F=B?8:D;G=B?C:E}if(z<<24>>24==16|m^1){H=F;I=G}else{C=c[772448+(h<<2)>>2]|0;B=C>>>24>>>0<G>>>24>>>0;H=B?16:F;I=B?C:G}if(!((H&255&x>>>8|0)!=0&(y|0)>-1)){A=y;break}C=e[384300]|0;B=c[125080+((C&31)<<2)>>2]|0;J=(ac(B,y&31)|0)>>>4;K=c[125080+((C>>>8&31)<<2)>>2]|0;C=c[130360+(((ac(K,I&31)|0)>>>4)+J<<2)>>2]|0;J=(ac(B,y>>>5&31)|0)>>>4;L=c[130360+(((ac(K,I>>>5&31)|0)>>>4)+J<<2)>>2]|0;J=(ac(B,y>>>10&31)|0)>>>4;A=C|y&-65536|L<<5|c[130360+(((ac(K,I>>>10&31)|0)>>>4)+J<<2)>>2]<<10;break}else if((n|0)==3){if((x&(z&255)|0)==0){A=y;break}x=y<<16&65011712|y&31775;n=x-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,x)|0)>>>4&65043487)|0;A=n>>>16|n;break}else{A=y;break}}else{if(q){n=c[770528+(h<<2)>>2]|0;x=n>>>0<r>>>0;M=x?4:32;N=x?n:r}else{M=32;N=r}if(f){n=c[771488+(h<<2)>>2]|0;x=n>>>24>>>0<N>>>24>>>0;O=x?8:M;P=x?n:N}else{O=M;P=N}n=e[384132]|0;if((n>>>8&(O&255)|0)==0){A=y;break}if((y|0)>-1){x=e[384300]|0;J=c[125080+((x&31)<<2)>>2]|0;K=(ac(J,y&31)|0)>>>4;L=c[125080+((x>>>8&31)<<2)>>2]|0;x=c[130360+(((ac(L,P&31)|0)>>>4)+K<<2)>>2]|0;K=(ac(J,y>>>5&31)|0)>>>4;C=c[130360+(((ac(L,P>>>5&31)|0)>>>4)+K<<2)>>2]|0;K=(ac(J,y>>>10&31)|0)>>>4;A=x|y&-65536|C<<5|c[130360+(((ac(L,P>>>10&31)|0)>>>4)+K<<2)>>2]<<10;break}if((n&(z&255)|0)==0){A=y;break}K=n>>>6&3;if((K|0)==2){n=y<<16&65011712|y&31775;L=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-n|0)|0)>>>4&65043487)+n|0;A=L>>>16|L;break}else if((K|0)==3){K=y<<16&65011712|y&31775;L=K-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,K)|0)>>>4&65043487)|0;A=L>>>16|L;break}else{A=y;break}}}while(0);b[d+(h+g<<1)>>1]=(A<<1&1984|A<<11|A>>>4&32|A>>>10&31)&65535;h=h+1|0;}while((h|0)<240);c[195146]=0;c[195144]=0;return}function j4(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;if((c[191863]&1024|0)!=0){vx(c[195146]|0)}g=e[f>>1]|0|805306368;f=0;do{h=c[770528+(f<<2)>>2]|0;i=h>>>0<g>>>0;j=i?h:g;h=c[772448+(f<<2)>>2]|0;do{if(h>>>24>>>0<j>>>24>>>0){if((h&65536|0)==0){k=h;break}l=e[384132]|0;if((l>>>8&(i?4:32)|0)==0){k=h;break}if((h|0)>-1){m=e[384300]|0;n=c[125080+((m&31)<<2)>>2]|0;o=(ac(n,h&31)|0)>>>4;p=c[125080+((m>>>8&31)<<2)>>2]|0;m=c[130360+(((ac(p,j&31)|0)>>>4)+o<<2)>>2]|0;o=(ac(n,h>>>5&31)|0)>>>4;q=c[130360+(((ac(p,j>>>5&31)|0)>>>4)+o<<2)>>2]|0;o=(ac(n,h>>>10&31)|0)>>>4;k=m|h&-65536|q<<5|c[130360+(((ac(p,j>>>10&31)|0)>>>4)+o<<2)>>2]<<10;break}if((l&16|0)==0){k=h;break}o=l>>>6&3;if((o|0)==2){l=h<<16&65011712|h&31775;p=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-l|0)|0)>>>4&65043487)+l|0;k=p>>>16|p;break}else if((o|0)==3){o=h<<16&65011712|h&31775;p=o-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,o)|0)>>>4&65043487)|0;k=p>>>16|p;break}else{k=h;break}}else{k=j}}while(0);b[a+(f+d<<1)>>1]=(k<<1&1984|k<<11|k>>>4&32|k>>>10&31)&65535;f=f+1|0;}while((f|0)<240);c[195146]=0;return}function j5(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;if((c[191863]&1024|0)!=0){vx(c[195146]|0)}g=e[f>>1]|0|805306368;f=0;do{h=c[770528+(f<<2)>>2]|0;i=h>>>0<g>>>0;j=i?4:32;k=i?h:g;h=c[772448+(f<<2)>>2]|0;l=h>>>24;m=l>>>0<k>>>24>>>0;n=m?16:j;o=m?h:k;do{if((o&65536|0)==0){p=e[384132]|0;q=p>>>6&3;if((q|0)==2){if((p&(n&255)|0)==0){r=o;break}s=o<<16&65011712|o&31775;t=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-s|0)|0)>>>4&65043487)+s|0;r=t>>>16|t;break}else if((q|0)==3){if((p&(n&255)|0)==0){r=o;break}t=o<<16&65011712|o&31775;s=t-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,t)|0)>>>4&65043487)|0;r=s>>>16|s;break}else if((q|0)==1){if((p&(n&255)|0)==0){r=o;break}q=n<<24>>24==4;s=q?32:j;t=q?g:k;if(m){u=t;v=s}else{q=l>>>0<t>>>24>>>0;u=q?h:t;v=q?16:s}if(!((v&255&p>>>8|0)!=0&(o|0)>-1)){r=o;break}p=e[384300]|0;s=c[125080+((p&31)<<2)>>2]|0;q=(ac(s,o&31)|0)>>>4;t=c[125080+((p>>>8&31)<<2)>>2]|0;p=c[130360+(((ac(t,u&31)|0)>>>4)+q<<2)>>2]|0;q=(ac(s,o>>>5&31)|0)>>>4;w=c[130360+(((ac(t,u>>>5&31)|0)>>>4)+q<<2)>>2]|0;q=(ac(s,o>>>10&31)|0)>>>4;r=p|o&-65536|w<<5|c[130360+(((ac(t,u>>>10&31)|0)>>>4)+q<<2)>>2]<<10;break}else{r=o;break}}else{q=e[384132]|0;if((q>>>8&(i?4:32)|0)==0){r=o;break}if((o|0)>-1){t=e[384300]|0;w=c[125080+((t&31)<<2)>>2]|0;p=(ac(w,o&31)|0)>>>4;s=c[125080+((t>>>8&31)<<2)>>2]|0;t=c[130360+(((ac(s,k&31)|0)>>>4)+p<<2)>>2]|0;p=(ac(w,o>>>5&31)|0)>>>4;x=c[130360+(((ac(s,k>>>5&31)|0)>>>4)+p<<2)>>2]|0;p=(ac(w,o>>>10&31)|0)>>>4;r=t|o&-65536|x<<5|c[130360+(((ac(s,k>>>10&31)|0)>>>4)+p<<2)>>2]<<10;break}if((q&(n&255)|0)==0){r=o;break}p=q>>>6&3;if((p|0)==3){q=o<<16&65011712|o&31775;s=q-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,q)|0)>>>4&65043487)|0;r=s>>>16|s;break}else if((p|0)==2){p=o<<16&65011712|o&31775;s=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-p|0)|0)>>>4&65043487)+p|0;r=s>>>16|s;break}else{r=o;break}}}while(0);b[a+(f+d<<1)>>1]=(r<<1&1984|r<<11|r>>>4&32|r>>>10&31)&65535;f=f+1|0;}while((f|0)<240);c[195146]=0;return}function j6(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=c[37236]|0;f=b[390347]|0;g=(f&65535)<<8;h=c[191862]|0;i=c[191863]|0;if((i&8192|0)==0){j=0}else{k=b[390378]|0;l=(k&65535)>>>8;m=k&255;if(l<<16>>16==m<<16>>16){n=(k&65535)>59391|0}else{n=0}k=(-((m&65535)>=(l&65535)|0)|0)>>>31;o=(f&65535)<(l&65535);l=(f&65535)<(m&65535)|0;j=(n|(o?l:1))&~k|(n|(o?0:l))&k}if((i&16384|0)==0){p=0}else{k=b[390379]|0;l=(k&65535)>>>8;o=k&255;if(l<<16>>16==o<<16>>16){q=(k&65535)>59391|0}else{q=0}k=(-((o&65535)>=(l&65535)|0)|0)>>>31;n=(f&65535)<(l&65535);l=(f&65535)<(o&65535)|0;p=(q|(n?l:1))&~k|(q|(n?0:l))&k}if((i&1024|0)!=0){vx(c[195146]|0)}i=b[390380]|0;k=b[390381]&255;l=e[h>>1]|0|805306368;h=(i&65535)>>>8&65535;n=i&255;i=0;do{if((c[773408+(i<<2)>>2]|0)<0){r=k}else{r=(e[390381]|0)>>>8&255}q=a[767464+i|0]&1&p;o=a[767704+i|0]&1&j;f=(q+255&(r&255)|h&-q)&o+255|n&-o;o=(f&4|0)!=0;if(o){q=c[770528+(i<<2)>>2]|0;m=q>>>0<l>>>0;s=m?q:l;t=m?4:32}else{s=l;t=32}m=(f&16|0)!=0;if(m){q=c[772448+(i<<2)>>2]|0;u=q>>>24>>>0<s>>>24>>>0;v=u?q:s;w=u?16:t}else{v=s;w=t}do{if((v&65536|0)==0){if((f&32|0)==0){x=v;break}u=e[384132]|0;q=u>>>6&3;if((q|0)==1){if((u&(w&255)|0)==0){x=v;break}if(w<<24>>24==4|o^1){y=32;z=l}else{A=c[770528+(i<<2)>>2]|0;B=A>>>0<l>>>0;y=B?4:32;z=B?A:l}if(w<<24>>24==16|m^1){C=y;D=z}else{A=c[772448+(i<<2)>>2]|0;B=A>>>24>>>0<z>>>24>>>0;C=B?16:y;D=B?A:z}if(!((C&255&u>>>8|0)!=0&(v|0)>-1)){x=v;break}A=e[384300]|0;B=c[125080+((A&31)<<2)>>2]|0;E=(ac(B,v&31)|0)>>>4;F=c[125080+((A>>>8&31)<<2)>>2]|0;A=c[130360+(((ac(F,D&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(B,v>>>5&31)|0)>>>4;G=c[130360+(((ac(F,D>>>5&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(B,v>>>10&31)|0)>>>4;x=A|v&-65536|G<<5|c[130360+(((ac(F,D>>>10&31)|0)>>>4)+E<<2)>>2]<<10;break}else if((q|0)==2){if((u&(w&255)|0)==0){x=v;break}E=v<<16&65011712|v&31775;F=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-E|0)|0)>>>4&65043487)+E|0;x=F>>>16|F;break}else if((q|0)==3){if((u&(w&255)|0)==0){x=v;break}u=v<<16&65011712|v&31775;q=u-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,u)|0)>>>4&65043487)|0;x=q>>>16|q;break}else{x=v;break}}else{if(o){q=c[770528+(i<<2)>>2]|0;u=q>>>0<l>>>0;H=u?4:32;I=u?q:l}else{H=32;I=l}q=e[384132]|0;if((q>>>8&H|0)==0){x=v;break}if((v|0)>-1){u=e[384300]|0;F=c[125080+((u&31)<<2)>>2]|0;E=(ac(F,v&31)|0)>>>4;G=c[125080+((u>>>8&31)<<2)>>2]|0;u=c[130360+(((ac(G,I&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(F,v>>>5&31)|0)>>>4;A=c[130360+(((ac(G,I>>>5&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(F,v>>>10&31)|0)>>>4;x=u|v&-65536|A<<5|c[130360+(((ac(G,I>>>10&31)|0)>>>4)+E<<2)>>2]<<10;break}if((q&(w&255)|0)==0){x=v;break}E=q>>>6&3;if((E|0)==2){q=v<<16&65011712|v&31775;G=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-q|0)|0)>>>4&65043487)+q|0;x=G>>>16|G;break}else if((E|0)==3){E=v<<16&65011712|v&31775;G=E-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,E)|0)>>>4&65043487)|0;x=G>>>16|G;break}else{x=v;break}}}while(0);b[d+(i+g<<1)>>1]=(x<<1&1984|x<<11|x>>>4&32|x>>>10&31)&65535;i=i+1|0;}while((i|0)<240);c[195146]=0;return}function j7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;if((c[191863]&1024|0)!=0){vw(c[195146]|0)}g=e[f>>1]|0|805306368;f=0;do{h=c[770528+(f<<2)>>2]|0;i=h>>>0<g>>>0;j=i?h:g;h=c[772448+(f<<2)>>2]|0;do{if(h>>>24>>>0<j>>>24>>>0){if((h&65536|0)==0){k=h;break}l=e[384132]|0;if((l>>>8&(i?4:32)|0)==0){k=h;break}if((h|0)>-1){m=e[384300]|0;n=c[125080+((m&31)<<2)>>2]|0;o=(ac(n,h&31)|0)>>>4;p=c[125080+((m>>>8&31)<<2)>>2]|0;m=c[130360+(((ac(p,j&31)|0)>>>4)+o<<2)>>2]|0;o=(ac(n,h>>>5&31)|0)>>>4;q=c[130360+(((ac(p,j>>>5&31)|0)>>>4)+o<<2)>>2]|0;o=(ac(n,h>>>10&31)|0)>>>4;k=m|h&-65536|q<<5|c[130360+(((ac(p,j>>>10&31)|0)>>>4)+o<<2)>>2]<<10;break}if((l&16|0)==0){k=h;break}o=l>>>6&3;if((o|0)==2){l=h<<16&65011712|h&31775;p=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-l|0)|0)>>>4&65043487)+l|0;k=p>>>16|p;break}else if((o|0)==3){o=h<<16&65011712|h&31775;p=o-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,o)|0)>>>4&65043487)|0;k=p>>>16|p;break}else{k=h;break}}else{k=j}}while(0);b[a+(f+d<<1)>>1]=(k<<1&1984|k<<11|k>>>4&32|k>>>10&31)&65535;f=f+1|0;}while((f|0)<240);c[195146]=0;return}function j8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;if((c[191863]&1024|0)!=0){vw(c[195146]|0)}g=e[f>>1]|0|805306368;f=0;do{h=c[770528+(f<<2)>>2]|0;i=h>>>0<g>>>0;j=i?4:32;k=i?h:g;h=c[772448+(f<<2)>>2]|0;l=h>>>24;m=l>>>0<k>>>24>>>0;n=m?16:j;o=m?h:k;do{if((o&65536|0)==0){p=e[384132]|0;q=p>>>6&3;if((q|0)==2){if((p&(n&255)|0)==0){r=o;break}s=o<<16&65011712|o&31775;t=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-s|0)|0)>>>4&65043487)+s|0;r=t>>>16|t;break}else if((q|0)==3){if((p&(n&255)|0)==0){r=o;break}t=o<<16&65011712|o&31775;s=t-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,t)|0)>>>4&65043487)|0;r=s>>>16|s;break}else if((q|0)==1){if((p&(n&255)|0)==0){r=o;break}q=n<<24>>24==4;s=q?32:j;t=q?g:k;if(m){u=t;v=s}else{q=l>>>0<t>>>24>>>0;u=q?h:t;v=q?16:s}if(!((v&255&p>>>8|0)!=0&(o|0)>-1)){r=o;break}p=e[384300]|0;s=c[125080+((p&31)<<2)>>2]|0;q=(ac(s,o&31)|0)>>>4;t=c[125080+((p>>>8&31)<<2)>>2]|0;p=c[130360+(((ac(t,u&31)|0)>>>4)+q<<2)>>2]|0;q=(ac(s,o>>>5&31)|0)>>>4;w=c[130360+(((ac(t,u>>>5&31)|0)>>>4)+q<<2)>>2]|0;q=(ac(s,o>>>10&31)|0)>>>4;r=p|o&-65536|w<<5|c[130360+(((ac(t,u>>>10&31)|0)>>>4)+q<<2)>>2]<<10;break}else{r=o;break}}else{q=e[384132]|0;if((q>>>8&(i?4:32)|0)==0){r=o;break}if((o|0)>-1){t=e[384300]|0;w=c[125080+((t&31)<<2)>>2]|0;p=(ac(w,o&31)|0)>>>4;s=c[125080+((t>>>8&31)<<2)>>2]|0;t=c[130360+(((ac(s,k&31)|0)>>>4)+p<<2)>>2]|0;p=(ac(w,o>>>5&31)|0)>>>4;x=c[130360+(((ac(s,k>>>5&31)|0)>>>4)+p<<2)>>2]|0;p=(ac(w,o>>>10&31)|0)>>>4;r=t|o&-65536|x<<5|c[130360+(((ac(s,k>>>10&31)|0)>>>4)+p<<2)>>2]<<10;break}if((q&(n&255)|0)==0){r=o;break}p=q>>>6&3;if((p|0)==2){q=o<<16&65011712|o&31775;s=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-q|0)|0)>>>4&65043487)+q|0;r=s>>>16|s;break}else if((p|0)==3){p=o<<16&65011712|o&31775;s=p-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,p)|0)>>>4&65043487)|0;r=s>>>16|s;break}else{r=o;break}}}while(0);b[a+(f+d<<1)>>1]=(r<<1&1984|r<<11|r>>>4&32|r>>>10&31)&65535;f=f+1|0;}while((f|0)<240);c[195146]=0;return}function j9(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=c[37236]|0;f=b[390347]|0;g=(f&65535)<<8;h=c[191862]|0;i=c[191863]|0;if((i&8192|0)==0){j=0}else{k=b[390378]|0;l=(k&65535)>>>8;m=k&255;if(l<<16>>16==m<<16>>16){n=(k&65535)>59391|0}else{n=0}k=(-((m&65535)>=(l&65535)|0)|0)>>>31;o=(f&65535)<(l&65535);l=(f&65535)<(m&65535)|0;j=(n|(o?l:1))&~k|(n|(o?0:l))&k}if((i&16384|0)==0){p=0}else{k=b[390379]|0;l=(k&65535)>>>8;o=k&255;if(l<<16>>16==o<<16>>16){q=(k&65535)>59391|0}else{q=0}k=(-((o&65535)>=(l&65535)|0)|0)>>>31;n=(f&65535)<(l&65535);l=(f&65535)<(o&65535)|0;p=(q|(n?l:1))&~k|(q|(n?0:l))&k}if((i&1024|0)!=0){vw(c[195146]|0)}i=e[h>>1]|0|805306368;h=b[390380]|0;k=b[390381]&255;l=(h&65535)>>>8&65535;n=h&255;h=0;do{if((c[773408+(h<<2)>>2]|0)<0){r=k}else{r=(e[390381]|0)>>>8&255}q=a[767464+h|0]&1&p;o=a[767704+h|0]&1&j;f=(q+255&(r&255)|l&-q)&o+255|n&-o;o=(f&4|0)!=0;if(o){q=c[770528+(h<<2)>>2]|0;m=q>>>0<i>>>0;s=m?q:i;t=m?4:32}else{s=i;t=32}m=(f&16|0)!=0;if(m){q=c[772448+(h<<2)>>2]|0;u=q>>>24>>>0<s>>>24>>>0;v=u?q:s;w=u?16:t}else{v=s;w=t}do{if((v&65536|0)==0){if((f&32|0)==0){x=v;break}u=e[384132]|0;q=u>>>6&3;if((q|0)==1){if((u&(w&255)|0)==0){x=v;break}if(w<<24>>24==4|o^1){y=32;z=i}else{A=c[770528+(h<<2)>>2]|0;B=A>>>0<i>>>0;y=B?4:32;z=B?A:i}if(w<<24>>24==16|m^1){C=y;D=z}else{A=c[772448+(h<<2)>>2]|0;B=A>>>24>>>0<z>>>24>>>0;C=B?16:y;D=B?A:z}if(!((C&255&u>>>8|0)!=0&(v|0)>-1)){x=v;break}A=e[384300]|0;B=c[125080+((A&31)<<2)>>2]|0;E=(ac(B,v&31)|0)>>>4;F=c[125080+((A>>>8&31)<<2)>>2]|0;A=c[130360+(((ac(F,D&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(B,v>>>5&31)|0)>>>4;G=c[130360+(((ac(F,D>>>5&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(B,v>>>10&31)|0)>>>4;x=A|v&-65536|G<<5|c[130360+(((ac(F,D>>>10&31)|0)>>>4)+E<<2)>>2]<<10;break}else if((q|0)==2){if((u&(w&255)|0)==0){x=v;break}E=v<<16&65011712|v&31775;F=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-E|0)|0)>>>4&65043487)+E|0;x=F>>>16|F;break}else if((q|0)==3){if((u&(w&255)|0)==0){x=v;break}u=v<<16&65011712|v&31775;q=u-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,u)|0)>>>4&65043487)|0;x=q>>>16|q;break}else{x=v;break}}else{if(o){q=c[770528+(h<<2)>>2]|0;u=q>>>0<i>>>0;H=u?4:32;I=u?q:i}else{H=32;I=i}q=e[384132]|0;if((q>>>8&H|0)==0){x=v;break}if((v|0)>-1){u=e[384300]|0;F=c[125080+((u&31)<<2)>>2]|0;E=(ac(F,v&31)|0)>>>4;G=c[125080+((u>>>8&31)<<2)>>2]|0;u=c[130360+(((ac(G,I&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(F,v>>>5&31)|0)>>>4;A=c[130360+(((ac(G,I>>>5&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(F,v>>>10&31)|0)>>>4;x=u|v&-65536|A<<5|c[130360+(((ac(G,I>>>10&31)|0)>>>4)+E<<2)>>2]<<10;break}if((q&(w&255)|0)==0){x=v;break}E=q>>>6&3;if((E|0)==2){q=v<<16&65011712|v&31775;G=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-q|0)|0)>>>4&65043487)+q|0;x=G>>>16|G;break}else if((E|0)==3){E=v<<16&65011712|v&31775;G=E-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,E)|0)>>>4&65043487)|0;x=G>>>16|G;break}else{x=v;break}}}while(0);b[d+(h+g<<1)>>1]=(x<<1&1984|x<<11|x>>>4&32|x>>>10&31)&65535;h=h+1|0;}while((h|0)<240);c[195146]=0;return}function ka(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;if((c[191863]&1024|0)!=0){vv(c[195146]|0)}g=e[f>>1]|0|805306368;f=0;do{h=c[770528+(f<<2)>>2]|0;i=h>>>0<g>>>0;j=i?h:g;h=c[772448+(f<<2)>>2]|0;do{if(h>>>24>>>0<j>>>24>>>0){if((h&65536|0)==0){k=h;break}l=e[384132]|0;if((l>>>8&(i?4:32)|0)==0){k=h;break}if((h|0)>-1){m=e[384300]|0;n=c[125080+((m&31)<<2)>>2]|0;o=(ac(n,h&31)|0)>>>4;p=c[125080+((m>>>8&31)<<2)>>2]|0;m=c[130360+(((ac(p,j&31)|0)>>>4)+o<<2)>>2]|0;o=(ac(n,h>>>5&31)|0)>>>4;q=c[130360+(((ac(p,j>>>5&31)|0)>>>4)+o<<2)>>2]|0;o=(ac(n,h>>>10&31)|0)>>>4;k=m|h&-65536|q<<5|c[130360+(((ac(p,j>>>10&31)|0)>>>4)+o<<2)>>2]<<10;break}if((l&16|0)==0){k=h;break}o=l>>>6&3;if((o|0)==2){l=h<<16&65011712|h&31775;p=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-l|0)|0)>>>4&65043487)+l|0;k=p>>>16|p;break}else if((o|0)==3){o=h<<16&65011712|h&31775;p=o-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,o)|0)>>>4&65043487)|0;k=p>>>16|p;break}else{k=h;break}}else{k=j}}while(0);b[a+(f+d<<1)>>1]=(k<<1&1984|k<<11|k>>>4&32|k>>>10&31)&65535;f=f+1|0;}while((f|0)<240);c[195146]=0;return}function kb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[37236]|0;d=(e[390347]|0)<<8;f=c[191862]|0;if((c[191863]&1024|0)!=0){vv(c[195146]|0)}g=e[f>>1]|0|805306368;f=0;do{h=c[770528+(f<<2)>>2]|0;i=h>>>0<g>>>0;j=i?4:32;k=i?h:g;h=c[772448+(f<<2)>>2]|0;l=h>>>24;m=l>>>0<k>>>24>>>0;n=m?16:j;o=m?h:k;do{if((o&65536|0)==0){p=e[384132]|0;q=p>>>6&3;if((q|0)==2){if((p&(n&255)|0)==0){r=o;break}s=o<<16&65011712|o&31775;t=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-s|0)|0)>>>4&65043487)+s|0;r=t>>>16|t;break}else if((q|0)==3){if((p&(n&255)|0)==0){r=o;break}t=o<<16&65011712|o&31775;s=t-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,t)|0)>>>4&65043487)|0;r=s>>>16|s;break}else if((q|0)==1){if((p&(n&255)|0)==0){r=o;break}q=n<<24>>24==4;s=q?32:j;t=q?g:k;if(m){u=t;v=s}else{q=l>>>0<t>>>24>>>0;u=q?h:t;v=q?16:s}if(!((v&255&p>>>8|0)!=0&(o|0)>-1)){r=o;break}p=e[384300]|0;s=c[125080+((p&31)<<2)>>2]|0;q=(ac(s,o&31)|0)>>>4;t=c[125080+((p>>>8&31)<<2)>>2]|0;p=c[130360+(((ac(t,u&31)|0)>>>4)+q<<2)>>2]|0;q=(ac(s,o>>>5&31)|0)>>>4;w=c[130360+(((ac(t,u>>>5&31)|0)>>>4)+q<<2)>>2]|0;q=(ac(s,o>>>10&31)|0)>>>4;r=p|o&-65536|w<<5|c[130360+(((ac(t,u>>>10&31)|0)>>>4)+q<<2)>>2]<<10;break}else{r=o;break}}else{q=e[384132]|0;if((q>>>8&(i?4:32)|0)==0){r=o;break}if((o|0)>-1){t=e[384300]|0;w=c[125080+((t&31)<<2)>>2]|0;p=(ac(w,o&31)|0)>>>4;s=c[125080+((t>>>8&31)<<2)>>2]|0;t=c[130360+(((ac(s,k&31)|0)>>>4)+p<<2)>>2]|0;p=(ac(w,o>>>5&31)|0)>>>4;x=c[130360+(((ac(s,k>>>5&31)|0)>>>4)+p<<2)>>2]|0;p=(ac(w,o>>>10&31)|0)>>>4;r=t|o&-65536|x<<5|c[130360+(((ac(s,k>>>10&31)|0)>>>4)+p<<2)>>2]<<10;break}if((q&(n&255)|0)==0){r=o;break}p=q>>>6&3;if((p|0)==2){q=o<<16&65011712|o&31775;s=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-q|0)|0)>>>4&65043487)+q|0;r=s>>>16|s;break}else if((p|0)==3){p=o<<16&65011712|o&31775;s=p-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,p)|0)>>>4&65043487)|0;r=s>>>16|s;break}else{r=o;break}}}while(0);b[a+(f+d<<1)>>1]=(r<<1&1984|r<<11|r>>>4&32|r>>>10&31)&65535;f=f+1|0;}while((f|0)<240);c[195146]=0;return}function kc(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=c[37236]|0;f=(e[390347]|0)<<8;g=c[191862]|0;h=c[191863]|0;if((h&1024|0)==0){i=h}else{vv(c[195146]|0);i=c[191863]|0}if((i&8192|0)==0){j=0}else{h=b[390378]|0;k=(h&65535)>>>8;l=h&255;if(k<<16>>16==l<<16>>16){m=(h&65535)>59391|0}else{m=0}h=(-((l&65535)>=(k&65535)|0)|0)>>>31;n=b[390347]|0;o=(n&65535)<(k&65535);k=(n&65535)<(l&65535)|0;j=((o?k:1)|m)&~h|((o?0:k)|m)&h}if((i&16384|0)==0){p=0}else{i=b[390379]|0;h=(i&65535)>>>8;m=i&255;if(h<<16>>16==m<<16>>16){q=(i&65535)>59391|0}else{q=0}i=(-((m&65535)>=(h&65535)|0)|0)>>>31;k=b[390347]|0;o=(k&65535)<(h&65535);h=(k&65535)<(m&65535)|0;p=((o?h:1)|q)&~i|((o?0:h)|q)&i}i=b[390380]|0;q=b[390381]&255;h=e[g>>1]|0|805306368;g=(i&65535)>>>8&65535;o=i&255;i=0;do{if((c[773408+(i<<2)>>2]|0)<0){r=q}else{r=(e[390381]|0)>>>8&255}m=a[767464+i|0]&1&p;k=a[767704+i|0]&1&j;l=(m+255&(r&255)|g&-m)&k+255|o&-k;k=(l&4|0)!=0;if(k){m=c[770528+(i<<2)>>2]|0;n=m>>>0<h>>>0;s=n?m:h;t=n?4:32}else{s=h;t=32}n=(l&16|0)!=0;if(n){m=c[772448+(i<<2)>>2]|0;u=m>>>24>>>0<s>>>24>>>0;v=u?m:s;w=u?16:t}else{v=s;w=t}do{if((v&65536|0)==0){if((l&32|0)==0){x=v;break}u=e[384132]|0;m=u>>>6&3;if((m|0)==1){if((u&(w&255)|0)==0){x=v;break}if(w<<24>>24==4|k^1){y=32;z=h}else{A=c[770528+(i<<2)>>2]|0;B=A>>>0<h>>>0;y=B?4:32;z=B?A:h}if(w<<24>>24==16|n^1){C=y;D=z}else{A=c[772448+(i<<2)>>2]|0;B=A>>>24>>>0<z>>>24>>>0;C=B?16:y;D=B?A:z}if(!((C&255&u>>>8|0)!=0&(v|0)>-1)){x=v;break}A=e[384300]|0;B=c[125080+((A&31)<<2)>>2]|0;E=(ac(B,v&31)|0)>>>4;F=c[125080+((A>>>8&31)<<2)>>2]|0;A=c[130360+(((ac(F,D&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(B,v>>>5&31)|0)>>>4;G=c[130360+(((ac(F,D>>>5&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(B,v>>>10&31)|0)>>>4;x=A|v&-65536|G<<5|c[130360+(((ac(F,D>>>10&31)|0)>>>4)+E<<2)>>2]<<10;break}else if((m|0)==2){if((u&(w&255)|0)==0){x=v;break}E=v<<16&65011712|v&31775;F=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-E|0)|0)>>>4&65043487)+E|0;x=F>>>16|F;break}else if((m|0)==3){if((u&(w&255)|0)==0){x=v;break}u=v<<16&65011712|v&31775;m=u-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,u)|0)>>>4&65043487)|0;x=m>>>16|m;break}else{x=v;break}}else{if(k){m=c[770528+(i<<2)>>2]|0;u=m>>>0<h>>>0;H=u?4:32;I=u?m:h}else{H=32;I=h}m=e[384132]|0;if((m>>>8&H|0)==0){x=v;break}if((v|0)>-1){u=e[384300]|0;F=c[125080+((u&31)<<2)>>2]|0;E=(ac(F,v&31)|0)>>>4;G=c[125080+((u>>>8&31)<<2)>>2]|0;u=c[130360+(((ac(G,I&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(F,v>>>5&31)|0)>>>4;A=c[130360+(((ac(G,I>>>5&31)|0)>>>4)+E<<2)>>2]|0;E=(ac(F,v>>>10&31)|0)>>>4;x=u|v&-65536|A<<5|c[130360+(((ac(G,I>>>10&31)|0)>>>4)+E<<2)>>2]<<10;break}if((m&(w&255)|0)==0){x=v;break}E=m>>>6&3;if((E|0)==2){m=v<<16&65011712|v&31775;G=((ac(c[125080+((b[387188]&31)<<2)>>2]|0,65043487-m|0)|0)>>>4&65043487)+m|0;x=G>>>16|G;break}else if((E|0)==3){E=v<<16&65011712|v&31775;G=E-((ac(c[125080+((b[387188]&31)<<2)>>2]|0,E)|0)>>>4&65043487)|0;x=G>>>16|G;break}else{x=v;break}}}while(0);b[d+(i+f<<1)>>1]=(x<<1&1984|x<<11|x>>>4&32|x>>>10&31)&65535;i=i+1|0;}while((i|0)<240);c[195146]=0;return}function kd(f,j){f=f|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0;k=i;i=i+48|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=k+32|0;q=k+40|0;switch(f|0){case 176:{b[384068]=j;b[(c[120068]|0)+176>>1]=j;i=k;return};case 60:{b[384136]=j;b[(c[120068]|0)+60>>1]=j;c[195144]=c[195144]|2;i=k;return};case 62:{r=j&4095;b[384140]=r;b[(c[120068]|0)+62>>1]=r;c[195144]=c[195144]|2;i=k;return};case 64:{b[390376]=j;b[(c[120068]|0)+64>>1]=j;r=e[390376]|0;s=r>>>8;t=r&255;r=s>>>0<=t>>>0;u=~(r&1);v=0;do{w=(v|0)>=(s|0);x=(v|0)<(t|0);a[767704+v|0]=(w?x&r&1:0)|(w?1:x&1)&u;v=v+1|0;}while((v|0)<240);i=k;return};case 66:{b[390377]=j;b[(c[120068]|0)+66>>1]=j;v=e[390377]|0;u=v>>>8;r=v&255;v=u>>>0<=r>>>0;t=~(v&1);s=0;do{x=(s|0)>=(u|0);w=(s|0)<(r|0);a[767464+s|0]=(x?w&v&1:0)|(x?1:w&1)&t;s=s+1|0;}while((s|0)<240);i=k;return};case 68:case 70:{b[c[813712+(f<<2)>>2]>>1]=j;b[(c[120068]|0)+f>>1]=j;i=k;return};case 6:{i=k;return};case 82:{s=j&7967;b[384300]=s;b[(c[120068]|0)+82>>1]=s;i=k;return};case 84:{s=j&31;b[387188]=s;b[(c[120068]|0)+84>>1]=s;i=k;return};case 96:case 98:case 100:case 104:case 108:case 112:case 114:case 116:case 120:case 124:case 128:case 132:{s=o|0;t=f&255;v=p|0;c[v>>2]=t;c[p+4>>2]=t+1;p=q|0;a[p]=j&255;a[q+1|0]=(j&65535)>>>8&255;c[s>>2]=c[124824+(t-96<<2)>>2];c[o+4>>2]=c[124824+(t-95<<2)>>2];jE(s,v,p);i=k;return};case 130:case 136:case 160:case 162:case 164:case 166:case 144:case 146:case 148:case 150:case 152:case 154:case 156:case 158:{p=f&255;v=n|0;switch(p|0){case 130:{s=j&65535;t=(c[120068]|0)+130|0;b[t>>1]=j&30479;jH(s,s>>>4);y=+g[52048+((a[t]&3)<<2)>>2];if(+h[63147]==y){i=k;return}h[63147]=y;t=d[505109]|0;s=t>>>4&7;o=t&7;t=~~(y*.6*.25/15.0*.125*+((s>>>0<o>>>0?o:s)+1|0)*1073741824.0+.5);c[126377]=t;c[126379]=t;i=k;return};case 160:case 162:{a[774385+(c[193608]|0)|0]=j&255;a[(c[193608]|0)+774386|0]=(j&65535)>>>8&255;c[193605]=(c[193605]|0)+2;c[193608]=(c[193608]|0)+2&31;b[(c[120068]|0)+p>>1]=j;i=k;return};case 164:case 166:{a[774461+(c[193627]|0)|0]=j&255;a[(c[193627]|0)+774462|0]=(j&65535)>>>8&255;c[193624]=(c[193624]|0)+2;c[193627]=(c[193627]|0)+2&31;b[(c[120068]|0)+p>>1]=j;i=k;return};case 136:{b[(c[120068]|0)+136>>1]=j&-15361;i=k;return};default:{t=l|0;s=f&254;o=p|1;p=m|0;c[p>>2]=s;c[m+4>>2]=o;a[v]=j&255;a[n+1|0]=(j&65535)>>>8&255;c[t>>2]=c[124824+(s-96<<2)>>2];c[l+4>>2]=c[124824+(o-96<<2)>>2];jE(t,p,v);i=k;return}}break};case 32:case 34:case 36:case 38:{b[c[813712+(f<<2)>>2]>>1]=j;b[(c[120068]|0)+f>>1]=j;i=k;return};case 40:{b[384160]=j;b[(c[120068]|0)+40>>1]=j;c[195146]=c[195146]|1;i=k;return};case 0:{v=j&65535;p=v&7;if(p>>>0>5){t=p&65535;b[390344]=t;z=t}else{z=b[390344]|0}t=(z^j)&65535;p=(t&3840|0)==0;o=j&3840&(z^3840);z=j&-9;b[390344]=z;l=c[120068]|0;b[l>>1]=z;c[191863]=v;if(o<<16>>16==0){A=v}else{c[191864]=4;z=v&~(o&65535);c[191863]=z;A=z}z=(A&24576|0)!=0;a[767392]=z&1;do{if((t&128|0)!=0){if((v&128|0)!=0){break}A=b[390346]|0;if((A&1)!=0){break}c[191865]=1008;o=A&-4;b[390346]=o;A=l+4|0;b[A>>1]=o;o=b[390346]|0;do{if((e[390347]|0|0)==((o&65535)>>>8|0)){s=o|4;b[390346]=s;b[A>>1]=s;if((b[390346]&32)==0){break}s=b[390601]|4;b[390601]=s;b[l+514>>1]=s}else{s=o&-5;b[390346]=s;b[A>>1]=s}}while(0);A=c[191864]|0;if((A|0)<=0){break}o=A-1|0;c[191864]=o;if((o|0)!=1){break}c[191863]=e[390344]|0}}while(0);a[125248]=0;L4690:do{switch(b[390344]&7|0){case 4:{do{if((a[774368]&1)==0){if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=94;break L4690}else{if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=44;break L4690}}while(0);c[36766]=12;a[125248]=1;break};case 2:{do{if((a[774368]&1)==0){if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=42;break L4690}else{if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=50;break L4690}}while(0);c[36766]=68;a[125248]=1;break};case 3:{do{if((a[774368]&1)==0){if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=58;break L4690}else{if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=52;break L4690}}while(0);c[36766]=8;a[125248]=1;break};case 5:{do{if((a[774368]&1)==0){if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=10;break L4690}else{if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=64;break L4690}}while(0);c[36766]=4;a[125248]=1;break};case 0:{do{if((a[774368]&1)==0){if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=76;break L4690}else{if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=62;break L4690}}while(0);c[36766]=74;a[125248]=1;break};case 1:{do{if((a[774368]&1)==0){if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=26;break L4690}else{if(z){break}if((c[191863]&32768|0)!=0){break}c[36766]=30;break L4690}}while(0);c[36766]=20;a[125248]=1;break};default:{}}}while(0);if(p){i=k;return}p=c[191863]|0;if((p&256|0)==0){v3(768608,-1|0,960)}if((p&512|0)==0){v3(769568,-1|0,960)}if((p&1024|0)==0){v3(770528,-1|0,960)}if((p&2048|0)!=0){i=k;return}v3(771488,-1|0,960);i=k;return};case 76:{b[384124]=j;b[(c[120068]|0)+76>>1]=j;i=k;return};case 80:{p=j&16383;b[384132]=p;b[(c[120068]|0)+80>>1]=p;p=(b[384132]&192)!=0;a[774368]=p&1;a[125248]=0;switch(b[390344]&7|0){case 3:{z=(a[767392]&1)==0;do{if(p){if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=52;i=k;return}else{if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=58;i=k;return}}while(0);c[36766]=8;a[125248]=1;i=k;return};case 2:{z=(a[767392]&1)==0;do{if(p){if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=50;i=k;return}else{if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=42;i=k;return}}while(0);c[36766]=68;a[125248]=1;i=k;return};case 0:{z=(a[767392]&1)==0;do{if(p){if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=62;i=k;return}else{if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=76;i=k;return}}while(0);c[36766]=74;a[125248]=1;i=k;return};case 1:{z=(a[767392]&1)==0;do{if(p){if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=30;i=k;return}else{if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=26;i=k;return}}while(0);c[36766]=20;a[125248]=1;i=k;return};case 4:{z=(a[767392]&1)==0;do{if(p){if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=44;i=k;return}else{if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=94;i=k;return}}while(0);c[36766]=12;a[125248]=1;i=k;return};case 5:{z=(a[767392]&1)==0;do{if(p){if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=64;i=k;return}else{if(!z){break}if((c[191863]&32768|0)!=0){break}c[36766]=10;i=k;return}}while(0);c[36766]=4;a[125248]=1;i=k;return};default:{i=k;return}}break};case 214:{z=j&4095;b[384e3]=z;b[(c[120068]|0)+214>>1]=z;i=k;return};case 216:{b[384004]=j;b[(c[120068]|0)+216>>1]=j;i=k;return};case 218:{z=j&4095;b[384008]=z;b[(c[120068]|0)+218>>1]=z;i=k;return};case 220:{b[384012]=j;b[(c[120068]|0)+220>>1]=0;i=k;return};case 222:{z=b[384016]|0;p=j&-32;b[384016]=p;b[(c[120068]|0)+222>>1]=p;if(((z^-32768)&j)<<16>>16>=0){i=k;return}c[204454]=(e[384e3]|0)<<16|(e[383996]|0);c[191986]=(e[384008]|0)<<16|(e[384004]|0);kj(0,8);i=k;return};case 256:{c[195158]=j&65535;i=k;return};case 258:{b[406756]=j;a[776824]=a[776824]|1;c[203364]=c[195148];i=k;return};case 260:{c[195156]=j&65535;i=k;return};case 262:{b[406748]=j;a[776824]=a[776824]|2;c[203364]=c[195148];i=k;return};case 264:{c[195154]=j&65535;i=k;return};case 12:case 14:{z=j&-49;b[c[813712+(f<<2)>>2]>>1]=z;b[(c[120068]|0)+f>>1]=z;i=k;return};case 16:case 18:case 20:case 22:case 24:case 26:case 28:case 30:{z=j&511;b[c[813712+(f<<2)>>2]>>1]=z;b[(c[120068]|0)+f>>1]=z;i=k;return};case 42:{z=j&4095;b[384164]=z;b[(c[120068]|0)+42>>1]=z;c[195146]=c[195146]|1;i=k;return};case 266:{b[406740]=j;a[776824]=a[776824]|4;c[203364]=c[195148];i=k;return};case 268:{c[195152]=j&65535;i=k;return};case 270:{b[406732]=j;a[776824]=a[776824]|8;c[203364]=c[195148];i=k;return};case 304:{z=b[390496]|j&1023;b[390496]=z;b[(c[120068]|0)+304>>1]=z;i=k;return};case 306:{b[(c[120068]|0)+306>>1]=j&-15361;i=k;return};case 512:{z=j&16383;b[390600]=z;b[(c[120068]|0)+512>>1]=z;if((b[390604]&1)==0){i=k;return}if((b[390600]&b[390601])<<16>>16==0){i=k;return}if((a[130632]&1)==0){i=k;return}c[203364]=c[195148];i=k;return};case 514:{z=b[390601]&~j;b[390601]=z;b[(c[120068]|0)+514>>1]=z;i=k;return};case 516:{z=a[125256+(j&3)|0]|0;a[130342]=z;a[147086]=z;a[147081]=3;a[147080]=3;a[130337]=1;a[130336]=1;a[147083]=3;a[147082]=3;a[130339]=1;a[130338]=1;a[147085]=3;a[147084]=3;a[130341]=1;a[130340]=1;a[130624]=5;a[125304]=3;a[130625]=5;a[125305]=3;a[130626]=5;a[125306]=3;a[130627]=5;a[125307]=3;a[130628]=5;a[125308]=3;a[130629]=5;a[125309]=3;p=z<<1|1;a[130630]=p;a[125310]=p;a[776765]=(j&65535)>>>14&1;a[776764]=0;c[194192]=0;b[(c[120068]|0)+516>>1]=j&32767;i=k;return};case 520:{p=j&1;b[390604]=p;b[(c[120068]|0)+520>>1]=p;if((b[390604]&1)==0){i=k;return}if((b[390600]&b[390601])<<16>>16==0){i=k;return}if((a[130632]&1)==0){i=k;return}c[203364]=c[195148];i=k;return};case 200:{b[384020]=j;b[(c[120068]|0)+200>>1]=j;i=k;return};case 202:{p=j&4095;b[384024]=p;b[(c[120068]|0)+202>>1]=p;i=k;return};case 204:{b[384028]=j;b[(c[120068]|0)+204>>1]=j;i=k;return};case 206:{p=j&2047;b[384032]=p;b[(c[120068]|0)+206>>1]=p;i=k;return};case 208:{b[384036]=j&16383;b[(c[120068]|0)+208>>1]=0;i=k;return};case 210:{p=b[384040]|0;z=j&-2080;b[384040]=z;b[(c[120068]|0)+210>>1]=z;if(((p^-32768)&j)<<16>>16>=0){i=k;return}c[204456]=(e[384024]|0)<<16|(e[384020]|0);c[191988]=(e[384032]|0)<<16|(e[384028]|0);kj(0,4);i=k;return};case 212:{b[383996]=j;b[(c[120068]|0)+212>>1]=j;i=k;return};case 48:case 50:case 52:case 54:{b[c[813712+(f<<2)>>2]>>1]=j;b[(c[120068]|0)+f>>1]=j;i=k;return};case 56:{b[384144]=j;b[(c[120068]|0)+56>>1]=j;c[195144]=c[195144]|1;i=k;return};case 58:{p=j&4095;b[384148]=p;b[(c[120068]|0)+58>>1]=p;c[195144]=c[195144]|1;i=k;return};case 44:{b[384152]=j;b[(c[120068]|0)+44>>1]=j;c[195146]=c[195146]|2;i=k;return};case 46:{p=j&4095;b[384156]=p;b[(c[120068]|0)+46>>1]=p;c[195146]=c[195146]|2;i=k;return};case 188:{b[384044]=j;b[(c[120068]|0)+188>>1]=j;i=k;return};case 190:{p=j&4095;b[384048]=p;b[(c[120068]|0)+190>>1]=p;i=k;return};case 192:{b[384052]=j;b[(c[120068]|0)+192>>1]=j;i=k;return};case 194:{p=j&2047;b[384056]=p;b[(c[120068]|0)+194>>1]=p;i=k;return};case 196:{b[384060]=j&16383;b[(c[120068]|0)+196>>1]=0;i=k;return};case 198:{p=b[384064]|0;z=j&-2080;b[384064]=z;b[(c[120068]|0)+198>>1]=z;if(((p^-32768)&j)<<16>>16>=0){i=k;return}c[204458]=(e[384048]|0)<<16|(e[384044]|0);c[191990]=(e[384056]|0)<<16|(e[384052]|0);kj(0,2);i=k;return};case 768:{b[(c[120068]|0)+768>>1]=j&-2;i=k;return};case 72:case 74:{p=j&16191;b[c[813712+(f<<2)>>2]>>1]=p;b[(c[120068]|0)+f>>1]=p;i=k;return};case 4:{p=b[390346]&7|j&-200;b[390346]=p;b[(c[120068]|0)+4>>1]=p;i=k;return};case 8:case 10:{p=j&-8241;b[c[813712+(f<<2)>>2]>>1]=p;b[(c[120068]|0)+f>>1]=p;i=k;return};case 178:{p=j&2047;b[384072]=p;b[(c[120068]|0)+178>>1]=p;i=k;return};case 180:{b[384076]=j;b[(c[120068]|0)+180>>1]=j;i=k;return};case 182:{p=j&2047;b[384080]=p;b[(c[120068]|0)+182>>1]=p;i=k;return};case 184:{b[384084]=j&16383;b[(c[120068]|0)+184>>1]=0;i=k;return};case 186:{p=b[384088]|0;z=j&-2080;b[384088]=z;b[(c[120068]|0)+186>>1]=z;if(((p^-32768)&j)<<16>>16>=0){i=k;return}c[204460]=(e[384072]|0)<<16|(e[384068]|0);c[191992]=(e[384080]|0)<<16|(e[384076]|0);kj(0,1);i=k;return};default:{b[(c[120068]|0)+(f&1022)>>1]=j;i=k;return}}}function ke(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;L4970:do{switch(f>>>24|0){case 2:{g=c[(c[36848]|0)+(f&262140)>>2]|0;h=f;break};case 4:{if(f>>>0>=67109888){i=3726;break L4970}j=f&1020;if((a[816784+j|0]&1)==0){i=3726;break L4970}k=(c[120068]|0)+j|0;if((a[816784+(j|2)|0]&1)==0){g=e[k>>1]|0;h=f;break L4970}else{g=c[k>>2]|0;h=f;break L4970}break};case 0:{if((c[194161]|0)>>>0<=16777215){g=c[(c[191664]|0)+(f&16380)>>2]|0;h=f;break L4970}if(f>>>0>=16384){i=3726;break L4970}g=c[195150]|0;h=f;break};case 3:{g=c[(c[120070]|0)+(f&32764)>>2]|0;h=f;break};case 5:{g=c[(c[191862]|0)+(f&1020)>>2]|0;h=f;break};case 6:{k=f&131068;if((b[390344]&7)>>>0>2){if((f&114688|0)==98304){g=0;h=k;break L4970}}j=(f&98304|0)==98304?f&98300:k;g=c[(c[36850]|0)+j>>2]|0;h=j;break};case 7:{g=c[(c[37240]|0)+(f&1020)>>2]|0;h=f;break};case 8:case 9:case 10:case 11:case 12:{g=c[(c[36856]|0)+(f&33554428)>>2]|0;h=f;break};case 13:{if(a[9600]|0){i=3726;break L4970}switch(c[191532]|0){case 2:{j=(c[191542]|0)+1|0;c[191542]=j;if((j|0)!=4){l=0;return l|0}c[191532]=3;c[191542]=0;c[191536]=0;l=0;return l|0};case 3:{j=c[191542]|0;k=c[191536]|0;m=((d[(c[2374]|0)+(k+(c[191544]<<3))|0]|0)&1<<(j&7^7)|0)!=0|0;n=j+1|0;c[191542]=n;if((n&7|0)==0){c[191536]=k+1}if((n|0)!=64){l=m;return l|0}c[191532]=0;l=m;return l|0};case 0:case 1:case 4:{l=1;return l|0};default:{l=0;return l|0}}break};case 14:{if((a[9576]&1^1|a[9592]&1^1)<<24>>24==0){i=3726;break L4970}m=c[191526]|0;do{if((m|0)==0){o=a[341e3+(c[191528]<<16|f&65535)|0]|0}else if((m|0)==3){n=f&255;if((n|0)==0){o=c[2348]&255;break}else if((n|0)==1){o=c[2350]&255;break}else{o=0;break}}else if((m|0)==7){c[191524]=0;c[191526]=0;o=-1}else{o=0}}while(0);l=o&255;return l|0};default:{i=3726}}}while(0);do{if((i|0)==3726){o=c[194161]|0;m=o>>>24;n=(c[774536+(m<<3)>>2]|0)+(c[774540+(m<<3)>>2]&o)|0;if((a[52040]&1)==0){o=e[n>>1]|0;g=o<<16|o;h=f;break}else{g=c[n>>2]|0;h=f;break}}}while(0);f=h&3;if((f|0)==0){l=g;return l|0}h=f<<3;l=g<<32-h|g>>>(h>>>0);return l|0}function kf(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=c[a>>2]|0;j=c[b>>2]|0;c[191614]=g;k=i>>>0>268435455;l=j>>>0>268435455;m=(k^1)<<31>>31&i>>>24|-(k&1);k=-(l&1)&15|(l^1)<<31>>31&j>>>24;j=(h|0)!=0;L5032:do{if(j){h=i&-4;c[a>>2]=h;if(!(h>>>0<33554432&(c[194161]|0)>>>0>16777215)){l=g;n=h;while(1){h=c[b>>2]|0;kg(h,ke(n)|0);c[b>>2]=(c[b>>2]|0)+f;n=(c[a>>2]|0)+e|0;c[a>>2]=n;l=l-1|0;if((l|0)==0){break L5032}}}l=g;n=c[b>>2]|0;do{kg(n,0);n=(c[b>>2]|0)+f|0;c[b>>2]=n;l=l-1|0;}while((l|0)!=0)}else{l=i&-2;c[a>>2]=l;n=e>>1;h=f>>1;if(!(l>>>0<33554432&(c[194161]|0)>>>0>16777215)){o=g;p=l;while(1){l=c[b>>2]|0;kh(l,(ki(p)|0)&65535);c[b>>2]=(c[b>>2]|0)+h;p=(c[a>>2]|0)+n|0;c[a>>2]=p;o=o-1|0;if((o|0)==0){break L5032}}}o=g;p=c[b>>2]|0;do{kh(p,0);p=(c[b>>2]|0)+h|0;c[b>>2]=p;o=o-1|0;}while((o|0)!=0)}}while(0);c[191614]=0;b=m&15;if(j){j=d[125296+(k&15)|0]|0;m=ac((d[125296+b|0]|0)+2+j|0,g-1|0)|0;q=j+6+(d[130616+b|0]|0)+(c[194194]|0)+m|0;c[194194]=q;return}else{m=d[130328+(k&15)|0]|0;k=ac((d[130328+b|0]|0)+2+m|0,g-1|0)|0;q=m+6+(d[147072+b|0]|0)+(c[194194]|0)+k|0;c[194194]=q;return}}function kg(d,e){d=d|0;e=e|0;var f=0;switch(d>>>24|0){case 2:{c[(c[36848]|0)+(d&262140)>>2]=e;return};case 4:{if(d>>>0>=67109888){return}f=d&1020;kd(f,e&65535);kd(f|2,e>>>16&65535);return};case 6:{do{if((b[390344]&7)>>>0>2){if((d&114688|0)!=98304){break}return}}while(0);c[(c[36850]|0)+(((d&98304|0)==98304?98300:131068)&d)>>2]=e;return};case 7:{c[(c[37240]|0)+(d&1020)>>2]=e;return};case 3:{c[(c[120070]|0)+(d&32764)>>2]=e;return};case 5:{c[(c[191862]|0)+(d&1020)>>2]=e;return};case 13:{if(a[9600]|0){return}jR(e&255);return};case 14:{if((a[766136]&1^1|a[9576]&1^1|a[9592]&1^1)<<24>>24==0){return}fa[c[2396]&127](d,e&255);return};default:{return}}}function kh(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g|0;j=g+8|0;switch(e>>>24|0){case 5:{b[(c[191862]|0)+(e&1022)>>1]=f;i=g;return};case 4:{if(e>>>0>=67109888){i=g;return}kd(e&1022,f);i=g;return};case 2:{b[(c[36848]|0)+(e&262142)>>1]=f;i=g;return};case 6:{do{if((b[390344]&7)>>>0>2){if((e&114688|0)!=98304){break}i=g;return}}while(0);b[(c[36850]|0)+(((e&98304|0)==98304?98302:131070)&e)>>1]=f;i=g;return};case 3:{b[(c[120070]|0)+(e&32766)>>1]=f;i=g;return};case 7:{b[(c[37240]|0)+(e&1022)>>1]=f;i=g;return};case 8:case 9:{if(!((e|0)==134217928|(e|0)==134217926|(e|0)==134217924)){i=g;return}if(!(a[147056]|0)){i=g;return}if((e|0)==134217928){a[780642]=f&255;i=g;return}else if((e|0)==134217926){a[780641]=f&255;i=g;return}else if((e|0)==134217924){if((a[780642]&1)==0){i=g;return}k=c[195163]|0;l=a[780640]|0;if((k|0)==0&l<<24>>24==1&f<<16>>16==5){c[195163]=1;c[195162]=0;a[780643]=0;i=g;return}do{if((l&1)==0){m=f&65535;if((m&1|0)==0){break}a[780640]=f&255;if((k|0)==1){n=c[195162]|0;o=d[780643]|0|(m>>>1&1)<<7-n;a[780643]=o&255;p=n+1|0;c[195162]=p;if((p|0)!=8){i=g;return}c[195162]=0;switch(o&255|0){case 96:{c[195163]=0;c[195162]=0;i=g;return};case 98:{c[195163]=3;c[195161]=1;i=g;return};case 99:{c[195161]=1;a[780656]=64;c[195163]=2;i=g;return};case 101:{eF(h|0)|0;o=be(h|0)|0;c[195161]=7;p=(c[o+20>>2]&255)%100|0;a[780656]=((p&255)/10|0)<<4|((p&255)%10|0);p=((c[o+16>>2]|0)+1&255)%100|0;a[780657]=((p&255)/10|0)<<4|((p&255)%10|0);p=(c[o+12>>2]&255)%100|0;a[780658]=((p&255)/10|0)<<4|((p&255)%10|0);p=(c[o+24>>2]&255)%100|0;a[780659]=((p&255)/10|0)<<4|((p&255)%10|0);p=(c[o+8>>2]&255)%100|0;a[780660]=((p&255)/10|0)<<4|((p&255)%10|0);p=(c[o+4>>2]&255)%100|0;a[780661]=((p&255)/10|0)<<4|((p&255)%10|0);p=(c[o>>2]&255)%100|0;a[780662]=((p&255)/10|0)<<4|((p&255)%10|0);c[195163]=2;i=g;return};case 103:{eF(j|0)|0;p=be(j|0)|0;c[195161]=3;o=(c[p+8>>2]&255)%100|0;a[780656]=((o&255)/10|0)<<4|((o&255)%10|0);o=(c[p+4>>2]&255)%100|0;a[780657]=((o&255)/10|0)<<4|((o&255)%10|0);o=(c[p>>2]&255)%100|0;a[780658]=((o&255)/10|0)<<4|((o&255)%10|0);c[195163]=2;i=g;return};case 100:{i=g;return};default:{a6(0,c[q>>2]|0)|0;c[195163]=0;i=g;return}}}else if((k|0)==2){if((a[780641]&2)!=0){i=g;return}o=c[195162]|0;a[780640]=((d[780656+(o>>3)|0]|0)>>>((o&7)>>>0)<<1&2|m&253)&255;p=o+1|0;c[195162]=p;if((p|0)!=(c[195161]<<3|0)){i=g;return}c[195162]=0;c[195163]=0;i=g;return}else if((k|0)==3){if((a[780641]&2)==0){i=g;return}p=780656+(c[195162]>>3)|0;a[p]=((d[p]|0)>>>1|m<<6&128)&255;m=(c[195162]|0)+1|0;c[195162]=m;if((m|0)!=(c[195161]<<3|0)){i=g;return}c[195162]=0;c[195163]=0;i=g;return}else{i=g;return}}}while(0);a[780640]=f&255;i=g;return}else{i=g;return}break};case 13:{if(a[9600]|0){i=g;return}jR(f&255);i=g;return};case 14:{if((a[766136]&1^1|a[9576]&1^1|a[9592]&1^1)<<24>>24==0){i=g;return}fa[c[2396]&127](e,f&255);i=g;return};default:{i=g;return}}}function ki(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;L5180:do{switch(f>>>24|0){case 0:{if((c[194161]|0)>>>0<=16777215){g=e[(c[191664]|0)+(f&16382)>>1]|0;h=f;break L5180}if(f>>>0>=16384){i=3915;break L5180}g=e[780600+(f&2)>>1]|0;h=f;break};case 2:{g=e[(c[36848]|0)+(f&262142)>>1]|0;h=f;break};case 4:{if(f>>>0>=67109888){i=3915;break L5180}j=f&1022;if((a[816784+j|0]&1)==0){i=3915;break L5180}k=e[(c[120068]|0)+j>>1]|0;if((j-256|0)>>>0>=14){g=k;h=f;break L5180}if((j|0)==256){if((a[767432]&1)==0){g=k;h=f;break L5180}g=65535-((c[203380]|0)-(c[195148]|0)>>c[194204])|0;h=f;break L5180}else if((j|0)==260){if((a[767424]&1)==0){g=k;h=f;break L5180}if((b[390475]&4)!=0){g=k;h=f;break L5180}g=65535-((c[203376]|0)-(c[195148]|0)>>c[194202])|0;h=f;break L5180}else if((j|0)==264){if((a[767416]&1)==0){g=k;h=f;break L5180}if((b[390477]&4)!=0){g=k;h=f;break L5180}g=65535-((c[203372]|0)-(c[195148]|0)>>c[194200])|0;h=f;break L5180}else if((j|0)==268){if((a[767408]&1)==0){g=k;h=f;break L5180}if((b[390479]&4)!=0){g=k;h=f;break L5180}g=65535-((c[203368]|0)-(c[195148]|0)>>c[194198])|0;h=f;break L5180}else{g=k;h=f;break L5180}break};case 3:{g=e[(c[120070]|0)+(f&32766)>>1]|0;h=f;break};case 5:{g=e[(c[191862]|0)+(f&1022)>>1]|0;h=f;break};case 6:{k=f&131070;if((b[390344]&7)>>>0>2){if((f&114688|0)==98304){g=0;h=k;break L5180}}j=(f&98304|0)==98304?f&98302:k;g=e[(c[36850]|0)+j>>1]|0;h=j;break};case 7:{g=e[(c[37240]|0)+(f&1022)>>1]|0;h=f;break};case 8:case 9:case 10:case 11:case 12:{if(!((f|0)==134217928|(f|0)==134217926|(f|0)==134217924)){g=e[(c[36856]|0)+(f&33554430)>>1]|0;h=f;break L5180}do{if(a[147056]|0){if((f|0)==134217928){l=d[780642]|0;break}else if((f|0)==134217926){l=d[780641]|0;break}else if((f|0)==134217924){l=d[780640]|0;break}else{i=3895;break}}else{i=3895}}while(0);if((i|0)==3895){l=b[(c[36856]|0)+(f&33554430)>>1]|0}g=l&65535;h=f;break};case 13:{if(a[9600]|0){i=3915;break L5180}switch(c[191532]|0){case 2:{j=(c[191542]|0)+1|0;c[191542]=j;if((j|0)!=4){m=0;return m|0}c[191532]=3;c[191542]=0;c[191536]=0;m=0;return m|0};case 3:{j=c[191542]|0;k=c[191536]|0;n=((d[(c[2374]|0)+(k+(c[191544]<<3))|0]|0)&1<<(j&7^7)|0)!=0|0;o=j+1|0;c[191542]=o;if((o&7|0)==0){c[191536]=k+1}if((o|0)!=64){m=n;return m|0}c[191532]=0;m=n;return m|0};case 0:case 1:case 4:{m=1;return m|0};default:{m=0;return m|0}}break};case 14:{if((a[9576]&1^1|a[9592]&1^1)<<24>>24==0){i=3915;break L5180}n=c[191526]|0;do{if((n|0)==0){p=a[341e3+(c[191528]<<16|f&65535)|0]|0}else if((n|0)==3){o=f&255;if((o|0)==0){p=c[2348]&255;break}else if((o|0)==1){p=c[2350]&255;break}else{p=0;break}}else if((n|0)==7){c[191524]=0;c[191526]=0;p=-1}else{p=0}}while(0);m=p&255;return m|0};default:{i=3915}}}while(0);if((i|0)==3915){i=c[194161]|0;if((a[52040]&1)==0){q=i}else{q=i+(f&2)|0}i=q>>24;g=e[(c[774536+(i<<3)>>2]|0)+(c[774540+(i<<3)>>2]&q)>>1]|0;h=f}if((h&1|0)==0){m=g;return m|0}m=g>>>8|g<<24;return m|0}function kj(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=e[384088]|0;do{if((f&32768|0)!=0){if((d&1|0)==0){break}if((f>>>12&3|0)!=(a|0)){break}g=b[384084]|0;kf(817840,767968,c[51744+((f>>>7&3)<<2)>>2]|0,c[51744+((f>>>5&3)<<2)>>2]|0,g<<16>>16==0?16384:g&65535,f&1024);g=b[384088]|0;if((g&16384)==0){h=g}else{g=b[390601]|256;b[390601]=g;b[(c[120068]|0)+514>>1]=g;c[203364]=c[195148];h=b[384088]|0}if((h&96)==96){c[191992]=(e[384080]|0)<<16|(e[384076]|0)}if(!((h&512)==0|(a|0)==0)){break}g=h&32767;b[384088]=g;b[(c[120068]|0)+186>>1]=g}}while(0);h=e[384064]|0;do{if((h&32768|0)!=0){if((d&2|0)==0){break}if((h>>>12&3|0)!=(a|0)){break}if((a|0)==3){i=0;j=4;k=1024}else{f=b[384060]|0;i=c[51744+((h>>>5&3)<<2)>>2]|0;j=f<<16>>16==0?16384:f&65535;k=h&1024}kf(817832,767960,c[51744+((h>>>7&3)<<2)>>2]|0,i,j,k);f=b[384064]|0;if((f&16384)==0){l=f}else{f=b[390601]|512;b[390601]=f;b[(c[120068]|0)+514>>1]=f;c[203364]=c[195148];l=b[384064]|0}if((l&96)==96){c[191990]=(e[384056]|0)<<16|(e[384052]|0)}if(!((l&512)==0|(a|0)==0)){break}f=l&32767;b[384064]=f;b[(c[120068]|0)+198>>1]=f}}while(0);l=e[384040]|0;do{if((l&32768|0)!=0){if((d&4|0)==0){break}if((l>>>12&3|0)!=(a|0)){break}if((a|0)==3){m=0;n=1024;o=4}else{k=b[384036]|0;m=c[51744+((l>>>5&3)<<2)>>2]|0;n=l&1024;o=k<<16>>16==0?16384:k&65535}kf(817824,767952,c[51744+((l>>>7&3)<<2)>>2]|0,m,o,n);k=b[384040]|0;if((k&16384)==0){p=k}else{k=b[390601]|1024;b[390601]=k;b[(c[120068]|0)+514>>1]=k;c[203364]=c[195148];p=b[384040]|0}if((p&96)==96){c[191988]=(e[384032]|0)<<16|(e[384028]|0)}if(!((p&512)==0|(a|0)==0)){break}k=p&32767;b[384040]=k;b[(c[120068]|0)+210>>1]=k}}while(0);p=e[384016]|0;if((p&32768|0)==0){return}if((d&8|0)==0){return}if((p>>>12&3|0)!=(a|0)){return}d=b[384012]|0;kf(817816,767944,c[51744+((p>>>7&3)<<2)>>2]|0,c[51744+((p>>>5&3)<<2)>>2]|0,d<<16>>16==0?65536:d&65535,p&1024);p=b[384016]|0;if((p&16384)==0){q=p}else{p=b[390601]|2048;b[390601]=p;b[(c[120068]|0)+514>>1]=p;c[203364]=c[195148];q=b[384016]|0}if((q&96)==96){c[191986]=(e[384008]|0)<<16|(e[384004]|0)}if(!((q&512)==0|(a|0)==0)){return}a=q&32767;b[384016]=a;b[(c[120068]|0)+222>>1]=a;return}function kk(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((c[203382]|0)==0){if((a[766136]&1)!=0){c[203382]=3;break}d=c[36854]|0;if((d|0)==2){c[203382]=2;break}else if((d|0)==1){c[203382]=1;break}else{break}}}while(0);v3(780640,0,48);v3(780640,0,16);v3(776584,0,180);d=c[37240]|0;v3(d|0,0,1024);v3(c[191862]|0,0,1024);v3(c[37236]|0,0,153600);f=c[36850]|0;v3(f|0,0,131072);g=c[120068]|0;v3(g|0,0,1024);b[390344]=128;b[390346]=0;b[390347]=126;v3(780696,0,24);b[390360]=256;b[390361]=0;b[390362]=0;b[390363]=256;b[384160]=0;b[384164]=0;b[384152]=0;b[384156]=0;b[390368]=256;b[390369]=0;b[390370]=0;b[390371]=256;b[384144]=0;b[384148]=0;b[384136]=0;b[384140]=0;v3(780752,0,12);b[384124]=0;b[384132]=0;b[384300]=0;b[387188]=0;b[384068]=0;b[384072]=0;b[384076]=0;b[384080]=0;b[384084]=0;b[384088]=0;b[384044]=0;b[384048]=0;b[384052]=0;b[384056]=0;b[384060]=0;b[384064]=0;b[384020]=0;b[384024]=0;b[384028]=0;b[384032]=0;b[384036]=0;b[384040]=0;b[383996]=0;b[384e3]=0;b[384004]=0;b[384008]=0;b[384012]=0;b[384016]=0;v3(780944,0,16);b[390496]=1023;b[390600]=0;b[390601]=0;b[390604]=0;c[31194]=31;c[194159]=50364160;c[194161]=134217728;c[194164]=50364320;c[194174]=50364384;a[130632]=1;a[52040]=1;a[768224]=0;a[768240]=0;a[768232]=0;a[768256]=0;b[g>>1]=128;b[g+6>>1]=b[390347]|0;b[g+32>>1]=b[390360]|0;b[g+38>>1]=b[390363]|0;b[g+48>>1]=b[390368]|0;b[g+54>>1]=b[390371]|0;b[g+304>>1]=b[390496]|0;b[g+136>>1]=512;c[194162]=c[31194]&31|64;h=c[194161]|0;c[194193]=h;c[194161]=h+4;a[767384]=0;a[780600]=0;a[780601]=-16;a[780602]=41;a[780603]=-31;c[191865]=208;a[767432]=0;c[203380]=0;c[195158]=0;c[194204]=0;a[767424]=0;c[203376]=0;c[195156]=0;c[194202]=0;a[767416]=0;c[203372]=0;c[195154]=0;c[194200]=0;a[767408]=0;c[203368]=0;c[195152]=0;c[194198]=0;c[204460]=0;c[191992]=0;c[204458]=0;c[191990]=0;c[204456]=0;c[191988]=0;c[204454]=0;c[191986]=0;c[2396]=96;c[36766]=76;a[774368]=0;a[767392]=0;c[36854]=0;c[191863]=e[390344]|0;v3(768608,-1|0,3840);h=0;do{c[774536+(h<<3)>>2]=0;c[774540+(h<<3)>>2]=0;h=h+1|0;}while((h|0)<256);c[193634]=c[191664];c[193635]=16383;c[193638]=c[36848];c[193639]=262143;c[193640]=c[120070];c[193641]=32767;c[193642]=g;c[193643]=1023;c[193644]=c[191862];c[193645]=1023;c[193646]=f;c[193647]=131071;c[193648]=d;c[193649]=1023;d=c[36856]|0;c[193650]=d;c[193651]=33554431;c[193652]=d;c[193653]=33554431;c[193654]=d;c[193655]=33554431;c[193658]=d;c[193659]=33554431;c[193662]=341e3;c[193663]=65535;c[191532]=0;c[191536]=0;c[191542]=0;c[191544]=0;a[766136]=0;c[2356]=512;c[191524]=0;c[191526]=0;c[191528]=0;jK();d=e[390376]|0;f=d>>>8;g=d&255;d=f>>>0<=g>>>0;h=~(d&1);i=0;do{j=(i|0)>=(f|0);k=(i|0)<(g|0);a[767704+i|0]=(j?k&d&1:0)|(j?1:k&1)&h;i=i+1|0;}while((i|0)<240);i=e[390377]|0;h=i>>>8;d=i&255;i=h>>>0<=d>>>0;g=~(i&1);f=0;do{k=(f|0)>=(h|0);j=(f|0)<(d|0);a[767464+f|0]=(k?j&i&1:0)|(k?1:j&1)&g;f=f+1|0;}while((f|0)<240);kl(255);switch(c[191612]|0){case 0:{a[9576]=0;a[9592]=0;a[9600]=0;c[203382]=0;c[36854]=0;break};case 1:{a[9576]=1;a[9592]=1;a[9600]=0;c[203382]=3;c[36854]=3;break};case 2:{a[9576]=0;a[9592]=1;a[9600]=1;c[2396]=100;c[203382]=1;c[36854]=1;break};case 3:{a[9576]=1;a[9592]=0;a[9600]=1;c[2396]=34;c[203382]=2;c[36854]=2;break};case 4:{a[9576]=1;a[9592]=1;a[9600]=0;c[203382]=3;c[36854]=3;break};case 5:{a[9576]=1;a[9592]=1;a[9600]=1;c[203382]=5;c[36854]=5;break};default:{}}f=c[194193]|0;g=f>>>24;c[203402]=c[(c[774536+(g<<3)>>2]|0)+(c[774540+(g<<3)>>2]&f)>>2];g=f+4|0;f=g>>>24;c[203400]=c[(c[774536+(f<<3)>>2]|0)+(c[774540+(f<<3)>>2]&g)>>2];return}function kl(e){e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0.0,ak=0,al=0;f=i;i=i+408|0;j=f|0;k=f+8|0;l=f+16|0;m=f+24|0;n=f+32|0;o=f+40|0;p=f+48|0;q=f+56|0;r=f+64|0;s=f+72|0;t=f+80|0;u=f+88|0;v=f+96|0;w=f+104|0;x=f+112|0;y=f+120|0;z=f+128|0;A=f+136|0;B=f+144|0;C=f+152|0;D=f+160|0;E=f+168|0;F=f+176|0;G=f+184|0;H=f+192|0;I=f+200|0;J=f+208|0;K=f+216|0;L=f+224|0;M=f+232|0;N=f+240|0;O=f+248|0;P=f+256|0;Q=f+264|0;R=f+272|0;S=f+280|0;T=f+288|0;U=f+296|0;V=f+304|0;W=f+312|0;X=f+320|0;Y=f+328|0;Z=f+336|0;_=f+344|0;$=f+352|0;aa=f+360|0;ab=f+368|0;ac=f+376|0;ad=f+384|0;ae=f+392|0;af=f+400|0;kd(0,128);if((e|0)==0){i=f;return}if((e&1|0)!=0){v3(c[36848]|0,0,262144)}if((e&2|0)!=0){v3(c[120070]|0,0,32256)}if((e&4|0)!=0){v3(c[191862]|0,0,1024)}if((e&8|0)!=0){v3(c[36850]|0,0,98304)}if((e&16|0)!=0){v3(c[37240]|0,0,1024)}if((e&128|0)!=0){b[390600]=0;ag=c[120068]|0;b[ag+512>>1]=0;ah=b[390601]|0;do{if((b[390604]&1)!=0){if((b[390600]&ah)<<16>>16==0){break}if((a[130632]&1)==0){break}c[203364]=c[195148]}}while(0);b[ag+514>>1]=ah;a[130342]=4;a[147086]=4;a[147081]=3;a[147080]=3;a[130337]=1;a[130336]=1;a[147083]=3;a[147082]=3;a[130339]=1;a[130338]=1;a[147085]=3;a[147084]=3;a[130341]=1;a[130340]=1;a[130624]=5;a[125304]=3;a[130625]=5;a[125305]=3;a[130626]=5;a[125306]=3;a[130627]=5;a[125307]=3;a[130628]=5;a[125308]=3;a[130629]=5;a[125309]=3;a[130630]=9;a[125310]=9;a[776765]=0;a[776764]=0;c[194192]=0;b[ag+516>>1]=0;b[ag+518>>1]=0;b[390604]=0;b[ag+520>>1]=0;do{if((b[390604]&1)!=0){if((b[390600]&b[390601])<<16>>16==0){break}if((a[130632]&1)==0){break}c[203364]=c[195148]}}while(0);v3(ag+522|0,0,22);ah=b[390346]&7;b[390346]=ah;b[ag+4>>1]=ah;b[c[203436]>>1]=0;b[ag+8>>1]=0;b[c[203438]>>1]=0;b[ag+10>>1]=0;b[c[203440]>>1]=0;b[ag+12>>1]=0;b[c[203442]>>1]=0;b[ag+14>>1]=0;b[c[203444]>>1]=0;b[ag+16>>1]=0;b[c[203446]>>1]=0;b[ag+18>>1]=0;b[c[203448]>>1]=0;b[ag+20>>1]=0;b[c[203450]>>1]=0;b[ag+22>>1]=0;b[c[203452]>>1]=0;b[ag+24>>1]=0;b[c[203454]>>1]=0;b[ag+26>>1]=0;b[c[203456]>>1]=0;b[ag+28>>1]=0;b[c[203458]>>1]=0;b[ag+30>>1]=0;b[c[203460]>>1]=0;b[ag+32>>1]=0;ag=0;while(1){kd((ag<<1)+32|0,0);ah=ag+1|0;if((ah|0)<32){ag=ah}else{ai=0;break}}do{kd((ai<<1)+176|0,0);ai=ai+1|0;}while((ai|0)<24);ai=c[120068]|0;b[ai+304>>1]=b[390496]|0;b[c[203460]>>1]=256;b[ai+32>>1]=256;b[c[203476]>>1]=256;b[ai+48>>1]=256;b[c[203466]>>1]=256;b[ai+38>>1]=256;b[c[203482]>>1]=256;b[ai+54>>1]=256}if((e&32|0)!=0){ai=c[120068]|0;v3(ai+272|0,0,16);b[ai+308>>1]=-32768;v3(ai+320|0,0,14)}if((e&64|0)==0){i=f;return}jG(65318,132,0);jG(65318,132,-128);e=af|0;ai=ad|0;ag=ae|0;c[ag>>2]=128;c[ae+4>>2]=129;a[e]=0;a[af+1|0]=0;c[ai>>2]=65316;c[ad+4>>2]=65317;jE(ai,ag,e);e=c[120068]|0;ag=e+130|0;b[ag>>1]=14;jH(34830,2176);aj=+g[52048+((a[ag]&3)<<2)>>2];if(+h[63147]!=aj){h[63147]=aj;ag=d[505109]|0;ai=ag>>>4&7;ad=ag&7;ag=~~(aj*.6*.25/15.0*.125*+((ai>>>0<ad>>>0?ad:ai)+1|0)*1073741824.0+.5);c[126377]=ag;c[126379]=ag}if((a[816920]&1)==0){ag=c[194161]|0;ai=ag>>24;ak=(c[774536+(ai<<3)>>2]|0)+(c[774540+(ai<<3)>>2]&ag)|0;al=e+136|0}else{ag=e+136|0;ak=ag;al=ag}b[al>>1]=b[ak>>1]&1023;ak=e+112|0;a[ak]=112;e=167772-(c[322]|0)|0;do{if((a[505111]|0)<0){if((c[126289]|0)<(e|0)){jJ(e)}a[505099]=112;if((a[c[126344]|0]|0)<0){break}a[505412]=0}}while(0);al=l|0;ag=j|0;ai=k|0;c[ai>>2]=144;c[k+4>>2]=145;a[al]=0;a[l+1|0]=0;c[ag>>2]=65328;c[j+4>>2]=65329;jE(ag,ai,al);al=o|0;ai=m|0;ag=n|0;c[ag>>2]=146;c[n+4>>2]=147;a[al]=0;a[o+1|0]=0;c[ai>>2]=65330;c[m+4>>2]=65331;jE(ai,ag,al);al=r|0;ag=p|0;ai=q|0;c[ai>>2]=148;c[q+4>>2]=149;a[al]=0;a[r+1|0]=0;c[ag>>2]=65332;c[p+4>>2]=65333;jE(ag,ai,al);al=u|0;ai=s|0;ag=t|0;c[ag>>2]=150;c[t+4>>2]=151;a[al]=0;a[u+1|0]=0;c[ai>>2]=65334;c[s+4>>2]=65335;jE(ai,ag,al);al=x|0;ag=v|0;ai=w|0;c[ai>>2]=152;c[w+4>>2]=153;a[al]=0;a[x+1|0]=0;c[ag>>2]=65336;c[v+4>>2]=65337;jE(ag,ai,al);al=A|0;ai=y|0;ag=z|0;c[ag>>2]=154;c[z+4>>2]=155;a[al]=0;a[A+1|0]=0;c[ai>>2]=65338;c[y+4>>2]=65339;jE(ai,ag,al);al=D|0;ag=B|0;ai=C|0;c[ai>>2]=156;c[C+4>>2]=157;a[al]=0;a[D+1|0]=0;c[ag>>2]=65340;c[B+4>>2]=65341;jE(ag,ai,al);al=G|0;ai=E|0;ag=F|0;c[ag>>2]=158;c[F+4>>2]=159;a[al]=0;a[G+1|0]=0;c[ai>>2]=65342;c[E+4>>2]=65343;jE(ai,ag,al);a[ak]=0;do{if((a[505111]|0)<0){if((c[126289]|0)<(e|0)){jJ(e)}a[505099]=0;if((a[c[126344]|0]|0)<0){break}a[505412]=0}}while(0);e=J|0;ak=H|0;al=I|0;c[al>>2]=144;c[I+4>>2]=145;a[e]=0;a[J+1|0]=0;c[ak>>2]=65328;c[H+4>>2]=65329;jE(ak,al,e);e=M|0;al=K|0;ak=L|0;c[ak>>2]=146;c[L+4>>2]=147;a[e]=0;a[M+1|0]=0;c[al>>2]=65330;c[K+4>>2]=65331;jE(al,ak,e);e=P|0;ak=N|0;al=O|0;c[al>>2]=148;c[O+4>>2]=149;a[e]=0;a[P+1|0]=0;c[ak>>2]=65332;c[N+4>>2]=65333;jE(ak,al,e);e=S|0;al=Q|0;ak=R|0;c[ak>>2]=150;c[R+4>>2]=151;a[e]=0;a[S+1|0]=0;c[al>>2]=65334;c[Q+4>>2]=65335;jE(al,ak,e);e=V|0;ak=T|0;al=U|0;c[al>>2]=152;c[U+4>>2]=153;a[e]=0;a[V+1|0]=0;c[ak>>2]=65336;c[T+4>>2]=65337;jE(ak,al,e);e=Y|0;al=W|0;ak=X|0;c[ak>>2]=154;c[X+4>>2]=155;a[e]=0;a[Y+1|0]=0;c[al>>2]=65338;c[W+4>>2]=65339;jE(al,ak,e);e=$|0;ak=Z|0;al=_|0;c[al>>2]=156;c[_+4>>2]=157;a[e]=0;a[$+1|0]=0;c[ak>>2]=65340;c[Z+4>>2]=65341;jE(ak,al,e);e=ac|0;al=aa|0;ak=ab|0;c[ak>>2]=158;c[ab+4>>2]=159;a[e]=0;a[ac+1|0]=0;c[al>>2]=65342;c[aa+4>>2]=65343;jE(al,ak,e);jG(65318,132,0);i=f;return}function km(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=c[194162]&64;h=(a[768240]&1)==0?g:g|-2147483648;g=(a[768224]&1)==0?h:h|1073741824;h=(a[768256]&1)==0?g:g|536870912;g=(a[768232]&1)==0?h:h|268435456;h=(a[52040]&1)==0?g|32:g;g=c[31194]|0;i=((a[130632]&1)==0?h|128:h)|g&31;c[194162]=i;switch(g|0){case 17:{g=c[194154]|0;c[194154]=c[194183];c[194183]=g;g=c[194155]|0;c[194155]=c[194184];c[194184]=g;g=c[194156]|0;c[194156]=c[194185];c[194185]=g;g=c[194157]|0;c[194157]=c[194186];c[194186]=g;g=c[194158]|0;c[194158]=c[194187];c[194187]=g;c[194188]=c[194159];c[194189]=c[194160];g=c[194163]|0;c[194190]=g;j=g;break};case 27:{c[194180]=c[194159];c[194181]=c[194160];g=c[194163]|0;c[194182]=g;j=g;break};case 16:case 31:{c[194172]=c[194159];c[194173]=c[194160];c[194163]=i;j=i;break};case 23:{c[194177]=c[194159];c[194178]=c[194160];g=c[194163]|0;c[194179]=g;j=g;break};case 19:{c[194174]=c[194159];c[194175]=c[194160];g=c[194163]|0;c[194176]=g;j=g;break};case 18:{c[194164]=c[194159];c[194165]=c[194160];g=c[194163]|0;c[194166]=g;j=g;break};default:{j=c[194163]|0}}L5427:do{switch(d|0){case 16:case 31:{c[194159]=c[194172];c[194160]=c[194173];c[194162]=j;k=j;break};case 17:{g=c[194183]|0;c[194183]=c[194154];c[194154]=g;g=c[194184]|0;c[194184]=c[194155];c[194155]=g;g=c[194185]|0;c[194185]=c[194156];c[194156]=g;g=c[194186]|0;c[194186]=c[194157];c[194157]=g;g=c[194187]|0;c[194187]=c[194158];c[194158]=g;c[194159]=c[194188];c[194160]=c[194189];if(e){c[194163]=i;k=i;break L5427}else{c[194163]=c[194190];k=i;break L5427}break};case 18:{c[194159]=c[194164];c[194160]=c[194165];c[194162]=j;if(e){c[194163]=i;k=j;break L5427}else{c[194163]=c[194166];k=j;break L5427}break};case 19:{c[194159]=c[194174];c[194160]=c[194175];c[194162]=j;if(e){c[194163]=i;k=j;break L5427}else{c[194163]=c[194176];k=j;break L5427}break};case 23:{c[194159]=c[194177];c[194160]=c[194178];c[194162]=j;if(e){c[194163]=i;k=j;break L5427}else{c[194163]=c[194179];k=j;break L5427}break};case 27:{c[194159]=c[194180];c[194160]=c[194181];c[194162]=j;if(e){c[194163]=i;k=j;break L5427}else{c[194163]=c[194182];k=j;break L5427}break};default:{k=i}}}while(0);c[31194]=d;i=k>>>31&255;a[768240]=i;j=k>>>30&1;a[768224]=j;e=k>>>29&1;a[768256]=e;g=k>>>28&1;a[768232]=g;h=(k>>>5&1^1)&255;a[52040]=h;l=k>>>7&1;m=(l^1)&255;a[130632]=m;do{if((l|0)==0&f){if((b[390600]&b[390601])<<16>>16==0){break}if((b[390604]&1)==0){break}c[203364]=c[195148]}}while(0);f=k&64;k=i<<24>>24==0?f:f|-2147483648;f=j<<24>>24==0?k:k|1073741824;k=e<<24>>24==0?f:f|536870912;f=g<<24>>24==0?k:k|268435456;k=h<<24>>24==0?f|32:f;c[194162]=(m<<24>>24==0?k|128:k)|d&31;return}function kn(b){b=b|0;var d=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;c[776584+((b&7)<<2)>>2]=d;a[768240]=d>>>31&255;a[768224]=(d|0)==0|0;return}function ko(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>31&255;e=d<<1;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>30&1;a[768224]=(e|0)==0|0;return}function kp(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>30&1;e=d<<2;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>29&1;a[768224]=(e|0)==0|0;return}function kq(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>29&1;e=d<<3;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>28&1;a[768224]=(e|0)==0|0;return}function kr(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>28&1;e=d<<4;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>27&1;a[768224]=(e|0)==0|0;return}function ks(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>27&1;e=d<<5;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>26&1;a[768224]=(e|0)==0|0;return}function kt(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>26&1;e=d<<6;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>25&1;a[768224]=(e|0)==0|0;return}function ku(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>25&1;e=d<<7;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>24&1;a[768224]=(e|0)==0|0;return}function kv(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>24&1;e=d<<8;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>23&1;a[768224]=(e|0)==0|0;return}function kw(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>23&1;e=d<<9;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>22&1;a[768224]=(e|0)==0|0;return}function kx(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>22&1;e=d<<10;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>21&1;a[768224]=(e|0)==0|0;return}function ky(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>21&1;e=d<<11;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>20&1;a[768224]=(e|0)==0|0;return}function kz(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>20&1;e=d<<12;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>19&1;a[768224]=(e|0)==0|0;return}function kA(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>19&1;e=d<<13;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>18&1;a[768224]=(e|0)==0|0;return}function kB(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>18&1;e=d<<14;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>17&1;a[768224]=(e|0)==0|0;return}function kC(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>17&1;e=d<<15;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>16&1;a[768224]=(e|0)==0|0;return}function kD(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>16&1;e=d<<16;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>15&1;a[768224]=(e|0)==0|0;return}function kE(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>15&1;e=d<<17;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>14&1;a[768224]=(e|0)==0|0;return}function kF(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>14&1;e=d<<18;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>13&1;a[768224]=(e|0)==0|0;return}function kG(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>13&1;e=d<<19;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>12&1;a[768224]=(e|0)==0|0;return}function kH(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>12&1;e=d<<20;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>11&1;a[768224]=(e|0)==0|0;return}function kI(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>11&1;e=d<<21;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>10&1;a[768224]=(e|0)==0|0;return}function kJ(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>10&1;e=d<<22;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>9&1;a[768224]=(e|0)==0|0;return}function kK(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>9&1;e=d<<23;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>8&1;a[768224]=(e|0)==0|0;return}function kL(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>8&1;e=d<<24;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>7&1;a[768224]=(e|0)==0|0;return}function kM(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>7&1;e=d<<25;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>6&1;a[768224]=(e|0)==0|0;return}function kN(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>6&1;e=d<<26;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>5&1;a[768224]=(e|0)==0|0;return}function kO(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>5&1;e=d<<27;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>4&1;a[768224]=(e|0)==0|0;return}function kP(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>4&1;e=d<<28;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>3&1;a[768224]=(e|0)==0|0;return}function kQ(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>3&1;e=d<<29;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>2&1;a[768224]=(e|0)==0|0;return}function kR(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>2&1;e=d<<30;c[776584+((b&7)<<2)>>2]=e;a[768240]=d>>>1&1;a[768224]=(e|0)==0|0;return}function kS(b){b=b|0;var d=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>1&1;c[776584+((b&7)<<2)>>2]=d<<31;a[768240]=d&1;a[768224]=(d&1^1)&255;return}function kT(b){b=b|0;a[768256]=(c[776584+((b>>>3&7)<<2)>>2]|0)>>>31&255;c[776584+((b&7)<<2)>>2]=0;a[768240]=0;a[768224]=1;return}function kU(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d&1;e=d>>>1;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function kV(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>1&1;e=d>>>2;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function kW(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>2&1;e=d>>>3;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function kX(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>3&1;e=d>>>4;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function kY(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>4&1;e=d>>>5;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function kZ(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>5&1;e=d>>>6;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k_(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>6&1;e=d>>>7;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k$(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>7&1;e=d>>>8;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k0(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>8&1;e=d>>>9;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k1(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>9&1;e=d>>>10;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k2(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>10&1;e=d>>>11;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k3(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>11&1;e=d>>>12;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k4(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>12&1;e=d>>>13;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k5(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>13&1;e=d>>>14;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k6(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>14&1;e=d>>>15;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k7(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>15&1;e=d>>>16;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k8(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>16&1;e=d>>>17;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function k9(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>17&1;e=d>>>18;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function la(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>18&1;e=d>>>19;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function lb(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>19&1;e=d>>>20;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function lc(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>20&1;e=d>>>21;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function ld(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>21&1;e=d>>>22;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function le(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>22&1;e=d>>>23;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function lf(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>23&1;e=d>>>24;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function lg(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>24&1;e=d>>>25;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function lh(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>25&1;e=d>>>26;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function li(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>26&1;e=d>>>27;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function lj(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>27&1;e=d>>>28;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function lk(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>28&1;e=d>>>29;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function ll(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>29&1;e=d>>>30;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e|0)==0|0;return}function lm(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>30&1;e=d>>>31;c[776584+((b&7)<<2)>>2]=e;a[768240]=0;a[768224]=(e^1)&255;return}function ln(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;e=d>>31;a[768256]=d>>>31&255;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lo(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d&1;e=d>>1;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lp(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>1&1;e=d>>2;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lq(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>2&1;e=d>>3;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lr(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>3&1;e=d>>4;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function ls(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>4&1;e=d>>5;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lt(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>5&1;e=d>>6;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lu(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>6&1;e=d>>7;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lv(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>7&1;e=d>>8;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lw(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>8&1;e=d>>9;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lx(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>9&1;e=d>>10;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function ly(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>10&1;e=d>>11;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lz(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>11&1;e=d>>12;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lA(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>12&1;e=d>>13;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lB(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>13&1;e=d>>14;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lC(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>14&1;e=d>>15;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lD(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>15&1;e=d>>16;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lE(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>16&1;e=d>>17;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lF(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>17&1;e=d>>18;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lG(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>18&1;e=d>>19;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lH(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>19&1;e=d>>20;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lI(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>20&1;e=d>>21;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lJ(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>21&1;e=d>>22;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lK(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>22&1;e=d>>23;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lL(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>23&1;e=d>>24;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lM(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>24&1;e=d>>25;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lN(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>25&1;e=d>>26;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}function lO(b){b=b|0;var d=0,e=0;d=c[776584+((b>>>3&7)<<2)>>2]|0;a[768256]=d>>>26&1;e=d>>27;c[776584+((b&7)<<2)>>2]=e;a[768240]=e>>>31&255;a[768224]=(e|0)==0|0;return}
function hn(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;if(e>>>0<19){j=2;return j|0}k=c[i>>2]|0;l=a[b]|0;m=l&255;n=c[9512+((m&15^15)<<2)>>2]^268435455;o=n>>>4^c[9512+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=66){j=3;return j|0}l=a[b+1|0]|0;m=l&255;n=c[9512+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[9512+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=80){j=3;return j|0}l=a[b+2|0]|0;m=l&255;n=c[9512+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[9512+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=83){j=3;return j|0}l=a[b+3|0]|0;m=l&255;n=c[9512+(((m^o)&15)<<2)>>2]^o>>>4;if(l<<24>>24!=49){j=3;return j|0}l=0;o=0;p=0;q=1;r=n>>>4^c[9512+((n&15^m>>>4)<<2)>>2];m=4;n=7;while(1){s=d[b+m|0]|0;t=c[9512+(((s^r)&15)<<2)>>2]^r>>>4;u=t>>>4^c[9512+((t&15^s>>>4)<<2)>>2];t=m+1|0;v=wm(s&127,0,q,p)|0;w=wc(v,G,o,l)|0;if((s&128|0)!=0){x=0;y=0;z=0;A=1;B=u;C=t;D=n;break}s=q<<7|0>>>25;v=p<<7|q>>>25;E=wc(w,G,s,v)|0;l=G;o=E;p=v;q=s;r=u;m=t;n=n+1|0}while(1){n=d[b+C|0]|0;m=c[9512+(((n^B)&15)<<2)>>2]^B>>>4;r=m>>>4^c[9512+((m&15^n>>>4)<<2)>>2];m=C+1|0;q=wm(n&127,0,A,z)|0;F=wc(q,G,y,x)|0;if((n&128|0)!=0){H=0;I=0;J=0;K=1;L=r;M=m;N=D;break}n=A<<7|0>>>25;q=z<<7|A>>>25;p=wc(F,G,n,q)|0;x=G;y=p;z=q;A=n;B=r;C=m;D=D+1|0}while(1){O=a[b+M|0]|0;D=O&255;C=c[9512+(((D^L)&15)<<2)>>2]^L>>>4;P=C>>>4^c[9512+((C&15^D>>>4)<<2)>>2];Q=M+1|0;C=wm(D&127,0,K,J)|0;R=wc(C,G,I,H)|0;if((D&128|0)!=0){break}D=K<<7|0>>>25;C=J<<7|K>>>25;B=wc(R,G,D,C)|0;H=G;I=B;J=C;K=D;L=P;M=Q;N=N+1|0}M=w;w=F;F=R;if((F|0)==0){S=P;T=Q}else{R=wm(O&127,0,K,J)|0;J=wc(R,G,I,H)|0;H=P;P=Q;Q=0;while(1){I=d[b+P|0]|0;R=c[9512+(((I^H)&15)<<2)>>2]^H>>>4;U=R>>>4^c[9512+((R&15^I>>>4)<<2)>>2];I=Q+1|0;if(I>>>0<F>>>0){H=U;P=P+1|0;Q=I}else{break}}S=U;T=J+N|0}if(M>>>0>g>>>0){j=5;return j|0}if(w>>>0>k>>>0){j=6;return j|0}k=e-12|0;e=T;T=0;M=0;N=S;S=-1;J=0;L4376:while(1){U=e;Q=T;P=N;H=S;F=J;while(1){I=U;R=P;V=H;W=F;L4380:while(1){X=I;Y=R;while(1){if(X>>>0<k>>>0){Z=0;_=0;$=0;aa=1;ab=Y;ac=X}else{break L4376}while(1){K=d[b+ac|0]|0;O=c[9512+(((K^ab)&15)<<2)>>2]^ab>>>4;ad=O>>>4^c[9512+((O&15^K>>>4)<<2)>>2];ae=ac+1|0;O=wm(K&127,0,aa,$)|0;af=wc(O,G,_,Z)|0;if((K&128|0)!=0){break}K=aa<<7|0>>>25;O=$<<7|aa>>>25;L=wc(af,G,K,O)|0;Z=G;_=L;$=O;aa=K;ab=ad;ac=ae}ag=af;ah=ag&3;if((ah|0)==1){ai=3126;break}else if((ah|0)==2|(ah|0)==3){break L4380}else if((ah|0)==0){ai=3124;break}else{X=ae;Y=ad}}if((ai|0)==3126){ai=0;K=(ag>>>2)+1|0;O=W;L=V;D=ad;C=ae;B=K;while(1){A=B-1|0;z=a[b+C|0]|0;y=z&255;x=c[9512+(((y^D)&15)<<2)>>2]^D>>>4;m=y>>>4;aj=x>>>4^c[9512+((x&15^m)<<2)>>2];a[h+O|0]=z;z=c[9512+(((y^L)&15)<<2)>>2]^L>>>4;ak=z>>>4^c[9512+((z&15^m)<<2)>>2];if((A|0)==0){break}else{O=O+1|0;L=ak;D=aj;C=C+1|0;B=A}}al=K+ae|0;am=aj;an=ak;ao=K}else if((ai|0)==3124){ai=0;B=(ag>>>2)+1|0;C=W;D=V;L=B;while(1){O=a[f+C|0]|0;a[h+C|0]=O;A=O&255;O=c[9512+(((A^D)&15)<<2)>>2]^D>>>4;m=O>>>4^c[9512+((O&15^A>>>4)<<2)>>2];A=L-1|0;if((A|0)==0){al=ae;am=ad;an=m;ao=B;break}else{C=C+1|0;D=m;L=A}}}I=al;R=am;V=an;W=ao+W|0}ap=(ag>>>2)+1|0;R=0;I=0;L=0;D=1;C=ad;B=ae;while(1){K=d[b+B|0]|0;A=c[9512+(((K^C)&15)<<2)>>2]^C>>>4;aq=A>>>4^c[9512+((A&15^K>>>4)<<2)>>2];ar=B+1|0;A=wm(K&127,0,D,L)|0;as=wc(A,G,I,R)|0;if((K&128|0)!=0){break}K=D<<7|0>>>25;A=L<<7|D>>>25;m=wc(as,G,K,A)|0;R=G;I=m;L=A;D=K;C=aq;B=ar}B=as;C=B>>1;at=(B&1|0)==0?C:-C|0;if((ah|0)!=2){break}C=W;B=V;D=at+Q|0;L=ap;while(1){I=L-1|0;R=a[f+D|0]|0;a[h+C|0]=R;K=R&255;R=c[9512+(((K^B)&15)<<2)>>2]^B>>>4;au=R>>>4^c[9512+((R&15^K>>>4)<<2)>>2];if((I|0)==0){break}else{C=C+1|0;B=au;D=D+1|0;L=I}}U=ar;Q=ap+Q+at|0;P=aq;H=au;F=ap+W|0}F=W;H=V;P=at+M|0;U=ap;while(1){L=U-1|0;D=a[h+P|0]|0;a[h+F|0]=D;B=D&255;D=c[9512+(((B^H)&15)<<2)>>2]^H>>>4;av=D>>>4^c[9512+((D&15^B>>>4)<<2)>>2];if((L|0)==0){break}else{F=F+1|0;H=av;P=P+1|0;U=L}}e=ar;T=Q;M=ap+M+at|0;N=aq;S=av;J=ap+W|0}W=d[b+X|0]|0;ap=c[9512+(((W^Y)&15)<<2)>>2]^Y>>>4;Y=ap>>>4^c[9512+((ap&15^W>>>4)<<2)>>2];ap=d[b+(X+1)|0]|0;J=c[9512+(((ap^Y)&15)<<2)>>2]^Y>>>4;Y=J>>>4^c[9512+((J&15^ap>>>4)<<2)>>2];J=d[b+(X+2)|0]|0;av=c[9512+(((J^Y)&15)<<2)>>2]^Y>>>4;Y=av>>>4^c[9512+((av&15^J>>>4)<<2)>>2];av=d[b+(X+3)|0]|0;S=c[9512+(((av^Y)&15)<<2)>>2]^Y>>>4;Y=S>>>4^c[9512+((S&15^av>>>4)<<2)>>2];S=d[b+(X+4)|0]|0;aq=c[9512+(((S^Y)&15)<<2)>>2]^Y>>>4;Y=aq>>>4^c[9512+((aq&15^S>>>4)<<2)>>2];aq=ap<<8|W|J<<16|av<<24;av=d[b+(X+5)|0]|0;J=c[9512+(((av^Y)&15)<<2)>>2]^Y>>>4;Y=J>>>4^c[9512+((J&15^av>>>4)<<2)>>2];J=d[b+(X+6)|0]|0;W=c[9512+(((J^Y)&15)<<2)>>2]^Y>>>4;Y=W>>>4^c[9512+((W&15^J>>>4)<<2)>>2];W=d[b+(X+7)|0]|0;ap=c[9512+(((W^Y)&15)<<2)>>2]^Y>>>4;Y=~(ap>>>4^c[9512+((ap&15^W>>>4)<<2)>>2]);ap=(d[b+(X+9)|0]|0)<<8|(d[b+(X+8)|0]|0)|(d[b+(X+10)|0]|0)<<16|(d[b+(X+11)|0]|0)<<24;if((f|0)==0|(g|0)==0){aw=0}else{X=g;g=f;f=-1;while(1){b=X-1|0;N=d[g]|0;at=c[9512+(((N^f)&15)<<2)>>2]^f>>>4;ax=at>>>4^c[9512+((at&15^N>>>4)<<2)>>2];if((b|0)==0){break}else{X=b;g=g+1|0;f=ax}}aw=~ax}if((aw|0)!=(aq|0)){j=9;return j|0}if((av<<8|S|J<<16|W<<24|0)!=(~V|0)){j=10;return j|0}if((ap|0)!=(Y|0)){j=11;return j|0}c[i>>2]=w;j=1;return j|0}function ho(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;j=c[i>>2]|0;if(e>>>0<=17){k=4;return k|0}l=a[b]|0;m=l&255;n=c[9512+((m&15^15)<<2)>>2]^268435455;o=n>>>4^c[9512+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=85){k=4;return k|0}l=a[b+1|0]|0;m=l&255;n=c[9512+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[9512+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=80){k=4;return k|0}l=a[b+2|0]|0;m=l&255;n=c[9512+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[9512+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=83){k=4;return k|0}l=a[b+3|0]|0;m=l&255;n=c[9512+(((m^o)&15)<<2)>>2]^o>>>4;if(l<<24>>24!=49){k=4;return k|0}l=0;o=0;p=0;q=1;r=4;s=n>>>4^c[9512+((n&15^m>>>4)<<2)>>2];while(1){if(r>>>0<e>>>0){m=d[b+r|0]|0;n=c[9512+(((m^s)&15)<<2)>>2]^s>>>4;t=n>>>4^c[9512+((n&15^m>>>4)<<2)>>2];n=r+1|0;u=wm(m&127,0,q,p)|0;v=wc(u,G,o,l)|0;if((m&128|0)==0){w=G;x=v;y=n;z=t}else{A=0;B=0;C=0;D=1;E=n;F=t;break}}else{w=l;x=o;y=r;z=s}t=q<<7|0>>>25;n=p<<7|q>>>25;m=wc(x,w,t,n)|0;l=G;o=m;p=n;q=t;r=y;s=z}while(1){if(E>>>0<e>>>0){z=d[b+E|0]|0;s=c[9512+(((z^F)&15)<<2)>>2]^F>>>4;H=s>>>4^c[9512+((s&15^z>>>4)<<2)>>2];I=E+1|0;s=wm(z&127,0,D,C)|0;J=wc(s,G,B,A)|0;if((z&128|0)==0){K=G;L=J;M=I;N=H}else{break}}else{K=A;L=B;M=E;N=F}z=D<<7|0>>>25;s=C<<7|D>>>25;y=wc(L,K,z,s)|0;A=G;B=y;C=s;D=z;E=M;F=N}N=v;v=J;J=(N|0)==(g|0);F=(v|0)==(g|0);if(!(J|F)){k=7;return k|0}M=J?v:N;c[i>>2]=M;if(j>>>0<M>>>0){k=6;return k|0}j=e-12|0;if(I>>>0<j>>>0){i=-1;E=-1;D=H;C=0;B=0;A=I;while(1){K=0;L=0;z=0;s=1;y=A;r=D;while(1){if(y>>>0<e>>>0){q=d[b+y|0]|0;p=c[9512+(((q^r)&15)<<2)>>2]^r>>>4;O=p>>>4^c[9512+((p&15^q>>>4)<<2)>>2];P=y+1|0;p=wm(q&127,0,s,z)|0;Q=wc(p,G,L,K)|0;if((q&128|0)==0){R=G;S=Q;T=P;U=O}else{break}}else{R=K;S=L;T=y;U=r}q=s<<7|0>>>25;p=z<<7|s>>>25;o=wc(S,R,q,p)|0;K=G;L=o;z=p;s=q;y=T;r=U}r=Q;if((r|0)==0){V=P;W=B;X=C;Y=O;Z=E;_=i}else{y=i;s=E;z=C;L=B;K=r;while(1){q=K-1|0;if(L>>>0<g>>>0){p=a[f+L|0]|0;o=p&255;l=c[9512+(((o^s)&15)<<2)>>2]^s>>>4;$=p;aa=L+1|0;ab=l>>>4^c[9512+((l&15^o>>>4)<<2)>>2]}else{$=0;aa=L;ab=s}if(z>>>0<M>>>0){a[h+z|0]=$;o=$&255;l=c[9512+(((o^y)&15)<<2)>>2]^y>>>4;ac=l>>>4^c[9512+((l&15^o>>>4)<<2)>>2]}else{ac=y}if((q|0)==0){break}else{y=ac;s=ab;z=z+1|0;L=aa;K=q}}V=P;W=aa;X=r+C|0;Y=O;Z=ab;_=ac}while(1){if(V>>>0<e>>>0){K=a[b+V|0]|0;L=K&255;z=c[9512+(((L^Y)&15)<<2)>>2]^Y>>>4;ad=K;ae=V+1|0;af=z>>>4^c[9512+((z&15^L>>>4)<<2)>>2]}else{ad=0;ae=V;af=Y}if(W>>>0<g>>>0){L=a[f+W|0]|0;z=L&255;K=c[9512+(((z^Z)&15)<<2)>>2]^Z>>>4;ag=L;ah=W+1|0;ai=K>>>4^c[9512+((K&15^z>>>4)<<2)>>2]}else{ag=0;ah=W;ai=Z}z=ag^ad;if(X>>>0<M>>>0){a[h+X|0]=z;K=z&255;z=c[9512+(((K^_)&15)<<2)>>2]^_>>>4;aj=z>>>4^c[9512+((z&15^K>>>4)<<2)>>2]}else{aj=_}ak=X+1|0;if(ad<<24>>24==0){break}else{V=ae;W=ah;X=ak;Y=af;Z=ai;_=aj}}if(ae>>>0<j>>>0){i=aj;E=ai;D=af;C=ak;B=ah;A=ae}else{al=aj;am=ai;an=af;ao=ak;ap=ah;aq=ae;break}}}else{al=-1;am=-1;an=H;ao=0;ap=0;aq=I}if(ap>>>0<g>>>0){I=al;H=am;ae=ao;ah=ap;while(1){ak=a[f+ah|0]|0;af=ak&255;ai=c[9512+(((af^H)&15)<<2)>>2]^H>>>4;aj=af>>>4;ar=ai>>>4^c[9512+((ai&15^aj)<<2)>>2];ai=ah+1|0;if(ae>>>0<M>>>0){a[h+ae|0]=ak;ak=c[9512+(((af^I)&15)<<2)>>2]^I>>>4;as=ak>>>4^c[9512+((ak&15^aj)<<2)>>2]}else{as=I}if(ai>>>0<g>>>0){I=as;H=ar;ae=ae+1|0;ah=ai}else{break}}at=as;au=ar;av=g-ap+ao|0;aw=g}else{at=al;au=am;av=ao;aw=ap}if(av>>>0<M>>>0){ap=at;ao=au;am=av;av=aw;while(1){if(av>>>0<g>>>0){aw=a[f+av|0]|0;al=aw&255;ar=c[9512+(((al^ao)&15)<<2)>>2]^ao>>>4;ax=aw;ay=av+1|0;az=ar>>>4^c[9512+((ar&15^al>>>4)<<2)>>2]}else{ax=0;ay=av;az=ao}a[h+am|0]=ax;al=ax&255;ar=c[9512+(((al^ap)&15)<<2)>>2]^ap>>>4;aw=ar>>>4^c[9512+((ar&15^al>>>4)<<2)>>2];al=am+1|0;if(al>>>0<M>>>0){ap=aw;ao=az;am=al;av=ay}else{aA=aw;aB=az;break}}}else{aA=at;aB=au}if(aq>>>0<e>>>0){au=d[b+aq|0]|0;at=c[9512+(((au^an)&15)<<2)>>2]^an>>>4;aC=au;aD=aq+1|0;aE=at>>>4^c[9512+((at&15^au>>>4)<<2)>>2]}else{aC=0;aD=aq;aE=an}if(aD>>>0<e>>>0){an=d[b+aD|0]|0;aq=c[9512+(((an^aE)&15)<<2)>>2]^aE>>>4;aF=an<<8;aG=aD+1|0;aH=aq>>>4^c[9512+((aq&15^an>>>4)<<2)>>2]}else{aF=0;aG=aD;aH=aE}if(aG>>>0<e>>>0){aE=d[b+aG|0]|0;aD=c[9512+(((aE^aH)&15)<<2)>>2]^aH>>>4;aI=aE<<16;aJ=aG+1|0;aK=aD>>>4^c[9512+((aD&15^aE>>>4)<<2)>>2]}else{aI=0;aJ=aG;aK=aH}if(aJ>>>0<e>>>0){aH=d[b+aJ|0]|0;aG=c[9512+(((aH^aK)&15)<<2)>>2]^aK>>>4;aL=aH<<24;aM=aJ+1|0;aN=aG>>>4^c[9512+((aG&15^aH>>>4)<<2)>>2]}else{aL=0;aM=aJ;aN=aK}aK=aF|aC|aI|aL;if(aM>>>0<e>>>0){aL=d[b+aM|0]|0;aI=c[9512+(((aL^aN)&15)<<2)>>2]^aN>>>4;aO=aL;aP=aM+1|0;aQ=aI>>>4^c[9512+((aI&15^aL>>>4)<<2)>>2]}else{aO=0;aP=aM;aQ=aN}if(aP>>>0<e>>>0){aN=d[b+aP|0]|0;aM=c[9512+(((aN^aQ)&15)<<2)>>2]^aQ>>>4;aR=aN<<8;aS=aP+1|0;aT=aM>>>4^c[9512+((aM&15^aN>>>4)<<2)>>2]}else{aR=0;aS=aP;aT=aQ}if(aS>>>0<e>>>0){aQ=d[b+aS|0]|0;aP=c[9512+(((aQ^aT)&15)<<2)>>2]^aT>>>4;aU=aQ<<16;aV=aS+1|0;aW=aP>>>4^c[9512+((aP&15^aQ>>>4)<<2)>>2]}else{aU=0;aV=aS;aW=aT}if(aV>>>0<e>>>0){aT=d[b+aV|0]|0;aS=c[9512+(((aT^aW)&15)<<2)>>2]^aW>>>4;aX=aT<<24;aY=aV+1|0;aZ=aS>>>4^c[9512+((aS&15^aT>>>4)<<2)>>2]}else{aX=0;aY=aV;aZ=aW}aW=aR|aO|aU|aX;aX=~aB;if(aY>>>0<e>>>0){a_=d[b+aY|0]|0;a$=aY+1|0}else{a_=0;a$=aY}if(a$>>>0<e>>>0){a0=(d[b+a$|0]|0)<<8;a1=a$+1|0}else{a0=0;a1=a$}if(a1>>>0<e>>>0){a2=(d[b+a1|0]|0)<<16;a3=a1+1|0}else{a2=0;a3=a1}if(a3>>>0<e>>>0){a4=(d[b+a3|0]|0)<<24}else{a4=0}a3=~aA;if((a0|a_|a2|a4|0)!=(~aZ|0)){k=4;return k|0}if(!((aK|0)!=(aX|0)|J^1)){return((aW|0)==(a3|0)&(M|0)==(v|0)?1:8)|0}if((aW|0)!=(aX|0)|F^1){k=7;return k|0}k=(aK|0)==(a3|0)&(M|0)==(N|0)?1:8;return k|0}function hp(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if(e>>>0<8){j=4;return j|0}if((a[b]|0)!=80){j=4;return j|0}if((a[b+1|0]|0)!=65){j=4;return j|0}if((a[b+2|0]|0)!=84){j=4;return j|0}if((a[b+3|0]|0)!=67){j=4;return j|0}if((a[b+4|0]|0)!=72){j=4;return j|0}v6(h|0,f|0,g)|0;c[i>>2]=g;g=e-3|0;if(g>>>0<5){j=4;return j|0}f=e-2|0;k=5;while(1){l=k+3|0;m=d[b+(k+1)|0]<<8|d[b+k|0]<<16|d[b+(k+2)|0];if((m|0)==4542278){if((l|0)==(e|0)){j=1;n=3268;break}if((l|0)==(g|0)){n=3245;break}}if(l>>>0>f>>>0){j=4;n=3265;break}o=k+5|0;p=d[b+l|0]<<8|d[b+(k+4)|0];if((p|0)==0){if(o>>>0>g>>>0){j=4;n=3269;break}l=d[b+o|0]<<8|d[b+(k+6)|0];if((l|0)==0){j=4;n=3266;break}q=b+(k+7)|0;r=m;s=l;while(1){t=s-1|0;a[h+r|0]=a[q]|0;if((t|0)==0){break}else{r=r+1|0;s=t}}u=l;v=k+8|0}else{if(o>>>0>(e-p|0)>>>0){j=4;n=3270;break}else{w=o;x=m;y=p}while(1){s=y-1|0;a[h+x|0]=a[b+w|0]|0;if((s|0)==0){break}else{w=w+1|0;x=x+1|0;y=s}}u=p;v=p+o|0}l=u+m|0;if(l>>>0>(c[i>>2]|0)>>>0){c[i>>2]=l}if(v>>>0>g>>>0){j=4;n=3272;break}else{k=v}}if((n|0)==3272){return j|0}else if((n|0)==3270){return j|0}else if((n|0)==3265){return j|0}else if((n|0)==3269){return j|0}else if((n|0)==3245){c[i>>2]=d[b+(k+4)|0]<<8|d[b+g|0]<<16|d[b+(k+5)|0];j=1;return j|0}else if((n|0)==3266){return j|0}else if((n|0)==3268){return j|0}return 0}function hq(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=c[191244]|0;a3(49664,85,1,((f|0)!=0?f:c[q>>2]|0)|0)|0;f=c[191244]|0;aZ(((f|0)!=0?f:c[q>>2]|0)|0)|0;c[e>>2]=0;f=c2(b|0,41400)|0;if((f|0)==0){g=0;i=d;return g|0}b=vZ(4)|0;if((b|0)==0){aR(f|0)|0;g=0;i=d;return g|0}if((c[b-4>>2]&3|0)!=0){h=b;y=0;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255}h=b;eo(f|0,0,2)|0;j=cb(f|0)|0;ew(f|0);k=vZ(j+1|0)|0;do{if((k|0)==0){l=0;m=3288}else{a[k+j|0]=0;if((d5(k|0,1,j|0,f|0)|0)!=(j|0)){l=k;m=3288;break}aR(f|0)|0;c[e>>2]=k;do{if((wb(k|0,49088,5)|0)==0){n=bu(k|0,46936)|0;if((n|0)==0){o=k;break}p=n+3|0;c[e>>2]=p;r=p;m=3283}else{r=k;m=3283}}while(0);do{if((m|0)==3283){p=v2(r|0)|0;n=vZ(p+1|0)|0;if((n|0)==0){o=k;break}a[n+p|0]=0;p=bu(r|0,13624)|0;s=bu(r|0,51336)|0;if((p|0)==0|(s|0)==0){t=r;u=n}else{v=r;w=n;x=p;p=s;while(1){s=x-v|0;v6(w|0,v|0,s)|0;z=w+s|0;s=p+3|0;A=bu(s|0,13624)|0;B=bu(s|0,51336)|0;if((A|0)==0|(B|0)==0){t=s;u=z;break}else{v=s;w=z;x=A;p=B}}}p=v2(t|0)|0;v6(u|0,t|0,p)|0;a[u+p|0]=0;v_(k);c[e>>2]=n;p=hr(e)|0;c[b>>2]=p;if((p|0)==0){o=n;break}v_(n);g=h;i=d;return g|0}}while(0);v_(o)}}while(0);if((m|0)==3288){v_(l);aR(f|0)|0}f=c[b>>2]|0;if((f|0)!=0){hs(f)}v_(b);g=0;i=d;return g|0}function hr(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=vZ(24)|0;if((g|0)==0){h=0;i=d;return h|0}if((c[g-4>>2]&3|0)!=0){v3(g|0,0,24)}j=g;k=c[b>>2]|0;while(1){l=k+1|0;if((bd(a[k]|0)|0)==0){break}else{k=l}}c[b>>2]=k;L4649:do{if((a[k]|0)==60){m=b1(k|0,62)|0;if((m|0)==0){n=0;break}o=m-l|0;p=vZ(o+1|0)|0;if((p|0)==0){n=0;break}v6(p|0,l|0,o)|0;a[p+o|0]=0;o=p;while(1){if((bd(a[o]|0)|0)==0){q=o;break}else{o=o+1|0}}while(1){r=a[q]|0;if(r<<24>>24==0){s=0;break}if((bd(r<<24>>24|0)|0)==0){q=q+1|0}else{t=3311;break}}if((t|0)==3311){s=a[q]|0}r=(bd(s|0)|0)!=0?q:0;if((r|0)==0){u=dn(o|0)|0;c[g>>2]=u;if((u|0)==0){n=p;break}if((a[u]|0)==0){n=p;break}}else{u=r-o|0;v=vZ(u+1|0)|0;if((v|0)==0){c[g>>2]=0;n=p;break}v6(v|0,o|0,u)|0;a[v+u|0]=0;c[g>>2]=v;if((a[v]|0)==0){n=p;break}v=dn(r|0)|0;if((v|0)==0){w=0}else{r=v+((v2(v|0)|0)-1)|0;if((a[r]|0)==47){a[r]=0}r=d7(v|0,17760,e|0)|0;L4674:do{if((r|0)==0){x=0}else{u=r;y=0;z=0;while(1){A=bu(u|0,15848)|0;if((A|0)==0){x=z;break L4674}B=A+2|0;C=cf(B|0,34)|0;if((C|0)==0){x=z;break L4674}if((C|0)!=(u+((v2(u|0)|0)-1)|0)){x=z;break L4674}D=A-u|0;A=vZ(D+1|0)|0;if((A|0)==0){E=0}else{v6(A|0,u|0,D)|0;a[A+D|0]=0;E=A}A=C-B|0;C=vZ(A+1|0)|0;if((C|0)==0){x=z;break L4674}v6(C|0,B|0,A)|0;a[C+A|0]=0;if((E|0)==0){x=z;break L4674}A=vZ(12)|0;if((A|0)==0){x=z;break L4674}if((c[A-4>>2]&3|0)!=0){v3(A|0,0,12)}B=A;c[A>>2]=E;c[A+4>>2]=C;if((y|0)==0){F=B}else{c[y+8>>2]=B;F=z}C=d7(0,17760,e|0)|0;if((C|0)==0){x=F;break}else{u=C;y=B;z=F}}}}while(0);v_(v);w=x}c[g+8>>2]=w}if(((bu(k|0,36896)|0)+1|0)==(m|0)){c[b>>2]=m+1}else{r=c[g>>2]|0;o=(v2(r|0)|0)+4|0;z=vZ(o)|0;if((z|0)==0){n=p;break}bN(z|0,o|0,29264,(o=i,i=i+8|0,c[o>>2]=r,o)|0)|0;i=o;o=m+1|0;r=bu(o|0,25256)|0;y=b1(o|0,60)|0;u=bu(o|0,z|0)|0;if((u|0)==0){v_(z);n=p;break}L4702:do{if((r|0)==0){t=3349}else{B=o;while(1){if(B>>>0>=r>>>0){break}if((bd(a[B]|0)|0)==0){t=3349;break L4702}else{B=B+1|0}}B=bu(r|0,22056)|0;if((B|0)==0){v_(z);n=p;break L4649}C=r+9|0;A=B-C|0;B=vZ(A+1|0)|0;if((B|0)==0){G=0}else{v6(B|0,C|0,A)|0;a[B+A|0]=0;G=B}c[g+4>>2]=G;H=u}}while(0);do{if((t|0)==3349){if((u|0)==(y|0)){r=y-o|0;m=vZ(r+1|0)|0;if((m|0)==0){I=0}else{v6(m|0,o|0,r)|0;a[m+r|0]=0;I=m}c[g+4>>2]=I;H=y;break}c[f>>2]=y;m=b1(y|0,60)|0;r=bu(y|0,19712)|0;L4721:do{if((r|0)!=0&(m|0)!=0&m>>>0<r>>>0){v=0;B=0;while(1){A=hr(f)|0;if((A|0)==0){break}if((B|0)==0){J=A}else{c[B+16>>2]=A;J=v}C=c[f>>2]|0;D=b1(C|0,60)|0;K=bu(C|0,19712)|0;if((K|0)!=0&(D|0)!=0&D>>>0<K>>>0){v=J;B=A}else{L=J;M=C;break L4721}}v_(z);n=p;break L4649}else{L=0;M=y}}while(0);c[g+12>>2]=L;r=bu(M|0,z|0)|0;if((r|0)!=0){H=r;break}v_(z);n=p;break L4649}}while(0);c[b>>2]=H+(v2(z|0)|0);v_(z)}v_(p);h=j;i=d;return h|0}else{n=0}}while(0);v_(n);hs(j);h=0;i=d;return h|0}function hs(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((b|0)!=0){d=b;while(1){b=c[d+16>>2]|0;hs(d);if((b|0)==0){break}else{d=b}}}d=c[a+8>>2]|0;if((d|0)!=0){b=d;while(1){d=c[b+8>>2]|0;v_(c[b>>2]|0);v_(c[b+4>>2]|0);v_(b);if((d|0)==0){break}else{b=d}}}v_(c[a>>2]|0);v_(c[a+4>>2]|0);v_(a);return}function ht(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b;g=f-a|0;h=g>>2;do{if((h|0)==0){j=0}else{if(h>>>0<=65535){j=g;break}j=((g>>>0)/(h>>>0)|0|0)==4?g:-1}}while(0);k=vZ(j)|0;if((k|0)==0){l=c[191244]|0;m=(l|0)!=0?l:c[q>>2]|0;eb(m|0,33568,(m=i,i=i+16|0,c[m>>2]=49160,c[m+8>>2]=150,m)|0)|0;i=m;m=c[191244]|0;l=(m|0)!=0?m:c[q>>2]|0;aZ(l|0)|0;cd(2)}if((c[k-4>>2]&3|0)!=0){v3(k|0,0,j|0)}j=a;v6(k|0,j|0,g)|0;wa(j|0,b|0,d-f|0);f=d+(-h<<2)|0;v6(f|0,k|0,g)|0;v_(k);i=e;return}function hu(a){a=a|0;return 1}function hv(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;j=i;i=i+8256|0;k=j|0;l=j+8|0;m=j+64|0;n=j+4160|0;o=n|0;eF(k|0)|0;cR(o|0,4096,12960,be(k|0)|0)|0;k=v2(o|0)|0;p=k>>>0>4096?0:4096-k|0;L4758:do{if((p|0)==0){r=49432;s=3387}else{t=n+k|0;do{if((p|0)==1){u=49432;v=t}else{w=n+(k+1)|0;a[t]=98;if((p|0)==2){u=49433;v=w;break}x=n+(k+2)|0;a[w]=109;if((p|0)==3){u=49434;v=x;break}w=n+(k+3)|0;a[x]=112;if((p|0)==4){u=49435;v=w;break}a[w]=0;break L4758}}while(0);a[v]=0;r=u;s=3387}}while(0);do{if((s|0)==3387){if((a[r]|0)==0){break}else{z=r}do{z=z+1|0;}while((a[z]|0)!=0)}}while(0);z=m|0;gq(z,595580,o);o=c2(z|0,37672)|0;if((o|0)==0){m=c[191244]|0;r=(m|0)!=0?m:c[q>>2]|0;eb(r|0,36736,(r=i,i=i+8|0,c[r>>2]=z,r)|0)|0;i=r;r=c[191244]|0;z=(r|0)!=0?r:c[q>>2]|0;aZ(z|0)|0;A=0;i=j;return A|0}z=l|0;r=e*3|0;m=r+3&-4;u=ac(m,f)|0;v=u+54|0;a[z]=66;a[l+1|0]=77;a[l+2|0]=v&255;a[l+3|0]=v>>>8&255;a[l+4|0]=v>>>16&255;a[l+5|0]=v>>>24&255;v=l+6|0;y=0;a[v]=y&255;y=y>>8;a[v+1|0]=y&255;y=y>>8;a[v+2|0]=y&255;y=y>>8;a[v+3|0]=y&255;a[l+10|0]=54;a[l+11|0]=0;a[l+12|0]=0;a[l+13|0]=0;a[l+14|0]=40;a[l+15|0]=0;a[l+16|0]=0;a[l+17|0]=0;a[l+18|0]=e&255;a[l+19|0]=e>>>8&255;a[l+20|0]=e>>>16&255;a[l+21|0]=e>>>24&255;a[l+22|0]=f&255;a[l+23|0]=f>>>8&255;a[l+24|0]=f>>>16&255;a[l+25|0]=f>>>24&255;a[l+26|0]=1;a[l+27|0]=0;a[l+28|0]=24;v3(l+29|0,0,5);a[l+34|0]=u&255;a[l+35|0]=u>>>8&255;a[l+36|0]=u>>>16&255;a[l+37|0]=u>>>24&255;a[l+38|0]=19;a[l+39|0]=11;a[l+40|0]=0;a[l+41|0]=0;a[l+42|0]=19;a[l+43|0]=11;v3(l+44|0,0,10);l=(a3(z|0,1,54,o|0)|0)==54;do{if(l){z=(f|0)==0;do{if(z){B=0}else{u=f<<2;if(f>>>0<=65535){B=u;break}B=((u>>>0)/(f>>>0)|0|0)==4?u:-1}}while(0);u=vZ(B)|0;if((u|0)==0){break}if((c[u-4>>2]&3|0)!=0){v3(u|0,0,B|0)}v=u;p=0;while(1){if((p|0)>=(f|0)){s=3405;break}k=vZ(m)|0;if((k|0)==0){s=3404;break}if((c[k-4>>2]&3|0)!=0){v3(k|0,0,m|0)}c[v+(p<<2)>>2]=k;p=p+1|0}do{if((s|0)==3404){c[v+(p<<2)>>2]=0;s=3421}else if((s|0)==3405){do{if(h){if((f|0)>0){C=d;D=0}else{s=3419;break}while(1){k=c[v+(D<<2)>>2]|0;v6(k|0,C|0,r)|0;k=D+1|0;if((k|0)<(f|0)){C=C+g|0;D=k}else{s=3419;break}}}else{k=(f|0)>0;if((c[175572]|0)==1){if(!k){s=3419;break}if((e|0)==0){E=0;break}else{F=d;G=0}while(1){n=F;t=0;w=c[v+(G<<2)>>2]|0;while(1){x=c[n>>2]|0;a[w]=x&255;a[w+1|0]=x>>>8&255;a[w+2|0]=x>>>16&255;x=t+1|0;if(x>>>0<e>>>0){n=n+4|0;t=x;w=w+3|0}else{break}}w=G+1|0;if((w|0)<(f|0)){F=F+g|0;G=w}else{s=3419;break}}}else{if(!k){s=3419;break}if((e|0)==0){E=0;break}else{H=d;I=0}while(1){w=0;t=H;n=c[v+(I<<2)>>2]|0;while(1){x=b[t>>1]|0;J=x&255;a[n]=(J&255)>>>2&7|J<<3;a[n+1|0]=(x&65535)>>>5<<2&255|(x&65535)>>>9&3;J=(x&65535)>>>11&65535;a[n+2|0]=(J<<3|J>>>2)&255;J=w+1|0;if(J>>>0<e>>>0){w=J;t=t+2|0;n=n+3|0}else{break}}n=I+1|0;if((n|0)<(f|0)){H=H+g|0;I=n}else{s=3419;break}}}}}while(0);if((s|0)==3419){if(z){break}else{E=0}}while(1){a3(c[v+(E<<2)>>2]|0,1,m|0,o|0)|0;k=E+1|0;if(k>>>0<f>>>0){E=k}else{s=3421;break}}}}while(0);do{if((s|0)==3421){if((f|0)>0){K=0}else{break}do{v_(c[v+(K<<2)>>2]|0);K=K+1|0;}while((K|0)<(f|0))}}while(0);v_(u)}else{v=c[191244]|0;a3(29208,51,1,((v|0)!=0?v:c[q>>2]|0)|0)|0;v=c[191244]|0;aZ(((v|0)!=0?v:c[q>>2]|0)|0)|0}}while(0);aR(o|0)|0;A=l;i=j;return A|0}function hw(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+544|0;e=d|0;if((b|0)==0){i=d;return}f=b|0;if((c[f>>2]|0)!=0){g=e|0;h=d+512|0;do{if((a[591484]|0)!=0){j=gG(591484,0)|0;if((j|0)==0){k=vZ(20)|0;if((k|0)==0){l=c[191244]|0;m=(l|0)!=0?l:c[q>>2]|0;a3(51280,53,1,m|0)|0;m=c[191244]|0;l=(m|0)!=0?m:c[q>>2]|0;aZ(l|0)|0;break}if((c[k-4>>2]&3|0)!=0){v3(k|0,0,20)}n=k}else{n=j}v3(g|0,0,512);v3(h|0,0,32);j=b+8|0;k=c[j>>2]|0;do{if((k|0)!=0){l=0;m=k;while(1){if((a[(c[f>>2]|0)+(l*12|0)+4|0]&1)==0){o=m}else{bN(h|0,32,49080,(p=i,i=i+8|0,c[p>>2]=l,p)|0)|0;i=p;r=v2(g|0)|0;s=r>>>0>512?0:512-r|0;L4849:do{if((s|0)==0){t=h;u=3448}else{v=s;w=e+r|0;x=h;while(1){y=v-1|0;if((y|0)==0){break}z=a[x]|0;a[w]=z;if(z<<24>>24==0){break L4849}else{v=y;w=w+1|0;x=x+1|0}}a[w]=0;t=x;u=3448}}while(0);do{if((u|0)==3448){u=0;if((a[t]|0)==0){break}else{A=t}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);o=c[j>>2]|0}x=l+1|0;if(x>>>0<o>>>0){l=x;m=o}else{break}}if((a[g]|0)==0){break}a[e+((v2(g|0)|0)-1)|0]=0}}while(0);gJ(n,764812,g);if(!(gK(n,591484)|0)){j=c[191244]|0;k=(j|0)!=0?j:c[q>>2]|0;eb(k|0,46848,(p=i,i=i+8|0,c[p>>2]=591484,p)|0)|0;i=p;k=c[191244]|0;j=(k|0)!=0?k:c[q>>2]|0;aZ(j|0)|0}gE(n)}}while(0);n=b+8|0;p=c[f>>2]|0;if((c[n>>2]|0)==0){B=p}else{g=0;e=p;while(1){v_(c[e+(g*12|0)+8>>2]|0);p=g+1|0;o=c[f>>2]|0;if(p>>>0<(c[n>>2]|0)>>>0){g=p;e=o}else{B=o;break}}}v_(B)}v_(b);i=d;return}function hx(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+256|0;e=d|0;f=c[189113]|0;g=f+4|0;h=c[g>>2]|0;if(h>>>0>1){j=f|0;k=1;l=h;while(1){h=c[(c[j>>2]|0)+(k<<2)>>2]|0;if((h|0)==0){m=l}else{v_(c[h+8>>2]|0);v_(c[(c[j>>2]|0)+(k<<2)>>2]|0);c[(c[j>>2]|0)+(k<<2)>>2]=0;m=c[g>>2]|0}h=k+1|0;if(h>>>0<m>>>0){k=h;l=m}else{break}}}c[g>>2]=1;g=f+12|0;v_(c[g>>2]|0);c[g>>2]=0;g=e|0;e=c[b+4>>2]|0;f=c[b>>2]|0;b=(a[f+(e*12|0)+4|0]&1)!=0?29560:29080;m=c[f+(e*12|0)>>2]|0;bN(g|0,256,19688,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=b,c[f+16>>2]=m,f)|0)|0;i=f;m=c[189113]|0;b=m+4|0;L4883:do{if((c[b>>2]|0)>>>0<(c[m+8>>2]|0)>>>0){e=vZ(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}v3(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=180;l=dn(g|0)|0;k=c[b>>2]|0;c[e+8>>2]=l;l=m|0;c[(c[l>>2]|0)+(k<<2)>>2]=e;k=c[b>>2]|0;c[b>>2]=k+1;if(k>>>0>1){n=k}else{break}while(1){k=n>>>1;j=c[l>>2]|0;h=j+(k<<2)|0;o=c[h>>2]|0;p=c[j+(n<<2)>>2]|0;if((c[p+4>>2]|0)>>>0<=(c[o+4>>2]|0)>>>0){break L4883}c[h>>2]=p;c[(c[l>>2]|0)+(n<<2)>>2]=o;if(n>>>0>3){n=k}else{break}}}}while(0);if((a[607928]&1)==0){i=d;return}n=c[191244]|0;eb(((n|0)!=0?n:c[q>>2]|0)|0,47400,(f=i,i=i+8|0,c[f>>2]=g,f)|0)|0;i=f;f=c[191244]|0;aZ(((f|0)!=0?f:c[q>>2]|0)|0)|0;i=d;return}function hy(a,b,d){a=a|0;b=b|0;d=d|0;b=aS(d|0)|0;if((b|0)==0){return b|0}c[130526]=cV()|0;return b|0}function hz(a,b,c){a=a|0;b=b|0;c=c|0;return bE(b|0,c|0)|0}function hA(a){a=a|0;return aO()|0}function hB(a){a=a|0;return eU()|0}function hC(a,b){a=a|0;b=b|0;dZ(b|0);return}function hD(a){a=a|0;dT();return}function hE(a){a=a|0;return cL()|0}function hF(a){a=a|0;return bk()|0}function hG(b,d){b=b|0;d=+d;var e=0,f=0,h=0,i=0,j=0.0;e=b+24|0;if((c[e>>2]|0)!=0){f=b+12|0;h=0;do{i=c[f>>2]|0;if((a[i+(h*136|0)+20|0]&1)==0){g[i+(h*136|0)+56>>2]=d;g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2]*d;g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]*d;j=+g[i+(h*136|0)+60>>2];g[i+(h*136|0)+24>>2]=j+(+g[i+(h*136|0)+40>>2]-j)*d;j=+g[i+(h*136|0)+64>>2];g[i+(h*136|0)+28>>2]=j+(+g[i+(h*136|0)+44>>2]-j)*d}else{g[i+(h*136|0)+24>>2]=+g[i+(h*136|0)+40>>2];g[i+(h*136|0)+28>>2]=+g[i+(h*136|0)+44>>2];g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2];g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]}h=h+1|0;}while(h>>>0<(c[e>>2]|0)>>>0)}e=c[b+16>>2]|0;fe[c[(c[b+4>>2]|0)+12>>2]&7](c[b>>2]|0,+g[e+24>>2],+g[e+28>>2],+g[e+32>>2],+g[e+36>>2]);return}function hH(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aX=0,aY=0.0,a_=0.0,a$=0,a0=0,a1=0,a2=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0;b=i;i=i+9240|0;d=b|0;e=b+64|0;f=b+320|0;h=b+328|0;j=b+392|0;k=b+456|0;l=b+520|0;m=b+584|0;n=b+4680|0;o=b+8776|0;p=b+8792|0;r=b+8856|0;s=b+9112|0;t=b+9176|0;u=vZ(32)|0;if((u|0)==0){v=0;i=b;return v|0}if((c[u-4>>2]&3|0)!=0){v3(u|0,0,32)}w=u;x=c[(c[191559]|0)+52>>2]|0;do{if((x|0)==0){y=c[191244]|0;z=(y|0)!=0?y:c[q>>2]|0;a3(47904,71,1,z|0)|0;z=c[191244]|0;y=(z|0)!=0?z:c[q>>2]|0;aZ(y|0)|0}else{y=u+4|0;fa[x&127](c[191562]|0,y);z=u;c[z>>2]=c[191562];if((c[y>>2]|0)==0){break}A=gG(566896,0)|0;if((A|0)==0){B=c[191244]|0;C=(B|0)!=0?B:c[q>>2]|0;eb(C|0,48936,(D=i,i=i+8|0,c[D>>2]=566896,D)|0)|0;i=D;C=c[191244]|0;B=(C|0)!=0?C:c[q>>2]|0;aZ(B|0)|0;break}B=A+4|0;C=B;while(1){E=c[C>>2]|0;if((E|0)==0){F=3512;break}if((cJ(36560,c[E+4>>2]|0)|0)==0){F=3511;break}else{C=E+12|0}}L4936:do{if((F|0)==3511){c[(dR()|0)>>2]=0;C=aW(c[E+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){F=3512;break}if((C|0)==0){break}H=C*136|0;if(C>>>0>65535){I=((H>>>0)/(C>>>0)|0|0)==136?H:-1}else{I=H}H=vZ(I)|0;if((H|0)==0){c[u+12>>2]=0;break}if((c[H-4>>2]&3|0)!=0){v3(H|0,0,I|0)}J=H;H=u+12|0;c[H>>2]=J;K=u+24|0;c[K>>2]=C;C=k|0;L=l|0;M=m|0;N=n|0;O=o;P=p|0;Q=r|0;R=s|0;S=t|0;T=o+8|0;U=o|0;V=o+4|0;W=d|0;X=e|0;Y=h|0;Z=j|0;bN(C|0,64,17712,(D=i,i=i+8|0,c[D>>2]=0,D)|0)|0;i=D;L4949:do{if(gH(A,C,M)|0){_=J;$=0;L4950:while(1){bN(L|0,64,13600,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;aa=_+($*136|0)+69|0;ab=B;while(1){ac=c[ab>>2]|0;if((ac|0)==0){break}if((cJ(L|0,c[ac+4>>2]|0)|0)==0){F=3526;break}else{ab=ac+12|0}}L4955:do{if((F|0)==3526){F=0;ab=64;ad=aa;ae=c[ac+8>>2]|0;while(1){af=ab-1|0;if((af|0)==0){break}ag=a[ae]|0;a[ad]=ag;if(ag<<24>>24==0){break L4955}else{ab=af;ad=ad+1|0;ae=ae+1|0}}a[ad]=0;if((a[ae]|0)==0){break}else{ah=ae}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);gA(N,566896,M);v3(O|0,0,12);if((a[766412]&1)==0){if(!(h7(N,o,16,0)|0)){F=3534;break}}else{if(!(h7(N,o,0,16)|0)){F=3534;break}}c[_+($*136|0)+8>>2]=c[T>>2];c[_+($*136|0)+12>>2]=c[U>>2];c[_+($*136|0)+16>>2]=c[V>>2];aa=_+($*136|0)+44|0;g[aa>>2]=0.0;ae=_+($*136|0)+40|0;g[ae>>2]=0.0;ad=_+($*136|0)+52|0;g[ad>>2]=1.0;ab=_+($*136|0)+48|0;g[ab>>2]=1.0;bN(P|0,64,49024,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;af=B;while(1){ai=c[af>>2]|0;if((ai|0)==0){break}if((cJ(P|0,c[ai+4>>2]|0)|0)==0){F=3538;break}else{af=ai+12|0}}do{if((F|0)==3538){F=0;af=256;ag=0;aj=Q;ak=c[ai+8>>2]|0;while(1){al=af-1|0;if((al|0)==0){F=3541;break}am=a[ak]|0;a[aj]=am;if(am<<24>>24==0){an=ag;break}else{af=al;ag=ag+1|0;aj=aj+1|0;ak=ak+1|0}}do{if((F|0)==3541){F=0;a[aj]=0;if((a[ak]|0)==0){an=ag;break}else{ao=ak;ap=ag}while(1){af=ao+1|0;al=ap+1|0;if((a[af]|0)==0){an=al;break}else{ao=af;ap=al}}}}while(0);if(an>>>0>=256){break}ag=go(Q,46784)|0;ak=ag+4|0;if((c[ak>>2]|0)>>>0<4){F=3545;break L4950}aj=ag|0;g[ae>>2]=+v1(c[c[aj>>2]>>2]|0);g[aa>>2]=+v1(c[(c[aj>>2]|0)+8>>2]|0);g[ab>>2]=+v1(c[(c[aj>>2]|0)+16>>2]|0);g[ad>>2]=+v1(c[(c[aj>>2]|0)+24>>2]|0);if((ag|0)==0){break}al=c[aj>>2]|0;if((c[ak>>2]|0)==0){aq=al}else{af=0;am=al;while(1){v_(c[am+(af<<3)>>2]|0);al=af+1|0;ar=c[aj>>2]|0;if(al>>>0<(c[ak>>2]|0)>>>0){af=al;am=ar}else{aq=ar;break}}}v_(aq);v_(ag)}}while(0);bN(R|0,64,44480,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;am=_+($*136|0)+68|0;a[am]=0;gI(A,R,am)|0;bN(S|0,64,43128,(D=i,i=i+8|0,c[D>>2]=$,D)|0)|0;i=D;am=B;while(1){as=c[am>>2]|0;if((as|0)==0){F=3554;break L4950}if((cJ(S|0,c[as+4>>2]|0)|0)==0){break}else{am=as+12|0}}c[(dR()|0)>>2]=0;am=aW(c[as+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){F=3554;break}af=(am|0)==0;do{if(af){at=0}else{ak=am*104|0;if(am>>>0<=65535){at=ak;break}at=((ak>>>0)/(am>>>0)|0|0)==104?ak:-1}}while(0);ak=vZ(at)|0;if((ak|0)==0){F=3561;break}if((c[ak-4>>2]&3|0)!=0){v3(ak|0,0,at|0)}aj=ak;ak=_+($*136|0)|0;c[ak>>2]=aj;ar=_+($*136|0)+4|0;c[ar>>2]=am;L5002:do{if(!af){al=c[U>>2]|0;au=c[V>>2]|0;bN(W|0,64,38816,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=0,D)|0)|0;i=D;av=B;while(1){aw=c[av>>2]|0;if((aw|0)==0){ax=0;F=3572;break L4950}if((cJ(W|0,c[aw+4>>2]|0)|0)==0){break}else{av=aw+12|0}}av=256;ag=0;ay=X;az=c[aw+8>>2]|0;while(1){aA=av-1|0;if((aA|0)==0){F=3569;break}aB=a[az]|0;a[ay]=aB;if(aB<<24>>24==0){aC=ag;break}else{av=aA;ag=ag+1|0;ay=ay+1|0;az=az+1|0}}do{if((F|0)==3569){F=0;a[ay]=0;if((a[az]|0)==0){aC=ag;break}else{aD=az;aE=ag}while(1){av=aD+1|0;aA=aE+1|0;if((a[av]|0)==0){aC=aA;break}else{aD=av;aE=aA}}}}while(0);if(aC>>>0<256){aF=aj;aG=0;aH=al;aI=au}else{ax=0;F=3572;break L4950}while(1){aJ=go(X,46784)|0;if((aJ|0)==0){F=3574;break L4950}aK=aJ+4|0;aL=c[aK>>2]|0;if(aL>>>0<6){F=3576;break L4950}aM=aJ|0;ag=c[aM>>2]|0;az=c[ag+8>>2]|0;ay=c[ag+16>>2]|0;aN=c[ag+24>>2]|0;aA=c[ag>>2]|0;ag=aF+(aG*104|0)+24|0;c[ag>>2]=0;c[ag+4>>2]=0;L5020:do{if((cJ(aA|0,33680)|0)==0){c[aF+(aG*104|0)+20>>2]=1}else{av=aF+(aG*104|0)+20|0;if((cJ(aA|0,32616)|0)==0){c[av>>2]=2;break}c[av>>2]=0;av=d7(aA|0,47200,f|0)|0;if((av|0)!=0){aB=av;do{av=0;while(1){if(av>>>0>=56){aO=0;aP=56;break}if((cJ(c[840+(av<<3)>>2]|0,aB|0)|0)==0){F=3587;break}else{av=av+1|0}}if((F|0)==3587){F=0;aO=0;aP=c[844+(av<<3)>>2]|0}aQ=we(1,0,aP|0)|0;aR=G;aS=c[ag+4>>2]|aR;c[ag>>2]=c[ag>>2]|aQ;c[ag+4>>2]=aS;aB=d7(0,47200,f|0)|0;}while((aB|0)!=0)}if((c[ag>>2]&0|0)==0&(c[ag+4>>2]&524288|0)==0){break}bN(Y|0,64,31256,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aG,D)|0)|0;i=D;aB=aF+(aG*104|0)+40|0;aS=B;while(1){aT=c[aS>>2]|0;if((aT|0)==0){break L5020}if((cJ(Y|0,c[aT+4>>2]|0)|0)==0){break}else{aS=aT+12|0}}aS=64;aQ=aB;aR=c[aT+8>>2]|0;while(1){aU=aS-1|0;if((aU|0)==0){break}aV=a[aR]|0;a[aQ]=aV;if(aV<<24>>24==0){break L5020}else{aS=aU;aQ=aQ+1|0;aR=aR+1|0}}a[aQ]=0;if((a[aR]|0)==0){break}else{aX=aR}do{aX=aX+1|0;}while((a[aX]|0)!=0)}}while(0);aY=+(aH>>>0>>>0);g[aF+(aG*104|0)>>2]=+v1(az)/aY;a_=+(aI>>>0>>>0);g[aF+(aG*104|0)+4>>2]=+v1(ay)/a_;if((cJ(aN|0,30672)|0)==0){c[aF+(aG*104|0)+8>>2]=0;a$=0}else{if((cJ(aN|0,30344)|0)!=0){F=3602;break L4950}c[aF+(aG*104|0)+8>>2]=1;a$=1}do{if((c[aF+(aG*104|0)+20>>2]|0)!=0){if((a$|0)!=0){F=3607;break L4950}bN(Z|0,64,29168,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aG,D)|0)|0;i=D;ag=aF+(aG*104|0)+32|0;aA=B;while(1){a0=c[aA>>2]|0;if((a0|0)==0){F=3614;break}if((cJ(Z|0,c[a0+4>>2]|0)|0)==0){F=3613;break}else{aA=a0+12|0}}if((F|0)==3614){F=0;g[ag>>2]=1.0;break}else if((F|0)==3613){F=0;g[ag>>2]=+v1(c[a0+8>>2]|0);break}}}while(0);g[aF+(aG*104|0)+12>>2]=+v1(c[(c[aM>>2]|0)+32>>2]|0)/aY;g[aF+(aG*104|0)+16>>2]=+v1(c[(c[aM>>2]|0)+40>>2]|0)/a_;ay=c[aM>>2]|0;if((c[aK>>2]|0)==0){a1=ay}else{az=0;aA=ay;while(1){v_(c[aA+(az<<3)>>2]|0);ay=az+1|0;aR=c[aM>>2]|0;if(ay>>>0<(c[aK>>2]|0)>>>0){az=ay;aA=aR}else{a1=aR;break}}}v_(a1);v_(aJ);aA=aG+1|0;if(aA>>>0>=(c[ar>>2]|0)>>>0){break L5002}az=c[ak>>2]|0;aR=c[U>>2]|0;ay=c[V>>2]|0;bN(W|0,64,38816,(D=i,i=i+16|0,c[D>>2]=$,c[D+8>>2]=aA,D)|0)|0;i=D;aQ=B;while(1){a2=c[aQ>>2]|0;if((a2|0)==0){ax=aA;F=3572;break L4950}if((cJ(W|0,c[a2+4>>2]|0)|0)==0){break}else{aQ=a2+12|0}}aQ=256;aS=0;aB=X;aU=c[a2+8>>2]|0;while(1){aV=aQ-1|0;if((aV|0)==0){F=3624;break}a4=a[aU]|0;a[aB]=a4;if(a4<<24>>24==0){a5=aS;break}else{aQ=aV;aS=aS+1|0;aB=aB+1|0;aU=aU+1|0}}do{if((F|0)==3624){F=0;a[aB]=0;if((a[aU]|0)==0){a5=aS;break}else{a6=aU;a7=aS}while(1){aQ=a6+1|0;aV=a7+1|0;if((a[aQ]|0)==0){a5=aV;break}else{a6=aQ;a7=aV}}}}while(0);if(a5>>>0<256){aF=az;aG=aA;aH=aR;aI=ay}else{ax=aA;F=3572;break L4950}}}}while(0);a[_+($*136|0)+20|0]=0;g[_+($*136|0)+60>>2]=+g[ae>>2]+ +g[ab>>2]*.5;g[_+($*136|0)+64>>2]=+g[aa>>2]+ +g[ad>>2]*.5;ak=$+1|0;a8=c[K>>2]|0;if(ak>>>0>=a8>>>0){F=3521;break}ar=c[H>>2]|0;bN(C|0,64,17712,(D=i,i=i+8|0,c[D>>2]=ak,D)|0)|0;i=D;if(gH(A,C,M)|0){_=ar;$=ak}else{a9=ak;F=3522;break L4949}}if((F|0)==3521){L5084:do{if((a8|0)!=0){ak=0;ar=a8;L5085:while(1){aj=c[H>>2]|0;af=aj+(ak*136|0)+4|0;if((c[af>>2]|0)==0){ba=ar;bb=ak+1|0}else{am=aj+(ak*136|0)|0;au=ak+1|0;al=0;do{aS=c[am>>2]|0;bc=aS+(al*104|0)+40|0;if((a[bc]|0)==0){c[aS+(al*104|0)+36>>2]=(au>>>0)%(ar>>>0)|0}else{aU=0;while(1){if(aU>>>0>=ar>>>0){break L5085}if((cJ(aj+(aU*136|0)+69|0,bc|0)|0)==0){break}else{aU=aU+1|0}}if((aU|0)<0){break L5085}c[aS+(al*104|0)+36>>2]=aU}al=al+1|0;}while(al>>>0<(c[af>>2]|0)>>>0);ba=c[K>>2]|0;bb=au}if(bb>>>0<ba>>>0){ak=bb;ar=ba}else{break L5084}}ar=c[191244]|0;eb(((ar|0)!=0?ar:c[q>>2]|0)|0,19576,(D=i,i=i+8|0,c[D>>2]=bc,D)|0)|0;i=D;ar=c[191244]|0;aZ(((ar|0)!=0?ar:c[q>>2]|0)|0)|0;ar=c[191244]|0;a3(21888,64,1,((ar|0)!=0?ar:c[q>>2]|0)|0)|0;ar=c[191244]|0;aZ(((ar|0)!=0?ar:c[q>>2]|0)|0)|0;break L4936}}while(0);gE(A);ar=c[H>>2]|0;ak=u+16|0;c[ak>>2]=ar;ad=c[(c[y>>2]|0)+4>>2]|0;aa=c[z>>2]|0;ab=c[ar+8>>2]|0;ae=c[ar+12>>2]|0;af=c[ar+16>>2]|0;fv[ad&15](aa,ab,ae,af)|0;af=c[ak>>2]|0;fe[c[(c[y>>2]|0)+12>>2]&7](c[z>>2]|0,+g[af+24>>2],+g[af+28>>2],+g[af+32>>2],+g[af+36>>2]);fa[c[(c[y>>2]|0)+16>>2]&127](c[z>>2]|0,(a[(c[ak>>2]|0)+68|0]&1)!=0);fa[c[c[y>>2]>>2]&127](c[z>>2]|0,1);a[u+8|0]=1;e7[c[(c[y>>2]|0)+20>>2]&7](c[z>>2]|0,+g[142748]);hG(w,1.0);c[u+28>>2]=(((c[u+20>>2]|0)+1|0)>>>0)%((c[K>>2]|0)>>>0)|0;v=w;i=b;return v|0}else if((F|0)==3554){ak=c[191244]|0;eb(((ak|0)!=0?ak:c[q>>2]|0)|0,41832,(D=i,i=i+8|0,c[D>>2]=S,D)|0)|0;i=D;ak=c[191244]|0;aZ(((ak|0)!=0?ak:c[q>>2]|0)|0)|0;bd=$;break}else if((F|0)==3602){ak=c[191244]|0;eb(((ak|0)!=0?ak:c[q>>2]|0)|0,29920,(D=i,i=i+8|0,c[D>>2]=aN,D)|0)|0;i=D;ak=c[191244]|0;aZ(((ak|0)!=0?ak:c[q>>2]|0)|0)|0;ak=c[aM>>2]|0;if((c[aK>>2]|0)==0){be=ak}else{af=0;ae=ak;while(1){v_(c[ae+(af<<3)>>2]|0);ak=af+1|0;ab=c[aM>>2]|0;if(ak>>>0<(c[aK>>2]|0)>>>0){af=ak;ae=ab}else{be=ab;break}}}v_(be);v_(aJ);bf=aG}else if((F|0)==3576){ae=aJ|0;af=c[ae>>2]|0;if((aL|0)==0){bg=af}else{ab=0;ak=af;while(1){v_(c[ak+(ab<<3)>>2]|0);af=ab+1|0;aa=c[ae>>2]|0;if(af>>>0<(c[aK>>2]|0)>>>0){ab=af;ak=aa}else{bg=aa;break}}}v_(bg);v_(aJ);ak=c[191244]|0;a3(34912,85,1,((ak|0)!=0?ak:c[q>>2]|0)|0)|0;ak=c[191244]|0;aZ(((ak|0)!=0?ak:c[q>>2]|0)|0)|0;bf=aG}else if((F|0)==3534){ak=c[191244]|0;eb(((ak|0)!=0?ak:c[q>>2]|0)|0,51224,(D=i,i=i+8|0,c[D>>2]=M,D)|0)|0;i=D;ak=c[191244]|0;aZ(((ak|0)!=0?ak:c[q>>2]|0)|0)|0;bd=$;break}else if((F|0)==3572){ak=c[191244]|0;eb(((ak|0)!=0?ak:c[q>>2]|0)|0,37936,(D=i,i=i+8|0,c[D>>2]=W,D)|0)|0;i=D;ak=c[191244]|0;aZ(((ak|0)!=0?ak:c[q>>2]|0)|0)|0;bf=ax}else if((F|0)==3574){ak=c[191244]|0;a3(36656,62,1,((ak|0)!=0?ak:c[q>>2]|0)|0)|0;ak=c[191244]|0;aZ(((ak|0)!=0?ak:c[q>>2]|0)|0)|0;bf=aG}else if((F|0)==3607){ak=c[191244]|0;a3(29584,69,1,((ak|0)!=0?ak:c[q>>2]|0)|0)|0;ak=c[191244]|0;aZ(((ak|0)!=0?ak:c[q>>2]|0)|0)|0;ak=c[aM>>2]|0;if((c[aK>>2]|0)==0){bh=ak}else{ab=0;ae=ak;while(1){v_(c[ae+(ab<<3)>>2]|0);ak=ab+1|0;aa=c[aM>>2]|0;if(ak>>>0<(c[aK>>2]|0)>>>0){ab=ak;ae=aa}else{bh=aa;break}}}v_(bh);v_(aJ);bf=aG}else if((F|0)==3561){c[_+($*136|0)>>2]=0;ae=c[191244]|0;a3(40776,58,1,((ae|0)!=0?ae:c[q>>2]|0)|0)|0;ae=c[191244]|0;aZ(((ae|0)!=0?ae:c[q>>2]|0)|0)|0;bd=$;break}else if((F|0)==3545){ae=c[191244]|0;eb(((ae|0)!=0?ae:c[q>>2]|0)|0,45344,(D=i,i=i+8|0,c[D>>2]=Q,D)|0)|0;i=D;ae=c[191244]|0;aZ(((ae|0)!=0?ae:c[q>>2]|0)|0)|0;bd=$;break}ae=c[191244]|0;eb(((ae|0)!=0?ae:c[q>>2]|0)|0,39848,(D=i,i=i+8|0,c[D>>2]=bf,D)|0)|0;i=D;ae=c[191244]|0;aZ(((ae|0)!=0?ae:c[q>>2]|0)|0)|0;bd=$}else{a9=0;F=3522}}while(0);if((F|0)==3522){Q=c[191244]|0;W=(Q|0)!=0?Q:c[q>>2]|0;eb(W|0,15704,(D=i,i=i+8|0,c[D>>2]=C,D)|0)|0;i=D;W=c[191244]|0;Q=(W|0)!=0?W:c[q>>2]|0;aZ(Q|0)|0;bd=a9}Q=c[191244]|0;W=(Q|0)!=0?Q:c[q>>2]|0;eb(W|0,25120,(D=i,i=i+8|0,c[D>>2]=bd,D)|0)|0;i=D;W=c[191244]|0;Q=(W|0)!=0?W:c[q>>2]|0;aZ(Q|0)|0}}while(0);if((F|0)==3512){z=c[191244]|0;y=(z|0)!=0?z:c[q>>2]|0;a3(29088,62,1,y|0)|0;y=c[191244]|0;z=(y|0)!=0?y:c[q>>2]|0;aZ(z|0)|0}gE(A)}}while(0);F=u+24|0;D=u+12|0;bd=c[D>>2]|0;if((c[F>>2]|0)==0){bi=bd}else{a9=0;bf=bd;while(1){v_(c[bf+(a9*136|0)>>2]|0);v_(c[bf+(a9*136|0)+8>>2]|0);bd=a9+1|0;aG=c[D>>2]|0;if(bd>>>0<(c[F>>2]|0)>>>0){a9=bd;bf=aG}else{bi=aG;break}}}v_(bi);bi=c[u+4>>2]|0;if((bi|0)!=0){fa[c[bi>>2]&127](c[u>>2]|0,0)}v_(u);v=0;i=b;return v|0}function hI(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,W=0,X=0,Y=0.0,Z=0.0,_=0.0,$=0,aa=0,ab=0,ad=0,ae=0.0,af=0.0,ag=0.0,ah=0.0,ai=0.0,aj=0.0,ak=0,al=0,am=0.0,an=0.0,ao=0,ap=0,aq=0;e=i;f=d+64|0;v_(c[f>>2]|0);g=d+76|0;v_(c[g>>2]|0);h=d+80|0;v_(c[h>>2]|0);j=d+92|0;v_(c[j>>2]|0);k=d+104|0;v_(c[k>>2]|0);l=d+96|0;v_(c[l>>2]|0);m=d+120|0;v_(c[m>>2]|0);v3(f|0,0,64);n=d|0;o=c[n>>2]|0;p=d+12|0;r=c[p>>2]|0;s=d+4|0;t=c[s>>2]|0;do{if((o|0)==(r|0)){if((t|0)!=(c[d+16>>2]|0)){u=3658;break}a[d+60|0]=1;v=1}else{u=3658}}while(0);if((u|0)==3658){c[d+36>>2]=78;c[d+40>>2]=30;a[d+60|0]=0;v=0}w=d+44|0;c[w>>2]=0;x=(r<<3)+56&-64;c[d+116>>2]=x;c[d+108>>2]=r;c[d+112>>2]=t;y=ac(x,t)|0;x=y>>3;if(x>>>0>65535){z=(y>>>3|0)==(x|0)?y:-1}else{z=y}y=vZ(z)|0;if((y|0)==0){c[k>>2]=0;A=0;i=e;return A|0}if((c[y-4>>2]&3|0)!=0){v3(y|0,0,z|0)}c[k>>2]=y;y=c[d+24>>2]|0;if((y|0)!=0){k=(o<<2)+28&-32;c[d+100>>2]=k;o=ac(k,t)|0;t=o>>2;if(t>>>0>65535){B=(o>>>2|0)==(t|0)?o:-1}else{B=o}o=vZ(B)|0;if((o|0)==0){c[l>>2]=0;A=0;i=e;return A|0}if((c[o-4>>2]&3|0)!=0){v3(o|0,0,B|0)}c[l>>2]=o}o=c[d+28>>2]|0;l=(o|0)==0;if(!l){B=(r<<2)+28&-32;c[d+124>>2]=B;r=ac(c[d+16>>2]|0,B)|0;B=r>>2;if(B>>>0>65535){C=(r>>>2|0)==(B|0)?r:-1}else{C=r}r=vZ(C)|0;if((r|0)==0){c[m>>2]=0;A=0;i=e;return A|0}if((c[r-4>>2]&3|0)!=0){v3(r|0,0,C|0)}c[m>>2]=r}r=v<<24>>24==0;L5185:do{if(r){if((y|0)==2){c[d+48>>2]=4}else if((y|0)==3){c[d+48>>2]=24}else if((y|0)==4){c[d+48>>2]=2}else if((y|0)!=0){A=0;i=e;return A|0}if((o|0)==2){c[d+52>>2]=16;break}else if((o|0)==4){c[d+52>>2]=18;break}else if((o|0)==0){break}else{A=0;i=e;return A|0}}else{if((y|0)==(o|0)){c[d+56>>2]=8;A=1;i=e;return A|0}v=(y|0)==2;if(v&l){c[d+56>>2]=4;A=1;i=e;return A|0}if(!((y|0)!=3|l^1)){c[d+56>>2]=24;break}m=(y|0)==3;C=(o|0)==4;if(m&C){c[d+56>>2]=12;break}if(v&(o|0)==3){c[d+56>>2]=10;break}do{if(m){if((o|0)!=2){D=0;break}c[d+56>>2]=22;break L5185}else{if((y|0)==4){if(!l){D=0;break}c[d+56>>2]=2;break L5185}else if((y|0)!=0){D=0;break}if((o|0)==2){c[d+56>>2]=16;break L5185}else if((o|0)==4){c[d+56>>2]=18;break L5185}else{D=1;break}}}while(0);if(v&C){c[d+56>>2]=20;break}if(D&(o|0)==1){c[d+56>>2]=6;break}else{A=0;i=e;return A|0}}}while(0);if(!r){A=1;i=e;return A|0}r=c[d+32>>2]|0;L5237:do{if((r|0)==1){c[d+68>>2]=1;c[d+72>>2]=1;c[d+84>>2]=1;o=d+88|0;c[o>>2]=1;D=c[p>>2]|0;y=D<<1;if(D>>>0>65535){E=(D&2147483647|0)==(D|0)?y:-1}else{E=y}y=vZ(E)|0;do{if((y|0)!=0){if((c[y-4>>2]&3|0)==0){break}v3(y|0,0,E|0)}}while(0);C=d+64|0;c[C>>2]=y;v=c[p>>2]|0;D=v<<2;if(v>>>0>65535){F=(v&1073741823|0)==(v|0)?D:-1}else{F=D}D=vZ(F)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}v3(D|0,0,F|0)}}while(0);c[g>>2]=D;y=d+16|0;v=ac(c[y>>2]|0,c[o>>2]|0)|0;l=v<<1;if(v>>>0>65535){G=(v&2147483647|0)==(v|0)?l:-1}else{G=l}l=vZ(G)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}v3(l|0,0,G|0)}}while(0);c[h>>2]=l;o=c[y>>2]|0;D=o<<2;if(o>>>0>65535){H=(o&1073741823|0)==(o|0)?D:-1}else{H=D}D=vZ(H)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}v3(D|0,0,H|0)}}while(0);c[j>>2]=D;if((c[C>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}l=c[n>>2]|0;o=c[p>>2]|0;v=(l<<16|0)/(o|0)|0;m=c[s>>2]|0;B=c[y>>2]|0;t=((m<<15|0)/(B|0)|0)-32768|0;k=(m<<16|0)/(B|0)|0;if((o|0)>0){m=((l<<15|0)/(o|0)|0)-32768|0;l=0;while(1){c[(c[g>>2]|0)+(l<<2)>>2]=m>>16;b[(c[C>>2]|0)+(l<<1)>>1]=16384;z=l+1|0;if((z|0)<(o|0)){m=m+v|0;l=z}else{break}}I=c[y>>2]|0}else{I=B}L5279:do{if((I|0)>0){l=t;v=0;while(1){c[(c[j>>2]|0)+(v<<2)>>2]=l>>16;b[(c[h>>2]|0)+(v<<1)>>1]=16384;m=v+1|0;if((m|0)>=(I|0)){break L5279}l=l+k|0;v=m}}}while(0);c[w>>2]=2}else if((r|0)==2){c[d+68>>2]=2;c[d+72>>2]=2;c[d+84>>2]=2;k=d+88|0;c[k>>2]=2;t=c[p>>2]|0;B=t<<1;y=t<<2;if(B>>>0>65535){J=(B&2147483646|0)==(B|0)?y:-1}else{J=y}y=vZ(J)|0;do{if((y|0)!=0){if((c[y-4>>2]&3|0)==0){break}v3(y|0,0,J|0)}}while(0);B=d+64|0;c[B>>2]=y;t=c[p>>2]|0;v=t<<2;if(t>>>0>65535){K=(t&1073741823|0)==(t|0)?v:-1}else{K=v}v=vZ(K)|0;do{if((v|0)!=0){if((c[v-4>>2]&3|0)==0){break}v3(v|0,0,K|0)}}while(0);c[g>>2]=v;y=d+16|0;t=ac(c[y>>2]|0,c[k>>2]|0)|0;l=t<<1;if(t>>>0>65535){L=(t&2147483647|0)==(t|0)?l:-1}else{L=l}l=vZ(L)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}v3(l|0,0,L|0)}}while(0);c[h>>2]=l;k=c[y>>2]|0;v=k<<2;if(k>>>0>65535){M=(k&1073741823|0)==(k|0)?v:-1}else{M=v}v=vZ(M)|0;do{if((v|0)!=0){if((c[v-4>>2]&3|0)==0){break}v3(v|0,0,M|0)}}while(0);c[j>>2]=v;if((c[B>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}l=c[n>>2]|0;k=c[p>>2]|0;t=(l<<16|0)/(k|0)|0;m=c[s>>2]|0;o=c[y>>2]|0;C=((m<<15|0)/(o|0)|0)-32768|0;D=(m<<16|0)/(o|0)|0;if((k|0)>0){m=((l<<15|0)/(k|0)|0)-32768|0;l=0;while(1){c[(c[g>>2]|0)+(l<<2)>>2]=m>>16;z=l<<1;x=z|1;b[(c[B>>2]|0)+(x<<1)>>1]=m>>>2&16383;N=c[B>>2]|0;b[N+(z<<1)>>1]=16384-(b[N+(x<<1)>>1]|0)&65535;x=l+1|0;if((x|0)<(k|0)){m=m+t|0;l=x}else{break}}O=c[y>>2]|0}else{O=o}if((O|0)>0){P=C;Q=0}else{break}while(1){c[(c[j>>2]|0)+(Q<<2)>>2]=P>>16;l=Q<<1;t=l|1;b[(c[h>>2]|0)+(t<<1)>>1]=P>>>2&16383;m=c[h>>2]|0;b[m+(l<<1)>>1]=16384-(b[m+(t<<1)>>1]|0)&65535;t=Q+1|0;if((t|0)>=(O|0)){break L5237}P=P+D|0;Q=t}}else if((r|0)==3){D=c[n>>2]|0;C=c[p>>2]|0;if((D|0)>(C|0)){o=((D|0)/(C|0)|0)-1|0;D=o>>>1|o;o=D>>>2|D;D=o>>>4|o;o=D>>>8|D;S=((o>>>16|o)<<3)+8|0}else{S=8}o=d+68|0;c[o>>2]=S;c[d+72>>2]=S;D=d+84|0;c[D>>2]=S;y=d+88|0;c[y>>2]=S;t=ac(S,C)|0;C=t<<1;if(t>>>0>65535){T=(t&2147483647|0)==(t|0)?C:-1}else{T=C}C=vZ(T)|0;do{if((C|0)!=0){if((c[C-4>>2]&3|0)==0){break}v3(C|0,0,T|0)}}while(0);t=d+64|0;c[t>>2]=C;m=c[p>>2]|0;l=m<<2;if(m>>>0>65535){U=(m&1073741823|0)==(m|0)?l:-1}else{U=l}l=vZ(U)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}v3(l|0,0,U|0)}}while(0);c[g>>2]=l;C=d+16|0;m=ac(c[C>>2]|0,c[y>>2]|0)|0;k=m<<1;if(m>>>0>65535){W=(m&2147483647|0)==(m|0)?k:-1}else{W=k}k=vZ(W)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}v3(k|0,0,W|0)}}while(0);c[h>>2]=k;y=c[C>>2]|0;l=y<<2;if(y>>>0>65535){X=(y&1073741823|0)==(y|0)?l:-1}else{X=l}l=vZ(X)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}v3(l|0,0,X|0)}}while(0);c[j>>2]=l;if((c[t>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}k=c[n>>2]|0;y=c[p>>2]|0;m=-32768-(S<<15)|0;B=((k<<15|0)/(y|0)|0)+m|0;v=(k<<16|0)/(y|0)|0;x=c[s>>2]|0;N=c[C>>2]|0;z=((x<<15|0)/(N|0)|0)+m|0;m=(x<<16|0)/(N|0)|0;if((k|0)>(y|0)){Y=+(y|0)/+(k|0)}else{Y=1.0}if((x|0)>(N|0)){Z=+(N|0)/+(x|0)}else{Z=1.0}x=c[o>>2]|0;L5372:do{if((y|0)>0){N=x<<15;_=+(x>>1|0);if((x|0)>0){$=0;aa=B}else{k=0;ab=B;while(1){c[(c[g>>2]|0)+(k<<2)>>2]=ab>>16;ad=k+1|0;if((ad|0)<(y|0)){k=ad;ab=ab+v|0}else{break L5372}}}while(1){c[(c[g>>2]|0)+($<<2)>>2]=aa>>16;ae=+((aa&65535)+N|0)*152587890625.0e-16;ab=ac($,x)|0;k=0;do{af=(ae- +(k|0))*3.141592653589793;ag=af/_;ah=Y*af;if(+R(+ah)<1.0e-4){ai=16384.0}else{ai=+V(+ah)/ah*16384.0}if(+R(+ag)<1.0e-4){aj=1.0}else{aj=+V(+ag)/ag}b[(c[t>>2]|0)+(k+ab<<1)>>1]=~~(Y*ai*aj);k=k+1|0;}while((k|0)<(x|0));k=$+1|0;if((k|0)<(y|0)){$=k;aa=aa+v|0}else{break}}}}while(0);v=c[C>>2]|0;y=c[D>>2]|0;if((v|0)<=0){break}x=y<<15;_=+(y>>1|0);if((y|0)>0){ak=0;al=z}else{t=0;B=z;while(1){c[(c[j>>2]|0)+(t<<2)>>2]=B>>16;o=t+1|0;if((o|0)>=(v|0)){break L5237}t=o;B=B+m|0}}while(1){c[(c[j>>2]|0)+(ak<<2)>>2]=al>>16;ae=+((al&65535)+x|0)*152587890625.0e-16;B=ac(ak,y)|0;t=0;do{ag=(ae- +(t|0))*3.141592653589793;ah=ag/_;af=Z*ag;if(+R(+af)<1.0e-4){am=16384.0}else{am=+V(+af)/af*16384.0}if(+R(+ah)<1.0e-4){an=1.0}else{an=+V(+ah)/ah}b[(c[h>>2]|0)+(t+B<<1)>>1]=~~(Z*am*an);t=t+1|0;}while((t|0)<(y|0));t=ak+1|0;if((t|0)>=(v|0)){break L5237}ak=t;al=al+m|0}}else{A=0;i=e;return A|0}}while(0);hY(f,c[p>>2]|0,c[n>>2]|0);f=d+16|0;hY(d+80|0,c[f>>2]|0,c[s>>2]|0);al=(c[n>>2]|0)-(c[d+68>>2]|0)|0;n=c[p>>2]|0;p=0;while(1){if((p|0)>=(n|0)){break}ao=c[(c[g>>2]|0)+(p<<2)>>2]|0;if((ao|0)>(al|0)|(ao|0)<0){u=3826;break}else{p=p+1|0}}if((u|0)==3826){al=c[q>>2]|0;eb(al|0,45712,(ap=i,i=i+16|0,c[ap>>2]=p,c[ap+8>>2]=ao,ap)|0)|0;i=ap;A=0;i=e;return A|0}ao=(c[s>>2]|0)-(c[d+84>>2]|0)|0;d=c[f>>2]|0;f=0;while(1){if((f|0)>=(d|0)){A=1;u=3845;break}aq=c[(c[j>>2]|0)+(f<<2)>>2]|0;if((aq|0)>(ao|0)|(aq|0)<0){break}else{f=f+1|0}}if((u|0)==3845){i=e;return A|0}eb(c[q>>2]|0,48376,(ap=i,i=i+16|0,c[ap>>2]=f,c[ap+8>>2]=aq,ap)|0)|0;i=ap;A=0;i=e;return A|0}function hJ(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=0;i=a;a=c;while(1){c=0;do{j=b[a+(c<<1)>>1]|0;b[i+(c<<1)>>1]=(j&65535)>>>1&32736|j&31;c=c+1|0;}while((c|0)<(d|0));c=g+1|0;if((c|0)<(e|0)){g=c;i=i+(h<<1)|0;a=a+(f<<1)|0}else{break}}return}function hK(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=0;i=a;a=c;while(1){c=0;do{j=b[a+(c<<1)>>1]|0;b[i+(c<<1)>>1]=j<<1&-64|j&31|(j&65535)>>>4&32;c=c+1|0;}while((c|0)<(d|0));c=g+1|0;if((c|0)<(e|0)){g=c;i=i+(h<<1)|0;a=a+(f<<1)|0}else{break}}return}function hL(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=0;j=a;a=b;while(1){b=0;do{k=e[a+(b<<1)>>1]|0;l=k>>>10&31;m=k>>>5&31;n=k&31;c[j+(b<<2)>>2]=n<<3|n>>>2|(m<<3|m>>>2)<<8|(l<<3|l>>>2)<<16|-16777216;b=b+1|0;}while((b|0)<(d|0));b=h+1|0;if((b|0)<(f|0)){h=b;j=j+(i<<2)|0;a=a+(g<<1)|0}else{break}}return}function hM(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=0;j=a;a=b;while(1){b=0;do{k=e[a+(b<<1)>>1]|0;l=k>>>5&63;m=k&31;c[j+(b<<2)>>2]=m<<3|m>>>2|(k>>>11<<3|k>>>13)<<16|(l<<2|l>>>4)<<8|-16777216;b=b+1|0;}while((b|0)<(d|0));b=h+1|0;if((b|0)<(f|0)){h=b;j=j+(i<<2)|0;a=a+(g<<1)|0}else{break}}return}function hN(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<3|m>>>7&7)&255;a[l+2|0]=(m>>>10<<3|m>>>12&7)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function hO(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<2|m>>>9&3)&255;a[l+2|0]=(m>>>11<<3|m>>>13)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function hP(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>2;g=0;k=a;a=b;while(1){if(i){b=a;l=0;while(1){c[k+(l<<2)>>2]=d[b]|0|(d[b+1|0]|0)<<8|(d[b+2|0]|0)<<16|-16777216;m=l+1|0;if((m|0)<(e|0)){b=b+3|0;l=m}else{break}}}l=g+1|0;if((l|0)<(f|0)){g=l;k=k+(j<<2)|0;a=a+h|0}else{break}}return}function hQ(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>1;g=h>>2;h=0;k=a;a=d;while(1){if(i){d=0;do{l=c[a+(d<<2)>>2]|0;b[k+(d<<1)>>1]=(l>>>11<<5&992|l>>>3&31|l>>>19<<10&31744)&65535;d=d+1|0;}while((d|0)<(e|0))}d=h+1|0;if((d|0)<(f|0)){h=d;k=k+(j<<1)|0;a=a+(g<<2)|0}else{break}}return}function hR(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=h>>2;h=b;b=0;k=d;while(1){if(i){d=h;l=0;while(1){m=c[k+(l<<2)>>2]|0;a[d]=m&255;a[d+1|0]=m>>>8&255;a[d+2|0]=m>>>16&255;m=l+1|0;if((m|0)<(e|0)){d=d+3|0;l=m}else{break}}}l=b+1|0;if((l|0)<(f|0)){h=h+g|0;b=l;k=k+(j<<2)|0}else{break}}return}function hS(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((e|0)<=0){return}h=(d|0)>0;i=f>>2;f=g>>2;g=a;a=0;j=b;while(1){if(h){b=0;do{k=c[j+(b<<2)>>2]|0;c[g+(b<<2)>>2]=k>>>16&255|k&-16711936|k<<16&16711680;b=b+1|0;}while((b|0)<(d|0))}b=a+1|0;if((b|0)<(e|0)){g=g+(i<<2)|0;a=b;j=j+(f<<2)|0}else{break}}return}function hT(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[a+104>>2]|0;g=a+16|0;h=c[g>>2]|0;if((h|0)<=0){return}i=a+92|0;j=a+116|0;k=a+12|0;l=a+88|0;m=e>>2;e=a+84|0;n=0;o=c[a+80>>2]|0;a=d;d=c[k>>2]|0;p=h;while(1){h=ac(c[j>>2]>>3,c[(c[i>>2]|0)+(n<<2)>>2]|0)|0;if((d|0)>0){q=0;do{r=c[e>>2]|0;if((r|0)==0){s=0;t=0;u=0;v=0}else{w=c[j>>2]>>3;x=0;y=0;z=f+(q+h<<3)|0;A=0;B=0;C=0;while(1){D=c[z>>2]|0;E=c[z+4>>2]|0;F=b[o+(A<<1)>>1]|0;G=ac(((E>>>16|0<<16)&65535)<<16>>16,F)|0;H=ac((E&65535)<<16>>16,F)|0;I=ac(((D>>>16|E<<16)&65535)<<16>>16,F)|0;E=A+1|0;J=G+(C<<16)>>16;K=H+(B<<16)>>16;L=I+(x<<16)>>16;M=(ac((D&65535)<<16>>16,F)|0)+(y<<16)>>16;if(E>>>0<r>>>0){x=L;y=M;z=z+(w<<3)|0;A=E;B=K;C=J}else{break}}s=L>>>3;t=M>>>3;u=K>>>3;v=J>>>3}C=v&65535;B=u&65535;A=s&65535;w=t&65535;if(C<<16>>16>255){N=-16777216}else{N=C<<16>>16<0?0:v<<24}if(B<<16>>16>255){O=16711680}else{O=B<<16>>16<0?0:u<<16&16711680}if(A<<16>>16>255){P=65280}else{P=A<<16>>16<0?0:s<<8&65280}if(w<<16>>16>255){Q=255}else{Q=w<<16>>16<0?0:t&255}c[a+(q<<2)>>2]=O|N|P|Q;q=q+1|0;R=c[k>>2]|0;}while((q|0)<(R|0));S=R;T=c[g>>2]|0}else{S=d;T=p}q=n+1|0;if((q|0)>=(T|0)){break}n=q;o=o+(c[l>>2]<<1)|0;a=a+(m<<2)|0;d=S;p=T}return}function hU(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[b+60|0]&1)!=0){fs[c[b+56>>2]&31](d,e,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[b+8>>2]|0);return}f=b+44|0;if((c[f>>2]|0)==0){if((c[b+24>>2]|0)==0){fw[c[b+36>>2]&127](b,e,c[b+8>>2]|0)}else{g=b+96|0;h=b+100|0;fs[c[b+48>>2]&31](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,c[b+8>>2]|0);fw[c[b+36>>2]&127](b,c[g>>2]|0,c[h>>2]|0)}h=c[b+40>>2]|0;if((c[b+28>>2]|0)==0){fw[h&127](b,d,c[b+20>>2]|0);return}else{g=b+120|0;i=b+124|0;fw[h&127](b,c[g>>2]|0,c[i>>2]|0);fs[c[b+52>>2]&31](d,c[g>>2]|0,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[i>>2]|0);return}}else{i=c[b+8>>2]|0;if((c[b+24>>2]|0)==0){j=e;k=i}else{g=b+96|0;h=b+100|0;fs[c[b+48>>2]&31](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,i);j=c[g>>2]|0;k=c[h>>2]|0}h=(c[b+28>>2]|0)!=0;g=b+20|0;if(h){l=b+124|0;m=c[b+120>>2]|0}else{l=g;m=d}i=b+12|0;e=b+16|0;fq[c[f>>2]&15](b,m,j,c[i>>2]|0,c[e>>2]|0,c[b>>2]|0,c[b+4>>2]|0,c[l>>2]|0,k);if(!h){return}fs[c[b+52>>2]&31](d,c[b+120>>2]|0,c[i>>2]|0,c[e>>2]|0,c[g>>2]|0,c[b+124>>2]|0);return}}function hV(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;c=(e|0)>-1?e:-e|0;g=(f|0)>-1?f:-f|0;h=(g|0)<(c|0)?g:c;if((d|0)>0){i=b;j=a;k=0}else{return}while(1){v6(j|0,i|0,h)|0;a=k+1|0;if((a|0)<(d|0)){i=i+f|0;j=j+e|0;k=a}else{break}}return}function hW(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=a+112|0;g=c[f>>2]|0;if((g|0)<=0){return}h=a+64|0;i=a+108|0;j=e>>2;e=a+116|0;k=a+76|0;l=a+68|0;m=a+72|0;n=0;o=c[a+104>>2]|0;a=d;d=c[i>>2]|0;p=g;while(1){if((d|0)>0){g=0;q=c[h>>2]|0;while(1){r=c[(c[k>>2]|0)+(g<<2)>>2]|0;s=c[l>>2]|0;if((s|0)==0){t=0;u=0;v=0;w=0;x=0;y=0;z=0;A=0}else{B=0;C=0;D=0;E=0;F=0;while(1){G=c[a+(E+r<<2)>>2]|0;H=b[q+(E<<1)>>1]|0;I=((ac(G>>>17&32640,H)|0)>>>16)+(F&65535)|0;J=((ac(G>>>9&32640,H)|0)>>>16)+(B&65535)|0;K=((ac(G>>>1&32640,H)|0)>>>16)+(C&65535)|0;L=((ac(G<<7&32640,H)|0)>>>16)+(D&65535)|0;H=E+1|0;if(H>>>0<s>>>0){B=J&65535;C=K&65535;D=L&65535;E=H;F=I&65535}else{break}}F=K&65535;t=J&65535;u=0;v=0<<16|F>>>16;w=F<<16|0>>>16;x=0;y=L&65535;z=I<<16|0>>>16;A=0<<16|0>>>16}F=o+(g<<3)|0;c[F>>2]=y|A|w|u;c[F+4>>2]=x|z|v|t;F=g+1|0;M=c[i>>2]|0;if((F|0)<(M|0)){g=F;q=q+(c[m>>2]<<1)|0}else{break}}N=M;O=c[f>>2]|0}else{N=d;O=p}q=n+1|0;if((q|0)<(O|0)){n=q;o=o+(c[e>>2]>>3<<3)|0;a=a+(j<<2)|0;d=N;p=O}else{break}}return}function hX(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;a=((g<<15|0)/(e|0)|0)-32768|0;k=(g<<16|0)/(e|0)|0;g=((h<<15|0)/(f|0)|0)-32768|0;l=(h<<16|0)/(f|0)|0;h=(a|0)<0?0:a;a=d;if((f|0)<=0){return}d=j>>2;j=i>>2;if((e|0)<=0){return}i=(g|0)<0?0:g;g=b;b=0;while(1){m=ac(i>>16,d)|0;n=h;o=0;while(1){c[g+(o<<2)>>2]=c[a+((n>>16)+m<<2)>>2];p=o+1|0;if((p|0)<(e|0)){n=n+k|0;o=p}else{break}}o=b+1|0;if((o|0)<(f|0)){i=i+l|0;g=g+(j<<2)|0;b=o}else{break}}return}function hY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=a+4|0;f=d-(c[e>>2]|0)|0;if((b|0)<=0){return}d=a+12|0;g=a|0;h=a+8|0;a=0;do{i=(c[d>>2]|0)+(a<<2)|0;j=c[i>>2]|0;k=j-f|0;l=-j|0;do{if((k|0)>0){c[i>>2]=f;m=c[g>>2]|0;n=ac(c[h>>2]|0,a)|0;o=m+(n<<1)|0;p=c[e>>2]|0;if((k|0)>(p|0)){v3(o|0,0,p<<1|0);break}else{q=o;wa(m+(n+k<<1)|0,q|0,p-k<<1|0);v3(q|0,0,k<<1|0);break}}}while(0);do{if((j|0)<0){k=(c[d>>2]|0)+(a<<2)|0;c[k>>2]=(c[k>>2]|0)-j;k=c[g>>2]|0;i=ac(c[h>>2]|0,a)|0;q=c[e>>2]|0;p=k+(i<<1)|0;if((q|0)<(l|0)){v3(p|0,0,q<<1|0);break}else{wa(p|0,k+(i-j<<1)|0,q+j<<1|0);v3(k+(i+j+(c[e>>2]|0)<<1)|0,0,l<<1|0);break}}}while(0);a=a+1|0;}while((a|0)<(b|0));return}function hZ(d,e){d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aX=0,aY=0,a_=0,a$=0,a1=0,a2=0,a4=0,a5=0,a6=0,a7=0,a8=0;f=i;i=i+1824|0;h=f|0;j=f+8|0;k=f+1032|0;l=f+1040|0;m=f+1048|0;n=f+1112|0;o=f+1176|0;p=f+1184|0;r=f+1248|0;s=f+1312|0;t=f+1376|0;u=f+1440|0;v=f+1504|0;w=f+1568|0;x=f+1632|0;y=f+1696|0;z=f+1760|0;v3(e|0,0,109528);c[e>>2]=0;A=d+4|0;B=A;while(1){C=c[B>>2]|0;if((C|0)==0){break}if((cJ(45672,c[C+4>>2]|0)|0)==0){D=4027;break}else{B=C+12|0}}do{if((D|0)==4027){c[(dR()|0)>>2]=0;B=aW(c[C+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}if((B|0)==0){E=c[191244]|0;F=(E|0)!=0?E:c[q>>2]|0;a3(36288,55,1,F|0)|0;F=c[191244]|0;E=(F|0)!=0?F:c[q>>2]|0;aZ(E|0)|0;G=0;i=f;return G|0}E=B>>>0<16?B:16;B=e+72|0;c[B>>2]=E;F=m|0;H=n|0;I=p|0;J=r|0;K=s|0;L=t|0;M=u|0;N=v|0;O=w|0;P=x|0;Q=y|0;R=z|0;L5665:do{if((E|0)!=0){S=0;while(1){bN(F|0,64,29568,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;L5668:do{if(gH(d,F,e+76+(S*4148|0)|0)|0){bN(H|0,64,29152,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;a[o]=0;if(gI(d,H,o)|0){c[e+76+(S*4148|0)+4136>>2]=(a[o]&1)!=0?1:2}else{c[e+76+(S*4148|0)+4136>>2]=0}bN(I|0,64,28440,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;U=A;while(1){V=c[U>>2]|0;if((V|0)==0){break}if((cJ(I|0,c[V+4>>2]|0)|0)==0){D=4040;break}else{U=V+12|0}}do{if((D|0)==4040){D=0;U=64;W=0;X=J;Y=c[V+8>>2]|0;while(1){Z=U-1|0;if((Z|0)==0){D=4043;break}_=a[Y]|0;a[X]=_;if(_<<24>>24==0){$=W;break}else{U=Z;W=W+1|0;X=X+1|0;Y=Y+1|0}}do{if((D|0)==4043){D=0;a[X]=0;if((a[Y]|0)==0){$=W;break}else{aa=Y;ab=W}while(1){U=aa+1|0;Z=ab+1|0;if((a[U]|0)==0){$=Z;break}else{aa=U;ab=Z}}}}while(0);if($>>>0>=64){break}c[e+76+(S*4148|0)+4140>>2]=h2(J)|0}}while(0);v3(K|0,0,64);bN(L|0,64,28032,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;W=A;while(1){ac=c[W>>2]|0;if((ac|0)==0){break}if((cJ(L|0,c[ac+4>>2]|0)|0)==0){D=4050;break}else{W=ac+12|0}}do{if((D|0)==4050){D=0;W=64;Y=0;X=K;Z=c[ac+8>>2]|0;while(1){U=W-1|0;if((U|0)==0){D=4053;break}_=a[Z]|0;a[X]=_;if(_<<24>>24==0){ad=Y;break}else{W=U;Y=Y+1|0;X=X+1|0;Z=Z+1|0}}do{if((D|0)==4053){D=0;a[X]=0;if((a[Z]|0)==0){ad=Y;break}else{ae=Z;af=Y}while(1){W=ae+1|0;U=af+1|0;if((a[W]|0)==0){ad=U;break}else{ae=W;af=U}}}}while(0);if(ad>>>0>=64){break}c[e+76+(S*4148|0)+4144>>2]=aW(K|0,0,0)|0}}while(0);v3(M|0,0,64);v3(N|0,0,64);v3(O|0,0,64);bN(P|0,64,45952,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;Y=A;while(1){ag=c[Y>>2]|0;if((ag|0)==0){break}if((cJ(P|0,c[ag+4>>2]|0)|0)==0){D=4060;break}else{Y=ag+12|0}}L5708:do{if((D|0)==4060){D=0;Y=64;Z=M;X=c[ag+8>>2]|0;while(1){U=Y-1|0;if((U|0)==0){break}W=a[X]|0;a[Z]=W;if(W<<24>>24==0){break L5708}else{Y=U;Z=Z+1|0;X=X+1|0}}a[Z]=0;if((a[X]|0)==0){break}else{ah=X}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);bN(P|0,64,45872,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;X=A;while(1){ai=c[X>>2]|0;if((ai|0)==0){break}if((cJ(P|0,c[ai+4>>2]|0)|0)==0){D=4068;break}else{X=ai+12|0}}L5720:do{if((D|0)==4068){D=0;X=64;Z=N;Y=c[ai+8>>2]|0;while(1){U=X-1|0;if((U|0)==0){break}W=a[Y]|0;a[Z]=W;if(W<<24>>24==0){break L5720}else{X=U;Z=Z+1|0;Y=Y+1|0}}a[Z]=0;if((a[Y]|0)==0){break}else{aj=Y}do{aj=aj+1|0;}while((a[aj]|0)!=0)}}while(0);bN(P|0,64,45752,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;Y=A;while(1){ak=c[Y>>2]|0;if((ak|0)==0){break}if((cJ(P|0,c[ak+4>>2]|0)|0)==0){D=4076;break}else{Y=ak+12|0}}L5732:do{if((D|0)==4076){D=0;Y=64;Z=O;X=c[ak+8>>2]|0;while(1){U=Y-1|0;if((U|0)==0){break}W=a[X]|0;a[Z]=W;if(W<<24>>24==0){break L5732}else{Y=U;Z=Z+1|0;X=X+1|0}}a[Z]=0;if((a[X]|0)==0){break}else{al=X}do{al=al+1|0;}while((a[al]|0)!=0)}}while(0);L5741:do{if((a[M]|0)==0){if((a[N]|0)!=0){break}if((a[O]|0)==0){am=1;break L5668}}else{X=64;Z=N;Y=M;while(1){U=X-1|0;if((U|0)==0){D=4086;break}W=a[Y]|0;a[Z]=W;if(W<<24>>24==0){an=64;ao=O;ap=M;break}else{X=U;Z=Z+1|0;Y=Y+1|0}}do{if((D|0)==4086){D=0;a[Z]=0;if((a[Y]|0)==0){an=64;ao=O;ap=M;break}else{aq=Y}while(1){X=aq+1|0;if((a[X]|0)==0){an=64;ao=O;ap=M;break}else{aq=X}}}}while(0);while(1){Y=an-1|0;if((Y|0)==0){break}Z=a[ap]|0;a[ao]=Z;if(Z<<24>>24==0){break L5741}else{an=Y;ao=ao+1|0;ap=ap+1|0}}a[ao]=0;if((a[ap]|0)==0){break}else{ar=ap}do{ar=ar+1|0;}while((a[ar]|0)!=0)}}while(0);a[e+76+(S*4148|0)+4104|0]=1;Y=e+76+(S*4148|0)+4108|0;c[Y>>2]=0;Z=e+76+(S*4148|0)+4112|0;c[Z>>2]=0;X=e+76+(S*4148|0)+4116|0;g[X>>2]=1.0;U=e+76+(S*4148|0)+4120|0;g[U>>2]=1.0;bN(R|0,64,20184,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;gI(d,R,e+76+(S*4148|0)+4132|0)|0;do{if((a[N]|0)!=0){if((cJ(N|0,19272)|0)==0){c[Y>>2]=0;break}if((cJ(N|0,19096)|0)==0){c[Y>>2]=2;break}if((cJ(N|0,18872)|0)==0){c[Y>>2]=1;break}else{W=c[191244]|0;_=(W|0)!=0?W:c[q>>2]|0;a3(45624,40,1,_|0)|0;_=c[191244]|0;W=(_|0)!=0?_:c[q>>2]|0;aZ(W|0)|0;am=0;break L5668}}}while(0);do{if((a[O]|0)!=0){if((cJ(O|0,19272)|0)==0){c[Z>>2]=0;break}if((cJ(O|0,19096)|0)==0){c[Z>>2]=2;break}if((cJ(O|0,18872)|0)==0){c[Z>>2]=1;break}else{W=c[191244]|0;_=(W|0)!=0?W:c[q>>2]|0;a3(45624,40,1,_|0)|0;_=c[191244]|0;W=(_|0)!=0?_:c[q>>2]|0;aZ(W|0)|0;am=0;break L5668}}}while(0);W=(c[Y>>2]|0)==1;bN(Q|0,64,45568,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;L5782:do{if(W){_=A;while(1){as=c[_>>2]|0;if((as|0)==0){break}if((cJ(Q|0,c[as+4>>2]|0)|0)==0){D=4111;break}else{_=as+12|0}}do{if((D|0)==4111){D=0;c[(dR()|0)>>2]=0;_=a0(c[as+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4124>>2]=_;break L5782}}while(0);bN(Q|0,64,45472,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;_=A;while(1){at=c[_>>2]|0;if((at|0)==0){break L5782}if((cJ(Q|0,c[at+4>>2]|0)|0)==0){break}else{_=at+12|0}}c[(dR()|0)>>2]=0;_=a0(c[at+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4124>>2]=_}else{_=A;while(1){au=c[_>>2]|0;if((au|0)==0){break}if((cJ(Q|0,c[au+4>>2]|0)|0)==0){D=4120;break}else{_=au+12|0}}if((D|0)==4120){D=0;g[X>>2]=+v1(c[au+8>>2]|0);break}bN(Q|0,64,45472,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;_=A;while(1){av=c[_>>2]|0;if((av|0)==0){break L5782}if((cJ(Q|0,c[av+4>>2]|0)|0)==0){break}else{_=av+12|0}}g[X>>2]=+v1(c[av+8>>2]|0)}}while(0);X=(c[Z>>2]|0)==1;bN(Q|0,64,45568,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;if(X){aw=A}else{X=A;while(1){ax=c[X>>2]|0;if((ax|0)==0){break}if((cJ(Q|0,c[ax+4>>2]|0)|0)==0){D=4137;break}else{X=ax+12|0}}if((D|0)==4137){D=0;g[U>>2]=+v1(c[ax+8>>2]|0);am=1;break}bN(Q|0,64,45432,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;X=A;while(1){ay=c[X>>2]|0;if((ay|0)==0){am=1;break L5668}if((cJ(Q|0,c[ay+4>>2]|0)|0)==0){break}else{X=ay+12|0}}g[U>>2]=+v1(c[ay+8>>2]|0);am=1;break}while(1){az=c[aw>>2]|0;if((az|0)==0){break}if((cJ(Q|0,c[az+4>>2]|0)|0)==0){D=4128;break}else{aw=az+12|0}}do{if((D|0)==4128){D=0;c[(dR()|0)>>2]=0;U=a0(c[az+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4128>>2]=U;am=1;break L5668}}while(0);bN(Q|0,64,45432,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;U=A;while(1){aA=c[U>>2]|0;if((aA|0)==0){am=1;break L5668}if((cJ(Q|0,c[aA+4>>2]|0)|0)==0){break}else{U=aA+12|0}}c[(dR()|0)>>2]=0;U=a0(c[aA+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){am=1;break}c[e+76+(S*4148|0)+4128>>2]=U;am=1}else{U=c[191244]|0;eb(((U|0)!=0?U:c[q>>2]|0)|0,46032,(T=i,i=i+8|0,c[T>>2]=F,T)|0)|0;i=T;U=c[191244]|0;aZ(((U|0)!=0?U:c[q>>2]|0)|0)|0;am=0}}while(0);if(!am){G=0;break}S=S+1|0;if(S>>>0>=(c[B>>2]|0)>>>0){break L5665}}i=f;return G|0}}while(0);B=j|0;Q=A;while(1){aB=c[Q>>2]|0;if((aB|0)==0){break}if((cJ(27376,c[aB+4>>2]|0)|0)==0){D=4147;break}else{Q=aB+12|0}}L5836:do{if((D|0)==4147){Q=1024;O=0;N=B;R=c[aB+8>>2]|0;while(1){M=Q-1|0;if((M|0)==0){D=4150;break}P=a[R]|0;a[N]=P;if(P<<24>>24==0){aC=O;break}else{Q=M;O=O+1|0;N=N+1|0;R=R+1|0}}do{if((D|0)==4150){a[N]=0;if((a[R]|0)==0){aC=O;break}else{aD=R;aE=O}while(1){Q=aD+1|0;M=aE+1|0;if((a[Q]|0)==0){aC=M;break}else{aD=Q;aE=M}}}}while(0);if(aC>>>0>=1024){break}O=d7(B|0,27720,k|0)|0;if((O|0)==0){break}R=e+66444|0;N=O;L5848:while(1){O=c[R>>2]|0;if(O>>>0>=8){break L5836}M=e+66448+(O*4168|0)+64|0;O=A;while(1){aF=c[O>>2]|0;if((aF|0)==0){break L5848}if((cJ(N|0,c[aF+4>>2]|0)|0)==0){break}else{O=aF+12|0}}O=4096;Q=0;P=M;E=c[aF+8>>2]|0;while(1){S=O-1|0;if((S|0)==0){D=4162;break}U=a[E]|0;a[P]=U;if(U<<24>>24==0){aG=Q;break}else{O=S;Q=Q+1|0;P=P+1|0;E=E+1|0}}do{if((D|0)==4162){D=0;a[P]=0;if((a[E]|0)==0){aG=Q;break}else{aH=E;aI=Q}while(1){O=aH+1|0;M=aI+1|0;if((a[O]|0)==0){aG=M;break}else{aH=O;aI=M}}}}while(0);if(aG>>>0>=4096){break}Q=64;E=e+66448+((c[R>>2]|0)*4168|0)|0;P=N;while(1){M=Q-1|0;if((M|0)==0){D=4169;break}O=a[P]|0;a[E]=O;if(O<<24>>24==0){break}else{Q=M;E=E+1|0;P=P+1|0}}do{if((D|0)==4169){D=0;a[E]=0;if((a[P]|0)==0){break}else{aJ=P}do{aJ=aJ+1|0;}while((a[aJ]|0)!=0)}}while(0);bN(F|0,64,27056,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;a[l]=0;if(gI(d,F,l)|0){c[e+66448+((c[R>>2]|0)*4168|0)+4160>>2]=(a[l]&1)!=0?1:2}else{c[e+66448+((c[R>>2]|0)*4168|0)+4160>>2]=0}bN(H|0,64,26664,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;P=A;while(1){aK=c[P>>2]|0;if((aK|0)==0){break}if((cJ(H|0,c[aK+4>>2]|0)|0)==0){D=4177;break}else{P=aK+12|0}}do{if((D|0)==4177){D=0;P=64;E=0;Q=I;M=c[aK+8>>2]|0;while(1){O=P-1|0;if((O|0)==0){D=4180;break}S=a[M]|0;a[Q]=S;if(S<<24>>24==0){aL=E;break}else{P=O;E=E+1|0;Q=Q+1|0;M=M+1|0}}do{if((D|0)==4180){D=0;a[Q]=0;if((a[M]|0)==0){aL=E;break}else{aM=M;aN=E}while(1){P=aM+1|0;O=aN+1|0;if((a[P]|0)==0){aL=O;break}else{aM=P;aN=O}}}}while(0);if(aL>>>0>=64){break}E=h2(I)|0;c[e+66448+((c[R>>2]|0)*4168|0)+4164>>2]=E}}while(0);c[R>>2]=(c[R>>2]|0)+1;E=d7(0,27720,k|0)|0;if((E|0)==0){break L5836}else{N=E}}R=c[191244]|0;eb(((R|0)!=0?R:c[q>>2]|0)|0,46536,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;R=c[191244]|0;aZ(((R|0)!=0?R:c[q>>2]|0)|0)|0;G=0;i=f;return G|0}}while(0);R=A;while(1){aO=c[R>>2]|0;if((aO|0)==0){G=1;D=4256;break}if((cJ(25640,c[aO+4>>2]|0)|0)==0){break}else{R=aO+12|0}}if((D|0)==4256){i=f;return G|0}R=1024;E=0;M=B;Q=c[aO+8>>2]|0;while(1){O=R-1|0;if((O|0)==0){D=4191;break}P=a[Q]|0;a[M]=P;if(P<<24>>24==0){aP=E;break}else{R=O;E=E+1|0;M=M+1|0;Q=Q+1|0}}do{if((D|0)==4191){a[M]=0;if((a[Q]|0)==0){aP=E;break}else{aQ=Q;aR=E}while(1){R=aQ+1|0;O=aR+1|0;if((a[R]|0)==0){aP=O;break}else{aQ=R;aR=O}}}}while(0);if(aP>>>0>=1024){G=1;i=f;return G|0}E=d7(B|0,27720,h|0)|0;L5911:do{if((E|0)!=0){Q=e+99792|0;M=E;L5913:while(1){N=c[Q>>2]|0;if(N>>>0>=64){break L5911}O=64;R=e+99796+(N*80|0)|0;P=M;while(1){S=O-1|0;if((S|0)==0){D=4200;break}U=a[P]|0;a[R]=U;if(U<<24>>24==0){break}else{O=S;R=R+1|0;P=P+1|0}}do{if((D|0)==4200){D=0;a[R]=0;if((a[P]|0)==0){break}else{aS=P}do{aS=aS+1|0;}while((a[aS]|0)!=0)}}while(0);bN(F|0,64,23584,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bN(H|0,64,23376,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bN(I|0,64,23056,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bN(J|0,64,22848,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bN(K|0,64,22568,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;P=A;while(1){aT=c[P>>2]|0;if((aT|0)==0){D=4211;break L5913}if((cJ(F|0,c[aT+4>>2]|0)|0)==0){break}else{P=aT+12|0}}P=64;R=0;O=L;S=c[aT+8>>2]|0;while(1){U=P-1|0;if((U|0)==0){D=4208;break}X=a[S]|0;a[O]=X;if(X<<24>>24==0){aU=R;break}else{P=U;R=R+1|0;O=O+1|0;S=S+1|0}}do{if((D|0)==4208){D=0;a[O]=0;if((a[S]|0)==0){aU=R;break}else{aV=S;aX=R}while(1){P=aV+1|0;U=aX+1|0;if((a[P]|0)==0){aU=U;break}else{aV=P;aX=U}}}}while(0);if(aU>>>0>=64){D=4211;break}do{if((cJ(L|0,22440)|0)==0){c[e+99796+(N*80|0)+68>>2]=0;aY=A;D=4225}else{if((cJ(L|0,21960)|0)==0){c[e+99796+(N*80|0)+68>>2]=2;aY=A;D=4225;break}if((cJ(L|0,21360)|0)==0){c[e+99796+(N*80|0)+68>>2]=3;aY=A;D=4225;break}if((cJ(L|0,20992)|0)==0){c[e+99796+(N*80|0)+68>>2]=1;aY=A;D=4225;break}if((cJ(L|0,20488)|0)==0){c[e+99796+(N*80|0)+68>>2]=4;aY=A;D=4225;break}if((cJ(L|0,20336)|0)!=0){D=4223;break L5913}c[e+99796+(N*80|0)+68>>2]=5;a_=A}}while(0);L5953:do{if((D|0)==4225){while(1){D=0;a$=c[aY>>2]|0;if((a$|0)==0){a1=A;break}if((cJ(I|0,c[a$+4>>2]|0)|0)==0){D=4227;break}else{aY=a$+12|0;D=4225}}do{if((D|0)==4227){D=0;c[(dR()|0)>>2]=0;R=aW(c[a$+8>>2]|0,0,0)|0;if((c[(dR()|0)>>2]|0)!=0){a1=A;break}if((R|0)==1){c[e+99796+(N*80|0)+72>>2]=2;a_=A;break L5953}else if((R|0)==2){c[e+99796+(N*80|0)+72>>2]=3;a_=A;break L5953}else{D=4231;break L5913}}}while(0);while(1){a2=c[a1>>2]|0;if((a2|0)==0){D=4236;break L5913}if((cJ(H|0,c[a2+4>>2]|0)|0)==0){break}else{a1=a2+12|0}}c[(dR()|0)>>2]=0;R=aW(c[a2+8>>2]|0,0,16)|0;if((c[(dR()|0)>>2]|0)!=0){D=4236;break L5913}c[e+99796+(N*80|0)+72>>2]=1;c[e+99796+(N*80|0)+64>>2]=R;a_=A}}while(0);while(1){a4=c[a_>>2]|0;if((a4|0)==0){a5=A;break}if((cJ(J|0,c[a4+4>>2]|0)|0)==0){D=4239;break}else{a_=a4+12|0}}do{if((D|0)==4239){D=0;c[(dR()|0)>>2]=0;R=aW(c[a4+8>>2]|0,0,16)|0;if((c[(dR()|0)>>2]|0)!=0){a5=A;break}b[e+99796+(N*80|0)+76>>1]=R&65535;a5=A}}while(0);while(1){a6=c[a5>>2]|0;if((a6|0)==0){break}if((cJ(K|0,c[a6+4>>2]|0)|0)==0){D=4243;break}else{a5=a6+12|0}}do{if((D|0)==4243){D=0;c[(dR()|0)>>2]=0;R=aW(c[a6+8>>2]|0,0,16)|0;if((c[(dR()|0)>>2]|0)!=0){break}b[e+99796+(N*80|0)+78>>1]=R&65535}}while(0);c[Q>>2]=(c[Q>>2]|0)+1;M=d7(0,27720,h|0)|0;if((M|0)==0){break L5911}}if((D|0)==4231){M=c[191244]|0;Q=(M|0)!=0?M:c[q>>2]|0;a3(15032,52,1,Q|0)|0;Q=c[191244]|0;M=(Q|0)!=0?Q:c[q>>2]|0;aZ(M|0)|0;G=0;i=f;return G|0}else if((D|0)==4236){M=c[191244]|0;a3(46792,54,1,((M|0)!=0?M:c[q>>2]|0)|0)|0;M=c[191244]|0;aZ(((M|0)!=0?M:c[q>>2]|0)|0)|0;G=0;i=f;return G|0}else if((D|0)==4223){M=c[191244]|0;a3(46984,39,1,((M|0)!=0?M:c[q>>2]|0)|0)|0;M=c[191244]|0;aZ(((M|0)!=0?M:c[q>>2]|0)|0)|0;G=0;i=f;return G|0}else if((D|0)==4211){M=c[191244]|0;a3(47104,54,1,((M|0)!=0?M:c[q>>2]|0)|0)|0;M=c[191244]|0;aZ(((M|0)!=0?M:c[q>>2]|0)|0)|0;G=0;i=f;return G|0}}}while(0);gH(d,26408,e+104916|0)|0;K=e+109016|0;J=A;while(1){a7=c[J>>2]|0;if((a7|0)==0){G=1;D=4265;break}if((cJ(25984,c[a7+4>>2]|0)|0)==0){break}else{J=a7+12|0}}if((D|0)==4265){i=f;return G|0}J=512;H=K;I=c[a7+8>>2]|0;while(1){L=J-1|0;if((L|0)==0){break}F=a[I]|0;a[H]=F;if(F<<24>>24==0){G=1;D=4266;break}else{J=L;H=H+1|0;I=I+1|0}}if((D|0)==4266){i=f;return G|0}a[H]=0;if((a[I]|0)==0){G=1;i=f;return G|0}else{a8=I}while(1){J=a8+1|0;if((a[J]|0)==0){G=1;break}else{a8=J}}i=f;return G|0}}while(0);a8=c[191244]|0;a3(48320,50,1,((a8|0)!=0?a8:c[q>>2]|0)|0)|0;a8=c[191244]|0;aZ(((a8|0)!=0?a8:c[q>>2]|0)|0)|0;G=0;i=f;return G|0}function h_(){return 766672|0}function h$(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+8200|0;g=f|0;h=f+4104|0;c[g>>2]=b;j=f+8|0;k=e+8|0;while(1){l=c[k>>2]|0;if((l|0)==0){break}if((cJ(40768,c[l>>2]|0)|0)==0){m=4273;break}else{k=l+8|0}}do{if((m|0)==4273){k=c[l+4>>2]|0;if((k|0)==0){break}else{n=4096;o=0;p=j;r=k}while(1){k=n-1|0;if((k|0)==0){m=4277;break}e=a[r]|0;a[p]=e;if(e<<24>>24==0){s=o;break}else{n=k;o=o+1|0;p=p+1|0;r=r+1|0}}do{if((m|0)==4277){a[p]=0;if((a[r]|0)==0){s=o;break}else{t=r;u=o}while(1){k=t+1|0;e=u+1|0;if((a[k]|0)==0){s=e;break}else{t=k;u=e}}}}while(0);if(s>>>0>=4096){i=f;return b|0}v_(b);c[g>>2]=0;e=h|0;gA(e,d,j);if((a[607928]&1)==0){v=gf(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}k=c[191244]|0;eb(((k|0)!=0?k:c[q>>2]|0)|0,47256,(k=i,i=i+8|0,c[k>>2]=e,k)|0)|0;i=k;k=c[191244]|0;aZ(((k|0)!=0?k:c[q>>2]|0)|0)|0;v=gf(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}}while(0);a[j]=0;i=f;return b|0}function h0(a,b){a=a|0;b=b|0;var c=0,d=0;if((a|0)==0){c=b;return c|0}d=cf(a|0,46)|0;a=(d|0)==0?766672:d+1|0;if((cJ(a|0,28824)|0)==0){c=0;return c|0}if((cJ(a|0,47896)|0)==0){c=0;return c|0}if((cJ(a|0,19552)|0)==0){c=2;return c|0}if((cJ(a|0,47392)|0)==0){c=2;return c|0}else{return((cJ(a|0,40432)|0)==0?2:b)|0}return 0}function h1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+4096|0;f=e|0;g=b+72|0;h=c[g>>2]|0;if((h|0)!=0){j=f|0;k=0;l=h;while(1){h=b+76+(k*4148|0)|0;if((a[h]|0)==0){m=l}else{n=4096;o=j;p=h;while(1){q=n-1|0;if((q|0)==0){r=4307;break}s=a[p]|0;a[o]=s;if(s<<24>>24==0){break}else{n=q;o=o+1|0;p=p+1|0}}do{if((r|0)==4307){r=0;a[o]=0;if((a[p]|0)==0){break}else{t=p}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);gA(h,d,j);m=c[g>>2]|0}p=k+1|0;if(p>>>0<m>>>0){k=p;l=m}else{break}}}m=b+66444|0;if((c[m>>2]|0)!=0){l=f|0;k=0;do{g=b+66448+(k*4168|0)+64|0;j=4096;t=l;p=g;while(1){o=j-1|0;if((o|0)==0){r=4314;break}n=a[p]|0;a[t]=n;if(n<<24>>24==0){break}else{j=o;t=t+1|0;p=p+1|0}}do{if((r|0)==4314){r=0;a[t]=0;if((a[p]|0)==0){break}else{u=p}do{u=u+1|0;}while((a[u]|0)!=0)}}while(0);gA(g,d,l);k=k+1|0;}while(k>>>0<(c[m>>2]|0)>>>0)}m=b+104916|0;if((a[m]|0)==0){i=e;return}b=f|0;f=4096;k=b;l=m;while(1){u=f-1|0;if((u|0)==0){r=4321;break}p=a[l]|0;a[k]=p;if(p<<24>>24==0){break}else{f=u;k=k+1|0;l=l+1|0}}do{if((r|0)==4321){a[k]=0;if((a[l]|0)==0){break}else{v=l}do{v=v+1|0;}while((a[v]|0)!=0)}}while(0);gA(m,d,b);i=e;return}function h2(a){a=a|0;var b=0,d=0,e=0;b=i;if((cJ(a|0,18696)|0)==0){d=0;i=b;return d|0}if((cJ(a|0,18584)|0)==0){d=1;i=b;return d|0}if((cJ(a|0,18448)|0)==0){d=2;i=b;return d|0}if((cJ(a|0,18288)|0)==0){d=3;i=b;return d|0}e=c[191244]|0;eb(((e|0)!=0?e:c[q>>2]|0)|0,46240,(e=i,i=i+8|0,c[e>>2]=a,e)|0)|0;i=e;e=c[191244]|0;aZ(((e|0)!=0?e:c[q>>2]|0)|0)|0;d=0;i=b;return d|0}function h3(b,e){b=b|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=vZ(1032)|0;if((b|0)==0){f=0;return f|0}if((c[b-4>>2]&3|0)!=0){v3(b|0,0,1032)}g=b;h=~~+bH(+(e/10.0));i=b;j=(h|0)==0?1:h;c[i>>2]=j;h=vZ(ac(j*12800|0,j)|0)|0;k=b+1028|0;c[k>>2]=h;if((h|0)==0){v_(b);f=0;return f|0}else{l=0;m=j;n=h}while(1){h=ac(ac(m*50|0,m)|0,l)|0;c[g+4+(l<<2)>>2]=n+h;j=l*7|0;o=c[i>>2]|0;p=0;q=o;while(1){r=p*5|0;s=0;t=q;u=q;while(1){v=s+r|0;w=((1<<(v&7)&(d[9760+((v>>>3)+j)|0]|0)|0)!=0)<<31>>31;if((t|0)==0){x=0;y=u}else{v=0;z=u;while(1){if((z|0)==0){A=0}else{B=v+h|0;C=0;D=z;while(1){a[n+(B+(ac((((ac(D,p)|0)+C|0)*5|0)+s|0,D)|0))|0]=w;E=C+1|0;if(E>>>0<o>>>0){C=E;D=o}else{A=o;break}}}D=v+1|0;if(D>>>0<A>>>0){v=D;z=A}else{x=A;y=A;break}}}z=s+1|0;if(z>>>0<5){s=z;t=x;u=y}else{break}}u=p+1|0;if(u>>>0<10){p=u;q=y}else{break}}q=l+1|0;if(q>>>0>=256){f=b;break}l=q;m=o;n=c[k>>2]|0}return f|0}function h4(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=e|0;c[f>>2]=0;e=v2(d|0)|0;if((e|0)==0){return}g=b+4|0;h=b;b=0;i=0;j=0;while(1){k=vZ(52)|0;if((k|0)==0){l=4370;break}if((c[k-4>>2]&3|0)!=0){v3(k|0,0,52)}m=k;c[k>>2]=c[g+(a[d+i|0]<<2)>>2];n=c[h>>2]|0;o=n*5|0;c[k+4>>2]=o;p=n*10|0;c[k+8>>2]=p;c[k+12>>2]=o;c[k+32>>2]=o;c[k+36>>2]=p;c[k+40>>2]=0;c[k+44>>2]=p;c[k+24>>2]=b;c[k+28>>2]=0;c[k+48>>2]=0;if((i|0)==0){c[f>>2]=m;q=c[h>>2]|0}else{c[j+48>>2]=m;q=n}n=i+1|0;if(n>>>0<e>>>0){b=(q*6|0)+b|0;i=n;j=m}else{l=4368;break}}if((l|0)==4368){return}else if((l|0)==4370){return}}function h5(a,b){a=a|0;b=b|0;var d=0;a=b|0;b=c[a>>2]|0;if((b|0)==0){c[a>>2]=0;return}else{d=b}while(1){b=c[d+48>>2]|0;v_(d);if((b|0)==0){break}else{d=b}}c[a>>2]=0;return}function h6(a){a=a|0;v_(c[a+1028>>2]|0);v_(a);return}function h7(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0;h=i;i=i+1912|0;j=h|0;k=h+16|0;l=h+784|0;m=h+792|0;n=h+840|0;o=h+856|0;p=h+1880|0;r=h+1888|0;s=h+1904|0;if((bu(b|0,44304)|0)!=0){c[s>>2]=0;if((gf(b,s)|0)<0){t=c[191244]|0;u=(t|0)!=0?t:c[q>>2]|0;eb(u|0,28832,(v=i,i=i+8|0,c[v>>2]=b,v)|0)|0;i=v;u=c[191244]|0;t=(u|0)!=0?u:c[q>>2]|0;aZ(t|0)|0;w=0;i=h;return w|0}t=c[s>>2]|0;if((a[t+2|0]|0)!=2){s=c[191244]|0;u=(s|0)!=0?s:c[q>>2]|0;a3(24776,56,1,u|0)|0;u=c[191244]|0;s=(u|0)!=0?u:c[q>>2]|0;aZ(s|0)|0;v_(t);w=0;i=h;return w|0}s=a[t+16|0]|0;u=d[t+13|0]<<8|d[t+12|0];x=d[t+15|0]<<8|d[t+14|0];if((a[607928]&1)!=0){y=s&255;z=c[191244]|0;A=(z|0)!=0?z:c[q>>2]|0;eb(A|0,21632,(v=i,i=i+24|0,c[v>>2]=u,c[v+8>>2]=x,c[v+16>>2]=y,v)|0)|0;i=v;y=c[191244]|0;A=(y|0)!=0?y:c[q>>2]|0;aZ(A|0)|0}A=ac(x,u)|0;y=vZ(A<<2)|0;z=y;B=e+8|0;c[B>>2]=z;c[e>>2]=u;c[e+4>>2]=x;if((y|0)==0){y=c[191244]|0;x=(y|0)!=0?y:c[q>>2]|0;a3(19496,52,1,x|0)|0;x=c[191244]|0;y=(x|0)!=0?x:c[q>>2]|0;aZ(y|0)|0;v_(t);w=0;i=h;return w|0}L6176:do{if((s<<24>>24|0)==32){if((A|0)==0){break}else{C=0;D=z}while(1){y=C<<2;c[D+(C<<2)>>2]=d[t+((y|1)+18)|0]<<8|d[t+(y+18)|0]<<g|d[t+((y|2)+18)|0]<<f|d[t+((y|3)+18)|0]<<24;y=C+1|0;if(y>>>0>=A>>>0){break L6176}C=y;D=c[B>>2]|0}}else if((s<<24>>24|0)==24){if((A|0)==0){break}else{E=0;F=z}while(1){y=E*3|0;c[F+(E<<2)>>2]=d[t+(y+18)|0]<<g|d[t+(y+19)|0]<<8|d[t+(y+20)|0]<<f|-16777216;y=E+1|0;if(y>>>0>=A>>>0){break L6176}E=y;F=c[B>>2]|0}}else{y=c[191244]|0;a3(17568,88,1,((y|0)!=0?y:c[q>>2]|0)|0)|0;y=c[191244]|0;aZ(((y|0)!=0?y:c[q>>2]|0)|0)|0;v_(t);v_(c[B>>2]|0);c[B>>2]=0;w=0;i=h;return w|0}}while(0);v_(t);w=1;i=h;return w|0}if((bu(b|0,48008)|0)==0){w=0;i=h;return w|0}if((a[607928]&1)!=0){t=c[191244]|0;B=(t|0)!=0?t:c[q>>2]|0;a3(36096,38,1,B|0)|0;B=c[191244]|0;t=(B|0)!=0?B:c[q>>2]|0;aZ(t|0)|0}t=e+8|0;B=e|0;F=e+4|0;e=n;E=p|0;p=r;c[t>>2]=0;c[B>>2]=0;c[F>>2]=0;A=c2(b|0,34720)|0;if((A|0)==0){w=0;i=h;return w|0}eo(A|0,0,2)|0;b=cb(A|0)|0;ew(A|0);v3(m|0,0,48);c[e>>2]=c[458];c[e+4>>2]=c[459];c[e+8>>2]=c[460];c[e+12>>2]=c[461];v3(o|0,0,1024);if((d5(E|0,1,8,A|0)|0)==8){L6202:do{if((wb(E|0,6584,8)|0)==0){z=cb(A|0)|0;do{if((z|0)<(b|0)&(z|0)>-1){s=l;D=s+1|0;C=s+2|0;y=s+3|0;x=r|0;u=r+4|0;G=r+8|0;H=n|0;I=n+4|0;J=n+8|0;K=n+9|0;L=n+10|0;M=n+11|0;N=n+12|0;O=k|0;P=0;Q=0;R=0;S=0;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;L6207:while(1){v3(p|0,0,12);c[l>>2]=0;if((d5(s|0,1,4,A|0)|0)!=4){_=4407;break}c[x>>2]=d[D]<<16|d[s]<<24|d[C]<<8|d[y];if((d5(u|0,1,4,A|0)|0)==4){$=0}else{_=4407;break}while(1){if($>>>0>=4){_=4411;break}if((wb(u|0,c[9648+($<<3)>>2]|0,4)|0)==0){_=4410;break}else{$=$+1|0}}L6213:do{if((_|0)==4410){_=0;switch(c[9652+($<<3)>>2]|0){case 1:{_=4413;break L6207;break};case 2:{if(R|S|T){_=4415;break L6207}v_(c[G>>2]|0);aa=c[x>>2]|0;ab=aa+4|0;ad=vZ(ab)|0;if((ad|0)==0){_=4417;break L6207}if((c[ad-4>>2]&3|0)!=0){v3(ad|0,0,ab|0)}c[G>>2]=ad;if((d5(ad|0,1,ab|0,A|0)|0)!=(ab|0)){_=4421;break L6207}if((aa|0)!=13){_=4423;break L6207}aa=d[ad+1|0]<<16|d[ad]<<24|d[ad+2|0]<<8|d[ad+3|0];c[H>>2]=aa;ab=d[ad+5|0]<<16|d[ad+4|0]<<24|d[ad+6|0]<<8|d[ad+7|0];c[I>>2]=ab;ae=a[ad+8|0]|0;a[J]=ae;af=a[ad+9|0]|0;a[K]=af;ag=a[ad+10|0]|0;a[L]=ag;a[M]=a[ad+11|0]|0;ah=a[ad+12|0]|0;a[N]=ah;if((aa|0)==0|(ab|0)==0){_=4425;break L6207}switch(af<<24>>24){case 0:{ai=ae&255;aj=0;while(1){if(aj>>>0>=5){_=4433;break L6207}if((c[6560+(aj<<2)>>2]|0)==(ai|0)){break}else{aj=aj+1|0}}break};case 3:{aj=ae&255;ai=0;while(1){if(ai>>>0>=4){_=4436;break L6207}if((c[6544+(ai<<2)>>2]|0)==(aj|0)){break}else{ai=ai+1|0}}break};case 2:case 4:case 6:{if(!((ae<<24>>24|0)==8|(ae<<24>>24|0)==16)){_=4430;break L6207}break};default:{_=4437;break L6207}}if(ag<<24>>24!=0){_=4439;break L6207}v_(ad);c[G>>2]=0;ak=U;al=0;am=0;an=1;ao=Q;ap=P;aq=af;ar=ab;as=ah;at=aa;au=ae;break L6213;break};case 4:{if(U|R^1|T|S){_=4444;break L6207}ai=c[x>>2]|0;if(((ai>>>0)%3|0|0)!=0){_=4446;break L6207}aj=(ai>>>0)/3|0;if(ai>>>0>770){_=4452;break L6207}if((d5(O|0,3,aj|0,A|0)|0)!=(aj|0)){_=4452;break L6207}if(ai>>>0>=3){ai=0;do{av=ai*3|0;c[o+(ai<<2)>>2]=d[k+av|0]<<16|d[k+(av+1)|0]<<8|d[k+(av+2)|0]|-16777216;ai=ai+1|0;}while(ai>>>0<aj>>>0)}if((eo(A|0,4,1)|0)>-1){ak=1;al=0;am=0;an=R;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z;break L6213}else{_=4452;break L6207}break};case 3:{if(T|R^1){_=4455;break L6207}if(!(V<<24>>24!=3|U)){_=4455;break L6207}aj=c[x>>2]|0;ai=aj+P|0;ae=v$(Q,ai)|0;if((ae|0)==0){aw=Q;_=4459;break L6207}if((d5(ae+P|0,1,aj|0,A|0)|0)!=(aj|0)){aw=ae;_=4459;break L6207}if((eo(A|0,4,1)|0)<0){aw=ae;_=4459;break L6207}else{ak=U;al=0;am=1;an=R;ao=ae;ap=ai;aq=V;ar=W;as=X;at=Y;au=Z;break L6213}break};case 5:{if(!(R&S)){_=4461;break L6207}if((eo(A|0,4,1)|0)<0){_=4463;break L6207}else{ak=U;al=1;am=1;an=1;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z;break L6213}break};default:{_=4411;break L6213}}}}while(0);if((_|0)==4411){_=0;if((eo(A|0,(c[x>>2]|0)+4|0,1)|0)<0){_=4412;break}else{ak=U;al=T;am=S;an=R;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z}}ai=cb(A|0)|0;if((ai|0)<(b|0)&(ai|0)>-1){P=ap;Q=ao;R=an;S=am;T=al;U=ak;V=aq;W=ar;X=as;Y=at;Z=au}else{_=4465;break}}if((_|0)==4407){Z=c[q>>2]|0;eb(Z|0,47208,(v=i,i=i+8|0,c[v>>2]=613,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4412){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=620,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4413){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=624,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4415){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=628,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4417){c[G>>2]=0}else if((_|0)==4421){v_(ad)}else if((_|0)==4423){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=154,v)|0)|0;i=v;_=4440}else if((_|0)==4425){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=165,v)|0)|0;i=v;_=4440}else if((_|0)==4430){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=170,v)|0)|0;i=v;_=4440}else if((_|0)==4433){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=186,v)|0)|0;i=v;_=4440}else if((_|0)==4436){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=202,v)|0)|0;i=v;_=4440}else if((_|0)==4437){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=205,v)|0)|0;i=v;_=4440}else if((_|0)==4439){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=217,v)|0)|0;i=v;_=4440}else if((_|0)==4444){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=638,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4446){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=641,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4452){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=644,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4455){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=651,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4459){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=654,v)|0)|0;i=v;ax=0;ay=aw;break L6202}else if((_|0)==4461){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=661,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4463){eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=664,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else if((_|0)==4465){if(!(an&am&al)){az=ao;break}c[m+36>>2]=0;c[m+40>>2]=0;c[m+24>>2]=0;c[m+8>>2]=0;Z=m+20|0;c[Z>>2]=0;c[m+44>>2]=0;Y=vZ(43784)|0;if((Y|0)==0){X=c[q>>2]|0;eb(X|0,47208,(v=i,i=i+8|0,c[v>>2]=675,v)|0)|0;i=v;ax=0;ay=ao;break L6202}X=m+28|0;c[X>>2]=Y;c[Y>>2]=0;c[Y+10992>>2]=0;c[Y+10996>>2]=0;c[Y+43780>>2]=1;c[Y+11e3>>2]=1;c[Y+11004>>2]=0;c[Y+11008>>2]=15;switch(aq&255|0){case 0:{aA=((ac(at,au&255)|0)+7|0)>>>3;break};case 2:{aA=((ac((au&255)*3|0,at)|0)+7|0)>>>3;break};case 3:{aA=((ac(at,au&255)|0)+7|0)>>>3;break};case 4:{aA=((ac((au&255)<<1,at)|0)+7|0)>>>3;break};case 6:{aA=((ac((au&255)<<2,at)|0)+7|0)>>>3;break};default:{aA=0}}Y=as<<24>>24==1;W=(ac(ar,aA+1|0)|0)<<(Y&1);V=vZ(W)|0;if((V|0)==0){U=c[q>>2]|0;eb(U|0,47208,(v=i,i=i+8|0,c[v>>2]=683,v)|0)|0;i=v;ax=0;ay=ao;break L6202}c[m>>2]=ao;c[m+4>>2]=ap;c[m+16>>2]=W;c[m+12>>2]=V;W=(jz(m)|0)==1;U=c[X>>2]|0;if((U|0)!=0){v_(U);c[X>>2]=0}if(!W){W=c[q>>2]|0;eb(W|0,47208,(v=i,i=i+8|0,c[v>>2]=693,v)|0)|0;i=v;ax=V;ay=ao;break L6202}c[B>>2]=at;c[F>>2]=ar;W=vZ(ac(ar<<2,at)|0)|0;X=W;c[t>>2]=X;if((W|0)==0){W=c[q>>2]|0;eb(W|0,47208,(v=i,i=i+8|0,c[v>>2]=701,v)|0)|0;i=v;ax=V;ay=ao;break L6202}W=c[Z>>2]|0;Z=o|0;L6301:do{if(Y){U=j;T=j|0;S=j+4|0;R=j+9|0;P=j+8|0;x=0;O=W;N=V;M=at;L6303:while(1){L=c[6432+(x<<4)>>2]|0;do{if(M>>>0>L>>>0){K=c[I>>2]|0;J=c[6436+(x<<4)>>2]|0;if(K>>>0<=J>>>0){aB=N;aC=O;break}u=c[6440+(x<<4)>>2]|0;y=((M-1-L+u|0)>>>0)/(u>>>0)|0;C=c[6444+(x<<4)>>2]|0;s=((K-1-J+C|0)>>>0)/(C>>>0)|0;K=y<<2;aD=vZ(ac(s,K)|0)|0;D=aD;if((aD|0)==0){break L6303}c[U>>2]=c[e>>2];c[U+4>>2]=c[e+4>>2];c[U+8>>2]=c[e+8>>2];c[U+12>>2]=c[e+12>>2];c[T>>2]=y;c[S>>2]=s;switch(d[R]|0){case 0:{aE=((ac(d[P]|0,y)|0)+7|0)>>>3;break};case 2:{aE=((ac(y*3|0,d[P]|0)|0)+7|0)>>>3;break};case 3:{aE=((ac(d[P]|0,y)|0)+7|0)>>>3;break};case 4:{aE=((ac(y<<1,d[P]|0)|0)+7|0)>>>3;break};case 6:{aE=((ac(d[P]|0,K)|0)+7|0)>>>3;break};default:{aE=0}}K=ac(aE+1|0,s)|0;if(K>>>0>O>>>0){_=4495;break L6303}if(!(jy(D,j,N,K,Z)|0)){_=4497;break L6303}ai=N+K|0;ae=O-K|0;if(!((s|0)==0|(y|0)==0)){K=D;D=X+((ac(c[H>>2]|0,J)|0)+L<<2)|0;J=0;while(1){aj=D;aa=0;while(1){c[aj>>2]=c[K+(aa<<2)>>2];ah=aa+1|0;if(ah>>>0<y>>>0){aj=aj+(u<<2)|0;aa=ah}else{break}}aa=J+1|0;aj=D+((ac(c[H>>2]|0,C)|0)<<2)|0;if(aa>>>0<s>>>0){K=K+(y<<2)|0;D=aj;J=aa}else{break}}}v_(aD);aB=ai;aC=ae}else{aB=N;aC=O}}while(0);L=x+1|0;if(L>>>0>=7){break L6301}x=L;O=aC;N=aB;M=c[H>>2]|0}if((_|0)==4495){v_(aD)}else if((_|0)==4497){v_(aD)}eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=706,v)|0)|0;i=v;ax=V;ay=ao;break L6202}else{if(jy(X,n,V,W,Z)|0){break}eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=709,v)|0)|0;i=v;ax=V;ay=ao;break L6202}}while(0);aR(A|0)|0;v_(ao);v_(V);if((f|0)==16&(g|0)==0){w=1;i=h;return w|0}Z=ac(c[F>>2]|0,c[B>>2]|0)|0;W=c[t>>2]|0;if((Z|0)==0){w=1;i=h;return w|0}else{aF=0}while(1){X=W+(aF<<2)|0;H=c[X>>2]|0;c[X>>2]=(H&255)<<g|H&-16777216|(H>>>16&255)<<f|H&65280;H=aF+1|0;if(H>>>0<Z>>>0){aF=H}else{w=1;break}}i=h;return w|0}if((_|0)==4440){v_(ad);c[G>>2]=0}eb(c[q>>2]|0,47208,(v=i,i=i+8|0,c[v>>2]=631,v)|0)|0;i=v;ax=0;ay=Q;break L6202}else{az=0}}while(0);z=c[q>>2]|0;eb(z|0,47208,(v=i,i=i+8|0,c[v>>2]=672,v)|0)|0;i=v;ax=0;ay=az}else{z=c[q>>2]|0;eb(z|0,47208,(v=i,i=i+8|0,c[v>>2]=606,v)|0)|0;i=v;ax=0;ay=0}}while(0);aR(A|0)|0;aG=ax;aH=ay}else{ay=c[q>>2]|0;eb(ay|0,47208,(v=i,i=i+8|0,c[v>>2]=603,v)|0)|0;i=v;aR(A|0)|0;aG=0;aH=0}v_(c[t>>2]|0);v_(aH);v_(aG);w=0;i=h;return w|0}function h8(a,b,c){a=a|0;b=b|0;c=c|0;return-1|0}function h9(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function ia(a){a=a|0;return 1}function ib(a){a=a|0;return 1}function ic(a,b){a=a|0;b=b|0;return}function id(a){a=a|0;return}function ie(a){a=a|0;return 1}function ig(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0.0,N=0,O=0.0,P=0.0,Q=0,R=0.0,S=0.0;d=~~(16777216.0/+h[b+16>>3]);e=c[b+8>>2]|0;if((e|0)==0){f=0;i=b+12|0;c[i>>2]=f;return}j=a+20|0;k=a+4|0;l=a+16|0;m=a+8|0;n=a+12|0;o=a;a=c[b>>2]|0;p=c[b+4>>2]|0;q=e;e=0;r=c[j>>2]|0;while(1){L6363:do{if((q|0)==0){s=a;t=r;u=4541}else{v=a;w=q;x=r;while(1){if(x>>>0<=16777215){y=x;z=w;A=v;break L6363}B=c[l>>2]|0;if((B|0)==0){C=c[n>>2]|0;c[l>>2]=C;D=C}else{D=B}B=D-1|0;c[l>>2]=B;E=+g[v>>2];g[(c[k>>2]|0)+(B<<2)>>2]=E;g[(c[k>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;B=v+8|0;E=+g[v+4>>2];g[(c[m>>2]|0)+(c[l>>2]<<2)>>2]=E;g[(c[m>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;C=(c[j>>2]|0)-16777216|0;c[j>>2]=C;F=w-1|0;if((F|0)==0){s=B;t=C;u=4541;break}else{v=B;w=F;x=C}}}}while(0);if((u|0)==4541){u=0;if(t>>>0<16777216){y=t;z=0;A=s}else{f=e;u=4548;break}}x=p;w=e;v=y;do{C=c[k>>2]|0;F=c[l>>2]|0;B=c[m>>2]|0;G=c[n>>2]|0;H=c[o>>2]|0;I=ac(G<<1,v>>>16)|0;J=I+G|0;E=+((v&65535)>>>0>>>0)*152587890625.0e-16;if((G|0)==0){K=0.0;L=0.0}else{M=0.0;N=0;O=0.0;while(1){P=+g[H+(N+I<<2)>>2]+E*+g[H+(J+N<<2)>>2];Q=N+F|0;R=O+ +g[C+(Q<<2)>>2]*P;S=M+ +g[B+(Q<<2)>>2]*P;Q=N+1|0;if(Q>>>0<G>>>0){M=S;N=Q;O=R}else{K=S;L=R;break}}}g[x>>2]=L;g[x+4>>2]=K;x=x+8|0;w=w+1|0;v=(c[j>>2]|0)+d|0;c[j>>2]=v;}while(v>>>0<16777216);if((z|0)==0){f=w;u=4547;break}else{a=A;p=x;q=z;e=w;r=v}}if((u|0)==4547){i=b+12|0;c[i>>2]=f;return}else if((u|0)==4548){i=b+12|0;c[i>>2]=f;return}}function ih(b){b=+b;var d=0,e=0,f=0,h=0,j=0.0,k=0,l=0,m=0,n=0,o=0.0,p=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0,E=0,F=0.0,G=0.0,H=0;d=i;e=vZ(28)|0;if((e|0)==0){f=0;i=d;return f|0}if((c[e-4>>2]&3|0)!=0){v3(e|0,0,28)}v3(e|0,0,28);h=e+12|0;if(b<1.0){j=b*.825;k=~~+ab(+(16.0/b))+3&-4}else{j=.825;k=16}c[h>>2]=k;l=k<<9;m=vZ((l+(k<<2)<<2)+132|0)|0;k=m+132&-128;c[k-4>>2]=m;m=k;c[e+24>>2]=m;if((k|0)==0){v_(c[m-4>>2]|0);v_(e);f=0;i=d;return f|0}c[e>>2]=m;c[e+4>>2]=m+(l<<2);k=c[h>>2]|0;n=k<<1;c[e+8>>2]=m+(n+l<<2);b=1.0;o=0.0;p=1.0;r=1.0;s=0.0;l=0;while(1){t=s+r*p/(b*b);u=o+1.0;v=l+1|0;if(v>>>0<18){b=b*u;o=u;p=p*30.25;r=r*.25;s=t;l=v}else{break}}s=+(k|0)*.5;r=+(k<<8|0);if((k|0)>0){l=0;while(1){v=ac(l,n)|0;w=0;do{p=+((w<<8)+l|0)/r*2.0+-1.0;o=j*s*p*3.141592653589793;if(+R(+o)<1.0e-5){x=1.0}else{x=+V(+o)/o}o=+S(+(1.0-p*p))*5.5;p=o*o;o=1.0;b=0.0;u=1.0;y=1.0;z=0.0;A=0;while(1){B=z+y*u/(o*o);C=b+1.0;D=A+1|0;if(D>>>0<18){o=o*C;b=C;u=p*u;y=y*.25;z=B;A=D}else{break}}g[m+(w+v<<2)>>2]=j*x*B/t;w=w+1|0;}while((w|0)<(k|0));w=l+1|0;if((w|0)<256){l=w}else{E=0;break}}while(1){l=E+1|0;w=ac(l,n)|0;v=E<<1;A=ac(v,k)|0;D=ac(v|1,k)|0;v=0;do{g[m+(v+D<<2)>>2]=+g[m+(v+w<<2)>>2]- +g[m+(v+A<<2)>>2];v=v+1|0;}while((v|0)<(k|0));if((l|0)<255){E=l}else{break}}E=k*510|0;n=k*511|0;v=0;do{B=+((v<<8)+256|0)/r*2.0+-1.0;x=j*s*B*3.141592653589793;if(+R(+x)<1.0e-5){F=1.0}else{F=+V(+x)/x}x=+S(+(1.0-B*B))*5.5;B=x*x;x=1.0;z=0.0;y=1.0;u=1.0;p=0.0;A=0;while(1){G=p+u*y/(x*x);b=z+1.0;w=A+1|0;if(w>>>0<18){x=x*b;z=b;y=B*y;u=u*.25;p=G;A=w}else{break}}g[m+(v+n<<2)>>2]=j*F*G/t- +g[m+(v+E<<2)>>2];v=v+1|0;}while((v|0)<(k|0))}k=a[607928]|0;if((k&1)==0){H=k}else{k=c[191244]|0;v=(k|0)!=0?k:c[q>>2]|0;a3(47976,30,1,v|0)|0;v=c[191244]|0;k=(v|0)!=0?v:c[q>>2]|0;aZ(k|0)|0;H=a[607928]|0}if((H&1)==0){f=e;i=d;return f|0}H=c[191244]|0;k=c[h>>2]|0;eb(((H|0)!=0?H:c[q>>2]|0)|0,35976,(H=i,i=i+16|0,c[H>>2]=8,c[H+8>>2]=k,H)|0)|0;i=H;H=c[191244]|0;aZ(((H|0)!=0?H:c[q>>2]|0)|0)|0;f=e;i=d;return f|0}function ii(a){a=a|0;if((a|0)==0){v_(a);return}v_(c[(c[a+24>>2]|0)-4>>2]|0);v_(a);return}function ij(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=v2(e|0)|0;if(g>>>0<=c>>>0){h=c+1|0;do{if((h|0)==0){i=e}else{j=h;k=b;l=e;while(1){m=j-1|0;if((m|0)==0){n=4594;break}o=a[l]|0;a[k]=o;if(o<<24>>24==0){n=4647;break}else{j=m;k=k+1|0;l=l+1|0}}if((n|0)==4647){return}else if((n|0)==4594){a[k]=0;i=l;break}}}while(0);if((a[i]|0)==0){return}else{p=i}do{p=p+1|0;}while((a[p]|0)!=0);return}if(!f){f=c+1|0;p=c-2|0;L6458:do{if((p|0)==0){q=e;n=4602}else{i=p;h=b;j=e;while(1){m=i-1|0;if((m|0)==0){break}o=a[j]|0;a[h]=o;if(o<<24>>24==0){break L6458}else{i=m;h=h+1|0;j=j+1|0}}a[h]=0;q=j;n=4602}}while(0);do{if((n|0)==4602){if((a[q]|0)==0){break}else{r=q}do{r=r+1|0;}while((a[r]|0)!=0)}}while(0);r=v2(b|0)|0;q=r>>>0>f>>>0?0:f-r|0;if((q|0)==0){s=34896}else{f=b+r|0;do{if((q|0)==1){t=34896;u=f}else{j=b+(r+1)|0;a[f]=46;if((q|0)==2){t=34897;u=j;break}h=b+(r+2)|0;a[j]=46;if((q|0)==3){t=34898;u=h;break}j=b+(r+3)|0;a[h]=46;if((q|0)==4){t=34899;u=j;break}a[j]=0;return}}while(0);a[u]=0;s=t}if((a[s]|0)==0){return}else{v=s}do{v=v+1|0;}while((a[v]|0)!=0);return}v=g-c|0;g=(d>>>0)%(((v<<1)+4|0)>>>0)|0;d=v+4|0;s=g-2|0;t=d+v-g|0;if(g>>>0<2){u=c+1|0;do{if((u|0)==0){w=e}else{q=u;r=b;f=e;while(1){j=q-1|0;if((j|0)==0){n=4614;break}h=a[f]|0;a[r]=h;if(h<<24>>24==0){n=4657;break}else{q=j;r=r+1|0;f=f+1|0}}if((n|0)==4614){a[r]=0;w=f;break}else if((n|0)==4657){return}}}while(0);if((a[w]|0)==0){return}else{x=w}do{x=x+1|0;}while((a[x]|0)!=0);return}if(g>>>0<(v+2|0)>>>0){x=e+s|0;s=c+1|0;do{if((s|0)==0){y=x}else{w=s;u=b;q=x;while(1){j=w-1|0;if((j|0)==0){n=4621;break}h=a[q]|0;a[u]=h;if(h<<24>>24==0){n=4643;break}else{w=j;u=u+1|0;q=q+1|0}}if((n|0)==4643){return}else if((n|0)==4621){a[u]=0;y=q;break}}}while(0);if((a[y]|0)==0){return}else{z=y}do{z=z+1|0;}while((a[z]|0)!=0);return}if(g>>>0<d>>>0){d=e+v|0;v=c+1|0;do{if((v|0)==0){A=d}else{g=v;z=b;y=d;while(1){x=g-1|0;if((x|0)==0){n=4628;break}s=a[y]|0;a[z]=s;if(s<<24>>24==0){n=4658;break}else{g=x;z=z+1|0;y=y+1|0}}if((n|0)==4628){a[z]=0;A=y;break}else if((n|0)==4658){return}}}while(0);if((a[A]|0)==0){return}else{B=A}do{B=B+1|0;}while((a[B]|0)!=0);return}else{B=e+t|0;t=c+1|0;do{if((t|0)==0){C=B}else{c=t;e=b;A=B;while(1){d=c-1|0;if((d|0)==0){n=4634;break}v=a[A]|0;a[e]=v;if(v<<24>>24==0){n=4655;break}else{c=d;e=e+1|0;A=A+1|0}}if((n|0)==4655){return}else if((n|0)==4634){a[e]=0;C=A;break}}}while(0);if((a[C]|0)==0){return}else{D=C}do{D=D+1|0;}while((a[D]|0)!=0);return}}function ik(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=b+44|0;e=c[d>>2]|0;f=e+8|0;if((c[f>>2]|0)!=0){g=e|0;e=0;do{v_(c[(c[g>>2]|0)+(e*12|0)>>2]|0);e=e+1|0;}while(e>>>0<(c[f>>2]|0)>>>0)}c[f>>2]=0;do{if((c[b+113712>>2]|0)==0){h=4668}else{f=c[d>>2]|0;if((f|0)==0){break}e=f+8|0;g=f+4|0;i=c[g>>2]|0;if((c[e>>2]|0)>>>0<i>>>0){j=f|0}else{k=(i<<1)+2|0;c[g>>2]=k;g=f|0;c[g>>2]=v$(c[g>>2]|0,k*12|0)|0;j=g}g=dn(44728)|0;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)>>2]=g;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=56;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1;h=4668}}while(0);do{if((h|0)==4668){j=c[d>>2]|0;if((j|0)==0){break}b=j+8|0;e=j+4|0;g=c[e>>2]|0;if((c[b>>2]|0)>>>0<g>>>0){l=j|0}else{k=(g<<1)+2|0;c[e>>2]=k;e=j|0;c[e>>2]=v$(c[e>>2]|0,k*12|0)|0;l=e}e=dn(44688)|0;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)>>2]=e;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)+4>>2]=55;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)+8>>2]=0;c[b>>2]=(c[b>>2]|0)+1;b=c[d>>2]|0;if((b|0)==0){break}e=b+8|0;k=b+4|0;j=c[k>>2]|0;if((c[e>>2]|0)>>>0<j>>>0){m=b|0}else{g=(j<<1)+2|0;c[k>>2]=g;k=b|0;c[k>>2]=v$(c[k>>2]|0,g*12|0)|0;m=k}k=dn(44624)|0;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)>>2]=k;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=58;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1;e=c[d>>2]|0;if((e|0)==0){break}k=e+8|0;g=e+4|0;b=c[g>>2]|0;if((c[k>>2]|0)>>>0<b>>>0){n=e|0}else{j=(b<<1)+2|0;c[g>>2]=j;g=e|0;c[g>>2]=v$(c[g>>2]|0,j*12|0)|0;n=g}g=dn(44464)|0;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)>>2]=g;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)+4>>2]=5;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)+8>>2]=0;c[k>>2]=(c[k>>2]|0)+1;k=c[d>>2]|0;if((k|0)==0){break}g=k+8|0;j=k+4|0;e=c[j>>2]|0;if((c[g>>2]|0)>>>0<e>>>0){o=k|0}else{b=(e<<1)+2|0;c[j>>2]=b;j=k|0;c[j>>2]=v$(c[j>>2]|0,b*12|0)|0;o=j}j=dn(44216)|0;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)>>2]=j;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)+4>>2]=59;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)+8>>2]=0;c[g>>2]=(c[g>>2]|0)+1;g=c[d>>2]|0;if((g|0)==0){break}j=g+8|0;b=g+4|0;k=c[b>>2]|0;if((c[j>>2]|0)>>>0<k>>>0){p=g|0}else{e=(k<<1)+2|0;c[b>>2]=e;b=g|0;c[b>>2]=v$(c[b>>2]|0,e*12|0)|0;p=b}b=dn(44104)|0;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)>>2]=b;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)+4>>2]=60;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)+8>>2]=0;c[j>>2]=(c[j>>2]|0)+1;j=c[d>>2]|0;if((j|0)==0){break}b=j+8|0;e=j+4|0;g=c[e>>2]|0;if((c[b>>2]|0)>>>0<g>>>0){q=j|0}else{k=(g<<1)+2|0;c[e>>2]=k;e=j|0;c[e>>2]=v$(c[e>>2]|0,k*12|0)|0;q=e}e=dn(43968)|0;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)>>2]=e;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)+4>>2]=61;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)+8>>2]=0;c[b>>2]=(c[b>>2]|0)+1;b=c[d>>2]|0;if((b|0)==0){break}e=b+8|0;k=b+4|0;j=c[k>>2]|0;if((c[e>>2]|0)>>>0<j>>>0){r=b|0}else{g=(j<<1)+2|0;c[k>>2]=g;k=b|0;c[k>>2]=v$(c[k>>2]|0,g*12|0)|0;r=k}k=dn(43840)|0;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)>>2]=k;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=62;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1}}while(0);do{if((a[764980]&1)!=0){if((a[766053]&1)!=0){break}if((c[176732]|0)!=0){r=c[d>>2]|0;if((r|0)==0){return}q=r+8|0;p=r+4|0;o=c[p>>2]|0;if((c[q>>2]|0)>>>0<o>>>0){s=r|0}else{n=(o<<1)+2|0;c[p>>2]=n;p=r|0;c[p>>2]=v$(c[p>>2]|0,n*12|0)|0;s=p}p=dn(43712)|0;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)>>2]=p;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)+4>>2]=69;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)+8>>2]=0;c[q>>2]=(c[q>>2]|0)+1}q=c[d>>2]|0;if((q|0)==0){return}p=q+8|0;n=q+4|0;r=c[n>>2]|0;if((c[p>>2]|0)>>>0<r>>>0){t=q|0}else{o=(r<<1)+2|0;c[n>>2]=o;n=q|0;c[n>>2]=v$(c[n>>2]|0,o*12|0)|0;t=n}n=dn(43584)|0;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)>>2]=n;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)+4>>2]=67;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)+8>>2]=0;c[p>>2]=(c[p>>2]|0)+1;p=c[d>>2]|0;if((p|0)==0){return}n=p+8|0;o=p+4|0;q=c[o>>2]|0;if((c[n>>2]|0)>>>0<q>>>0){u=p|0}else{r=(q<<1)+2|0;c[o>>2]=r;o=p|0;c[o>>2]=v$(c[o>>2]|0,r*12|0)|0;u=o}o=dn(43464)|0;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)>>2]=o;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)+4>>2]=68;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)+8>>2]=0;c[n>>2]=(c[n>>2]|0)+1;n=c[d>>2]|0;if((n|0)==0){return}o=n+8|0;r=n+4|0;p=c[r>>2]|0;if((c[o>>2]|0)>>>0<p>>>0){v=n|0}else{q=(p<<1)+2|0;c[r>>2]=q;r=n|0;c[r>>2]=v$(c[r>>2]|0,q*12|0)|0;v=r}r=dn(43296)|0;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)>>2]=r;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=72;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1;o=c[d>>2]|0;if((o|0)==0){return}r=o+8|0;q=o+4|0;n=c[q>>2]|0;if((c[r>>2]|0)>>>0<n>>>0){w=o|0}else{p=(n<<1)+2|0;c[q>>2]=p;q=o|0;c[q>>2]=v$(c[q>>2]|0,p*12|0)|0;w=q}q=dn(43224)|0;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)>>2]=q;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)+4>>2]=86;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)+8>>2]=0;c[r>>2]=(c[r>>2]|0)+1;r=c[d>>2]|0;if((r|0)==0){return}q=r+8|0;p=r+4|0;o=c[p>>2]|0;if((c[q>>2]|0)>>>0<o>>>0){x=r|0}else{n=(o<<1)+2|0;c[p>>2]=n;p=r|0;c[p>>2]=v$(c[p>>2]|0,n*12|0)|0;x=p}p=dn(43112)|0;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)>>2]=p;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)+4>>2]=80;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)+8>>2]=0;c[q>>2]=(c[q>>2]|0)+1}}while(0);x=c[d>>2]|0;if((x|0)==0){return}w=x+8|0;v=x+4|0;u=c[v>>2]|0;if((c[w>>2]|0)>>>0<u>>>0){y=x|0}else{t=(u<<1)+2|0;c[v>>2]=t;v=x|0;c[v>>2]=v$(c[v>>2]|0,t*12|0)|0;y=v}v=dn(42840)|0;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)>>2]=v;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)+4>>2]=85;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)+8>>2]=0;c[w>>2]=(c[w>>2]|0)+1;w=c[d>>2]|0;if((w|0)==0){return}d=w+8|0;y=w+4|0;v=c[y>>2]|0;if((c[d>>2]|0)>>>0<v>>>0){z=w|0}else{t=(v<<1)+2|0;c[y>>2]=t;y=w|0;c[y>>2]=v$(c[y>>2]|0,t*12|0)|0;z=y}y=dn(42736)|0;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)>>2]=y;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)+4>>2]=87;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)+8>>2]=0;c[d>>2]=(c[d>>2]|0)+1;return}function il(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,a_=0,a$=0,a0=0,a1=0,a2=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0;e=i;i=i+22120|0;f=e|0;h=e+16|0;j=e+528|0;k=e+1552|0;l=e+5648|0;m=e+9744|0;n=e+9768|0;o=e+9832|0;p=e+13928|0;r=e+18024|0;s=d+8|0;t=c[s>>2]|0;u=c[s+4>>2]|0;do{if((t&1|0)==0&(u&0|0)==0){if(!((t&2|0)==0&(u&0|0)==0)){v=1;break}if(!((t&4|0)==0&(u&0|0)==0)){v=2;break}if(!((t&8|0)==0&(u&0|0)==0)){v=3;break}if(!((t&32|0)==0&(u&0|0)==0)){v=5;break}if(!((t&16|0)==0&(u&0|0)==0)){v=4;break}if(!((t&128|0)==0&(u&0|0)==0)){v=8;break}v=(t&64|0)==0&(u&0|0)==0?10:7}else{v=0}}while(0);u=d+40|0;t=c[u>>2]|0;s=c[t+8>>2]|0;if((s|0)==0){w=0;x=0}else{y=s-1|0;s=c[t>>2]|0;w=c[s+(y*12|0)+4>>2]|0;x=c[s+(y*12|0)>>2]|0}y=c[191610]|0;do{if((y|0)!=0){if((c[y+24>>2]|0)==0){break}fh[c[y+20>>2]&3](c[191562]|0,149e3,0,320,240,1.0)}}while(0);switch(w|0){case 69:case 62:case 61:case 59:case 58:case 26:case 5:case 4:case 60:{z=im(d,v)|0;i=e;return z|0};default:{}}if((w-12|0)>>>0<2){y=n|0;n=c[u>>2]|0;s=n+8|0;t=c[s>>2]|0;A=(t|0)==0;if(A){B=0}else{B=c[(c[n>>2]|0)+((t-1|0)*12|0)+4>>2]|0}C=(a[505629]&1)==0;D=C?1:c[175558]|0;E=C?1:c[175559]|0;L6686:do{switch(v|0){case 2:{do{if((B|0)==12){c[191229]=(c[191229]|0)-D;c[191231]=(c[191231]|0)+D}else{F=c[191231]|0;if(F>>>0<D>>>0){break}c[191231]=F-D}}while(0);F=c[(c[191610]|0)+16>>2]|0;if((F|0)==0){break L6686}e9[F&2047](c[191562]|0);break};case 7:{F=d+48|0;if(!A){H=t-1|0;c[s>>2]=H;v_(c[(c[n>>2]|0)+(H*12|0)>>2]|0)}if((F|0)==0){break L6686}c[F>>2]=c[(c[n>>2]|0)+((c[s>>2]|0)*12|0)+8>>2];break};case 1:{do{if((B|0)==12){c[191230]=(c[191230]|0)+E;F=c[191232]|0;if(F>>>0<E>>>0){break}c[191232]=F-E}else{c[191232]=(c[191232]|0)+E}}while(0);F=c[(c[191610]|0)+16>>2]|0;if((F|0)==0){break L6686}e9[F&2047](c[191562]|0);break};case 4:{F=d+48|0;if(!A){H=t-1|0;c[s>>2]=H;v_(c[(c[n>>2]|0)+(H*12|0)>>2]|0)}if((F|0)!=0){c[F>>2]=c[(c[n>>2]|0)+((c[s>>2]|0)*12|0)+8>>2]}if((B|0)!=12){break L6686}if((a[505629]&1)!=0){break L6686}H=c[u>>2]|0;I=c[F>>2]|0;if((H|0)==0){break L6686}F=H+8|0;J=H+4|0;K=c[J>>2]|0;if((c[F>>2]|0)>>>0<K>>>0){L=H|0}else{M=(K<<1)+2|0;c[J>>2]=M;J=H|0;c[J>>2]=v$(c[J>>2]|0,M*12|0)|0;L=J}J=dn(766672)|0;c[(c[L>>2]|0)+((c[F>>2]|0)*12|0)>>2]=J;c[(c[L>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=13;c[(c[L>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=I;c[F>>2]=(c[F>>2]|0)+1;break};case 3:{do{if((B|0)==12){c[191229]=(c[191229]|0)+D;F=c[191231]|0;if(F>>>0<D>>>0){break}c[191231]=F-D}else{c[191231]=(c[191231]|0)+D}}while(0);F=c[(c[191610]|0)+16>>2]|0;if((F|0)==0){break L6686}e9[F&2047](c[191562]|0);break};case 5:{F=d+48|0;if(!A){I=t-1|0;c[s>>2]=I;v_(c[(c[n>>2]|0)+(I*12|0)>>2]|0)}if((F|0)!=0){c[F>>2]=c[(c[n>>2]|0)+((c[s>>2]|0)*12|0)+8>>2]}if((B|0)!=13){break L6686}I=c[u>>2]|0;J=c[F>>2]|0;if((I|0)==0){break L6686}F=I+8|0;M=I+4|0;H=c[M>>2]|0;if((c[F>>2]|0)>>>0<H>>>0){N=I|0}else{K=(H<<1)+2|0;c[M>>2]=K;M=I|0;c[M>>2]=v$(c[M>>2]|0,K*12|0)|0;N=M}M=dn(766672)|0;c[(c[N>>2]|0)+((c[F>>2]|0)*12|0)>>2]=M;c[(c[N>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=12;c[(c[N>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=J;c[F>>2]=(c[F>>2]|0)+1;break};case 0:{do{if((B|0)==12){c[191230]=(c[191230]|0)-E;c[191232]=(c[191232]|0)+E}else{F=c[191232]|0;if(F>>>0<E>>>0){break}c[191232]=F-E}}while(0);F=c[(c[191610]|0)+16>>2]|0;if((F|0)==0){break L6686}e9[F&2047](c[191562]|0);break};case 9:{a[d+53|0]=1;break};case 8:{if(!C){break L6686}fa[c[(c[191559]|0)+44>>2]&127](c[191562]|0,m);if((B|0)==12){c[191231]=(c[191231]|0)+(c[191229]|0);c[191232]=(c[191232]|0)+(c[191230]|0);c[191229]=0;c[191230]=0}else{c[191231]=(c[m+16>>2]|0)-(c[191229]|0);c[191232]=(c[m+20>>2]|0)-(c[191230]|0)}F=c[(c[191610]|0)+16>>2]|0;if((F|0)==0){break L6686}e9[F&2047](c[191562]|0);break};default:{}}}while(0);m=c[u>>2]|0;C=c[m+8>>2]|0;if((C|0)==0){O=B}else{O=c[(c[m>>2]|0)+((C-1|0)*12|0)+4>>2]|0}ip(d);if((a[505629]&1)==0){if((O|0)==12){P=17264}else{P=(O|0)==13?17040:0}O=c[191229]|0;C=c[191230]|0;m=c[191231]|0;B=c[191232]|0;bN(y|0,64,16792,(Q=i,i=i+40|0,c[Q>>2]=P,c[Q+8>>2]=O,c[Q+16>>2]=C,c[Q+24>>2]=m,c[Q+32>>2]=B,Q)|0)|0;i=Q}else{c[191229]=0;c[191230]=0;B=c[175558]|0;m=(c[191231]|0)-1+B|0;C=m-((m>>>0)%(B>>>0)|0)|0;c[191231]=C;O=c[175559]|0;P=(c[191232]|0)-1+O|0;N=P-((P>>>0)%(O>>>0)|0)|0;c[191232]=N;s=(m>>>0)/(B>>>0)|0;B=(P>>>0)/(O>>>0)|0;bN(y|0,64,17680,(Q=i,i=i+40|0,c[Q>>2]=17840,c[Q+8>>2]=C,c[Q+16>>2]=N,c[Q+24>>2]=s,c[Q+32>>2]=B,Q)|0)|0;i=Q}if((a[y]|0)!=0){B=dn(y|0)|0;if((v2(B|0)|0)>>>0>48){a[B+46|0]=46;a[B+47|0]=46;a[B+48|0]=46;a[B+49|0]=0}y=(v2(B|0)|0)*6|0;s=y+15|0;N=(305-y|0)>>>1;C=d+28|0;O=c[C>>2]|0;P=d+32|0;m=N+5|0;n=c[P>>2]|0;t=y+5+m|0;A=n>>>1;if(t>>>0>m>>>0){L=112;do{F=ac(L,A)|0;J=L>>>1;M=m;do{K=((M>>>1)+J&1)+1|0;b[O+(M+F<<1)>>1]=(K<<13|K<<9|K<<5|12)&65535;M=M+1|0;}while(M>>>0<t>>>0);L=L+1|0;}while(L>>>0<128);R=c[C>>2]|0;S=c[P>>2]|0}else{R=O;S=n}n=y+10|0;y=N+n|0;O=S>>>1;if(y>>>0>N>>>0){L=107;do{t=ac(L,O)|0;A=L>>>1;M=N;do{F=((M>>>1)+A&1)+1|0;b[R+(M+t<<1)>>1]=(F<<13|F<<10|F<<5|12)&65535;M=M+1|0;}while(M>>>0<y>>>0);L=L+1|0;}while(L>>>0<112);T=c[C>>2]|0;U=c[P>>2]|0}else{T=R;U=S}S=N+s|0;s=cn(S|0,-5|0)|0;R=s;s=U>>>1;if(G){L=107;do{y=ac(L,s)|0;O=L>>>1;M=R;do{t=((M>>>1)+O&1)+1|0;b[T+(M+y<<1)>>1]=(t<<13|t<<10|t<<5|12)&65535;M=M+1|0;}while(M>>>0<S>>>0);L=L+1|0;}while(L>>>0<128);V=c[C>>2]|0;W=c[P>>2]|0}else{V=T;W=U}U=m+n|0;n=W>>>1;if(U>>>0>m>>>0){T=n<<7;L=m;do{S=(L>>>1&1)+1|0;b[V+(L+T<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;L=L+1|0;}while(L>>>0<U>>>0);L=n*129|0;T=m;do{S=(T>>>1&1)+1|0;b[V+(T+L<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;T=T+1|0;}while(T>>>0<U>>>0);T=n*130|0;L=m;do{S=2-(L>>>1&1)|0;b[V+(L+T<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;L=L+1|0;}while(L>>>0<U>>>0);L=n*131|0;T=m;do{S=2-(T>>>1&1)|0;b[V+(T+L<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;T=T+1|0;}while(T>>>0<U>>>0);T=n*132|0;n=m;do{L=(n>>>1&1)+1|0;b[V+(n+T<<1)>>1]=(L<<13|L<<10|L<<5|12)&65535;n=n+1|0;}while(n>>>0<U>>>0);X=c[C>>2]|0;Y=c[P>>2]|0}else{X=V;Y=W}W=Y>>>1;Y=112;do{V=ac(Y,W)|0;P=Y>>>1;C=N;do{U=((C>>>1)+P&1)+1|0;b[X+(C+V<<1)>>1]=(U<<13|U<<10|U<<5|12)&65535;C=C+1|0;}while(C>>>0<m>>>0);Y=Y+1|0;}while(Y>>>0<133);iq(d,N+8|0,115,B,0);v_(B)}B=c[191231]|0;if((B|0)==0){c[191231]=D;Z=D}else{Z=B}B=c[191232]|0;if((B|0)==0){c[191232]=E;_=E}else{_=B}g[3053]=+(Z>>>0>>>0)/+(_>>>0>>>0);_=c[(c[191610]|0)+16>>2]|0;if((_|0)==0){z=0;i=e;return z|0}e9[_&2047](c[191562]|0);z=0;i=e;return z|0}_=d+52|0;L6831:do{switch(((a[_]&1)==0?v:10)|0){case 3:{Z=d+48|0;B=(c[Z>>2]|0)+8|0;E=c[(c[d+44>>2]|0)+8>>2]|0;if(B>>>0<E>>>0){c[Z>>2]=B;$=0;break L6831}else{c[Z>>2]=E-1;$=0;break L6831}break};case 1:{E=d+48|0;Z=(c[E>>2]|0)+1|0;if(Z>>>0<(c[(c[d+44>>2]|0)+8>>2]|0)>>>0){c[E>>2]=Z;$=0;break L6831}else{c[E>>2]=0;$=0;break L6831}break};case 2:{E=d+48|0;Z=c[E>>2]|0;if(Z>>>0>8){c[E>>2]=Z-8;$=0;break L6831}else{c[E>>2]=0;$=0;break L6831}break};case 0:{E=d+48|0;Z=c[E>>2]|0;if((Z|0)==0){c[E>>2]=(c[(c[d+44>>2]|0)+8>>2]|0)-1;$=0;break L6831}else{c[E>>2]=Z-1;$=0;break L6831}break};case 6:{c[d+48>>2]=0;a[_]=1;$=0;break};case 7:{a[_]=1;Z=c[u>>2]|0;E=c[Z+8>>2]|0;if(E>>>0>1){B=d+48|0;D=(B|0)==0;N=Z;Z=E;do{E=N+8|0;if((Z|0)!=0){Y=Z-1|0;c[E>>2]=Y;v_(c[(c[N>>2]|0)+(Y*12|0)>>2]|0)}if(!D){c[B>>2]=c[(c[N>>2]|0)+((c[E>>2]|0)*12|0)+8>>2]}N=c[u>>2]|0;Z=c[N+8>>2]|0;}while(Z>>>0>1)}z=im(d,6)|0;i=e;return z|0};case 9:{a[d+53|0]=1;$=0;break};case 5:{Z=c[u>>2]|0;N=Z+8|0;if((c[N>>2]|0)>>>0<=1){$=0;break L6831}a[_]=1;B=d+48|0;D=c[N>>2]|0;if((D|0)!=0){E=D-1|0;c[N>>2]=E;v_(c[(c[Z>>2]|0)+(E*12|0)>>2]|0)}if((B|0)==0){$=0;break L6831}c[B>>2]=c[(c[Z>>2]|0)+((c[N>>2]|0)*12|0)+8>>2];$=0;break};case 4:{N=c[d+44>>2]|0;if((c[N+8>>2]|0)==0){z=0;i=e;return z|0}Z=d+48|0;B=c[Z>>2]|0;E=c[N>>2]|0;N=c[E+(B*12|0)>>2]|0;D=c[E+(B*12|0)+4>>2]|0;E=D-31|0;do{if(!(E>>>0<24&((E>>>0)%3|0|0)==0|(D|0)==28)){if((D-73|0)>>>0<4|(D|0)==78|(D|0)==79){break}if((D|0)==88|(D|0)==71|(D|0)==57|(D|0)==1){break}Y=w-31|0;m=(w|0)==28;if(Y>>>0<24&((Y>>>0)%3|0|0)==0|m){if(m){m=p|0;gq(m,x,N);io(d+4180|0,h0(m,3)|0,m)}else{gq(d+4256+(((Y>>>0)/3|0)*4148|0)|0,x,N)}a[_]=1;Y=c[u>>2]|0;m=c[Y+8>>2]|0;if((m|0)==0){aa=0}else{X=c[(c[Y>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((X|0)==26){$=0;break L6831}else{aa=X}}X=(Z|0)==0;W=aa;C=Y;Y=m;while(1){m=C+8|0;if((Y|0)!=0){V=Y-1|0;c[m>>2]=V;v_(c[(c[C>>2]|0)+(V*12|0)>>2]|0)}if(!X){c[Z>>2]=c[(c[C>>2]|0)+((c[m>>2]|0)*12|0)+8>>2]}m=c[u>>2]|0;V=c[m+8>>2]|0;if((V|0)==0){ab=W}else{ab=c[(c[m>>2]|0)+((V-1|0)*12|0)+4>>2]|0}if((ab|0)==26){$=0;break L6831}else{W=ab;C=m;Y=V}}}switch(w|0){case 57:{a[_]=1;Y=c[u>>2]|0;C=c[Y+8>>2]|0;if((C|0)==0){ad=0}else{W=c[(c[Y>>2]|0)+((C-1|0)*12|0)+4>>2]|0;if((W|0)==4){$=0;break L6831}else{ad=W}}W=(Z|0)==0;X=ad;V=Y;Y=C;while(1){C=V+8|0;if((Y|0)!=0){m=Y-1|0;c[C>>2]=m;v_(c[(c[V>>2]|0)+(m*12|0)>>2]|0)}if(!W){c[Z>>2]=c[(c[V>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]}C=c[u>>2]|0;m=c[C+8>>2]|0;if((m|0)==0){ae=X}else{ae=c[(c[C>>2]|0)+((m-1|0)*12|0)+4>>2]|0}if((ae|0)==4){$=0;break L6831}else{X=ae;V=C;Y=m}}break};case 75:{Y=4096;V=681706;X=x;while(1){W=Y-1|0;if((W|0)==0){af=5028;break}m=a[X]|0;a[V]=m;if(m<<24>>24==0){break}else{Y=W;V=V+1|0;X=X+1|0}}do{if((af|0)==5028){a[V]=0;if((a[X]|0)==0){break}else{ag=X}do{ag=ag+1|0;}while((a[ag]|0)!=0)}}while(0);a[_]=1;X=c[u>>2]|0;V=c[X+8>>2]|0;if((V|0)==0){ah=0}else{Y=c[(c[X>>2]|0)+((V-1|0)*12|0)+4>>2]|0;if((Y|0)==61){$=0;break L6831}else{ah=Y}}Y=(Z|0)==0;W=ah;m=X;X=V;while(1){V=m+8|0;if((X|0)!=0){C=X-1|0;c[V>>2]=C;v_(c[(c[m>>2]|0)+(C*12|0)>>2]|0)}if(!Y){c[Z>>2]=c[(c[m>>2]|0)+((c[V>>2]|0)*12|0)+8>>2]}V=c[u>>2]|0;C=c[V+8>>2]|0;if((C|0)==0){ai=W}else{ai=c[(c[V>>2]|0)+((C-1|0)*12|0)+4>>2]|0}if((ai|0)==61){$=0;break L6831}else{W=ai;m=V;X=C}}break};case 78:{X=4096;m=685802;W=x;while(1){Y=X-1|0;if((Y|0)==0){af=5014;break}C=a[W]|0;a[m]=C;if(C<<24>>24==0){break}else{X=Y;m=m+1|0;W=W+1|0}}do{if((af|0)==5014){a[m]=0;if((a[W]|0)==0){break}else{aj=W}do{aj=aj+1|0;}while((a[aj]|0)!=0)}}while(0);a[_]=1;W=c[u>>2]|0;m=c[W+8>>2]|0;if((m|0)==0){ak=0}else{X=c[(c[W>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((X|0)==61){$=0;break L6831}else{ak=X}}X=(Z|0)==0;Y=ak;C=W;W=m;while(1){m=C+8|0;if((W|0)!=0){V=W-1|0;c[m>>2]=V;v_(c[(c[C>>2]|0)+(V*12|0)>>2]|0)}if(!X){c[Z>>2]=c[(c[C>>2]|0)+((c[m>>2]|0)*12|0)+8>>2]}m=c[u>>2]|0;V=c[m+8>>2]|0;if((V|0)==0){al=Y}else{al=c[(c[m>>2]|0)+((V-1|0)*12|0)+4>>2]|0}if((al|0)==61){$=0;break L6831}else{Y=al;C=m;W=V}}break};case 76:{W=4096;C=677610;Y=x;while(1){X=W-1|0;if((X|0)==0){af=5e3;break}V=a[Y]|0;a[C]=V;if(V<<24>>24==0){break}else{W=X;C=C+1|0;Y=Y+1|0}}do{if((af|0)==5e3){a[C]=0;if((a[Y]|0)==0){break}else{am=Y}do{am=am+1|0;}while((a[am]|0)!=0)}}while(0);a[_]=1;Y=c[u>>2]|0;C=c[Y+8>>2]|0;if((C|0)==0){an=0}else{W=c[(c[Y>>2]|0)+((C-1|0)*12|0)+4>>2]|0;if((W|0)==61){$=0;break L6831}else{an=W}}W=(Z|0)==0;X=an;V=Y;Y=C;while(1){C=V+8|0;if((Y|0)!=0){m=Y-1|0;c[C>>2]=m;v_(c[(c[V>>2]|0)+(m*12|0)>>2]|0)}if(!W){c[Z>>2]=c[(c[V>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]}C=c[u>>2]|0;m=c[C+8>>2]|0;if((m|0)==0){ao=X}else{ao=c[(c[C>>2]|0)+((m-1|0)*12|0)+4>>2]|0}if((ao|0)==61){$=0;break L6831}else{X=ao;V=C;Y=m}}break};case 74:{Y=4096;V=513837;X=x;while(1){W=Y-1|0;if((W|0)==0){af=5042;break}m=a[X]|0;a[V]=m;if(m<<24>>24==0){break}else{Y=W;V=V+1|0;X=X+1|0}}do{if((af|0)==5042){a[V]=0;if((a[X]|0)==0){break}else{ap=X}do{ap=ap+1|0;}while((a[ap]|0)!=0)}}while(0);a[_]=1;X=c[u>>2]|0;V=c[X+8>>2]|0;if((V|0)==0){aq=0}else{Y=c[(c[X>>2]|0)+((V-1|0)*12|0)+4>>2]|0;if((Y|0)==61){$=0;break L6831}else{aq=Y}}Y=(Z|0)==0;W=aq;m=X;X=V;while(1){V=m+8|0;if((X|0)!=0){C=X-1|0;c[V>>2]=C;v_(c[(c[m>>2]|0)+(C*12|0)>>2]|0)}if(!Y){c[Z>>2]=c[(c[m>>2]|0)+((c[V>>2]|0)*12|0)+8>>2]}V=c[u>>2]|0;C=c[V+8>>2]|0;if((C|0)==0){ar=W}else{ar=c[(c[V>>2]|0)+((C-1|0)*12|0)+4>>2]|0}if((ar|0)==61){$=0;break L6831}else{W=ar;m=V;X=C}}break};case 71:{X=r|0;gq(X,x,N);m=h|0;f4(1,0);fu[c[176734]&31]()|0;W=fu[c[176732]&31]()|0;if((W|0)!=0){Y=W-1|0;v3(f|0,0,16);c[f>>2]=X;W=c[176733]|0;fr[W&63](Y,f)|0;f5(Y);bN(m|0,512,33824,(Q=i,i=i+8|0,c[Q>>2]=X,Q)|0)|0;i=Q;if((a[607928]&1)!=0){Y=c[191244]|0;W=(Y|0)!=0?Y:c[q>>2]|0;eb(W|0,47400,(Q=i,i=i+8|0,c[Q>>2]=m,Q)|0)|0;i=Q;W=c[191244]|0;Y=(W|0)!=0?W:c[q>>2]|0;aZ(Y|0)|0}Y=c[189113]|0;W=Y+4|0;C=c[W>>2]|0;if(C>>>0>1){V=Y|0;P=1;U=C;while(1){C=c[(c[V>>2]|0)+(P<<2)>>2]|0;if((C|0)==0){as=U}else{v_(c[C+8>>2]|0);v_(c[(c[V>>2]|0)+(P<<2)>>2]|0);c[(c[V>>2]|0)+(P<<2)>>2]=0;as=c[W>>2]|0}C=P+1|0;if(C>>>0<as>>>0){P=C;U=as}else{break}}}c[W>>2]=1;U=Y+12|0;v_(c[U>>2]|0);c[U>>2]=0;U=c[189113]|0;P=U+4|0;L7030:do{if((c[P>>2]|0)>>>0<(c[U+8>>2]|0)>>>0){V=vZ(12)|0;do{if((V|0)!=0){if((c[V-4>>2]&3|0)==0){break}v3(V|0,0,12)}}while(0);c[V+4>>2]=0;c[V>>2]=180;C=dn(m|0)|0;n=c[P>>2]|0;c[V+8>>2]=C;C=U|0;c[(c[C>>2]|0)+(n<<2)>>2]=V;n=c[P>>2]|0;c[P>>2]=n+1;if(n>>>0>1){at=n}else{break}while(1){n=at>>>1;T=c[C>>2]|0;L=T+(n<<2)|0;S=c[L>>2]|0;R=c[T+(at<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[S+4>>2]|0)>>>0){break L7030}c[L>>2]=R;c[(c[C>>2]|0)+(at<<2)>>2]=S;if(at>>>0>3){at=n}else{break}}}}while(0);f6(X);f7();f4(0,0)}P=764968;U=c[P+4>>2]|0;m=764968;c[m>>2]=c[P>>2]|1;c[m+4>>2]=U;a[_]=1;U=c[u>>2]|0;m=c[U+8>>2]|0;if((m|0)==0){au=0;av=U;aw=m}else{P=c[(c[U>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((P|0)==4){$=-1;break L6831}else{au=P;av=U;aw=m}}while(1){m=av+8|0;if((aw|0)==0){ax=0;ay=av;az=av|0}else{U=aw-1|0;c[m>>2]=U;P=av|0;v_(c[(c[P>>2]|0)+(U*12|0)>>2]|0);ax=c[m>>2]|0;ay=c[u>>2]|0;az=P}c[Z>>2]=c[(c[az>>2]|0)+(ax*12|0)+8>>2];P=c[ay+8>>2]|0;if((P|0)==0){aA=au}else{aA=c[(c[ay>>2]|0)+((P-1|0)*12|0)+4>>2]|0}if((aA|0)==4){$=-1;break L6831}else{au=aA;av=ay;aw=P}}break};case 88:{gq(566896,x,N);X=c[191604]|0;if((X|0)!=0){P=X+24|0;m=X+12|0;U=c[m>>2]|0;if((c[P>>2]|0)==0){aB=U}else{Y=0;W=U;while(1){v_(c[W+(Y*136|0)>>2]|0);v_(c[W+(Y*136|0)+8>>2]|0);U=Y+1|0;C=c[m>>2]|0;if(U>>>0<(c[P>>2]|0)>>>0){Y=U;W=C}else{aB=C;break}}}v_(aB);W=c[X+4>>2]|0;if((W|0)!=0){fa[c[W>>2]&127](c[X>>2]|0,0)}v_(X)}W=hH()|0;c[191604]=W;if((W|0)==0){W=c[191244]|0;Y=(W|0)!=0?W:c[q>>2]|0;a3(35904,45,1,Y|0)|0;Y=c[191244]|0;W=(Y|0)!=0?Y:c[q>>2]|0;aZ(W|0)|0}a[_]=1;W=c[u>>2]|0;Y=c[W+8>>2]|0;if((Y|0)==0){aC=0}else{P=c[(c[W>>2]|0)+((Y-1|0)*12|0)+4>>2]|0;if((P|0)==60){$=0;break L6831}else{aC=P}}P=(Z|0)==0;m=aC;C=W;W=Y;while(1){Y=C+8|0;if((W|0)!=0){U=W-1|0;c[Y>>2]=U;v_(c[(c[C>>2]|0)+(U*12|0)>>2]|0)}if(!P){c[Z>>2]=c[(c[C>>2]|0)+((c[Y>>2]|0)*12|0)+8>>2]}Y=c[u>>2]|0;U=c[Y+8>>2]|0;if((U|0)==0){aD=m}else{aD=c[(c[Y>>2]|0)+((U-1|0)*12|0)+4>>2]|0}if((aD|0)==60){$=0;break L6831}else{m=aD;C=Y;W=U}}break};case 79:{W=4096;C=599676;m=x;while(1){P=W-1|0;if((P|0)==0){af=5056;break}X=a[m]|0;a[C]=X;if(X<<24>>24==0){break}else{W=P;C=C+1|0;m=m+1|0}}do{if((af|0)==5056){a[C]=0;if((a[m]|0)==0){break}else{aE=m}do{aE=aE+1|0;}while((a[aE]|0)!=0)}}while(0);a[_]=1;m=c[u>>2]|0;C=c[m+8>>2]|0;if((C|0)==0){aF=0}else{W=c[(c[m>>2]|0)+((C-1|0)*12|0)+4>>2]|0;if((W|0)==61){$=0;break L6831}else{aF=W}}W=(Z|0)==0;P=aF;X=m;m=C;while(1){C=X+8|0;if((m|0)!=0){U=m-1|0;c[C>>2]=U;v_(c[(c[X>>2]|0)+(U*12|0)>>2]|0)}if(!W){c[Z>>2]=c[(c[X>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]}C=c[u>>2]|0;U=c[C+8>>2]|0;if((U|0)==0){aG=P}else{aG=c[(c[C>>2]|0)+((U-1|0)*12|0)+4>>2]|0}if((aG|0)==61){$=0;break L6831}else{P=aG;X=C;m=U}}break};case 56:{m=c[c[(c[36858]|0)+113712>>2]>>2]|0;X=c[m+(B*12|0)>>2]|0;gN(131072,c[m+(B*12|0)+4>>2]|0)|0;m=(X|0)==0;a[(c[36858]|0)+4176|0]=m&1;L7103:do{if(m){a[644842]=0}else{P=4096;W=644842;U=X;while(1){C=P-1|0;if((C|0)==0){break}Y=a[U]|0;a[W]=Y;if(Y<<24>>24==0){break L7103}else{P=C;W=W+1|0;U=U+1|0}}a[W]=0;if((a[U]|0)==0){break}else{aH=U}do{aH=aH+1|0;}while((a[aH]|0)!=0)}}while(0);if((a[607928]&1)!=0){X=c[191244]|0;m=(X|0)!=0?X:c[q>>2]|0;a3(22912,35,1,m|0)|0;m=c[191244]|0;X=(m|0)!=0?m:c[q>>2]|0;aZ(X|0)|0}a[_]=1;X=c[u>>2]|0;m=c[X+8>>2]|0;if((m|0)==0){aI=0;aJ=X;aK=m}else{U=c[(c[X>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((U|0)==4){$=-1;break L6831}else{aI=U;aJ=X;aK=m}}while(1){m=aJ+8|0;if((aK|0)==0){aL=0;aM=aJ;aN=aJ|0}else{X=aK-1|0;c[m>>2]=X;U=aJ|0;v_(c[(c[U>>2]|0)+(X*12|0)>>2]|0);aL=c[m>>2]|0;aM=c[u>>2]|0;aN=U}c[Z>>2]=c[(c[aN>>2]|0)+(aL*12|0)+8>>2];U=c[aM+8>>2]|0;if((U|0)==0){aO=aI}else{aO=c[(c[aM>>2]|0)+((U-1|0)*12|0)+4>>2]|0}if((aO|0)==4){$=-1;break L6831}else{aI=aO;aJ=aM;aK=U}}break};case 73:{U=4096;m=603809;X=x;while(1){W=U-1|0;if((W|0)==0){af=4981;break}P=a[X]|0;a[m]=P;if(P<<24>>24==0){break}else{U=W;m=m+1|0;X=X+1|0}}do{if((af|0)==4981){a[m]=0;if((a[X]|0)==0){break}else{aP=X}do{aP=aP+1|0;}while((a[aP]|0)!=0)}}while(0);X=4096;m=d+54|0;U=x;while(1){W=X-1|0;if((W|0)==0){af=4986;break}P=a[U]|0;a[m]=P;if(P<<24>>24==0){break}else{X=W;m=m+1|0;U=U+1|0}}do{if((af|0)==4986){a[m]=0;if((a[U]|0)==0){break}else{aQ=U}do{aQ=aQ+1|0;}while((a[aQ]|0)!=0)}}while(0);a[_]=1;U=c[u>>2]|0;m=c[U+8>>2]|0;if((m|0)==0){aR=0}else{X=c[(c[U>>2]|0)+((m-1|0)*12|0)+4>>2]|0;if((X|0)==61){$=0;break L6831}else{aR=X}}X=(Z|0)==0;W=aR;P=U;U=m;while(1){m=P+8|0;if((U|0)!=0){C=U-1|0;c[m>>2]=C;v_(c[(c[P>>2]|0)+(C*12|0)>>2]|0)}if(!X){c[Z>>2]=c[(c[P>>2]|0)+((c[m>>2]|0)*12|0)+8>>2]}m=c[u>>2]|0;C=c[m+8>>2]|0;if((C|0)==0){aS=W}else{aS=c[(c[m>>2]|0)+((C-1|0)*12|0)+4>>2]|0}if((aS|0)==61){$=0;break L6831}else{W=aS;P=m;U=C}}break};default:{gq(644842,x,N);U=764968;P=c[U+4>>2]|0;W=764968;c[W>>2]=c[U>>2]|2;c[W+4>>2]=P;a[_]=1;P=c[u>>2]|0;W=c[P+8>>2]|0;if((W|0)==0){aT=0;aU=P;aV=W;af=5070}else{U=c[(c[P>>2]|0)+((W-1|0)*12|0)+4>>2]|0;if((U|0)!=4){aT=U;aU=P;aV=W;af=5070}}if((af|0)==5070){while(1){af=0;W=aU+8|0;if((aV|0)==0){aW=0;aX=aU;aY=aU|0}else{P=aV-1|0;c[W>>2]=P;U=aU|0;v_(c[(c[U>>2]|0)+(P*12|0)>>2]|0);aW=c[W>>2]|0;aX=c[u>>2]|0;aY=U}c[Z>>2]=c[(c[aY>>2]|0)+(aW*12|0)+8>>2];U=c[aX+8>>2]|0;if((U|0)==0){a_=aT}else{a_=c[(c[aX>>2]|0)+((U-1|0)*12|0)+4>>2]|0}if((a_|0)==4){break}else{aT=a_;aU=aX;aV=U;af=5070}}}a[d+53|0]=1;$=-1;break L6831}}}}while(0);B=o|0;gq(B,x,N);E=c[u>>2]|0;U=c[Z>>2]|0;if((E|0)!=0){W=E+8|0;P=E+4|0;X=c[P>>2]|0;if((c[W>>2]|0)>>>0<X>>>0){a$=E|0}else{C=(X<<1)+2|0;c[P>>2]=C;P=E|0;c[P>>2]=v$(c[P>>2]|0,C*12|0)|0;a$=P}P=dn(B|0)|0;c[(c[a$>>2]|0)+((c[W>>2]|0)*12|0)>>2]=P;c[(c[a$>>2]|0)+((c[W>>2]|0)*12|0)+4>>2]=D;c[(c[a$>>2]|0)+((c[W>>2]|0)*12|0)+8>>2]=U;c[W>>2]=(c[W>>2]|0)+1}c[Z>>2]=0;a[_]=1;$=0;break};default:{$=0}}}while(0);a$=c[u>>2]|0;u=c[a$+8>>2]|0;if((u|0)==0){a0=w;a1=x}else{x=u-1|0;u=c[a$>>2]|0;a0=c[u+(x*12|0)+4>>2]|0;a1=c[u+(x*12|0)>>2]|0}L7168:do{if((a[_]&1)!=0){do{if((a0|0)!=1){x=a0-31|0;if(x>>>0<24&((x>>>0)%3|0|0)==0|(a0|0)==28){break}if((a0-73|0)>>>0<4|(a0|0)==78|(a0|0)==79){break}if(!((a0|0)==88|(a0|0)==71|(a0|0)==57|(a0|0)==56)){break L7168}}}while(0);a[_]=0;Z=d+44|0;D=c[Z>>2]|0;N=D+8|0;if((c[N>>2]|0)!=0){x=D|0;D=0;do{v_(c[(c[x>>2]|0)+(D*12|0)>>2]|0);D=D+1|0;}while(D>>>0<(c[N>>2]|0)>>>0)}c[N>>2]=0;L7180:do{if((a0|0)==56){D=k|0;x=l|0;u=d+113712|0;a$=c[u>>2]|0;w=c[a$+4>>2]|0;if((w|0)==0){break}else{a2=0;a4=a$}while(1){a$=c[a4>>2]|0;o=c[a$+(a2*12|0)>>2]|0;af=c[a$+(a2*12|0)+8>>2]|0;L7184:do{if((o|0)==0){a$=4096;aV=D;aX=af;while(1){aU=a$-1|0;if((aU|0)==0){break}a_=a[aX]|0;a[aV]=a_;if(a_<<24>>24==0){break L7184}else{a$=aU;aV=aV+1|0;aX=aX+1|0}}a[aV]=0;if((a[aX]|0)==0){break}else{a5=aX}do{a5=a5+1|0;}while((a[a5]|0)!=0)}else{aX=cf(o|0,47)|0;gr(x,(aX|0)==0?o:aX+1|0,766672);bN(D|0,4096,18576,(Q=i,i=i+16|0,c[Q>>2]=x,c[Q+8>>2]=af,Q)|0)|0;i=Q}}while(0);af=c[Z>>2]|0;if((af|0)!=0){o=af+8|0;aX=af+4|0;aV=c[aX>>2]|0;if((c[o>>2]|0)>>>0<aV>>>0){a6=af|0}else{a$=(aV<<1)+2|0;c[aX>>2]=a$;aX=af|0;c[aX>>2]=v$(c[aX>>2]|0,a$*12|0)|0;a6=aX}aX=dn(D|0)|0;c[(c[a6>>2]|0)+((c[o>>2]|0)*12|0)>>2]=aX;c[(c[a6>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=0;c[(c[a6>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1}o=a2+1|0;if(o>>>0>=w>>>0){break L7180}a2=o;a4=c[u>>2]|0}}else{u=c[Z>>2]|0;w=j|0;if((a[a1]|0)==0){if((u|0)==0){break}D=u+8|0;x=u+4|0;o=c[x>>2]|0;if((c[D>>2]|0)>>>0<o>>>0){a7=u|0}else{aX=(o<<1)+2|0;c[x>>2]=aX;x=u|0;c[x>>2]=v$(c[x>>2]|0,aX*12|0)|0;a7=x}x=dn(19832)|0;c[(c[a7>>2]|0)+((c[D>>2]|0)*12|0)>>2]=x;c[(c[a7>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=a0;c[(c[a7>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;break}do{if((a0|0)==28){a8=19560}else if((a0|0)==57){a8=766672}else{D=a0-31|0;if(D>>>0<24&((D>>>0)%3|0|0)==0){a8=19264;break}if((a0|0)==88){a8=19088;break}if((a0-73|0)>>>0<4|(a0|0)==78|(a0|0)==79){a8=766672;break}D=c[d+4168>>2]|0;if((D|0)==0){a8=702808;break}if((a[D]|0)==0){a[w]=0;a8=w;break}else{bN(w|0,1024,18864,(Q=i,i=i+8|0,c[Q>>2]=D,Q)|0)|0;i=Q;a8=w;break}}}while(0);w=gp(a1,a8,1)|0;if((w|0)==0){break}D=w|0;x=w+4|0;df(c[D>>2]|0,c[x>>2]|0,8,42);aX=(a0-73|0)>>>0<4|(a0|0)==78|(a0|0)==79;o=(u|0)==0;if(!(o|aX^1)){a$=u+8|0;af=u+4|0;aV=c[af>>2]|0;if((c[a$>>2]|0)>>>0<aV>>>0){a9=u|0}else{aU=(aV<<1)+2|0;c[af>>2]=aU;af=u|0;c[af>>2]=v$(c[af>>2]|0,aU*12|0)|0;a9=af}af=dn(18672)|0;c[(c[a9>>2]|0)+((c[a$>>2]|0)*12|0)>>2]=af;c[(c[a9>>2]|0)+((c[a$>>2]|0)*12|0)+4>>2]=3;c[(c[a9>>2]|0)+((c[a$>>2]|0)*12|0)+8>>2]=0;c[a$>>2]=(c[a$>>2]|0)+1}a$=c[x>>2]|0;do{if((a$|0)==0){ba=c[D>>2]|0}else{af=u+8|0;aU=u+4|0;aV=u|0;if(aX){a_=0;aT=a$;while(1){aW=c[D>>2]|0;do{if((a[aW+(a_<<3)+4|0]&1)==0){bb=aT}else{aY=c[aW+(a_<<3)>>2]|0;if((a[a1]|0)==0){bc=aY}else{aS=cf(aY|0,47)|0;bc=(aS|0)==0?aY:aS+1|0}if(o){bb=aT;break}aS=c[aU>>2]|0;if((c[af>>2]|0)>>>0>=aS>>>0){aY=(aS<<1)+2|0;c[aU>>2]=aY;c[aV>>2]=v$(c[aV>>2]|0,aY*12|0)|0}aY=dn(bc|0)|0;c[(c[aV>>2]|0)+((c[af>>2]|0)*12|0)>>2]=aY;c[(c[aV>>2]|0)+((c[af>>2]|0)*12|0)+4>>2]=a0;c[(c[aV>>2]|0)+((c[af>>2]|0)*12|0)+8>>2]=0;c[af>>2]=(c[af>>2]|0)+1;bb=c[x>>2]|0}}while(0);aW=a_+1|0;if(aW>>>0<bb>>>0){a_=aW;aT=bb}else{bd=bb;break}}}else{aT=0;a_=a$;while(1){aW=c[D>>2]|0;aY=a[aW+(aT<<3)+4|0]|0;aS=c[aW+(aT<<3)>>2]|0;if((a[a1]|0)==0){be=aS}else{aW=cf(aS|0,47)|0;be=(aW|0)==0?aS:aW+1|0}aW=(aY&1)!=0?a0:0;if(o){bf=a_}else{aY=c[aU>>2]|0;if((c[af>>2]|0)>>>0>=aY>>>0){aS=(aY<<1)+2|0;c[aU>>2]=aS;c[aV>>2]=v$(c[aV>>2]|0,aS*12|0)|0}aS=dn(be|0)|0;c[(c[aV>>2]|0)+((c[af>>2]|0)*12|0)>>2]=aS;c[(c[aV>>2]|0)+((c[af>>2]|0)*12|0)+4>>2]=aW;c[(c[aV>>2]|0)+((c[af>>2]|0)*12|0)+8>>2]=0;c[af>>2]=(c[af>>2]|0)+1;bf=c[x>>2]|0}aW=aT+1|0;if(aW>>>0<bf>>>0){aT=aW;a_=bf}else{bd=bf;break}}}a_=c[D>>2]|0;if((bd|0)==0){ba=a_;break}else{bg=0;bh=a_}while(1){v_(c[bh+(bg<<3)>>2]|0);a_=bg+1|0;aT=c[D>>2]|0;if(a_>>>0<(c[x>>2]|0)>>>0){bg=a_;bh=aT}else{ba=aT;break}}}}while(0);v_(ba);v_(w)}}while(0);N=d+48|0;x=c[(c[Z>>2]|0)+8>>2]|0;D=(x|0)==0;if(!((c[N>>2]|0)>>>0<x>>>0|D)){c[N>>2]=x-1;break}if(!D){break}c[N>>2]=0}}while(0);ip(d);z=$;i=e;return z|0}function im(b,d){b=b|0;d=d|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0.0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0.0,ae=0,af=0,ag=0.0,ah=0.0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,a_=0.0,a$=0,a0=0.0,a1=0,a2=0,a4=0,a5=0.0,a6=0,a7=0,a8=0.0,a9=0,ba=0.0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0;f=i;i=i+13184|0;j=f|0;k=f+128|0;l=f+192|0;m=f+256|0;n=f+320|0;o=f+384|0;p=f+448|0;r=f+512|0;s=f+4608|0;t=f+4672|0;u=f+8768|0;v=f+9024|0;w=f+9088|0;c[b+32>>2]=640;do{if((d|0)==6){x=0;y=0}else{z=c[b+48>>2]|0;A=c[c[b+44>>2]>>2]|0;B=c[A+(z*12|0)>>2]|0;C=c[A+(z*12|0)+4>>2]|0;if((C|0)==57){x=766672;y=57;break}else if((C|0)==71){x=b+54|0;y=71;break}else{x=B;y=C;break}}}while(0);C=b+40|0;B=c[C>>2]|0;z=B+8|0;A=c[z>>2]|0;if((A|0)==0){D=0}else{D=c[(c[B>>2]|0)+((A-1|0)*12|0)+4>>2]|0}E=b+52|0;F=(a[E]&1)==0?d:10;L7277:do{switch(F|0){case 1:{d=b+48|0;H=(c[d>>2]|0)+1|0;if(H>>>0<(c[(c[b+44>>2]|0)+8>>2]|0)>>>0){c[d>>2]=H;break L7277}else{c[d>>2]=0;break L7277}break};case 6:{c[b+48>>2]=0;a[E]=1;break};case 9:{a[b+53|0]=1;break};case 2:case 3:case 4:case 8:{d=(F|0)==4;if((y|0)==55&d){H=b+54|0;I=b+48|0;J=c[I>>2]|0;if((B|0)!=0){K=B+4|0;L=c[K>>2]|0;if(A>>>0<L>>>0){M=B|0}else{N=(L<<1)+2|0;c[K>>2]=N;K=B|0;c[K>>2]=v$(c[K>>2]|0,N*12|0)|0;M=K}K=dn(H|0)|0;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)>>2]=K;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=1;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=J;c[z>>2]=(c[z>>2]|0)+1}c[I>>2]=0;a[E]=1;break L7277}do{if((y|0)==56){if(!d){break L7277}}else{if(((y-73|0)>>>0<4|(y|0)==78|(y|0)==79)&d){break}L7298:do{switch(y|0){case 69:case 62:case 61:case 59:case 58:case 26:case 5:case 4:case 60:case 71:case 57:{if(!d){break L7298}I=b+48|0;J=c[I>>2]|0;if((B|0)!=0){K=B+4|0;H=c[K>>2]|0;if(A>>>0<H>>>0){O=B|0}else{N=(H<<1)+2|0;c[K>>2]=N;K=B|0;c[K>>2]=v$(c[K>>2]|0,N*12|0)|0;O=K}K=dn(x|0)|0;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)>>2]=K;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=J;c[z>>2]=(c[z>>2]|0)+1}c[I>>2]=0;a[E]=1;break L7277;break};default:{if(!((y|0)==12&d)){break L7298}I=c[b+48>>2]|0;if((B|0)!=0){J=B+4|0;K=c[J>>2]|0;if(A>>>0<K>>>0){P=B|0}else{N=(K<<1)+2|0;c[J>>2]=N;J=B|0;c[J>>2]=v$(c[J>>2]|0,N*12|0)|0;P=J}J=dn(766672)|0;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)>>2]=J;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=12;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=I;c[z>>2]=(c[z>>2]|0)+1}fa[c[(c[191559]|0)+44>>2]&127](c[191562]|0,764916);g[3053]=+((c[191231]|0)>>>0>>>0)/+((c[191232]|0)>>>0>>>0);c[126408]=7;I=c[(c[191610]|0)+12>>2]|0;if((I|0)==0){break L7277}fa[I&127](c[191562]|0,7);break L7277}}}while(0);I=b+113708|0;J=c[I>>2]|0;if((y-6|0)>>>0<20){switch(y|0){case 20:{N=c[126403]|0;if((F|0)==8){c[126403]=1;Q=1}else if((F|0)==2){K=N-1|0;c[126403]=K;Q=K}else if((F|0)==3|(F|0)==4){K=N+1|0;c[126403]=K;Q=K}else{Q=N}K=Q>>>0<4?Q:4;H=K>>>0>1?K:1;c[126403]=H;K=c[191559]|0;L=c[191562]|0;if(!((N|0)!=(H|0)&(K|0)!=0&(L|0)!=0)){break L7277}fa[c[K+8>>2]&127](L,0);break L7277;break};case 19:{if((F|0)==8){a[505610]=0;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){a[505610]=a[505610]&1^1;break L7277}else{break L7277}break};case 7:{if((F|0)==8){R=1}else{R=a[505620]&1^1}a[505620]=R;L=c[c[191610]>>2]|0;if((L|0)==0){break L7277}fw[L&127](c[191562]|0,1,(R&1)!=0);break L7277;break};case 14:{if(!d){break L7277}f1((a[505592]&1)==0);break L7277;break};case 24:{if((F|0)==8){L=756280;c[L>>2]=0;c[L+4>>2]=0;break L7277}else if((F|0)!=4){break L7277}if((a[513836]&1)!=0){break L7277}L=756280;K=c[L>>2]|0;H=c[L+4>>2]|0;L=0;N=H>>>0>L>>>0|H>>>0==L>>>0&K>>>0>2048>>>0?2048:K;if(N>>>0<2){break L7277}else{S=0;T=0;U=0}do{K=739896+(S<<3)|0;U=wc(c[K>>2]|0,c[K+4>>2]|0,U,T)|0;T=G;S=S+1|0;}while(S>>>0<N>>>0);K=wk(U,T,N,0)|0;V=1.0e6/(+(K>>>0)+ +(G|0)*4294967296.0);K=u|0;bN(K|0,256,27080,(W=i,i=i+8|0,h[W>>3]=V,W)|0)|0;i=W;L=c[189113]|0;H=L+4|0;L7348:do{if((c[H>>2]|0)>>>0<(c[L+8>>2]|0)>>>0){X=vZ(12)|0;do{if((X|0)!=0){if((c[X-4>>2]&3|0)==0){break}v3(X|0,0,12)}}while(0);c[X+4>>2]=1;c[X>>2]=180;Y=dn(K|0)|0;Z=c[H>>2]|0;c[X+8>>2]=Y;Y=L|0;c[(c[Y>>2]|0)+(Z<<2)>>2]=X;Z=c[H>>2]|0;c[H>>2]=Z+1;if(Z>>>0>1){_=Z}else{break}while(1){Z=_>>>1;$=c[Y>>2]|0;aa=$+(Z<<2)|0;ab=c[aa>>2]|0;ac=c[$+(_<<2)>>2]|0;if((c[ac+4>>2]|0)>>>0<=(c[ab+4>>2]|0)>>>0){break L7348}c[aa>>2]=ac;c[(c[Y>>2]|0)+(_<<2)>>2]=ab;if(_>>>0>3){_=Z}else{break}}}}while(0);if((a[607928]&1)!=0){H=c[191244]|0;L=(H|0)!=0?H:c[q>>2]|0;eb(L|0,47400,(W=i,i=i+8|0,c[W>>2]=K,W)|0)|0;i=W;L=c[191244]|0;H=(L|0)!=0?L:c[q>>2]|0;aZ(H|0)|0}g[128458]=V;gu();ad=+((c[130526]|0)>>>0>>>0)/+g[130528];h[88381]=ad;h[88387]=ad;fa[c[(c[191559]|0)+8>>2]&127](c[191562]|0,0);break L7277;break};case 15:{if((F|0)==3){H=c[191235]|0;if(H>>>0<3){L=H+1|0;c[191235]=L;ae=L}else{ae=H}fa[c[(c[191559]|0)+40>>2]&127](c[191562]|0,ae);break L7277}else if((F|0)==8){g[132579]=.004999999888241291;a[530313]=1;fa[c[(c[191559]|0)+40>>2]&127](c[191562]|0,c[191235]|0);break L7277}else if((F|0)==2){H=c[191235]|0;if((H|0)==0){af=0}else{L=H-1|0;c[191235]=L;af=L}fa[c[(c[191559]|0)+40>>2]&127](c[191562]|0,af);break L7277}else{break L7277}break};case 23:{if((F|0)==8){a[505622]=1;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){a[505622]=a[505622]&1^1;break L7277}else{break L7277}break};case 10:{do{if((F|0)==8){a[505629]=0}else{if((F-2|0)>>>0>=3){break}a[505629]=a[505629]&1^1}}while(0);K=c[(c[191610]|0)+16>>2]|0;if((K|0)==0){break L7277}e9[K&2047](c[191562]|0);break L7277;break};case 17:{if((F|0)==8){a[505609]=0;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){a[505609]=a[505609]&1^1;break L7277}else{break L7277}break};case 18:{if((F|0)==8){c[126404]=0;break L7277}else if((F|0)==2){K=c[126404]|0;if((K|0)==0){break L7277}c[126404]=K-1;break L7277}else if((F|0)==3|(F|0)==4){K=c[126404]|0;if(K>>>0>=3){break L7277}c[126404]=K+1;break L7277}else{break L7277}break};case 9:{if((F|0)==2){K=c[191236]|0;if((K|0)==0){break L7277}c[191236]=K-1;K=c[(c[191610]|0)+16>>2]|0;if((K|0)==0){break L7277}e9[K&2047](c[191562]|0);break L7277}else if((F|0)==8){c[191236]=0;K=c[(c[191610]|0)+16>>2]|0;if((K|0)==0){break L7277}e9[K&2047](c[191562]|0);break L7277}else{if(!((F|0)==3&(c[191236]|0)==0)){break L7277}c[191236]=1;K=c[(c[191610]|0)+16>>2]|0;if((K|0)==0){break L7277}e9[K&2047](c[191562]|0);break L7277}break};case 21:case 22:{K=(y|0)==21?505584:505588;V=+g[K>>2];if((F|0)==3){ad=V+1.0;g[K>>2]=ad;ag=ad}else if((F|0)==8){g[K>>2]=3.0;ag=3.0}else if((F|0)==2){ad=V+-1.0;g[K>>2]=ad;ag=ad}else{ag=V}ad=+bH(+ag);ah=ad>1.0?ad:1.0;g[K>>2]=ah;if(V==ah){break L7277}if((a[505592]&1)!=0){break L7277}f1(0);break L7277;break};case 16:{if((F|0)==8){a[505608]=1;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){a[505608]=a[505608]&1^1;break L7277}else{break L7277}break};case 11:{do{if((F|0)==3){K=c[126408]|0;if(K>>>0>=7){break}c[126408]=K+1}else if((F|0)==8){c[126408]=4}else if((F|0)==2){K=c[126408]|0;if((K|0)==0){break}c[126408]=K-1}}while(0);K=c[(c[191610]|0)+12>>2]|0;if((K|0)==0){break L7277}fa[K&127](c[191562]|0,c[126408]|0);break L7277;break};default:{break L7277}}}if((y-27|0)>>>0<28){K=w|0;L=y-31|0;H=y-32|0;N=y-33|0;if((y|0)==29){if(!((c[(c[191559]|0)+20>>2]|0)!=0&d)){break L7277}if((a[607928]&1)!=0){Y=c[191244]|0;X=(Y|0)!=0?Y:c[q>>2]|0;a3(44912,31,1,X|0)|0;X=c[191244]|0;Y=(X|0)!=0?X:c[q>>2]|0;aZ(Y|0)|0}Y=b+4252|0;X=c[Y>>2]|0;L7434:do{if((X|0)!=0){Z=3;ab=0;while(1){ac=h0(b+4256+(ab*4148|0)|0,3)|0;if(!((ac|0)==0|(ac|0)==2)){break L7434}if((Z|0)==3){ai=ac}else{if((Z|0)==(ac|0)){ai=Z}else{break L7434}}ac=ab+1|0;if(ac>>>0<X>>>0){Z=ai;ab=ac}else{break}}if((ai|0)==3){break}gq(K,(a[513837]|0)!=0?513837:599676,(ai|0)==2?44872:44784);ab=vZ(20)|0;if((ab|0)==0){break L7277}if((c[ab-4>>2]&3|0)!=0){v3(ab|0,0,20)}Z=ab;ab=p|0;ac=r|0;aa=s|0;$=t|0;aj=j|0;bN(aj|0,128,27712,(W=i,i=i+8|0,c[W>>2]=c[Y>>2],W)|0)|0;i=W;gJ(Z,45672,aj);if((c[Y>>2]|0)!=0){ak=l|0;al=k|0;am=0;do{bN(ab|0,64,29568,(W=i,i=i+8|0,c[W>>2]=am,W)|0)|0;i=W;gJ(Z,ab,b+4256+(am*4148|0)|0);an=b+4256+(am*4148|0)+4136|0;if((c[an>>2]|0)!=0){bN(ab|0,64,29152,(W=i,i=i+8|0,c[W>>2]=am,W)|0)|0;i=W;gJ(Z,ab,(c[an>>2]|0)==1?49992:20464)}bN(ab|0,64,28440,(W=i,i=i+8|0,c[W>>2]=am,W)|0)|0;i=W;an=c[b+4256+(am*4148|0)+4140>>2]|0;if((an|0)==1){ao=18584}else if((an|0)==2){ao=18448}else if((an|0)==3){ao=18288}else if((an|0)==0){ao=18696}else{ao=18080}gJ(Z,ab,ao);an=b+4256+(am*4148|0)+4144|0;if((c[an>>2]|0)!=0){bN(ab|0,64,28032,(W=i,i=i+8|0,c[W>>2]=am,W)|0)|0;i=W;ap=c[an>>2]|0;bN(aj|0,128,27712,(W=i,i=i+8|0,c[W>>2]=ap,W)|0)|0;i=W;gJ(Z,ab,aj)}bN(ak|0,64,20184,(W=i,i=i+8|0,c[W>>2]=am,W)|0)|0;i=W;gJ(Z,ak,(a[b+4256+(am*4148|0)+4132|0]&1)!=0?49992:20464);do{if((a[b+4256+(am*4148|0)+4104|0]&1)!=0){ap=c[b+4256+(am*4148|0)+4108>>2]|0;ah=+g[b+4256+(am*4148|0)+4116>>2];an=c[b+4256+(am*4148|0)+4124>>2]|0;bN(al|0,64,19840,(W=i,i=i+16|0,c[W>>2]=20088,c[W+8>>2]=am,W)|0)|0;i=W;if((ap|0)==0){aq=19272}else if((ap|0)==2){aq=19096}else if((ap|0)==1){aq=18872}else{aq=20272}gJ(Z,al,aq);bN(al|0,64,19648,(W=i,i=i+16|0,c[W>>2]=20088,c[W+8>>2]=am,W)|0)|0;i=W;if((ap|0)==1){bN(aj|0,128,27712,(W=i,i=i+8|0,c[W>>2]=an,W)|0)|0;i=W;gJ(Z,al,aj)}else{V=ah;bN(aj|0,128,14680,(W=i,i=i+8|0,h[W>>3]=V,W)|0)|0;i=W;gJ(Z,al,aj)}an=c[b+4256+(am*4148|0)+4112>>2]|0;V=+g[b+4256+(am*4148|0)+4120>>2];ap=c[b+4256+(am*4148|0)+4128>>2]|0;bN(al|0,64,19840,(W=i,i=i+16|0,c[W>>2]=19944,c[W+8>>2]=am,W)|0)|0;i=W;if((an|0)==0){ar=19272}else if((an|0)==2){ar=19096}else if((an|0)==1){ar=18872}else{ar=20272}gJ(Z,al,ar);bN(al|0,64,19648,(W=i,i=i+16|0,c[W>>2]=19944,c[W+8>>2]=am,W)|0)|0;i=W;if((an|0)==1){bN(aj|0,128,27712,(W=i,i=i+8|0,c[W>>2]=ap,W)|0)|0;i=W;gJ(Z,al,aj);break}else{ah=V;bN(aj|0,128,14680,(W=i,i=i+8|0,h[W>>3]=ah,W)|0)|0;i=W;gJ(Z,al,aj);break}}}while(0);am=am+1|0;}while(am>>>0<(c[Y>>2]|0)>>>0)}am=b+70624|0;do{if((c[am>>2]|0)!=0){v3(ac|0,0,4096);al=4096;ak=ac;ab=b+70628|0;while(1){ap=al-1|0;if((ap|0)==0){as=5348;break}an=a[ab]|0;a[ak]=an;if(an<<24>>24==0){break}else{al=ap;ak=ak+1|0;ab=ab+1|0}}do{if((as|0)==5348){a[ak]=0;if((a[ab]|0)==0){break}else{at=ab}do{at=at+1|0;}while((a[at]|0)!=0)}}while(0);if((c[am>>2]|0)>>>0>1){ab=1;do{ak=v2(ac|0)|0;al=ak>>>0>4096?0:4096-ak|0;L7497:do{if((al|0)==0){au=27720;as=5355}else{ap=r+ak|0;do{if((al|0)==1){av=27720;aw=ap}else{an=r+(ak+1)|0;a[ap]=59;if((al|0)==2){av=27721;aw=an;break}a[an]=0;break L7497}}while(0);a[aw]=0;au=av;as=5355}}while(0);do{if((as|0)==5355){as=0;if((a[au]|0)==0){break}else{ax=au}do{ax=ax+1|0;}while((a[ax]|0)!=0)}}while(0);al=b+70628+(ab*4168|0)|0;ak=v2(ac|0)|0;ap=ak>>>0>4096?0:4096-ak|0;L7508:do{if((ap|0)==0){ay=al;as=5362}else{an=ap;az=r+ak|0;aA=al;while(1){aB=an-1|0;if((aB|0)==0){break}aC=a[aA]|0;a[az]=aC;if(aC<<24>>24==0){break L7508}else{an=aB;az=az+1|0;aA=aA+1|0}}a[az]=0;ay=aA;as=5362}}while(0);do{if((as|0)==5362){as=0;if((a[ay]|0)==0){break}else{aD=ay}do{aD=aD+1|0;}while((a[aD]|0)!=0)}}while(0);ab=ab+1|0;}while(ab>>>0<(c[am>>2]|0)>>>0)}gJ(Z,27376,ac);if((c[am>>2]|0)==0){break}else{aE=0}do{ab=b+70628+(aE*4168|0)|0;gJ(Z,ab,b+70628+(aE*4168|0)+64|0);aA=b+70628+(aE*4168|0)+4160|0;if((c[aA>>2]|0)!=0){bN(aa|0,64,27056,(W=i,i=i+8|0,c[W>>2]=ab,W)|0)|0;i=W;gJ(Z,aa,(c[aA>>2]|0)!=1?49992:20464)}bN(aa|0,64,26664,(W=i,i=i+8|0,c[W>>2]=ab,W)|0)|0;i=W;ab=c[b+70628+(aE*4168|0)+4164>>2]|0;if((ab|0)==2){aF=18448}else if((ab|0)==3){aF=18288}else if((ab|0)==0){aF=18696}else if((ab|0)==1){aF=18584}else{aF=18080}gJ(Z,aa,aF);aE=aE+1|0;}while(aE>>>0<(c[am>>2]|0)>>>0)}}while(0);am=b+109096|0;if((a[am]|0)!=0){gJ(Z,26408,am)}am=b+113196|0;if((a[am]|0)!=0){gJ(Z,25984,am)}am=b+103972|0;L7538:do{if((c[am>>2]|0)!=0){v3($|0,0,4096);aa=4096;ac=$;ab=b+103976|0;while(1){aA=aa-1|0;if((aA|0)==0){as=5382;break}az=a[ab]|0;a[ac]=az;if(az<<24>>24==0){break}else{aa=aA;ac=ac+1|0;ab=ab+1|0}}do{if((as|0)==5382){a[ac]=0;if((a[ab]|0)==0){break}else{aG=ab}do{aG=aG+1|0;}while((a[aG]|0)!=0)}}while(0);if((c[am>>2]|0)>>>0>1){ab=1;do{ac=v2($|0)|0;aa=ac>>>0>4096?0:4096-ac|0;L7551:do{if((aa|0)==0){aH=27720;as=5389}else{aA=t+ac|0;do{if((aa|0)==1){aI=27720;aJ=aA}else{az=t+(ac+1)|0;a[aA]=59;if((aa|0)==2){aI=27721;aJ=az;break}a[az]=0;break L7551}}while(0);a[aJ]=0;aH=aI;as=5389}}while(0);do{if((as|0)==5389){as=0;if((a[aH]|0)==0){break}else{aK=aH}do{aK=aK+1|0;}while((a[aK]|0)!=0)}}while(0);aa=b+103976+(ab*80|0)|0;ac=v2($|0)|0;aA=ac>>>0>4096?0:4096-ac|0;L7562:do{if((aA|0)==0){aL=aa;as=5396}else{az=aA;al=t+ac|0;ak=aa;while(1){ap=az-1|0;if((ap|0)==0){break}an=a[ak]|0;a[al]=an;if(an<<24>>24==0){break L7562}else{az=ap;al=al+1|0;ak=ak+1|0}}a[al]=0;aL=ak;as=5396}}while(0);do{if((as|0)==5396){as=0;if((a[aL]|0)==0){break}else{aM=aL}do{aM=aM+1|0;}while((a[aM]|0)!=0)}}while(0);ab=ab+1|0;}while(ab>>>0<(c[am>>2]|0)>>>0)}gJ(Z,25640,$);if((c[am>>2]|0)==0){break}ab=k|0;ak=l|0;al=m|0;aa=n|0;ac=o|0;aA=0;while(1){az=b+103976+(aA*80|0)|0;bN(ab|0,64,23584,(W=i,i=i+8|0,c[W>>2]=az,W)|0)|0;i=W;bN(ak|0,64,23376,(W=i,i=i+8|0,c[W>>2]=az,W)|0)|0;i=W;bN(al|0,64,23056,(W=i,i=i+8|0,c[W>>2]=az,W)|0)|0;i=W;bN(aa|0,64,22848,(W=i,i=i+8|0,c[W>>2]=az,W)|0)|0;i=W;bN(ac|0,64,22568,(W=i,i=i+8|0,c[W>>2]=az,W)|0)|0;i=W;switch(c[b+103976+(aA*80|0)+68>>2]|0){case 2:{aN=21960;break};case 3:{aN=21360;break};case 1:{aN=20992;break};case 4:{aN=20488;break};case 5:{aN=20336;break};case 0:{aN=22440;break};default:{aN=20272}}gJ(Z,ab,aN);bN(aj|0,128,50440,(W=i,i=i+8|0,c[W>>2]=e[b+103976+(aA*80|0)+76>>1]|0,W)|0)|0;i=W;gJ(Z,aa,aj);bN(aj|0,128,50440,(W=i,i=i+8|0,c[W>>2]=e[b+103976+(aA*80|0)+78>>1]|0,W)|0)|0;i=W;gJ(Z,ac,aj);az=c[b+103976+(aA*80|0)+72>>2]|0;if((az|0)==1){ap=c[b+103976+(aA*80|0)+64>>2]|0;bN(aj|0,128,50440,(W=i,i=i+8|0,c[W>>2]=ap,W)|0)|0;i=W;gJ(Z,ak,aj)}else if((az|0)==2){bN(aj|0,128,27712,(W=i,i=i+8|0,c[W>>2]=1,W)|0)|0;i=W;gJ(Z,al,aj)}else if((az|0)==3){bN(aj|0,128,27712,(W=i,i=i+8|0,c[W>>2]=2,W)|0)|0;i=W;gJ(Z,al,aj)}aA=aA+1|0;if(aA>>>0>=(c[am>>2]|0)>>>0){break L7538}}}}while(0);gK(Z,K)|0;gE(Z);io(0,ai,K);break L7277}}while(0);K=h0(766672,2)|0;io(0,(K|0)==3?2:K,0);break L7277}else if((y|0)==30){do{if((F|0)==8){c[b+4252>>2]=0}else if((F|0)==2){K=b+4252|0;Y=c[K>>2]|0;if((Y|0)==0){break}c[K>>2]=Y-1}else if((F|0)==3|(F|0)==4){Y=b+4252|0;K=c[Y>>2]|0;if(K>>>0>=8){break}c[Y>>2]=K+1}}while(0);a[E]=1;break L7277}else if((y|0)==27){if((F|0)==8){a[505620]=1;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){a[505620]=a[505620]&1^1;break L7277}else{break L7277}}else{K=(y|0)==28;if(!(((L>>>0)%3|0|0)==0|K)){if(((H>>>0)%3|0|0)==0){Y=(H>>>0)/3|0;if((F|0)==8){c[b+4256+(Y*4148|0)+4136>>2]=0;break L7277}else if((F|0)==2|(F|0)==3|(F|0)==4){X=b+4256+(Y*4148|0)+4136|0;c[X>>2]=(((c[X>>2]|0)+((F|0)==2?2:1)|0)>>>0)%3|0;break L7277}else{break L7277}}if(((N>>>0)%3|0|0)!=0){break L7277}X=(N>>>0)/3|0;if((F|0)==2|(F|0)==3|(F|0)==4){Y=b+4256+(X*4148|0)+4116|0;am=((~~+g[Y>>2]+((F|0)==2?5:1)|0)>>>0)%6|0;a[b+4256+(X*4148|0)+4104|0]=(am|0)!=0|0;ah=+(am>>>0>>>0);g[b+4256+(X*4148|0)+4120>>2]=ah;g[Y>>2]=ah;break L7277}else if((F|0)==8){g[b+4256+(X*4148|0)+4120>>2]=0.0;g[b+4256+(X*4148|0)+4116>>2]=0.0;a[b+4256+(X*4148|0)+4104|0]=0;break L7277}else{break L7277}}if(K){aO=b+4256+(((L>>>0)/3|0)*4148|0)|0}else{aO=0}if((F|0)==8){if((aO|0)==0){break L7277}a[aO|0]=0;break L7277}else if((F|0)!=4){break L7277}K=b+48|0;X=c[K>>2]|0;if((B|0)!=0){Y=B+4|0;am=c[Y>>2]|0;if(A>>>0<am>>>0){aP=B|0}else{aj=(am<<1)+2|0;c[Y>>2]=aj;Y=B|0;c[Y>>2]=v$(c[Y>>2]|0,aj*12|0)|0;aP=Y}Y=dn(513837)|0;c[(c[aP>>2]|0)+((c[z>>2]|0)*12|0)>>2]=Y;c[(c[aP>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[aP>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=X;c[z>>2]=(c[z>>2]|0)+1}c[K>>2]=0;a[E]=1;break L7277}}if(y>>>0>65535){K=y-65536|0;if((F|0)==2){X=c[176752]|0;Y=c[X+4100>>2]|0;aj=Y+(K<<4)+12|0;am=c[(c[Y+(K<<4)+8>>2]|0)+4>>2]|0;c[aj>>2]=(((c[aj>>2]|0)-1+am|0)>>>0)%(am>>>0)|0;a[X+4108|0]=1;break L7277}else if((F|0)==3|(F|0)==4){X=c[176752]|0;am=c[X+4100>>2]|0;aj=am+(K<<4)+12|0;c[aj>>2]=(((c[aj>>2]|0)+1|0)>>>0)%((c[(c[am+(K<<4)+8>>2]|0)+4>>2]|0)>>>0)|0;a[X+4108|0]=1;break L7277}else if((F|0)==8){X=c[176752]|0;c[(c[X+4100>>2]|0)+(K<<4)+12>>2]=0;a[X+4108|0]=1;break L7277}else{break L7277}}L7640:do{switch(y|0){case 93:{X=607932+(J<<2)|0;K=c[X>>2]|0;am=0;while(1){if(am>>>0>=8){aQ=0;break}if((K|0)==(c[1976+(am<<2)>>2]|0)){aQ=am;break}else{am=am+1|0}}if((F|0)==2){aR=c[1976+((aQ+7&7)<<2)>>2]|0}else if((F|0)==3|(F|0)==4){aR=c[1976+((aQ+1&7)<<2)>>2]|0}else if((F|0)==8){aR=1}else{break L7277}c[X>>2]=aR;fa[c[37198]&127](J,aR);break L7277;break};case 94:{am=566852+(J<<2)|0;K=c[am>>2]|0;Z=K+4|0;c[am>>2]=Z;if((F|0)==8){c[am>>2]=1;aS=1}else if((F|0)==2){aj=K+3|0;c[am>>2]=aj;aS=aj}else if((F|0)==3){aj=K+5|0;c[am>>2]=aj;aS=aj}else{aS=Z}Z=aS&3;c[am>>2]=Z;am=c[(c[191560]|0)+20>>2]|0;if((am|0)==0){break L7277}if((Z|0)==2){aT=128}else if((Z|0)==0){aT=32}else if((Z|0)==1){aT=64}else{break L7277}e8[am&15](c[191563]|0,c[566308+(J<<2)>>2]|0,J,0,aT);break L7277;break};case 87:{if(!d){break L7277}am=764968;Z=c[am+4>>2]|0;aj=764968;c[aj>>2]=c[am>>2]&-2;c[aj+4>>2]=Z;aU=-1;i=f;return aU|0};case 88:{if((F|0)==4){Z=b+48|0;aj=c[Z>>2]|0;if((B|0)!=0){am=B+4|0;K=c[am>>2]|0;if(A>>>0<K>>>0){aV=B|0}else{Y=(K<<1)+2|0;c[am>>2]=Y;am=B|0;c[am>>2]=v$(c[am>>2]|0,Y*12|0)|0;aV=am}am=dn(685802)|0;c[(c[aV>>2]|0)+((c[z>>2]|0)*12|0)>>2]=am;c[(c[aV>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=88;c[(c[aV>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=aj;c[z>>2]=(c[z>>2]|0)+1}c[Z>>2]=0;a[E]=1;break L7277}else if((F|0)!=8){break L7277}Z=c[191604]|0;if((Z|0)!=0){aj=Z+24|0;am=Z+12|0;Y=c[am>>2]|0;if((c[aj>>2]|0)==0){aW=Y}else{K=0;$=Y;while(1){v_(c[$+(K*136|0)>>2]|0);v_(c[$+(K*136|0)+8>>2]|0);Y=K+1|0;aA=c[am>>2]|0;if(Y>>>0<(c[aj>>2]|0)>>>0){K=Y;$=aA}else{aW=aA;break}}}v_(aW);$=c[Z+4>>2]|0;if(($|0)!=0){fa[c[$>>2]&127](c[Z>>2]|0,0)}v_(Z)}c[191604]=0;a[566896]=0;break L7277;break};case 63:{if((F|0)==8){a[603772]=0;$=c[189115]|0;if(($|0)!=0){v_(c[$>>2]|0);v_(c[$+12>>2]|0);v_($)}c[189115]=0;v_(c[189116]|0);c[189116]=0;break L7277}else if(!((F|0)==4|(F|0)==3|(F|0)==2)){break L7277}$=a[603772]&1;a[603772]=$^1;if($<<24>>24==0){fZ();break L7277}$=c[189115]|0;if(($|0)!=0){v_(c[$>>2]|0);v_(c[$+12>>2]|0);v_($)}c[189115]=0;v_(c[189116]|0);c[189116]=0;break L7277;break};case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:case 105:case 106:case 107:case 108:case 109:case 110:{$=c[(c[191560]|0)+20>>2]|0;if(($|0)==0){break L7640}if((F|0)==2){aX=2}else if((F|0)==8){aX=8}else{K=(F|0)==3;if(K){aX=K?4:0}else{break L7640}}K=y-95|0;e8[$&15](c[191563]|0,c[566308+(K<<2)>>2]|0,J,c[2080+(K<<2)>>2]|0,aX);break};case 73:{break};case 76:{if((F|0)!=8){break L7277}a[677610]=0;break L7277;break};case 78:{if((F|0)!=8){break L7277}a[685802]=0;break L7277;break};case 75:{if((F|0)!=8){break L7277}a[681706]=0;break L7277;break};case 74:{if((F|0)!=8){break L7277}a[513837]=0;break L7277;break};case 79:{if((F|0)!=8){break L7277}a[599676]=0;break L7277;break};case 90:{if((F|0)==2){ah=+g[142749]+-.009999999776482582;g[142749]=ah;aY=1;a_=ah;as=5544}else if((F|0)==3|(F|0)==4){ah=+g[142749]+.009999999776482582;g[142749]=ah;aY=1;a_=ah;as=5544}else if((F|0)==8){g[142749]=1.0;a$=1;a0=1.0}else{aY=0;a_=+g[142749];as=5544}do{if((as|0)==5544){if(a_<.009999999776482582){g[142749]=.009999999776482582;a$=aY;a0=.009999999776482582;break}if(a_<=2.0){a$=aY;a0=a_;break}g[142749]=2.0;a$=aY;a0=2.0}}while(0);Z=c[191604]|0;if(!(a$&(Z|0)!=0)){break L7277}hG(Z,a0);break L7277;break};case 91:{if((F|0)==8){c[I>>2]=0;break L7277}else if((F|0)==2){if((J|0)==0){break L7277}c[I>>2]=J-1;break L7277}else if((F|0)==3){if(J>>>0>=7){break L7277}c[I>>2]=J+1;break L7277}else{break L7277}break};case 92:{Z=(c[191560]|0)+20|0;if((c[Z>>2]|0)==0){K=566276+(J<<2)|0;if((F|0)==8){c[K>>2]=J;a1=J}else if((F|0)==2){$=(c[K>>2]|0)-1|0;c[K>>2]=$;a1=$}else if((F|0)==3){$=(c[K>>2]|0)+1|0;c[K>>2]=$;a1=$}else{a1=c[K>>2]|0}if((a1|0)<-1){c[K>>2]=-1;break L7277}if((a1|0)<=7){break L7277}c[K>>2]=7;break L7277}else{K=566308+(J<<2)|0;$=c[K>>2]|0;if((F|0)==3){aj=$+1|0;c[K>>2]=aj;a2=aj}else if((F|0)==8){c[K>>2]=0;a2=0}else if((F|0)==2){aj=$-1|0;c[K>>2]=aj;a2=aj}else{a2=$}$=c[566852+(J<<2)>>2]|0;if(($|0)==1){a4=80}else if(($|0)==2){a4=144}else if(($|0)==0){a4=48}else{a4=16}e8[c[Z>>2]&15](c[191563]|0,a2,J,0,a4);break L7277}break};case 72:{if(!d){break L7277}do{if((a[522063]&1)!=0|(c[176735]|0)!=0){Z=c[191610]|0;do{if((Z|0)!=0){$=c[Z+24>>2]|0;if(($|0)==0){break}fw[$&127](c[191562]|0,0,0)}}while(0);if((c[191559]|0)==0){break}fU()}}while(0);fT();break L7277;break};case 80:{if(!d){break L7277}f2();Z=764968;$=c[Z+4>>2]|0;aj=764968;c[aj>>2]=c[Z>>2]|1;c[aj+4>>2]=$;aU=-1;i=f;return aU|0};case 81:{if((F|0)==8){a[707057]=0;break L7277}else{a[707057]=a[707057]&1^1;break L7277}break};case 64:{if((F-3|0)>>>0<2){c[150945]=(c[150945]|0)+1;break L7277}if((F|0)==8){c[150945]=1;break L7277}else if((F|0)!=2){break L7277}$=c[150945]|0;if($>>>0<=1){break L7277}c[150945]=$-1;break L7277;break};case 65:{if((F-3|0)>>>0<2|(F|0)==2){a[764982]=a[764982]&1^1;break L7277}if((F|0)!=8){break L7277}a[764982]=1;break L7277;break};case 67:case 68:{if((F|0)==3){c[175548]=(c[175548]|0)+1;break L7277}else if((F|0)==4){if((y|0)==67){f0()}else{f_()}$=764968;aj=c[$+4>>2]|0;Z=764968;c[Z>>2]=c[$>>2]|1;c[Z+4>>2]=aj;aU=-1;i=f;return aU|0}else if((F|0)==8){c[175548]=0;break L7277}else if((F|0)==2){aj=c[175548]|0;if((aj|0)==0){break L7277}c[175548]=aj-1;break L7277}else{break L7277}break};case 82:{if((F|0)==8){g[132579]=.004999999888241291;a[530313]=1;break L7277}else if((F|0)==2){ah=+g[132579];if(ah>0.0){V=ah+-.001;g[132579]=V;a5=V}else{a5=ah}if(a5<5.0e-4){a[530313]=0;g[132579]=0.0;break L7277}else{a[530313]=1;break L7277}}else if((F|0)==3){ah=+g[132579];if(ah<.2){g[132579]=ah+.001}a[530313]=1;break L7277}else{break L7277}break};case 84:{if((F|0)==8|(F|0)==2){aj=764968;Z=c[aj+4>>2]|0;$=764968;c[$>>2]=c[aj>>2]&-257;c[$+4>>2]=Z;break L7277}else if((F|0)==3){Z=764968;$=c[Z+4>>2]|0;aj=764968;c[aj>>2]=c[Z>>2]|256;c[aj+4>>2]=$;break L7277}else{break L7277}break};case 70:{$=fu[c[176732]&31]()|0;aj=fu[c[176730]&31]()|0;if((F-3|0)>>>0<2){a6=1}else{Z=(F|0)==2;if(Z){a6=Z<<31>>31}else{break L7277}}Z=$+1|0;f4(1,0);f5(((aj+Z+a6|0)>>>0)%(Z>>>0)|0);f4(0,0);break L7277;break};case 85:{if(!d){break L7277}Z=764968;aj=c[Z+4>>2]|0|0;$=764968;c[$>>2]=c[Z>>2]&-1026|1024;c[$+4>>2]=aj;aU=-1;i=f;return aU|0};case 86:{if(!d){break L7277}if((a[764980]&1)==0){break L7277}aj=764968;$=c[aj+4>>2]|0;Z=764968;c[Z>>2]=c[aj>>2]|1;c[Z+4>>2]=$;aU=-1;i=f;return aU|0};case 89:{if((F|0)==2){ah=+g[142748]+-.009999999776482582;g[142748]=ah;a7=1;a8=ah;as=5533}else if((F|0)==3|(F|0)==4){ah=+g[142748]+.009999999776482582;g[142748]=ah;a7=1;a8=ah;as=5533}else if((F|0)==8){g[142748]=1.0;a9=1;ba=1.0}else{a7=0;a8=+g[142748];as=5533}do{if((as|0)==5533){if(a8<0.0){g[142748]=0.0;a9=a7;ba=0.0;break}if(a8<=1.0){a9=a7;ba=a8;break}g[142748]=1.0;a9=a7;ba=1.0}}while(0);$=c[191604]|0;if(!(a9&($|0)!=0)){break L7277}e7[c[(c[$+4>>2]|0)+20>>2]&7](c[$>>2]|0,ba);break L7277;break};default:{break L7277}}}while(0);if((F|0)!=8){break L7277}a[603809]=0;a[b+54|0]=0;break L7277}}while(0);d=b+48|0;J=c[d>>2]|0;if((B|0)!=0){I=B+4|0;L=c[I>>2]|0;if(A>>>0<L>>>0){bb=B|0}else{N=(L<<1)+2|0;c[I>>2]=N;I=B|0;c[I>>2]=v$(c[I>>2]|0,N*12|0)|0;bb=I}I=dn(766672)|0;c[(c[bb>>2]|0)+((c[z>>2]|0)*12|0)>>2]=I;c[(c[bb>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[bb>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=J;c[z>>2]=(c[z>>2]|0)+1}c[d>>2]=0;a[E]=1;break};case 5:{if(A>>>0<=1){break L7277}d=b+48|0;J=A-1|0;c[z>>2]=J;I=B|0;v_(c[(c[I>>2]|0)+(J*12|0)>>2]|0);if((d|0)!=0){c[d>>2]=c[(c[I>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]}a[E]=1;break};case 0:{I=b+48|0;d=c[I>>2]|0;if((d|0)==0){c[I>>2]=(c[(c[b+44>>2]|0)+8>>2]|0)-1;break L7277}else{c[I>>2]=d-1;break L7277}break};default:{}}}while(0);z=c[C>>2]|0;C=c[z+8>>2]|0;if((C|0)==0){bc=D}else{bc=c[(c[z>>2]|0)+((C-1|0)*12|0)+4>>2]|0}L7868:do{if(!((a[E]&1)==0|(bc|0)==1)){C=bc-31|0;if(C>>>0<24&((C>>>0)%3|0|0)==0|(bc|0)==28){break}if((bc-73|0)>>>0<4|(bc|0)==78|(bc|0)==79){break}if((bc|0)==88|(bc|0)==71|(bc|0)==57|(bc|0)==56){break}a[E]=0;switch(bc|0){case 62:{C=b+44|0;z=c[C>>2]|0;D=z+8|0;if((c[D>>2]|0)!=0){B=z|0;z=0;do{v_(c[(c[B>>2]|0)+(z*12|0)>>2]|0);z=z+1|0;}while(z>>>0<(c[D>>2]|0)>>>0)}c[D>>2]=0;z=c[C>>2]|0;if((z|0)==0){break L7868}B=z+8|0;A=z+4|0;bb=c[A>>2]|0;if((c[B>>2]|0)>>>0<bb>>>0){bd=z|0}else{y=(bb<<1)+2|0;c[A>>2]=y;A=z|0;c[A>>2]=v$(c[A>>2]|0,y*12|0)|0;bd=A}A=dn(50728)|0;c[(c[bd>>2]|0)+((c[B>>2]|0)*12|0)>>2]=A;c[(c[bd>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=63;c[(c[bd>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[C>>2]|0;if((B|0)==0){break L7868}A=B+8|0;y=B+4|0;z=c[y>>2]|0;if((c[A>>2]|0)>>>0<z>>>0){be=B|0}else{bb=(z<<1)+2|0;c[y>>2]=bb;y=B|0;c[y>>2]=v$(c[y>>2]|0,bb*12|0)|0;be=y}y=dn(50592)|0;c[(c[be>>2]|0)+((c[A>>2]|0)*12|0)>>2]=y;c[(c[be>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=64;c[(c[be>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L7868}y=A+8|0;bb=A+4|0;B=c[bb>>2]|0;if((c[y>>2]|0)>>>0<B>>>0){bf=A|0}else{z=(B<<1)+2|0;c[bb>>2]=z;bb=A|0;c[bb>>2]=v$(c[bb>>2]|0,z*12|0)|0;bf=bb}bb=dn(50448)|0;c[(c[bf>>2]|0)+((c[y>>2]|0)*12|0)>>2]=bb;c[(c[bf>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=65;c[(c[bf>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L7868}bb=y+8|0;z=y+4|0;A=c[z>>2]|0;if((c[bb>>2]|0)>>>0<A>>>0){bg=y|0}else{B=(A<<1)+2|0;c[z>>2]=B;z=y|0;c[z>>2]=v$(c[z>>2]|0,B*12|0)|0;bg=z}z=dn(50288)|0;c[(c[bg>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=z;c[(c[bg>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=84;c[(c[bg>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;break L7868;break};case 58:{bb=b+44|0;z=c[bb>>2]|0;B=z+8|0;if((c[B>>2]|0)!=0){y=z|0;z=0;do{v_(c[(c[y>>2]|0)+(z*12|0)>>2]|0);z=z+1|0;}while(z>>>0<(c[B>>2]|0)>>>0)}c[B>>2]=0;z=c[176752]|0;if((z|0)==0){y=c[bb>>2]|0;if((y|0)==0){break L7868}C=y+8|0;D=y+4|0;A=c[D>>2]|0;if((c[C>>2]|0)>>>0<A>>>0){bh=y|0}else{F=(A<<1)+2|0;c[D>>2]=F;D=y|0;c[D>>2]=v$(c[D>>2]|0,F*12|0)|0;bh=D}D=dn(51200)|0;c[(c[bh>>2]|0)+((c[C>>2]|0)*12|0)>>2]=D;c[(c[bh>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=65535;c[(c[bh>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;break L7868}C=c[z+4104>>2]|0;if((C|0)==0){break L7868}else{bi=0;bj=z}while(1){z=c[bb>>2]|0;D=c[(c[bj+4100>>2]|0)+(bi<<4)>>2]|0;F=bi+65536|0;if((z|0)!=0){y=z+8|0;A=z+4|0;a9=c[A>>2]|0;if((c[y>>2]|0)>>>0<a9>>>0){bk=z|0}else{a7=(a9<<1)+2|0;c[A>>2]=a7;A=z|0;c[A>>2]=v$(c[A>>2]|0,a7*12|0)|0;bk=A}A=dn(D|0)|0;c[(c[bk>>2]|0)+((c[y>>2]|0)*12|0)>>2]=A;c[(c[bk>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=F;c[(c[bk>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1}y=bi+1|0;if(y>>>0>=C>>>0){break L7868}bi=y;bj=c[176752]|0}break};case 59:{C=b+44|0;bb=c[C>>2]|0;B=bb+8|0;if((c[B>>2]|0)!=0){y=bb|0;bb=0;do{v_(c[(c[y>>2]|0)+(bb*12|0)>>2]|0);bb=bb+1|0;}while(bb>>>0<(c[B>>2]|0)>>>0)}c[B>>2]=0;bb=c[C>>2]|0;if((bb|0)==0){break L7868}y=bb+8|0;F=bb+4|0;A=c[F>>2]|0;if((c[y>>2]|0)>>>0<A>>>0){bl=bb|0}else{D=(A<<1)+2|0;c[F>>2]=D;F=bb|0;c[F>>2]=v$(c[F>>2]|0,D*12|0)|0;bl=F}F=dn(12240)|0;c[(c[bl>>2]|0)+((c[y>>2]|0)*12|0)>>2]=F;c[(c[bl>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=81;c[(c[bl>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L7868}F=y+8|0;D=y+4|0;bb=c[D>>2]|0;if((c[F>>2]|0)>>>0<bb>>>0){bm=y|0}else{A=(bb<<1)+2|0;c[D>>2]=A;D=y|0;c[D>>2]=v$(c[D>>2]|0,A*12|0)|0;bm=D}D=dn(51416)|0;c[(c[bm>>2]|0)+((c[F>>2]|0)*12|0)>>2]=D;c[(c[bm>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=82;c[(c[bm>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;break L7868;break};case 69:{F=b+44|0;D=c[F>>2]|0;A=D+8|0;if((c[A>>2]|0)!=0){y=D|0;D=0;do{v_(c[(c[y>>2]|0)+(D*12|0)>>2]|0);D=D+1|0;}while(D>>>0<(c[A>>2]|0)>>>0)}c[A>>2]=0;D=c[F>>2]|0;if((D|0)==0){break L7868}y=D+8|0;C=D+4|0;B=c[C>>2]|0;if((c[y>>2]|0)>>>0<B>>>0){bn=D|0}else{bb=(B<<1)+2|0;c[C>>2]=bb;C=D|0;c[C>>2]=v$(c[C>>2]|0,bb*12|0)|0;bn=C}C=dn(12464)|0;c[(c[bn>>2]|0)+((c[y>>2]|0)*12|0)>>2]=C;c[(c[bn>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=70;c[(c[bn>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[F>>2]|0;if((y|0)==0){break L7868}C=y+8|0;bb=y+4|0;D=c[bb>>2]|0;if((c[C>>2]|0)>>>0<D>>>0){bo=y|0}else{B=(D<<1)+2|0;c[bb>>2]=B;bb=y|0;c[bb>>2]=v$(c[bb>>2]|0,B*12|0)|0;bo=bb}bb=dn(12360)|0;c[(c[bo>>2]|0)+((c[C>>2]|0)*12|0)>>2]=bb;c[(c[bo>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=71;c[(c[bo>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;break L7868;break};case 5:{C=b+44|0;bb=c[C>>2]|0;B=bb+8|0;if((c[B>>2]|0)!=0){y=bb|0;bb=0;do{v_(c[(c[y>>2]|0)+(bb*12|0)>>2]|0);bb=bb+1|0;}while(bb>>>0<(c[B>>2]|0)>>>0)}c[B>>2]=0;bb=c[C>>2]|0;if((bb|0)==0){break L7868}y=bb+8|0;F=bb+4|0;A=c[F>>2]|0;if((c[y>>2]|0)>>>0<A>>>0){bp=bb|0}else{D=(A<<1)+2|0;c[F>>2]=D;F=bb|0;c[F>>2]=v$(c[F>>2]|0,D*12|0)|0;bp=F}F=dn(15224)|0;c[(c[bp>>2]|0)+((c[y>>2]|0)*12|0)>>2]=F;c[(c[bp>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=26;c[(c[bp>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L7868}F=y+8|0;D=y+4|0;bb=c[D>>2]|0;if((c[F>>2]|0)>>>0<bb>>>0){bq=y|0}else{A=(bb<<1)+2|0;c[D>>2]=A;D=y|0;c[D>>2]=v$(c[D>>2]|0,A*12|0)|0;bq=D}D=dn(15016)|0;c[(c[bq>>2]|0)+((c[F>>2]|0)*12|0)>>2]=D;c[(c[bq>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=10;c[(c[bq>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[C>>2]|0;if((F|0)==0){break L7868}D=F+8|0;A=F+4|0;y=c[A>>2]|0;if((c[D>>2]|0)>>>0<y>>>0){br=F|0}else{bb=(y<<1)+2|0;c[A>>2]=bb;A=F|0;c[A>>2]=v$(c[A>>2]|0,bb*12|0)|0;br=A}A=dn(14688)|0;c[(c[br>>2]|0)+((c[D>>2]|0)*12|0)>>2]=A;c[(c[br>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=11;c[(c[br>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[C>>2]|0;if((D|0)==0){break L7868}A=D+8|0;bb=D+4|0;F=c[bb>>2]|0;if((c[A>>2]|0)>>>0<F>>>0){bs=D|0}else{y=(F<<1)+2|0;c[bb>>2]=y;bb=D|0;c[bb>>2]=v$(c[bb>>2]|0,y*12|0)|0;bs=bb}bb=dn(14528)|0;c[(c[bs>>2]|0)+((c[A>>2]|0)*12|0)>>2]=bb;c[(c[bs>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=12;c[(c[bs>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L7868}bb=A+8|0;y=A+4|0;D=c[y>>2]|0;if((c[bb>>2]|0)>>>0<D>>>0){bt=A|0}else{F=(D<<1)+2|0;c[y>>2]=F;y=A|0;c[y>>2]=v$(c[y>>2]|0,F*12|0)|0;bt=y}y=dn(14432)|0;c[(c[bt>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=y;c[(c[bt>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=14;c[(c[bt>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[C>>2]|0;if((bb|0)==0){break L7868}y=bb+8|0;F=bb+4|0;A=c[F>>2]|0;if((c[y>>2]|0)>>>0<A>>>0){bu=bb|0}else{D=(A<<1)+2|0;c[F>>2]=D;F=bb|0;c[F>>2]=v$(c[F>>2]|0,D*12|0)|0;bu=F}F=dn(14296)|0;c[(c[bu>>2]|0)+((c[y>>2]|0)*12|0)>>2]=F;c[(c[bu>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=15;c[(c[bu>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L7868}F=y+8|0;D=y+4|0;bb=c[D>>2]|0;if((c[F>>2]|0)>>>0<bb>>>0){bv=y|0}else{A=(bb<<1)+2|0;c[D>>2]=A;D=y|0;c[D>>2]=v$(c[D>>2]|0,A*12|0)|0;bv=D}D=dn(14176)|0;c[(c[bv>>2]|0)+((c[F>>2]|0)*12|0)>>2]=D;c[(c[bv>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=16;c[(c[bv>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[C>>2]|0;if((F|0)==0){break L7868}D=F+8|0;A=F+4|0;y=c[A>>2]|0;if((c[D>>2]|0)>>>0<y>>>0){bw=F|0}else{bb=(y<<1)+2|0;c[A>>2]=bb;A=F|0;c[A>>2]=v$(c[A>>2]|0,bb*12|0)|0;bw=A}A=dn(13912)|0;c[(c[bw>>2]|0)+((c[D>>2]|0)*12|0)>>2]=A;c[(c[bw>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=17;c[(c[bw>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[C>>2]|0;if((D|0)==0){break L7868}A=D+8|0;bb=D+4|0;F=c[bb>>2]|0;if((c[A>>2]|0)>>>0<F>>>0){bx=D|0}else{y=(F<<1)+2|0;c[bb>>2]=y;bb=D|0;c[bb>>2]=v$(c[bb>>2]|0,y*12|0)|0;bx=bb}bb=dn(13760)|0;c[(c[bx>>2]|0)+((c[A>>2]|0)*12|0)>>2]=bb;c[(c[bx>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=18;c[(c[bx>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L7868}bb=A+8|0;y=A+4|0;D=c[y>>2]|0;if((c[bb>>2]|0)>>>0<D>>>0){by=A|0}else{F=(D<<1)+2|0;c[y>>2]=F;y=A|0;c[y>>2]=v$(c[y>>2]|0,F*12|0)|0;by=y}y=dn(13576)|0;c[(c[by>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=y;c[(c[by>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=19;c[(c[by>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[C>>2]|0;if((bb|0)==0){break L7868}y=bb+8|0;F=bb+4|0;A=c[F>>2]|0;if((c[y>>2]|0)>>>0<A>>>0){bz=bb|0}else{D=(A<<1)+2|0;c[F>>2]=D;F=bb|0;c[F>>2]=v$(c[F>>2]|0,D*12|0)|0;bz=F}F=dn(13144)|0;c[(c[bz>>2]|0)+((c[y>>2]|0)*12|0)>>2]=F;c[(c[bz>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=20;c[(c[bz>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L7868}F=y+8|0;D=y+4|0;bb=c[D>>2]|0;if((c[F>>2]|0)>>>0<bb>>>0){bA=y|0}else{A=(bb<<1)+2|0;c[D>>2]=A;D=y|0;c[D>>2]=v$(c[D>>2]|0,A*12|0)|0;bA=D}D=dn(12984)|0;c[(c[bA>>2]|0)+((c[F>>2]|0)*12|0)>>2]=D;c[(c[bA>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=21;c[(c[bA>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[C>>2]|0;if((F|0)==0){break L7868}D=F+8|0;A=F+4|0;y=c[A>>2]|0;if((c[D>>2]|0)>>>0<y>>>0){bB=F|0}else{bb=(y<<1)+2|0;c[A>>2]=bb;A=F|0;c[A>>2]=v$(c[A>>2]|0,bb*12|0)|0;bB=A}A=dn(12816)|0;c[(c[bB>>2]|0)+((c[D>>2]|0)*12|0)>>2]=A;c[(c[bB>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=22;c[(c[bB>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[C>>2]|0;if((D|0)==0){break L7868}A=D+8|0;bb=D+4|0;F=c[bb>>2]|0;if((c[A>>2]|0)>>>0<F>>>0){bC=D|0}else{y=(F<<1)+2|0;c[bb>>2]=y;bb=D|0;c[bb>>2]=v$(c[bb>>2]|0,y*12|0)|0;bC=bb}bb=dn(12656)|0;c[(c[bC>>2]|0)+((c[A>>2]|0)*12|0)>>2]=bb;c[(c[bC>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=23;c[(c[bC>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L7868}bb=A+8|0;y=A+4|0;D=c[y>>2]|0;if((c[bb>>2]|0)>>>0<D>>>0){bD=A|0}else{F=(D<<1)+2|0;c[y>>2]=F;y=A|0;c[y>>2]=v$(c[y>>2]|0,F*12|0)|0;bD=y}y=dn(12584)|0;c[(c[bD>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=y;c[(c[bD>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=24;c[(c[bD>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;break L7868;break};case 61:{bb=b+44|0;y=c[bb>>2]|0;F=y+8|0;if((c[F>>2]|0)!=0){A=y|0;y=0;do{v_(c[(c[A>>2]|0)+(y*12|0)>>2]|0);y=y+1|0;}while(y>>>0<(c[F>>2]|0)>>>0)}c[F>>2]=0;y=c[bb>>2]|0;if((y|0)==0){break L7868}A=y+8|0;C=y+4|0;B=c[C>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bE=y|0}else{D=(B<<1)+2|0;c[C>>2]=D;C=y|0;c[C>>2]=v$(c[C>>2]|0,D*12|0)|0;bE=C}C=dn(50120)|0;c[(c[bE>>2]|0)+((c[A>>2]|0)*12|0)>>2]=C;c[(c[bE>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=73;c[(c[bE>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[bb>>2]|0;if((A|0)==0){break L7868}C=A+8|0;D=A+4|0;y=c[D>>2]|0;if((c[C>>2]|0)>>>0<y>>>0){bF=A|0}else{B=(y<<1)+2|0;c[D>>2]=B;D=A|0;c[D>>2]=v$(c[D>>2]|0,B*12|0)|0;bF=D}D=dn(49968)|0;c[(c[bF>>2]|0)+((c[C>>2]|0)*12|0)>>2]=D;c[(c[bF>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=74;c[(c[bF>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[bb>>2]|0;if((C|0)==0){break L7868}D=C+8|0;B=C+4|0;A=c[B>>2]|0;if((c[D>>2]|0)>>>0<A>>>0){bG=C|0}else{y=(A<<1)+2|0;c[B>>2]=y;B=C|0;c[B>>2]=v$(c[B>>2]|0,y*12|0)|0;bG=B}B=dn(49848)|0;c[(c[bG>>2]|0)+((c[D>>2]|0)*12|0)>>2]=B;c[(c[bG>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=75;c[(c[bG>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[bb>>2]|0;if((D|0)==0){break L7868}B=D+8|0;y=D+4|0;C=c[y>>2]|0;if((c[B>>2]|0)>>>0<C>>>0){bI=D|0}else{A=(C<<1)+2|0;c[y>>2]=A;y=D|0;c[y>>2]=v$(c[y>>2]|0,A*12|0)|0;bI=y}y=dn(49464)|0;c[(c[bI>>2]|0)+((c[B>>2]|0)*12|0)>>2]=y;c[(c[bI>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=76;c[(c[bI>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[bb>>2]|0;if((B|0)==0){break L7868}y=B+8|0;A=B+4|0;D=c[A>>2]|0;if((c[y>>2]|0)>>>0<D>>>0){bJ=B|0}else{C=(D<<1)+2|0;c[A>>2]=C;A=B|0;c[A>>2]=v$(c[A>>2]|0,C*12|0)|0;bJ=A}A=dn(49296)|0;c[(c[bJ>>2]|0)+((c[y>>2]|0)*12|0)>>2]=A;c[(c[bJ>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=78;c[(c[bJ>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[bb>>2]|0;if((y|0)==0){break L7868}A=y+8|0;C=y+4|0;B=c[C>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bK=y|0}else{D=(B<<1)+2|0;c[C>>2]=D;C=y|0;c[C>>2]=v$(c[C>>2]|0,D*12|0)|0;bK=C}C=dn(49e3)|0;c[(c[bK>>2]|0)+((c[A>>2]|0)*12|0)>>2]=C;c[(c[bK>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=79;c[(c[bK>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;break L7868;break};case 60:{A=b+44|0;C=c[A>>2]|0;D=C+8|0;if((c[D>>2]|0)!=0){y=C|0;C=0;do{v_(c[(c[y>>2]|0)+(C*12|0)>>2]|0);C=C+1|0;}while(C>>>0<(c[D>>2]|0)>>>0)}c[D>>2]=0;C=c[A>>2]|0;do{if((C|0)!=0){y=C+8|0;bb=C+4|0;F=c[bb>>2]|0;if((c[y>>2]|0)>>>0<F>>>0){bL=C|0}else{B=(F<<1)+2|0;c[bb>>2]=B;bb=C|0;c[bb>>2]=v$(c[bb>>2]|0,B*12|0)|0;bL=bb}bb=dn(48472)|0;c[(c[bL>>2]|0)+((c[y>>2]|0)*12|0)>>2]=bb;c[(c[bL>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=88;c[(c[bL>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[A>>2]|0;if((y|0)==0){break}bb=y+8|0;B=y+4|0;F=c[B>>2]|0;if((c[bb>>2]|0)>>>0<F>>>0){bM=y|0}else{a7=(F<<1)+2|0;c[B>>2]=a7;B=y|0;c[B>>2]=v$(c[B>>2]|0,a7*12|0)|0;bM=B}B=dn(48232)|0;c[(c[bM>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=B;c[(c[bM>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=89;c[(c[bM>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[A>>2]|0;if((bb|0)==0){break}B=bb+8|0;a7=bb+4|0;y=c[a7>>2]|0;if((c[B>>2]|0)>>>0<y>>>0){bO=bb|0}else{F=(y<<1)+2|0;c[a7>>2]=F;a7=bb|0;c[a7>>2]=v$(c[a7>>2]|0,F*12|0)|0;bO=a7}a7=dn(48016)|0;c[(c[bO>>2]|0)+((c[B>>2]|0)*12|0)>>2]=a7;c[(c[bO>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=90;c[(c[bO>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[A>>2]|0;if((B|0)==0){break}a7=B+8|0;F=B+4|0;bb=c[F>>2]|0;if((c[a7>>2]|0)>>>0<bb>>>0){bP=B|0}else{y=(bb<<1)+2|0;c[F>>2]=y;F=B|0;c[F>>2]=v$(c[F>>2]|0,y*12|0)|0;bP=F}F=dn(47792)|0;c[(c[bP>>2]|0)+((c[a7>>2]|0)*12|0)>>2]=F;c[(c[bP>>2]|0)+((c[a7>>2]|0)*12|0)+4>>2]=91;c[(c[bP>>2]|0)+((c[a7>>2]|0)*12|0)+8>>2]=0;c[a7>>2]=(c[a7>>2]|0)+1;a7=c[A>>2]|0;if((a7|0)==0){break}F=a7+8|0;y=a7+4|0;B=c[y>>2]|0;if((c[F>>2]|0)>>>0<B>>>0){bQ=a7|0}else{bb=(B<<1)+2|0;c[y>>2]=bb;y=a7|0;c[y>>2]=v$(c[y>>2]|0,bb*12|0)|0;bQ=y}y=dn(47704)|0;c[(c[bQ>>2]|0)+((c[F>>2]|0)*12|0)>>2]=y;c[(c[bQ>>2]|0)+((c[F>>2]|0)*12|0)+4>>2]=92;c[(c[bQ>>2]|0)+((c[F>>2]|0)*12|0)+8>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[A>>2]|0;if((F|0)==0){break}y=F+8|0;bb=F+4|0;a7=c[bb>>2]|0;if((c[y>>2]|0)>>>0<a7>>>0){bR=F|0}else{B=(a7<<1)+2|0;c[bb>>2]=B;bb=F|0;c[bb>>2]=v$(c[bb>>2]|0,B*12|0)|0;bR=bb}bb=dn(47472)|0;c[(c[bR>>2]|0)+((c[y>>2]|0)*12|0)>>2]=bb;c[(c[bR>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=93;c[(c[bR>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1}}while(0);C=c[191560]|0;if((C|0)==0){break L7868}if((c[C+20>>2]|0)==0){break L7868}C=c[A>>2]|0;if((C|0)==0){break L7868}D=C+8|0;y=C+4|0;bb=c[y>>2]|0;if((c[D>>2]|0)>>>0<bb>>>0){bS=C|0}else{B=(bb<<1)+2|0;c[y>>2]=B;y=C|0;c[y>>2]=v$(c[y>>2]|0,B*12|0)|0;bS=y}y=dn(47240)|0;c[(c[bS>>2]|0)+((c[D>>2]|0)*12|0)>>2]=y;c[(c[bS>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=94;c[(c[bS>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[A>>2]|0;if((D|0)==0){break L7868}y=D+8|0;B=D+4|0;C=c[B>>2]|0;if((c[y>>2]|0)>>>0<C>>>0){bT=D|0}else{bb=(C<<1)+2|0;c[B>>2]=bb;B=D|0;c[B>>2]=v$(c[B>>2]|0,bb*12|0)|0;bT=B}B=dn(47096)|0;c[(c[bT>>2]|0)+((c[y>>2]|0)*12|0)>>2]=B;c[(c[bT>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=95;c[(c[bT>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[A>>2]|0;if((y|0)==0){break L7868}B=y+8|0;bb=y+4|0;D=c[bb>>2]|0;if((c[B>>2]|0)>>>0<D>>>0){bU=y|0}else{C=(D<<1)+2|0;c[bb>>2]=C;bb=y|0;c[bb>>2]=v$(c[bb>>2]|0,C*12|0)|0;bU=bb}bb=dn(46976)|0;c[(c[bU>>2]|0)+((c[B>>2]|0)*12|0)>>2]=bb;c[(c[bU>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=96;c[(c[bU>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[A>>2]|0;if((B|0)==0){break L7868}bb=B+8|0;C=B+4|0;y=c[C>>2]|0;if((c[bb>>2]|0)>>>0<y>>>0){bV=B|0}else{D=(y<<1)+2|0;c[C>>2]=D;C=B|0;c[C>>2]=v$(c[C>>2]|0,D*12|0)|0;bV=C}C=dn(46776)|0;c[(c[bV>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=C;c[(c[bV>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=97;c[(c[bV>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[A>>2]|0;if((bb|0)==0){break L7868}C=bb+8|0;D=bb+4|0;B=c[D>>2]|0;if((c[C>>2]|0)>>>0<B>>>0){bW=bb|0}else{y=(B<<1)+2|0;c[D>>2]=y;D=bb|0;c[D>>2]=v$(c[D>>2]|0,y*12|0)|0;bW=D}D=dn(46528)|0;c[(c[bW>>2]|0)+((c[C>>2]|0)*12|0)>>2]=D;c[(c[bW>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=98;c[(c[bW>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[A>>2]|0;if((C|0)==0){break L7868}D=C+8|0;y=C+4|0;bb=c[y>>2]|0;if((c[D>>2]|0)>>>0<bb>>>0){bX=C|0}else{B=(bb<<1)+2|0;c[y>>2]=B;y=C|0;c[y>>2]=v$(c[y>>2]|0,B*12|0)|0;bX=y}y=dn(46232)|0;c[(c[bX>>2]|0)+((c[D>>2]|0)*12|0)>>2]=y;c[(c[bX>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=99;c[(c[bX>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[A>>2]|0;if((D|0)==0){break L7868}y=D+8|0;B=D+4|0;C=c[B>>2]|0;if((c[y>>2]|0)>>>0<C>>>0){bY=D|0}else{bb=(C<<1)+2|0;c[B>>2]=bb;B=D|0;c[B>>2]=v$(c[B>>2]|0,bb*12|0)|0;bY=B}B=dn(46024)|0;c[(c[bY>>2]|0)+((c[y>>2]|0)*12|0)>>2]=B;c[(c[bY>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=100;c[(c[bY>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[A>>2]|0;if((y|0)==0){break L7868}B=y+8|0;bb=y+4|0;D=c[bb>>2]|0;if((c[B>>2]|0)>>>0<D>>>0){bZ=y|0}else{C=(D<<1)+2|0;c[bb>>2]=C;bb=y|0;c[bb>>2]=v$(c[bb>>2]|0,C*12|0)|0;bZ=bb}bb=dn(45944)|0;c[(c[bZ>>2]|0)+((c[B>>2]|0)*12|0)>>2]=bb;c[(c[bZ>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=101;c[(c[bZ>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[A>>2]|0;if((B|0)==0){break L7868}bb=B+8|0;C=B+4|0;y=c[C>>2]|0;if((c[bb>>2]|0)>>>0<y>>>0){b_=B|0}else{D=(y<<1)+2|0;c[C>>2]=D;C=B|0;c[C>>2]=v$(c[C>>2]|0,D*12|0)|0;b_=C}C=dn(45864)|0;c[(c[b_>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=C;c[(c[b_>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=102;c[(c[b_>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[A>>2]|0;if((bb|0)==0){break L7868}C=bb+8|0;D=bb+4|0;B=c[D>>2]|0;if((c[C>>2]|0)>>>0<B>>>0){b$=bb|0}else{y=(B<<1)+2|0;c[D>>2]=y;D=bb|0;c[D>>2]=v$(c[D>>2]|0,y*12|0)|0;b$=D}D=dn(45744)|0;c[(c[b$>>2]|0)+((c[C>>2]|0)*12|0)>>2]=D;c[(c[b$>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=103;c[(c[b$>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[A>>2]|0;if((C|0)==0){break L7868}D=C+8|0;y=C+4|0;bb=c[y>>2]|0;if((c[D>>2]|0)>>>0<bb>>>0){b0=C|0}else{B=(bb<<1)+2|0;c[y>>2]=B;y=C|0;c[y>>2]=v$(c[y>>2]|0,B*12|0)|0;b0=y}y=dn(45616)|0;c[(c[b0>>2]|0)+((c[D>>2]|0)*12|0)>>2]=y;c[(c[b0>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=104;c[(c[b0>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[A>>2]|0;if((D|0)==0){break L7868}y=D+8|0;B=D+4|0;C=c[B>>2]|0;if((c[y>>2]|0)>>>0<C>>>0){b1=D|0}else{bb=(C<<1)+2|0;c[B>>2]=bb;B=D|0;c[B>>2]=v$(c[B>>2]|0,bb*12|0)|0;b1=B}B=dn(45560)|0;c[(c[b1>>2]|0)+((c[y>>2]|0)*12|0)>>2]=B;c[(c[b1>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=105;c[(c[b1>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[A>>2]|0;if((y|0)==0){break L7868}B=y+8|0;bb=y+4|0;D=c[bb>>2]|0;if((c[B>>2]|0)>>>0<D>>>0){b2=y|0}else{C=(D<<1)+2|0;c[bb>>2]=C;bb=y|0;c[bb>>2]=v$(c[bb>>2]|0,C*12|0)|0;b2=bb}bb=dn(45464)|0;c[(c[b2>>2]|0)+((c[B>>2]|0)*12|0)>>2]=bb;c[(c[b2>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=106;c[(c[b2>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[A>>2]|0;if((B|0)==0){break L7868}bb=B+8|0;C=B+4|0;y=c[C>>2]|0;if((c[bb>>2]|0)>>>0<y>>>0){b3=B|0}else{D=(y<<1)+2|0;c[C>>2]=D;C=B|0;c[C>>2]=v$(c[C>>2]|0,D*12|0)|0;b3=C}C=dn(45336)|0;c[(c[b3>>2]|0)+((c[bb>>2]|0)*12|0)>>2]=C;c[(c[b3>>2]|0)+((c[bb>>2]|0)*12|0)+4>>2]=107;c[(c[b3>>2]|0)+((c[bb>>2]|0)*12|0)+8>>2]=0;c[bb>>2]=(c[bb>>2]|0)+1;bb=c[A>>2]|0;if((bb|0)==0){break L7868}C=bb+8|0;D=bb+4|0;B=c[D>>2]|0;if((c[C>>2]|0)>>>0<B>>>0){b4=bb|0}else{y=(B<<1)+2|0;c[D>>2]=y;D=bb|0;c[D>>2]=v$(c[D>>2]|0,y*12|0)|0;b4=D}D=dn(45120)|0;c[(c[b4>>2]|0)+((c[C>>2]|0)*12|0)>>2]=D;c[(c[b4>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=108;c[(c[b4>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[A>>2]|0;if((C|0)==0){break L7868}D=C+8|0;y=C+4|0;bb=c[y>>2]|0;if((c[D>>2]|0)>>>0<bb>>>0){b5=C|0}else{B=(bb<<1)+2|0;c[y>>2]=B;y=C|0;c[y>>2]=v$(c[y>>2]|0,B*12|0)|0;b5=y}y=dn(45048)|0;c[(c[b5>>2]|0)+((c[D>>2]|0)*12|0)>>2]=y;c[(c[b5>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=109;c[(c[b5>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[A>>2]|0;if((D|0)==0){break L7868}y=D+8|0;B=D+4|0;C=c[B>>2]|0;if((c[y>>2]|0)>>>0<C>>>0){b6=D|0}else{bb=(C<<1)+2|0;c[B>>2]=bb;B=D|0;c[B>>2]=v$(c[B>>2]|0,bb*12|0)|0;b6=B}B=dn(44984)|0;c[(c[b6>>2]|0)+((c[y>>2]|0)*12|0)>>2]=B;c[(c[b6>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=110;c[(c[b6>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;break L7868;break};case 26:{y=v|0;B=b+44|0;bb=c[B>>2]|0;D=bb+8|0;if((c[D>>2]|0)!=0){C=bb|0;bb=0;do{v_(c[(c[C>>2]|0)+(bb*12|0)>>2]|0);bb=bb+1|0;}while(bb>>>0<(c[D>>2]|0)>>>0)}c[D>>2]=0;bb=c[B>>2]|0;do{if((bb|0)!=0){C=bb+8|0;A=bb+4|0;F=c[A>>2]|0;if((c[C>>2]|0)>>>0<F>>>0){b7=bb|0}else{a7=(F<<1)+2|0;c[A>>2]=a7;A=bb|0;c[A>>2]=v$(c[A>>2]|0,a7*12|0)|0;b7=A}A=dn(16624)|0;c[(c[b7>>2]|0)+((c[C>>2]|0)*12|0)>>2]=A;c[(c[b7>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=29;c[(c[b7>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[B>>2]|0;if((C|0)==0){break}A=C+8|0;a7=C+4|0;F=c[a7>>2]|0;if((c[A>>2]|0)>>>0<F>>>0){b8=C|0}else{z=(F<<1)+2|0;c[a7>>2]=z;a7=C|0;c[a7>>2]=v$(c[a7>>2]|0,z*12|0)|0;b8=a7}a7=dn(16512)|0;c[(c[b8>>2]|0)+((c[A>>2]|0)*12|0)>>2]=a7;c[(c[b8>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=27;c[(c[b8>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[B>>2]|0;if((A|0)==0){break}a7=A+8|0;z=A+4|0;C=c[z>>2]|0;if((c[a7>>2]|0)>>>0<C>>>0){b9=A|0}else{F=(C<<1)+2|0;c[z>>2]=F;z=A|0;c[z>>2]=v$(c[z>>2]|0,F*12|0)|0;b9=z}z=dn(16384)|0;c[(c[b9>>2]|0)+((c[a7>>2]|0)*12|0)>>2]=z;c[(c[b9>>2]|0)+((c[a7>>2]|0)*12|0)+4>>2]=28;c[(c[b9>>2]|0)+((c[a7>>2]|0)*12|0)+8>>2]=0;c[a7>>2]=(c[a7>>2]|0)+1;a7=c[B>>2]|0;if((a7|0)==0){break}z=a7+8|0;F=a7+4|0;A=c[F>>2]|0;if((c[z>>2]|0)>>>0<A>>>0){ca=a7|0}else{C=(A<<1)+2|0;c[F>>2]=C;F=a7|0;c[F>>2]=v$(c[F>>2]|0,C*12|0)|0;ca=F}F=dn(16296)|0;c[(c[ca>>2]|0)+((c[z>>2]|0)*12|0)>>2]=F;c[(c[ca>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=30;c[(c[ca>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1}}while(0);bb=b+4252|0;if((c[bb>>2]|0)==0){break L7868}else{cb=0}do{bN(y|0,64,16128,(W=i,i=i+8|0,c[W>>2]=cb,W)|0)|0;i=W;D=c[B>>2]|0;z=cb*3|0;F=z+31|0;if((D|0)!=0){C=D+8|0;a7=D+4|0;A=c[a7>>2]|0;if((c[C>>2]|0)>>>0<A>>>0){cc=D|0}else{a9=(A<<1)+2|0;c[a7>>2]=a9;a7=D|0;c[a7>>2]=v$(c[a7>>2]|0,a9*12|0)|0;cc=a7}a7=dn(y|0)|0;c[(c[cc>>2]|0)+((c[C>>2]|0)*12|0)>>2]=a7;c[(c[cc>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=F;c[(c[cc>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1}bN(y|0,64,15944,(W=i,i=i+8|0,c[W>>2]=cb,W)|0)|0;i=W;C=c[B>>2]|0;F=z+32|0;if((C|0)!=0){a7=C+8|0;a9=C+4|0;D=c[a9>>2]|0;if((c[a7>>2]|0)>>>0<D>>>0){cd=C|0}else{A=(D<<1)+2|0;c[a9>>2]=A;a9=C|0;c[a9>>2]=v$(c[a9>>2]|0,A*12|0)|0;cd=a9}a9=dn(y|0)|0;c[(c[cd>>2]|0)+((c[a7>>2]|0)*12|0)>>2]=a9;c[(c[cd>>2]|0)+((c[a7>>2]|0)*12|0)+4>>2]=F;c[(c[cd>>2]|0)+((c[a7>>2]|0)*12|0)+8>>2]=0;c[a7>>2]=(c[a7>>2]|0)+1}bN(y|0,64,15680,(W=i,i=i+8|0,c[W>>2]=cb,W)|0)|0;i=W;a7=c[B>>2]|0;F=z+33|0;if((a7|0)!=0){z=a7+8|0;a9=a7+4|0;A=c[a9>>2]|0;if((c[z>>2]|0)>>>0<A>>>0){ce=a7|0}else{C=(A<<1)+2|0;c[a9>>2]=C;a9=a7|0;c[a9>>2]=v$(c[a9>>2]|0,C*12|0)|0;ce=a9}a9=dn(y|0)|0;c[(c[ce>>2]|0)+((c[z>>2]|0)*12|0)>>2]=a9;c[(c[ce>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=F;c[(c[ce>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1}cb=cb+1|0;}while(cb>>>0<(c[bb>>2]|0)>>>0);break};default:{ik(b);break L7868}}}}while(0);ip(b);aU=0;i=f;return aU|0}function io(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;if((a[607928]&1)!=0){g=c[191244]|0;h=(g|0)!=0?g:c[q>>2]|0;g=(e|0)!=0?e:18272;eb(h|0,18408,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;h=c[191244]|0;g=(h|0)!=0?h:c[q>>2]|0;aZ(g|0)|0}if(!(fg[c[(c[191559]|0)+20>>2]&63](c[191562]|0,d,e)|0)){d=c[191244]|0;g=(d|0)!=0?d:c[q>>2]|0;a3(18032,46,1,g|0)|0;g=c[191244]|0;d=(g|0)!=0?g:c[q>>2]|0;aZ(d|0)|0;a[509732]=0;i=f;return}d=(e|0)!=0;g=4096;h=505636;j=d?e:766672;while(1){k=g-1|0;if((k|0)==0){l=5921;break}m=a[j]|0;a[h]=m;if(m<<24>>24==0){break}else{g=k;h=h+1|0;j=j+1|0}}do{if((l|0)==5921){a[h]=0;if((a[j]|0)==0){break}else{n=j}do{n=n+1|0;}while((a[n]|0)!=0)}}while(0);a[509732]=1;if((b|0)==0|d^1){i=f;return}d=gG(e,0)|0;if((d|0)!=0){hZ(d,b)|0;h1(b,e);gE(d)}a[(c[36858]|0)+52|0]=1;i=f;return}function ip(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0.0,aB=0.0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0;e=i;i=i+1480|0;f=e|0;j=e+256|0;k=e+512|0;l=e+576|0;m=e+832|0;n=e+1088|0;o=e+1160|0;p=e+1416|0;do{if((a[d+52|0]&1)!=0){q=764968;if((c[q>>2]&4|0)==0&(c[q+4>>2]&0|0)==0){break}if((a[d+53|0]&1)!=0){break}i=e;return}}while(0);q=d+48|0;r=c[q>>2]|0;s=r+17|0;t=d+44|0;u=c[(c[t>>2]|0)+8>>2]|0;v=s>>>0>u>>>0?u:s;s=u>>>0>17?r>>>0<8?0:r-8|0:0;r=(v-s|0)>>>0>17?s+17|0:v;v=d+28|0;u=c[v>>2]|0;w=d+32|0;x=(c[w>>2]|0)>>>1;y=0;do{z=ac(y,x)|0;A=y>>>1;B=0;do{C=((B>>>1)+A&1)+1|0;b[u+(B+z<<1)>>1]=(C<<9|C<<13|C<<5|12)&65535;B=B+1|0;}while(B>>>0<320);y=y+1|0;}while(y>>>0<240);y=c[v>>2]|0;u=(c[w>>2]|0)>>>1;x=u*5|0;B=5;do{z=(B>>>1&1)+1|0;b[y+(B+x<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=u*6|0;x=5;do{z=2-(x>>>1&1)|0;b[y+(x+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=u*7|0;B=5;do{z=2-(B>>>1&1)|0;b[y+(B+x<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=u<<3;x=5;do{z=(x>>>1&1)+1|0;b[y+(x+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=u*9|0;u=5;do{B=(u>>>1&1)+1|0;b[y+(u+x<<1)>>1]=(B<<10|B<<13|B<<5|12)&65535;u=u+1|0;}while(u>>>0<315);u=c[v>>2]|0;x=(c[w>>2]|0)>>>1;y=x*230|0;B=5;do{z=2-(B>>>1&1)|0;b[u+(B+y<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=x*231|0;y=5;do{z=2-(y>>>1&1)|0;b[u+(y+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;y=y+1|0;}while(y>>>0<315);y=x*232|0;B=5;do{z=(B>>>1&1)+1|0;b[u+(B+y<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=x*233|0;y=5;do{z=(y>>>1&1)+1|0;b[u+(y+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;y=y+1|0;}while(y>>>0<315);y=x*234|0;x=5;do{B=2-(x>>>1&1)|0;b[u+(x+y<<1)>>1]=(B<<10|B<<13|B<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=c[v>>2]|0;y=(c[w>>2]|0)>>>1;u=5;do{B=ac(u,y)|0;z=u>>>1&1;A=z+1|0;C=(A<<10|A<<13|A<<5|12)&65535;b[x+(B+5<<1)>>1]=C;A=2-z|0;z=(A<<10|A<<13|A<<5|12)&65535;b[x+(B+6<<1)>>1]=z;b[x+(B+7<<1)>>1]=z;b[x+(B+8<<1)>>1]=C;b[x+(B+9<<1)>>1]=C;u=u+1|0;}while(u>>>0<235);u=c[v>>2]|0;v=(c[w>>2]|0)>>>1;w=5;do{x=ac(w,v)|0;y=w>>>1&1;C=2-y|0;B=(C<<10|C<<13|C<<5|12)&65535;b[u+(x+310<<1)>>1]=B;b[u+(x+311<<1)>>1]=B;C=y+1|0;y=(C<<10|C<<13|C<<5|12)&65535;b[u+(x+312<<1)>>1]=y;b[u+(x+313<<1)>>1]=y;b[u+(x+314<<1)>>1]=B;w=w+1|0;}while(w>>>0<235);w=c[d+40>>2]|0;u=c[w+8>>2]|0;L48:do{if((u|0)==0){D=0;E=0;F=36}else{v=u-1|0;B=c[w>>2]|0;x=c[B+(v*12|0)>>2]|0;y=c[B+(v*12|0)+4>>2]|0;switch(y|0){case 57:{bN(f|0,256,28776,(H=i,i=i+8|0,c[H>>2]=x,H)|0)|0;i=H;I=57;break L48;break};case 71:{bN(f|0,256,24736,(H=i,i=i+8|0,c[H>>2]=x,H)|0)|0;i=H;I=71;break L48;break};case 5:{a[f|0]=86;a[f+1|0]=73;a[f+2|0]=68;a[f+3|0]=69;a[f+4|0]=79;a[f+5|0]=32;a[f+6|0]=79;a[f+7|0]=80;a[f+8|0]=84;a[f+9|0]=73;a[f+10|0]=79;a[f+11|0]=78;a[f+12|0]=83;a[f+13|0]=0;I=5;break L48;break};case 26:{a[f|0]=83;a[f+1|0]=72;a[f+2|0]=65;a[f+3|0]=68;a[f+4|0]=69;a[f+5|0]=82;a[f+6|0]=32;a[f+7|0]=79;a[f+8|0]=80;a[f+9|0]=84;a[f+10|0]=73;a[f+11|0]=79;a[f+12|0]=78;a[f+13|0]=83;a[f+14|0]=0;I=26;break L48;break};case 59:{a[f|0]=65;a[f+1|0]=85;a[f+2|0]=68;a[f+3|0]=73;a[f+4|0]=79;a[f+5|0]=32;a[f+6|0]=79;a[f+7|0]=80;a[f+8|0]=84;a[f+9|0]=73;a[f+10|0]=79;a[f+11|0]=78;a[f+12|0]=83;a[f+13|0]=0;I=59;break L48;break};case 69:{a[f|0]=68;a[f+1|0]=73;a[f+2|0]=83;a[f+3|0]=75;a[f+4|0]=32;a[f+5|0]=79;a[f+6|0]=80;a[f+7|0]=84;a[f+8|0]=73;a[f+9|0]=79;a[f+10|0]=78;a[f+11|0]=83;a[f+12|0]=0;I=69;break L48;break};case 58:{a[f|0]=67;a[f+1|0]=79;a[f+2|0]=82;a[f+3|0]=69;a[f+4|0]=32;a[f+5|0]=79;a[f+6|0]=80;a[f+7|0]=84;a[f+8|0]=73;a[f+9|0]=79;a[f+10|0]=78;a[f+11|0]=83;a[f+12|0]=0;I=58;break L48;break};default:{D=x;E=y;F=36;break L48}}}}while(0);L58:do{if((F|0)==36){w=E-31|0;if(w>>>0<24&((w>>>0)%3|0|0)==0|(E|0)==28){w=f|0;bN(w|0,256,51176,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=E;break}if((E-60|0)>>>0<3|(E|0)==12|(E|0)==13|(E|0)==4){w=f|0;bN(w|0,256,48920,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=E;break}switch(E|0){case 88:{bN(f|0,256,45240,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=88;break L58;break};case 73:{bN(f|0,256,44376,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=73;break L58;break};case 74:{bN(f|0,256,43040,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=74;break L58;break};case 75:{bN(f|0,256,41704,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=75;break L58;break};case 76:{bN(f|0,256,40680,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=76;break L58;break};case 78:{bN(f|0,256,39696,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=78;break L58;break};case 79:{bN(f|0,256,38784,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=79;break L58;break};case 56:{a[f|0]=76;a[f+1|0]=79;a[f+2|0]=65;a[f+3|0]=68;a[f+4|0]=32;a[f+5|0]=72;a[f+6|0]=73;a[f+7|0]=83;a[f+8|0]=84;a[f+9|0]=79;a[f+10|0]=82;a[f+11|0]=89;a[f+12|0]=0;I=56;break L58;break};default:{w=c[d+4160>>2]|0;u=(w|0)==0?c[175554]|0:w;bN(f|0,256,36496,(H=i,i=i+16|0,c[H>>2]=(u|0)==0?37792:u,c[H+8>>2]=D,H)|0)|0;i=H;I=E;break L58}}}}while(0);E=j|0;ij(E,45,((c[191184]|0)>>>0)/15|0,f|0,1);iq(d,30,15,E,1);E=c[d+4160>>2]|0;f=(E|0)==0?c[175554]|0:E;E=c[d+4164>>2]|0;j=(E|0)==0?c[175555]|0:E;E=k|0;bN(E|0,64,34880,(H=i,i=i+24|0,c[H>>2]=33560,c[H+8>>2]=(f|0)==0?37792:f,c[H+16>>2]=(j|0)==0?766672:j,H)|0)|0;i=H;iq(d,30,216,E,1);if(s>>>0>=r>>>0){i=e;return}E=d+113708|0;j=m|0;f=o|0;o=p|0;p=l|0;l=n+8|0;k=n|0;D=n;u=(I|0)==60?24:(I|0)==61?24:19;w=I-31|0;y=w>>>0<24&((w>>>0)%3|0|0)==0|(I|0)==28;w=m+1|0;x=m+2|0;v=m+3|0;B=m+4|0;C=m+5|0;z=m+6|0;A=m+7|0;J=m+8|0;K=m+9|0;L=m+10|0;M=d+4252|0;N=(I-73|0)>>>0<4|(I|0)==78|(I|0)==79;O=(I|0)==56;P=m+11|0;Q=m+12|0;R=m+13|0;T=m+14|0;U=m+15|0;V=m+16|0;W=m+17|0;X=m+18|0;m=n+9|0;Y=n+10|0;Z=n+11|0;_=n+12|0;$=n+13|0;aa=n+14|0;ab=n+15|0;n=s;s=27;while(1){ad=c[c[t>>2]>>2]|0;ae=c[ad+(n*12|0)>>2]|0;af=c[ad+(n*12|0)+4>>2]|0;ad=c[E>>2]|0;L82:do{if((af-27|0)>>>0<28){do{if(y){ag=af-31|0;if(!(ag>>>0<24&((ag>>>0)%3|0|0)==0|(af|0)==28)){break}a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break L82}}while(0);if((af|0)==27){ag=(a[505620]&1)!=0?30616:30248;bN(j|0,256,31240,(H=i,i=i+8|0,c[H>>2]=ag,H)|0)|0;i=H;ah=u;ai=27;break}else if((af|0)==29){a[j]=0;ah=u;ai=29;break}else if((af|0)==30){bN(j|0,256,27368,(H=i,i=i+8|0,c[H>>2]=c[M>>2],H)|0)|0;i=H;ah=u;ai=30;break}else if((af|0)==28){a[j]=46;a[w]=46;a[x]=46;a[v]=0;ah=u;ai=28;break}else{ag=af-31|0;aj=(ag>>>0)/3|0;ak=(ag>>>0)%3|0;if((ak|0)==0){ag=d+4256+(aj*4148|0)|0;if((a[ag]|0)==0){a[j]=78;a[w]=47;a[x]=65;a[v]=0;ah=u;ai=af;break}else{gy(j,ag,256);ah=u;ai=af;break}}else if((ak|0)==1){ag=c[d+4256+(aj*4148|0)+4136>>2]|0;if((ag|0)==1){a[j]=76;a[w]=105;a[x]=110;a[v]=101;a[B]=97;a[C]=114;a[z]=0;ah=u;ai=af;break}else if((ag|0)==2){a[j]=78;a[w]=101;a[x]=97;a[v]=114;a[B]=101;a[C]=115;a[z]=116;a[A]=0;ah=u;ai=af;break}else if((ag|0)==0){a[j]=68;a[w]=111;a[x]=110;a[v]=39;a[B]=116;a[C]=32;a[z]=99;a[A]=97;a[J]=114;a[K]=101;a[L]=0;ah=u;ai=af;break}else{ah=u;ai=af;break}}else if((ak|0)==2){ak=~~+g[d+4256+(aj*4148|0)+4116>>2];if((ak|0)==0){a[j]=68;a[w]=111;a[x]=110;a[v]=39;a[B]=116;a[C]=32;a[z]=99;a[A]=97;a[J]=114;a[K]=101;a[L]=0;ah=u;ai=af;break}else{bN(j|0,256,48928,(H=i,i=i+8|0,c[H>>2]=ak,H)|0)|0;i=H;ah=u;ai=af;break}}else{ah=u;ai=af;break}}}else{do{if(!((I|0)==88|(I|0)==71|(I|0)==57)){if(N){break}if(O){a[j]=0;ah=0;ai=af;break L82}if(af>>>0>65535){ak=af-65536|0;aj=c[(c[176752]|0)+4100>>2]|0;ag=256;al=j;am=c[(c[c[aj+(ak<<4)+8>>2]>>2]|0)+(c[aj+(ak<<4)+12>>2]<<3)>>2]|0;while(1){ak=ag-1|0;if((ak|0)==0){break}aj=a[am]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=af;break L82}else{ag=ak;al=al+1|0;am=am+1|0}}a[al]=0;if((a[am]|0)==0){ah=u;ai=af;break L82}else{an=am}while(1){ag=an+1|0;if((a[ag]|0)==0){ah=u;ai=af;break L82}else{an=ag}}}switch(af|0){case 15:{am=256;al=j;ag=1848+(c[191235]<<5)|0;while(1){ak=am-1|0;if((ak|0)==0){break}aj=a[ag]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=15;break L82}else{am=ak;al=al+1|0;ag=ag+1|0}}a[al]=0;if((a[ag]|0)==0){ah=u;ai=15;break L82}else{ao=ag}while(1){am=ao+1|0;if((a[am]|0)==0){ah=u;ai=15;break L82}else{ao=am}}break};case 8:{ag=764968;bN(j|0,256,((c[ag>>2]&65536|0)!=0|(c[ag+4>>2]&0|0)!=0?29560:29080)|0,(H=i,i=i+1|0,i=i+7>>3<<3,c[H>>2]=0,H)|0)|0;i=H;ah=u;ai=8;break L82;break};case 7:{if((a[505620]&1)==0){a[j]=80;a[w]=111;a[x]=105;a[v]=110;a[B]=116;a[C]=32;a[z]=102;a[A]=105;a[J]=108;a[K]=116;a[L]=101;a[P]=114;a[Q]=105;a[R]=110;a[T]=103;a[U]=0;ah=u;ai=7;break L82}else{a[j]=66;a[w]=105;a[x]=108;a[v]=105;a[B]=110;a[C]=101;a[z]=97;a[A]=114;a[J]=32;a[K]=102;a[L]=105;a[P]=108;a[Q]=116;a[R]=101;a[T]=114;a[U]=105;a[V]=110;a[W]=103;a[X]=0;ah=u;ai=7;break L82}break};case 9:{bN(j|0,256,27712,(H=i,i=i+8|0,c[H>>2]=c[191236],H)|0)|0;i=H;ah=u;ai=9;break L82;break};case 16:{ag=256;al=j;am=(a[505608]&1)!=0?29560:29080;while(1){ak=ag-1|0;if((ak|0)==0){break}aj=a[am]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=16;break L82}else{ag=ak;al=al+1|0;am=am+1|0}}a[al]=0;if((a[am]|0)==0){ah=u;ai=16;break L82}else{ap=am}while(1){ag=ap+1|0;if((a[ag]|0)==0){ah=u;ai=16;break L82}else{ap=ag}}break};case 17:{am=256;al=j;ag=(a[505609]&1)!=0?29560:29080;while(1){ak=am-1|0;if((ak|0)==0){break}aj=a[ag]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=17;break L82}else{am=ak;al=al+1|0;ag=ag+1|0}}a[al]=0;if((a[ag]|0)==0){ah=u;ai=17;break L82}else{aq=ag}while(1){am=aq+1|0;if((a[am]|0)==0){ah=u;ai=17;break L82}else{aq=am}}break};case 19:{ag=256;al=j;am=(a[505610]&1)!=0?29560:29080;while(1){ak=ag-1|0;if((ak|0)==0){break}aj=a[am]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=19;break L82}else{ag=ak;al=al+1|0;am=am+1|0}}a[al]=0;if((a[am]|0)==0){ah=u;ai=19;break L82}else{ar=am}while(1){ag=ar+1|0;if((a[ag]|0)==0){ah=u;ai=19;break L82}else{ar=ag}}break};case 20:{bN(j|0,256,27368,(H=i,i=i+8|0,c[H>>2]=c[126403],H)|0)|0;i=H;ah=u;ai=20;break L82;break};case 21:{bN(j|0,256,27048,(H=i,i=i+8|0,h[H>>3]=+g[126396],H)|0)|0;i=H;ah=u;ai=21;break L82;break};case 22:{bN(j|0,256,27048,(H=i,i=i+8|0,h[H>>3]=+g[126397],H)|0)|0;i=H;ah=u;ai=22;break L82;break};case 23:{am=256;al=j;ag=(a[505622]&1)!=0?29560:29080;while(1){ak=am-1|0;if((ak|0)==0){break}aj=a[ag]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=23;break L82}else{am=ak;al=al+1|0;ag=ag+1|0}}a[al]=0;if((a[ag]|0)==0){ah=u;ai=23;break L82}else{as=ag}while(1){am=as+1|0;if((a[am]|0)==0){ah=u;ai=23;break L82}else{as=am}}break};case 18:{bN(j|0,256,27368,(H=i,i=i+8|0,c[H>>2]=c[126404],H)|0)|0;i=H;ah=u;ai=18;break L82;break};case 24:{do{if((a[513836]&1)==0){ag=756280;al=c[ag>>2]|0;am=c[ag+4>>2]|0;ag=0;ak=am>>>0>ag>>>0|am>>>0==ag>>>0&al>>>0>2048>>>0?2048:al;if(ak>>>0<2){break}else{at=0;au=0;av=0}do{al=739896+(at<<3)|0;av=wc(c[al>>2]|0,c[al+4>>2]|0,av,au)|0;au=G;at=at+1|0;}while(at>>>0<ak>>>0);al=wk(av,au,ak,0)|0;ag=G;am=0;aj=0;aw=0;do{ax=739896+(aw<<3)|0;ay=wd(c[ax>>2]|0,c[ax+4>>2]|0,al,ag)|0;ax=G;az=wm(ay,ax,ay,ax)|0;aj=wc(az,G,aj,am)|0;am=G;aw=aw+1|0;}while(aw>>>0<ak>>>0);aA=+(al>>>0)+ +(ag|0)*4294967296.0;aB=+S(+((+(aj>>>0)+ +(am|0)*4294967296.0)/+((ak-1|0)>>>0>>>0)))/aA*100.0;bN(j|0,256,26624,(H=i,i=i+24|0,h[H>>3]=1.0e6/aA,h[H+8>>3]=aB,c[H+16>>2]=ak,H)|0)|0;i=H;ah=u;ai=24;break L82}}while(0);a[j]=78;a[w]=47;a[x]=65;a[v]=0;ah=u;ai=24;break L82;break};case 10:{aw=256;az=j;ax=(a[505629]&1)!=0?29560:29080;while(1){ay=aw-1|0;if((ay|0)==0){break}aC=a[ax]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=10;break L82}else{aw=ay;az=az+1|0;ax=ax+1|0}}a[az]=0;if((a[ax]|0)==0){ah=u;ai=10;break L82}else{aD=ax}while(1){aw=aD+1|0;if((a[aw]|0)==0){ah=u;ai=10;break L82}else{aD=aw}}break};case 11:{ax=256;az=j;aw=11672+((c[126408]|0)*68|0)|0;while(1){ay=ax-1|0;if((ay|0)==0){break}aC=a[aw]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=11;break L82}else{ax=ay;az=az+1|0;aw=aw+1|0}}a[az]=0;if((a[aw]|0)==0){ah=u;ai=11;break L82}else{aE=aw}while(1){ax=aE+1|0;if((a[ax]|0)==0){ah=u;ai=11;break L82}else{aE=ax}}break};case 63:{aw=256;az=j;ax=(a[603772]&1)!=0?29560:29080;while(1){ay=aw-1|0;if((ay|0)==0){break}aC=a[ax]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=63;break L82}else{aw=ay;az=az+1|0;ax=ax+1|0}}a[az]=0;if((a[ax]|0)==0){ah=u;ai=63;break L82}else{aF=ax}while(1){aw=aF+1|0;if((a[aw]|0)==0){ah=u;ai=63;break L82}else{aF=aw}}break};case 64:{bN(j|0,256,27368,(H=i,i=i+8|0,c[H>>2]=c[150945],H)|0)|0;i=H;ah=u;ai=64;break L82;break};case 65:{ax=256;az=j;aw=(a[764982]&1)!=0?29560:29080;while(1){ay=ax-1|0;if((ay|0)==0){break}aC=a[aw]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=65;break L82}else{ax=ay;az=az+1|0;aw=aw+1|0}}a[az]=0;if((a[aw]|0)==0){ah=u;ai=65;break L82}else{aG=aw}while(1){ax=aG+1|0;if((a[ax]|0)==0){ah=u;ai=65;break L82}else{aG=ax}}break};case 66:{aw=256;az=j;ax=(c[150949]|0)!=0?29560:29080;while(1){ay=aw-1|0;if((ay|0)==0){break}aC=a[ax]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=66;break L82}else{aw=ay;az=az+1|0;ax=ax+1|0}}a[az]=0;if((a[ax]|0)==0){ah=u;ai=66;break L82}else{aH=ax}while(1){aw=aH+1|0;if((a[aw]|0)==0){ah=u;ai=66;break L82}else{aH=aw}}break};case 67:case 68:{bN(j|0,256,27712,(H=i,i=i+8|0,c[H>>2]=c[175548],H)|0)|0;i=H;ah=u;ai=af;break L82;break};case 81:{ax=256;az=j;aw=(a[707057]&1)!=0?29560:29080;while(1){ay=ax-1|0;if((ay|0)==0){break}aC=a[aw]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=81;break L82}else{ax=ay;az=az+1|0;aw=aw+1|0}}a[az]=0;if((a[aw]|0)==0){ah=u;ai=81;break L82}else{aI=aw}while(1){ax=aI+1|0;if((a[ax]|0)==0){ah=u;ai=81;break L82}else{aI=ax}}break};case 82:{bN(j|0,256,25976,(H=i,i=i+8|0,h[H>>3]=+g[132579],H)|0)|0;i=H;ah=u;ai=82;break L82;break};case 84:{aw=764968;bN(j|0,256,((c[aw>>2]&256|0)!=0|(c[aw+4>>2]&0|0)!=0?29560:29080)|0,(H=i,i=i+1|0,i=i+7>>3<<3,c[H>>2]=0,H)|0)|0;i=H;ah=u;ai=84;break L82;break};case 73:{aw=256;az=j;ax=(a[603809]|0)!=0?603809:25624;while(1){ay=aw-1|0;if((ay|0)==0){break}aC=a[ax]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=73;break L82}else{aw=ay;az=az+1|0;ax=ax+1|0}}a[az]=0;if((a[ax]|0)==0){ah=u;ai=73;break L82}else{aJ=ax}while(1){aw=aJ+1|0;if((a[aw]|0)==0){ah=u;ai=73;break L82}else{aJ=aw}}break};case 76:{ax=256;az=j;aw=(a[677610]|0)!=0?677610:25104;while(1){ay=ax-1|0;if((ay|0)==0){break}aC=a[aw]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=76;break L82}else{ax=ay;az=az+1|0;aw=aw+1|0}}a[az]=0;if((a[aw]|0)==0){ah=u;ai=76;break L82}else{aK=aw}while(1){ax=aK+1|0;if((a[ax]|0)==0){ah=u;ai=76;break L82}else{aK=ax}}break};case 78:{aw=256;az=j;ax=(a[685802]|0)!=0?685802:25624;while(1){ay=aw-1|0;if((ay|0)==0){break}aC=a[ax]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=78;break L82}else{aw=ay;az=az+1|0;ax=ax+1|0}}a[az]=0;if((a[ax]|0)==0){ah=u;ai=78;break L82}else{aL=ax}while(1){aw=aL+1|0;if((a[aw]|0)==0){ah=u;ai=78;break L82}else{aL=aw}}break};case 75:{ax=256;az=j;aw=(a[681706]|0)!=0?681706:25104;while(1){ay=ax-1|0;if((ay|0)==0){break}aC=a[aw]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=75;break L82}else{ax=ay;az=az+1|0;aw=aw+1|0}}a[az]=0;if((a[aw]|0)==0){ah=u;ai=75;break L82}else{aM=aw}while(1){ax=aM+1|0;if((a[ax]|0)==0){ah=u;ai=75;break L82}else{aM=ax}}break};case 74:{aw=256;az=j;ax=(a[513837]|0)!=0?513837:25624;while(1){ay=aw-1|0;if((ay|0)==0){break}aC=a[ax]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=74;break L82}else{aw=ay;az=az+1|0;ax=ax+1|0}}a[az]=0;if((a[ax]|0)==0){ah=u;ai=74;break L82}else{aN=ax}while(1){aw=aN+1|0;if((a[aw]|0)==0){ah=u;ai=74;break L82}else{aN=aw}}break};case 79:{ax=256;az=j;aw=(a[599676]|0)!=0?599676:25104;while(1){ay=ax-1|0;if((ay|0)==0){break}aC=a[aw]|0;a[az]=aC;if(aC<<24>>24==0){ah=u;ai=79;break L82}else{ax=ay;az=az+1|0;aw=aw+1|0}}a[az]=0;if((a[aw]|0)==0){ah=u;ai=79;break L82}else{aO=aw}while(1){ax=aO+1|0;if((a[ax]|0)==0){ah=u;ai=79;break L82}else{aO=ax}}break};case 70:{aw=fu[c[176732]&31]()|0;az=fu[c[176730]&31]()|0;if(az>>>0<aw>>>0){aw=az+1|0;bN(j|0,256,27368,(H=i,i=i+8|0,c[H>>2]=aw,H)|0)|0;i=H;ah=u;ai=70;break L82}else{a[j]=78;a[w]=111;a[x]=32;a[v]=68;a[B]=105;a[C]=115;a[z]=107;a[A]=0;ah=u;ai=70;break L82}break};case 88:{aw=cf(566896,47)|0;az=256;ax=j;ay=(aw|0)==0?566896:aw+1|0;while(1){aw=az-1|0;if((aw|0)==0){break}aC=a[ay]|0;a[ax]=aC;if(aC<<24>>24==0){ah=u;ai=88;break L82}else{az=aw;ax=ax+1|0;ay=ay+1|0}}a[ax]=0;if((a[ay]|0)==0){ah=u;ai=88;break L82}else{aP=ay}while(1){az=aP+1|0;if((a[az]|0)==0){ah=u;ai=88;break L82}else{aP=az}}break};case 89:{bN(j|0,256,24112,(H=i,i=i+8|0,h[H>>3]=+g[142748],H)|0)|0;i=H;ah=u;ai=89;break L82;break};case 90:{bN(j|0,256,24112,(H=i,i=i+8|0,h[H>>3]=+g[142749],H)|0)|0;i=H;ah=u;ai=90;break L82;break};case 91:{bN(j|0,256,23864,(H=i,i=i+8|0,c[H>>2]=ad+1,H)|0)|0;i=H;ah=u;ai=91;break L82;break};case 92:{ay=c[566276+(ad<<2)>>2]|0;if(ay>>>0>=8){a[j]=68;a[w]=105;a[x]=115;a[v]=97;a[B]=98;a[C]=108;a[z]=101;a[A]=100;a[J]=0;ah=u;ai=92;break L82}ax=566340+(ay<<6)|0;if((a[ax]|0)==0){bN(j|0,256,23568,(H=i,i=i+8|0,c[H>>2]=ay,H)|0)|0;i=H;ah=u;ai=92;break L82}else{aQ=256;aR=j;aS=ax}while(1){ax=aQ-1|0;if((ax|0)==0){break}ay=a[aS]|0;a[aR]=ay;if(ay<<24>>24==0){ah=u;ai=92;break L82}else{aQ=ax;aR=aR+1|0;aS=aS+1|0}}a[aR]=0;if((a[aS]|0)==0){ah=u;ai=92;break L82}else{aT=aS}while(1){ax=aT+1|0;if((a[ax]|0)==0){ah=u;ai=92;break L82}else{aT=ax}}break};case 93:{switch(c[607932+(ad<<2)>>2]|0){case 1:{aU=256;aV=j;aW=22840;break};case 5:{aU=256;aV=j;aW=22544;break};case 257:{aU=256;aV=j;aW=22424;break};case 2:{aU=256;aV=j;aW=21880;break};case 516:{aU=256;aV=j;aW=21344;break};case 772:{aU=256;aV=j;aW=20976;break};case 260:{aU=256;aV=j;aW=20472;break};case 0:{aU=256;aV=j;aW=23048;break};default:{aU=256;aV=j;aW=20328}}while(1){ax=aU-1|0;if((ax|0)==0){break}ay=a[aW]|0;a[aV]=ay;if(ay<<24>>24==0){ah=u;ai=93;break L82}else{aU=ax;aV=aV+1|0;aW=aW+1|0}}a[aV]=0;if((a[aW]|0)==0){ah=u;ai=93;break L82}else{aX=aW}while(1){ax=aX+1|0;if((a[ax]|0)==0){ah=u;ai=93;break L82}else{aX=ax}}break};case 94:{ax=c[566852+(ad<<2)>>2]|0;if((ax|0)==2){a[j]=82;a[w]=105;a[x]=103;a[v]=104;a[B]=116;a[C]=32;a[z]=83;a[A]=116;a[J]=105;a[K]=99;a[L]=107;a[P]=0;ah=u;ai=94;break L82}else if((ax|0)==3){a[j]=68;a[w]=117;a[x]=97;a[v]=108;a[B]=32;a[C]=65;a[z]=110;a[A]=97;a[J]=108;a[K]=111;a[L]=103;a[P]=0;ah=u;ai=94;break L82}else if((ax|0)==1){a[j]=76;a[w]=101;a[x]=102;a[v]=116;a[B]=32;a[C]=83;a[z]=116;a[A]=105;a[J]=99;a[K]=107;a[L]=0;ah=u;ai=94;break L82}else if((ax|0)==0){a[j]=78;a[w]=111;a[x]=110;a[v]=101;a[B]=0;ah=u;ai=94;break L82}else{ah=u;ai=94;break L82}break};case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:case 105:case 106:case 107:case 108:case 109:case 110:{ax=c[2080+(af-95<<2)>>2]|0;a[l]=85;a[m]=110;a[Y]=107;a[Z]=110;a[_]=111;a[$]=119;a[aa]=110;a[ab]=0;ay=530424+(ad*2240|0)+(ax*40|0)+16|0;ax=c[ay+4>>2]|0;c[k>>2]=c[ay>>2];c[k+4>>2]=ax;ax=c[(c[191560]|0)+20>>2]|0;if((ax|0)==0){aY=256;aZ=j;a_=l}else{e8[ax&15](D,0,0,0,256);aY=256;aZ=j;a_=l}while(1){ax=aY-1|0;if((ax|0)==0){break}ay=a[a_]|0;a[aZ]=ay;if(ay<<24>>24==0){ah=u;ai=af;break L82}else{aY=ax;aZ=aZ+1|0;a_=a_+1|0}}a[aZ]=0;if((a[a_]|0)==0){ah=u;ai=af;break L82}else{a$=a_}while(1){ax=a$+1|0;if((a[ax]|0)==0){ah=u;ai=af;break L82}else{a$=ax}}break};case 55:case 56:case 58:case 12:case 14:case 5:case 59:case 69:case 26:case 28:case 57:case 71:case 60:case 61:case 62:{a[j]=46;a[w]=46;a[x]=46;a[v]=0;ah=u;ai=af;break L82;break};case 1:{a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break L82;break};case 0:{a[j]=40;a[w]=70;a[x]=73;a[v]=76;a[B]=69;a[C]=41;a[z]=0;ah=6;ai=0;break L82;break};default:{a[j]=0;ah=0;ai=af;break L82}}}}while(0);if((af|0)==3){a[j]=0;ah=0;ai=3;break}else if((af|0)==0){a[j]=40;a[w]=70;a[x]=73;a[v]=76;a[B]=69;a[C]=41;a[z]=0;ah=6;ai=0;break}else{a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break}}}while(0);af=(n|0)==(c[q>>2]|0);ad=256;ax=f;ay=ae;while(1){az=ad-1|0;if((az|0)==0){F=225;break}aw=a[ay]|0;a[ax]=aw;if(aw<<24>>24==0){a0=64;a1=o;a2=j;break}else{ad=az;ax=ax+1|0;ay=ay+1|0}}do{if((F|0)==225){F=0;a[ax]=0;if((a[ay]|0)==0){a0=64;a1=o;a2=j;break}else{a3=ay}while(1){ad=a3+1|0;if((a[ad]|0)==0){a0=64;a1=o;a2=j;break}else{a3=ad}}}}while(0);while(1){ay=a0-1|0;if((ay|0)==0){F=229;break}ax=a[a2]|0;a[a1]=ax;if(ax<<24>>24==0){break}else{a0=ay;a1=a1+1|0;a2=a2+1|0}}do{if((F|0)==229){F=0;a[a1]=0;if((a[a2]|0)==0){break}else{a4=a2}do{a4=a4+1|0;}while((a[a4]|0)!=0)}}while(0);if(ai>>>0<2){ay=-3-ah|0;ij(f,ay+48|0,((c[191184]|0)>>>0)/15|0,ae,af);a5=ay}else{ij(o,ah,((c[191184]|0)>>>0)/15|0,j,af);a5=-3-ah|0}ay=a5+48|0;bN(p|0,256,19928,(H=i,i=i+48|0,c[H>>2]=af?62:32,c[H+8>>2]=ay,c[H+16>>2]=ay,c[H+24>>2]=f,c[H+32>>2]=ah,c[H+40>>2]=o,H)|0)|0;i=H;iq(d,15,s,p,af);ay=n+1|0;if(ay>>>0<r>>>0){n=ay;s=s+11|0}else{break}}i=e;return}function iq(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=a[h]|0;if(j<<24>>24==0){return}k=e+4152|0;l=i?32639:-1;i=e+32|0;m=e+28|0;e=h;h=f;f=j;while(1){j=h+4|0;n=h+3|0;o=h+2|0;p=h+1|0;q=0;r=f;while(1){s=q*5|0;t=q+g|0;u=c[k>>2]|0;if((1<<(s&7)&(d[u+((s>>3)+((r&255)*7|0))|0]|0)|0)==0){v=r;w=u}else{u=(ac((c[i>>2]|0)>>>1,t)|0)+h|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;v=a[e]|0;w=c[k>>2]|0}u=s+1|0;if(((d[w+(((v&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){x=v;y=w}else{u=p+(ac((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;x=a[e]|0;y=c[k>>2]|0}u=s+2|0;if(((d[y+(((x&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){z=x;A=y}else{u=o+(ac((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;z=a[e]|0;A=c[k>>2]|0}u=s+3|0;if(((d[A+(((z&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){B=z;C=A}else{u=n+(ac((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;B=a[e]|0;C=c[k>>2]|0}u=s+4|0;if(((d[C+(((B&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)!=0){u=j+(ac((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l}u=q+1|0;if((u|0)>=10){break}q=u;r=a[e]|0}r=e+1|0;q=a[r]|0;if(q<<24>>24==0){break}else{e=r;h=h+6|0;f=q}}return}function ir(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+16|0;f=e|0;g=a+4|0;h=c[g>>2]|0;L382:do{if((h|0)==0){j=0}else{k=a|0;l=c[k>>2]|0;L384:do{if((b|0)==0){m=0;while(1){do{if((c[l+(m*12|0)>>2]|0)==0){if((cJ(c[l+(m*12|0)+4>>2]|0,583292)|0)!=0){break}if((cJ(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L384}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L382}}}else{m=0;while(1){o=c[l+(m*12|0)>>2]|0;do{if((o|0)!=0){if((cJ(b|0,o|0)|0)!=0){break}if((cJ(c[l+(m*12|0)+4>>2]|0,583292)|0)!=0){break}if((cJ(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L384}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L382}}}}while(0);if((n|0)==0){i=e;return}m=f;o=l+(n*12|0)|0;c[m>>2]=c[o>>2];c[m+4>>2]=c[o+4>>2];c[m+8>>2]=c[o+8>>2];wa(l+12|0,l|0,n*12|0|0);o=c[k>>2]|0;c[o>>2]=c[m>>2];c[o+4>>2]=c[m+4>>2];c[o+8>>2]=c[m+8>>2];i=e;return}}while(0);n=a+8|0;f=c[n>>2]|0;if((j|0)==(f|0)){h=j-1|0;j=a|0;m=c[j>>2]|0;o=m+(h*12|0)|0;v_(c[o>>2]|0);v_(c[m+(h*12|0)+4>>2]|0);v_(c[m+(h*12|0)+8>>2]|0);v3(o|0,0,12);c[g>>2]=(c[g>>2]|0)-1;p=c[n>>2]|0;q=j}else{p=f;q=a|0}a=c[q>>2]|0;wa(a+12|0,a|0,(p*12|0)-12|0);if((b|0)==0){r=0}else{r=dn(b|0)|0}c[c[q>>2]>>2]=r;r=dn(583292)|0;c[(c[q>>2]|0)+4>>2]=r;r=dn(d|0)|0;c[(c[q>>2]|0)+8>>2]=r;c[g>>2]=(c[g>>2]|0)+1;i=e;return}function is(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;if((a|0)==0){i=b;return}d=a+12|0;e=c[d>>2]|0;do{if((e|0)!=0){f=c2(e|0,47696)|0;if((f|0)==0){break}g=a+4|0;if((c[g>>2]|0)!=0){h=a|0;j=0;do{k=c[h>>2]|0;l=c[k+(j*12|0)>>2]|0;m=c[k+(j*12|0)+4>>2]|0;n=c[k+(j*12|0)+8>>2]|0;eb(f|0,35616,(k=i,i=i+24|0,c[k>>2]=(l|0)==0?766672:l,c[k+8>>2]=m,c[k+16>>2]=n,k)|0)|0;i=k;j=j+1|0;}while(j>>>0<(c[g>>2]|0)>>>0)}aR(f|0)|0}}while(0);v_(c[d>>2]|0);d=a+8|0;e=a|0;g=c[e>>2]|0;if((c[d>>2]|0)==0){o=g}else{j=0;h=g;while(1){g=h+(j*12|0)|0;v_(c[g>>2]|0);v_(c[h+(j*12|0)+4>>2]|0);v_(c[h+(j*12|0)+8>>2]|0);v3(g|0,0,12);g=j+1|0;k=c[e>>2]|0;if(g>>>0<(c[d>>2]|0)>>>0){j=g;h=k}else{o=k;break}}}v_(o);v_(a);i=b;return}function it(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+72|0;h=f|0;j=f+8|0;k=f+40|0;l=b+4|0;m=c[l>>2]|0;if((m|0)==0){i=f;return}if((fu[c[m+16>>2]&31]()|0)==0){i=f;return}m=j|0;a[m]=0;n=c[l>>2]|0;do{if((n|0)==0){o=320}else{fa[c[n+28>>2]&127](1,j);p=c[l>>2]|0;if((p|0)==0){o=320;break}r=fu[c[p+16>>2]&31]()|0;p=c[l>>2]|0;s=k|0;a[s]=0;if((p|0)==0){t=0;u=s;break}fa[c[p+28>>2]&127](r,k);r=c[l>>2]|0;if((r|0)==0){t=0;u=s;break}do{if((fu[c[r+16>>2]&31]()|0)==1){if((a[m]&1)!=0){break}i=f;return}}while(0);r=c[l>>2]|0;if((r|0)==0){t=0;u=s;break}t=fu[c[r+16>>2]&31]()|0;u=s}}while(0);if((o|0)==320){n=k|0;a[n]=0;t=0;u=n}n=t-1|0;k=b+1636|0;c[k>>2]=n;if((a[u]&1)==0){v=n}else{c[k>>2]=t;v=t}if((a[m]&1)==0){g[j+12>>2]=1.0;g[j+16>>2]=1.0;c[j+8>>2]=0;c[j+4>>2]=0;a[m]=1}j=b+1124|0;t=j;v6(j|0,m|0,32)|0;if((v|0)>1){v=1;while(1){m=v+1|0;j=t+(v<<5)|0;n=j|0;a[n]=0;u=c[l>>2]|0;if((u|0)==0){o=335}else{fa[c[u+28>>2]&127](m,j);if((a[n]&1)==0){o=335}}if((o|0)==335){o=0;g[t+(v<<5)+16>>2]=1.0;g[t+(v<<5)+12>>2]=1.0;c[t+(v<<5)+8>>2]=0;c[t+(v<<5)+4>>2]=0;a[n]=1}if((m|0)<(c[k>>2]|0)){v=m}else{break}}}iu(b,d,e,c[b+1728>>2]|0,c[b+1732>>2]|0);e=c[k>>2]|0;if((e|0)>0){d=b+740|0;v=0;while(1){m=(c[d+(v*24|0)>>2]|0)-1|0;n=m>>>1|m;m=n>>>2|n;n=m>>>4|m;m=n>>>8|n;n=(m>>>16|m)+1|0;c[d+(v*24|0)+16>>2]=n;m=(c[d+(v*24|0)+4>>2]|0)-1|0;j=m>>>1|m;m=j>>>2|j;j=m>>>4|m;m=j>>>8|j;j=(m>>>16|m)+1|0;c[d+(v*24|0)+20>>2]=j;if((a[607928]&1)!=0){m=c[191244]|0;u=(m|0)!=0?m:c[q>>2]|0;eb(u|0,41208,(w=i,i=i+24|0,c[w>>2]=v,c[w+8>>2]=n,c[w+16>>2]=j,w)|0)|0;i=w;j=c[191244]|0;n=(j|0)!=0?j:c[q>>2]|0;aZ(n|0)|0}n=v+1|0;j=c[k>>2]|0;if((n|0)<(j|0)){v=n}else{x=j;break}}}else{x=e}e=b+676|0;v=e;d=e;bx(x|0,d|0);x=(a[505620]&1)!=0?9729:9728;if((c[k>>2]|0)>0){e=b+740|0;j=b+2584|0;n=0;do{aY(3553,c[v+(n<<2)>>2]|0);a[h]=0;u=c[l>>2]|0;do{if((u|0)==0){y=33071;z=x}else{m=n+2|0;if(fr[c[u+20>>2]&63](m,h)|0){A=(a[h]&1)!=0?9729:9728}else{A=x}r=c[l>>2]|0;if((r|0)==0){y=33071;z=A;break}p=fc[c[r+24>>2]&127](m)|0;if((p|0)==2){y=10497;z=A;break}else if((p|0)==3){y=33648;z=A;break}else if((p|0)==0|(p|0)==1){y=33071;z=A;break}else{y=0;z=A;break}}}while(0);eV(3553,10240,z|0);eV(3553,10241,z|0);eV(3553,10242,y|0);eV(3553,10243,y|0);do{if((a[t+(n<<5)|0]&1)==0){o=363}else{if((a[t+(n<<5)+28|0]&1)==0){o=363;break}do{if((a[j]&1)==0){u=a2(7939)|0;if((u|0)==0){B=0;break}B=(bu(u|0,23016)|0)!=0}else{B=0}}while(0);if((a[607928]&1)!=0){u=c[191244]|0;s=(u|0)!=0?u:c[q>>2]|0;u=B?48872:46680;eb(s|0,51104,(w=i,i=i+16|0,c[w>>2]=23016,c[w+8>>2]=u,w)|0)|0;i=w;u=c[191244]|0;s=(u|0)!=0?u:c[q>>2]|0;aZ(s|0)|0}if(!B){s=c[191244]|0;u=(s|0)!=0?s:c[q>>2]|0;a3(22768,67,1,u|0)|0;u=c[191244]|0;s=(u|0)!=0?u:c[q>>2]|0;aZ(s|0)|0}if((a[607928]&1)!=0){s=c[191244]|0;u=(s|0)!=0?s:c[q>>2]|0;eb(u|0,22496,(w=i,i=i+8|0,c[w>>2]=n,w)|0)|0;i=w;u=c[191244]|0;s=(u|0)!=0?u:c[q>>2]|0;aZ(s|0)|0}d1(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5126,0)}}while(0);if((o|0)==363){o=0;d1(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5121,0)}n=n+1|0;}while((n|0)<(c[k>>2]|0))}aY(3553,0);aY(3553,0);n=b+612|0;e=n;w=n;dM(c[k>>2]|0,w|0);n=0;while(1){if((n|0)>=(c[k>>2]|0)){o=369;break}b$(36160,c[e+(n<<2)>>2]|0);dr(36160,36064,3553,c[v+(n<<2)>>2]|0,0);if((ck(36160)|0)==36053){n=n+1|0}else{o=368;break}}if((o|0)==368){b5(c[k>>2]|0,w|0);w=c[191244]|0;n=(w|0)!=0?w:c[q>>2]|0;a3(23280,94,1,n|0)|0;n=c[191244]|0;w=(n|0)!=0?n:c[q>>2]|0;aZ(w|0)|0;bf(c[k>>2]|0,d|0);d=c[191244]|0;k=(d|0)!=0?d:c[q>>2]|0;a3(47616,78,1,k|0)|0;k=c[191244]|0;d=(k|0)!=0?k:c[q>>2]|0;aZ(d|0)|0;i=f;return}else if((o|0)==369){a[b+1640|0]=1;i=f;return}}function iu(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,r=0.0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+8|0;j=h|0;k=c[a+1832>>2]|0;l=c[a+1836>>2]|0;c[j>>2]=0;dS(3379,j|0);m=a+1636|0;if((c[m>>2]|0)<=0){i=h;return}n=a+1124|0;o=a+740|0;p=+(f>>>0>>>0);r=+(e>>>0>>>0);e=b;b=d;d=k;k=l;l=0;f=0;while(1){a=c[n+(f<<5)+4>>2]|0;if((a|0)==0){s=+g[n+(f<<5)+12>>2];c[o+(f*24|0)>>2]=~~(+(e>>>0>>>0)*s);c[o+(f*24|0)+8>>2]=~~(+(d>>>0>>>0)*s)}else if((a|0)==1){t=c[n+(f<<5)+20>>2]|0;c[o+(f*24|0)+8>>2]=t;c[o+(f*24|0)>>2]=t}else if((a|0)==2){a=~~(r*+g[n+(f<<5)+12>>2]);c[o+(f*24|0)+8>>2]=a;c[o+(f*24|0)>>2]=a}a=c[n+(f<<5)+8>>2]|0;if((a|0)==0){s=+g[n+(f<<5)+16>>2];c[o+(f*24|0)+4>>2]=~~(+(b>>>0>>>0)*s);c[o+(f*24|0)+12>>2]=~~(+(k>>>0>>>0)*s)}else if((a|0)==1){t=c[n+(f<<5)+24>>2]|0;c[o+(f*24|0)+12>>2]=t;c[o+(f*24|0)+4>>2]=t}else if((a|0)==2){a=~~(p*+g[n+(f<<5)+16>>2]);c[o+(f*24|0)+12>>2]=a;c[o+(f*24|0)+4>>2]=a}a=o+(f*24|0)|0;t=c[a>>2]|0;u=c[j>>2]|0;if(t>>>0>u>>>0){c[a>>2]=u;v=1;w=u}else{v=l;w=t}t=o+(f*24|0)+4|0;x=c[t>>2]|0;if(x>>>0>u>>>0){c[t>>2]=u;y=1;z=u}else{y=v;z=x}x=o+(f*24|0)+8|0;A=c[x>>2]|0;if(A>>>0>u>>>0){c[x>>2]=u;B=1;C=u}else{B=y;C=A}A=o+(f*24|0)+12|0;D=c[A>>2]|0;if(D>>>0>u>>>0){c[A>>2]=u;E=395}else{if(B){E=395}else{F=0;G=w;H=z;I=C;J=D}}if((E|0)==395){E=0;D=c[191244]|0;K=(D|0)!=0?D:c[q>>2]|0;eb(K|0,22328,(K=i,i=i+16|0,c[K>>2]=u,c[K+8>>2]=u,K)|0)|0;i=K;K=c[191244]|0;u=(K|0)!=0?K:c[q>>2]|0;aZ(u|0)|0;F=1;G=c[a>>2]|0;H=c[t>>2]|0;I=c[x>>2]|0;J=c[A>>2]|0}A=f+1|0;if((A|0)<(c[m>>2]|0)){e=G;b=H;d=I;k=J;l=F;f=A}else{break}}i=h;return}function iv(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+64|0;j=h|0;k=c[(c[b>>2]|0)+24>>2]|0;if((k|0)==0){l=+(d>>>0>>>0)/+(e>>>0>>>0)}else{l=+fk[k&3](d,e)}do{if((a[505629]&1)==0){if((a[b+1714|0]&1)==0){c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=d;c[b+1748>>2]=e;m=d;n=e;o=0;p=0;break}q=+g[175568];do{if((c[126408]|0)==7){k=c[191232]|0;r=c[191231]|0;s=k;t=(c[b+1732>>2]|0)-(c[191230]|0)-k|0;u=c[191229]|0}else{if(+R(+(l-q))<9999999747378752.0e-20){r=d;s=e;t=0;u=0;break}if(l>q){v=(q/l+-1.0)*.5+.5;w=+(d>>>0>>>0);k=~~+bH(+(w*(.5-v)));r=~~+bH(+(w*2.0*v));s=e;t=0;u=k;break}else{v=(l/q+-1.0)*.5+.5;w=+(e>>>0>>>0);k=~~+bH(+(w*(.5-v)));r=d;s=~~+bH(+(w*2.0*v));t=k;u=0;break}}}while(0);c[b+1736>>2]=u;c[b+1740>>2]=t;c[b+1744>>2]=r;c[b+1748>>2]=s;m=r;n=s;o=u;p=t}else{k=b+1736|0;x=(a[b+1714|0]&1)==0;if((c[126408]|0)==7){y=c[191231]|0;z=c[191232]|0;A=y;B=z;C=d-y|0;D=e-z|0}else{z=c[175559]|0;y=~~+bH(+(+g[175568]*+(z>>>0>>>0)));do{if(y>>>0>d>>>0|z>>>0>e>>>0){E=0;F=0}else{if(x){E=(d>>>0)%(y>>>0)|0;F=(e>>>0)%(z>>>0)|0;break}else{G=(d>>>0)/(y>>>0)|0;H=(e>>>0)/(z>>>0)|0;I=G>>>0<H>>>0?G:H;H=d-(ac(I,y)|0)|0;E=H;F=e-(ac(I,z)|0)|0;break}}}while(0);A=d-E|0;B=e-F|0;C=E;D=F}c[b+1744>>2]=A;c[b+1748>>2]=B;z=(C|0)/2|0;c[k>>2]=z;y=(D|0)/2|0;c[b+1740>>2]=y;m=A;n=B;o=z;p=y}}while(0);eD(o|0,p|0,m|0,n|0);p=b+1936|0;v3(p|0,0,48);g[b+1996>>2]=1.0;g[p>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;if(f){l=+((c[b+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0;q=+U(+l);v=+V(+l);v3(j|0,0,60);g[j+40>>2]=1.0;g[j+60>>2]=1.0;g[j>>2]=q;g[j+20>>2]=q;g[j+16>>2]=-0.0-v;g[j+4>>2]=v;i_(b+1872|0,j,p);J=b+1760|0;K=J;c[K>>2]=m;L=b+1764|0;M=L;c[M>>2]=n;i=h;return}else{j=b+1872|0;v6(j|0,p|0,64)|0;J=b+1760|0;K=J;c[K>>2]=m;L=b+1764|0;M=L;c[M>>2]=n;i=h;return}}function iw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+8|0;h=f|0;j=vZ(2592)|0;if((j|0)==0){k=0;i=f;return k|0}if((c[j-4>>2]&3|0)!=0){v3(j|0,0,2592)}l=j;m=c[176740]|0;n=c[176741]|0;L590:do{if((a[505552]|0)==0){do{if((bg(12448)|0)!=0){if(!(jb()|0)){break}o=j;c[o>>2]=9304;p=9304;r=o;break L590}}while(0);c[j>>2]=0;s=442}else{o=(cJ(40552,505552)|0)==0;t=o?9304:0;if(!o){o=c[191244]|0;u=(o|0)!=0?o:c[q>>2]|0;eb(u|0,23512,(v=i,i=i+8|0,c[v>>2]=505552,v)|0)|0;i=v;u=c[191244]|0;o=(u|0)!=0?u:c[q>>2]|0;aZ(o|0)|0;s=442;break}if(!(fg[c[t+8>>2]&63](1,m,n)|0)){o=c[191244]|0;u=(o|0)!=0?o:c[q>>2]|0;eb(u|0,24048,(v=i,i=i+16|0,c[v>>2]=24272,c[v+8>>2]=505552,v)|0)|0;i=v;u=c[191244]|0;o=(u|0)!=0?u:c[q>>2]|0;aZ(o|0)|0;s=442;break}if(fu[c[t>>2]&31]()|0){o=j;c[o>>2]=t;p=t;r=o;break}else{o=c[191244]|0;u=(o|0)!=0?o:c[q>>2]|0;o=c[t+68>>2]|0;eb(u|0,23808,(v=i,i=i+8|0,c[v>>2]=o,v)|0)|0;i=v;o=c[191244]|0;u=(o|0)!=0?o:c[q>>2]|0;aZ(u|0)|0;s=442;break}}}while(0);if((s|0)==442){v_(j);k=0;i=f;return k|0}n=j+2476|0;m=b;c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];c[n+12>>2]=c[m+12>>2];c[n+16>>2]=c[m+16>>2];if((a[607928]&1)==0){w=p}else{m=c[191244]|0;n=(m|0)!=0?m:c[q>>2]|0;m=c[p+68>>2]|0;eb(n|0,34840,(v=i,i=i+8|0,c[v>>2]=m,v)|0)|0;i=v;m=c[191244]|0;n=(m|0)!=0?m:c[q>>2]|0;aZ(n|0)|0;w=c[r>>2]|0}n=j+1720|0;m=j+1724|0;fa[c[w+20>>2]&127](n,m);if((a[607928]&1)!=0){w=c[191244]|0;p=(w|0)!=0?w:c[q>>2]|0;w=c[n>>2]|0;u=c[m>>2]|0;eb(p|0,33512,(v=i,i=i+16|0,c[v>>2]=w,c[v+8>>2]=u,v)|0)|0;i=v;u=c[191244]|0;w=(u|0)!=0?u:c[q>>2]|0;aZ(w|0)|0}w=b+9|0;e9[c[(c[r>>2]|0)+12>>2]&2047]((a[w]&1)!=0?c[126403]|0:0);u=c[b>>2]|0;p=c[b+4>>2]|0;o=b+8|0;t=(a[o]&1)!=0;if(t&(u|0)==0&(p|0)==0){x=c[n>>2]|0;z=c[m>>2]|0}else{x=u;z=p}if(!(fg[c[(c[r>>2]|0)+16>>2]&63](x,z,t)|0)){v_(j);k=0;i=f;return k|0}dD()|0;t=a2(7936)|0;z=a2(7937)|0;if((a[607928]&1)!=0){x=c[191244]|0;p=(x|0)!=0?x:c[q>>2]|0;eb(p|0,32464,(v=i,i=i+16|0,c[v>>2]=t,c[v+8>>2]=z,v)|0)|0;i=v;z=c[191244]|0;t=(z|0)!=0?z:c[q>>2]|0;aZ(t|0)|0}t=a2(7938)|0;if((a[607928]&1)!=0){z=c[191244]|0;p=(z|0)!=0?z:c[q>>2]|0;eb(p|0,31952,(v=i,i=i+8|0,c[v>>2]=t,v)|0)|0;i=v;t=c[191244]|0;p=(t|0)!=0?t:c[q>>2]|0;aZ(p|0)|0}p=c[(c[r>>2]|0)+52>>2]|0;t=2144;z=40056;do{x=fc[p&127](z)|0;u=c[t+4>>2]|0;y=x;a[u]=y&255;y=y>>8;a[u+1|0]=y&255;y=y>>8;a[u+2|0]=y&255;y=y>>8;a[u+3|0]=y&255;t=t+8|0;z=c[t>>2]|0;}while((z|0)!=0);ey(770,771);a[766412]=0;z=j+2584|0;do{if((a[z]&1)==0){t=a2(7939)|0;if((t|0)==0){A=0;break}A=(bu(t|0,25960)|0)!=0}else{A=0}}while(0);if((a[607928]&1)!=0){t=c[191244]|0;p=(t|0)!=0?t:c[q>>2]|0;t=A?48872:46680;eb(p|0,51104,(v=i,i=i+16|0,c[v>>2]=25960,c[v+8>>2]=t,v)|0)|0;i=v;t=c[191244]|0;p=(t|0)!=0?t:c[q>>2]|0;aZ(p|0)|0}do{if(A){if((a[607928]&1)==0){break}p=c[191244]|0;t=(p|0)!=0?p:c[q>>2]|0;a3(25568,52,1,t|0)|0;t=c[191244]|0;p=(t|0)!=0?t:c[q>>2]|0;aZ(p|0)|0}else{a[766412]=1;p=c[191244]|0;t=(p|0)!=0?p:c[q>>2]|0;a3(24984,117,1,t|0)|0;t=c[191244]|0;p=(t|0)!=0?t:c[q>>2]|0;aZ(p|0)|0}}while(0);a[j+8|0]=a[w]&1;a[j+1713|0]=a[o]&1;o=j+1728|0;w=j+1732|0;fa[c[(c[r>>2]|0)+20>>2]&127](o,w);if((a[607928]&1)!=0){A=c[191244]|0;p=(A|0)!=0?A:c[q>>2]|0;A=c[o>>2]|0;t=c[w>>2]|0;eb(p|0,31200,(v=i,i=i+16|0,c[v>>2]=A,c[v+8>>2]=t,v)|0)|0;i=v;t=c[191244]|0;A=(t|0)!=0?t:c[q>>2]|0;aZ(A|0)|0}if((c[n>>2]|0)==0){if((c[m>>2]|0)!=0){s=470}}else{s=470}if((s|0)==470){c[n>>2]=c[o>>2];c[m>>2]=c[w>>2]}m=j+2016|0;c[m>>2]=(a[706958]&1)!=0?168:136;n=j+48|0;c[n>>2]=4;A=(c[176735]|0)==2;t=j+1710|0;a[t]=A&1;if(A){c[n>>2]=1}A=j+2020|0;c[A>>2]=8;c[124238]=c[(c[r>>2]|0)+52>>2];p=c[176740]|0;u=c[176741]|0;a[496960]=a[z]&1;c[124236]=p;c[124234]=u;if((a[509732]&1)==0){B=0}else{B=(a[505636]|0)!=0?505636:0}u=h0(B,2)|0;do{if((u|0)==3){if((a[607928]&1)==0){break}p=c[191244]|0;z=(p|0)!=0?p:c[q>>2]|0;a3(27664,41,1,z|0)|0;z=c[191244]|0;p=(z|0)!=0?z:c[q>>2]|0;aZ(p|0)|0}else if((u|0)==2){if((a[607928]&1)!=0){p=c[191244]|0;z=(p|0)!=0?p:c[q>>2]|0;a3(27320,44,1,z|0)|0;z=c[191244]|0;p=(z|0)!=0?z:c[q>>2]|0;aZ(p|0)|0}p=j+4|0;c[p>>2]=9192;if(ji(B)|0){break}z=c[191244]|0;a3(26328,73,1,((z|0)!=0?z:c[q>>2]|0)|0)|0;z=c[191244]|0;aZ(((z|0)!=0?z:c[q>>2]|0)|0)|0;if(fc[c[c[p>>2]>>2]&127](0)|0){break}p=c[191244]|0;a3(30568,47,1,((p|0)!=0?p:c[q>>2]|0)|0)|0;p=c[191244]|0;aZ(((p|0)!=0?p:c[q>>2]|0)|0)|0;fx[c[(c[r>>2]|0)+4>>2]&127]();v_(j);k=0;i=f;return k|0}else{p=c[191244]|0;a3(26952,89,1,((p|0)!=0?p:c[q>>2]|0)|0)|0;p=c[191244]|0;aZ(((p|0)!=0?p:c[q>>2]|0)|0)|0}}while(0);B=j+4|0;u=c[B>>2]|0;if((u|0)!=0){p=(fu[c[u+40>>2]&31]()|0)+1|0;u=c[n>>2]|0;c[n>>2]=p>>>0>u>>>0?p:u}u=a[607928]|0;if((u&1)==0){C=u}else{u=c[191244]|0;p=(u|0)!=0?u:c[q>>2]|0;u=c[n>>2]|0;eb(p|0,21584,(v=i,i=i+8|0,c[v>>2]=u,v)|0)|0;i=v;u=c[191244]|0;p=(u|0)!=0?u:c[q>>2]|0;aZ(p|0)|0;C=a[607928]|0}if((C&1)!=0){C=c[191244]|0;p=(C|0)!=0?C:c[q>>2]|0;C=c[B>>2]|0;if((C|0)==0){D=0}else{D=fu[c[C+16>>2]&31]()|0}eb(p|0,30208,(v=i,i=i+8|0,c[v>>2]=D,v)|0)|0;i=v;v=c[191244]|0;D=(v|0)!=0?v:c[q>>2]|0;aZ(D|0)|0}D=c[b+12>>2]<<8;v=j+1832|0;c[v>>2]=D;p=j+1836|0;c[p>>2]=D;a[j+1714|0]=a[b+10|0]&1;D=c[B>>2]|0;if((D|0)!=0){e9[c[D+12>>2]&2047](0)}iv(j,c[o>>2]|0,c[w>>2]|0,1);D=c[B>>2]|0;if((D|0)!=0){e9[c[D+12>>2]&2047](1)}iv(j,c[o>>2]|0,c[w>>2]|0,1);a[h]=0;w=c[B>>2]|0;do{if((w|0)==0){s=499}else{if(!(fr[c[w+20>>2]&63](1,h)|0)){s=499;break}c[j+468>>2]=(a[h]&1)!=0?9729:9728}}while(0);if((s|0)==499){c[j+468>>2]=(a[b+11|0]&1)!=0?9729:9728}s=c[B>>2]|0;do{if((s|0)==0){E=33071}else{B=fc[c[s+24>>2]&127](1)|0;if((B|0)==2){E=10497;break}else if((B|0)==3){E=33648;break}else if((B|0)==0|(B|0)==1){E=33071;break}else{E=0;break}}}while(0);c[j+2040>>2]=E;E=(a[b+16|0]&1)!=0;s=E?32993:6407;B=j+2028|0;c[B>>2]=s;h=j+2032|0;c[h>>2]=s;c[j+2036>>2]=E?5121:33635;c[j+2044>>2]=E?4:2;if(!((a[766412]&1)==0|E^1)){c[B>>2]=6408;c[h>>2]=6408}c9(2929);c9(2884);c9(3024);h=j+1840|0;v6(h|0,808,32)|0;c[j+2e3>>2]=c[m>>2];c[j+2008>>2]=h;c[j+2004>>2]=c[A>>2];c[j+2012>>2]=808;A=ac(c[p>>2]|0,c[v>>2]|0)|0;h=A<<2;m=A>>>0>65535;if(m){F=(A&1073741823|0)==(A|0)?h:-1}else{F=h}B=vZ(F)|0;do{if((B|0)!=0){if((c[B-4>>2]&3|0)==0){break}v3(B|0,0,F|0)}}while(0);c[j+472>>2]=B;if(m){G=(A&1073741823|0)==(A|0)?h:-1}else{G=h}h=vZ(G)|0;if((h|0)==0){c[j+476>>2]=0;fx[c[(c[r>>2]|0)+4>>2]&127]();v_(j);k=0;i=f;return k|0}if((c[h-4>>2]&3|0)!=0){v3(h|0,0,G|0)}c[j+476>>2]=h;iY(j,b);do{if((c[n>>2]|0)!=0){b=j+1768|0;h=j+1800|0;G=0;do{c[b+(G<<2)>>2]=c[v>>2];c[h+(G<<2)>>2]=c[p>>2];G=G+1|0;H=c[n>>2]|0;}while(G>>>0<H>>>0);if((H|0)==0){break}G=j+12|0;h=j+52|0;b=0;do{c[h+(b*52|0)>>2]=c[G>>2];g[h+(b*52|0)+4>>2]=+((c[v>>2]|0)>>>0>>>0);g[h+(b*52|0)+12>>2]=+((c[v>>2]|0)>>>0>>>0);g[h+(b*52|0)+8>>2]=+((c[p>>2]|0)>>>0>>>0);g[h+(b*52|0)+16>>2]=+((c[p>>2]|0)>>>0>>>0);A=h+(b*52|0)+20|0;v6(A|0,808,32)|0;b=b+1|0;}while(b>>>0<(c[n>>2]|0)>>>0)}}while(0);it(j,c[v>>2]|0,c[p>>2]|0);do{if((a[t]&1)!=0){if(iZ(l,c[v>>2]|0,c[p>>2]|0)|0){break}fx[c[(c[r>>2]|0)+4>>2]&127]();v_(j);k=0;i=f;return k|0}}while(0);if(!((d|0)==0|(e|0)==0)){fa[c[(c[r>>2]|0)+48>>2]&127](d,e)}if((a[522036]&1)!=0){c[j+2052>>2]=i0(j,517933,+g[130508])|0?9112:0}switch(dD()|0){case 0:{k=j;i=f;return k|0};case 1280:{e=c[191244]|0;a3(29824,39,1,((e|0)!=0?e:c[q>>2]|0)|0)|0;e=c[191244]|0;aZ(((e|0)!=0?e:c[q>>2]|0)|0)|0;break};case 1281:{e=c[191244]|0;a3(29512,40,1,((e|0)!=0?e:c[q>>2]|0)|0)|0;e=c[191244]|0;aZ(((e|0)!=0?e:c[q>>2]|0)|0)|0;break};case 1282:{e=c[191244]|0;a3(29032,44,1,((e|0)!=0?e:c[q>>2]|0)|0)|0;e=c[191244]|0;aZ(((e|0)!=0?e:c[q>>2]|0)|0)|0;break};case 1285:{e=c[191244]|0;a3(28392,40,1,((e|0)!=0?e:c[q>>2]|0)|0)|0;e=c[191244]|0;aZ(((e|0)!=0?e:c[q>>2]|0)|0)|0;break};default:{e=c[191244]|0;a3(27984,45,1,((e|0)!=0?e:c[q>>2]|0)|0)|0;e=c[191244]|0;aZ(((e|0)!=0?e:c[q>>2]|0)|0)|0}}fx[c[(c[r>>2]|0)+4>>2]&127]();v_(j);k=0;i=f;return k|0}function ix(b,d,e,f,h,j){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ab=0,ad=0.0,ae=0,af=0.0,ag=0.0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0;k=i;i=i+992|0;l=k|0;m=k+64|0;n=k+96|0;o=k+928|0;p=k+936|0;r=b+4|0;s=c[r>>2]|0;if((s|0)!=0){e9[c[s+12>>2]&2047](1)}s=b+1640|0;if((a[s]&1)!=0){iu(b,e,f,c[b+1760>>2]|0,c[b+1764>>2]|0);aY(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);b$(36160,c[b+612>>2]|0);t=c[b+740>>2]|0;u=c[b+744>>2]|0;v=c[(c[b>>2]|0)+24>>2]|0;if((v|0)!=0){+fk[v&3](t,u)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=t;c[b+1748>>2]=u;eD(0,0,t|0,u|0);u=b+1936|0;v3(u|0,0,48);g[b+1996>>2]=1.0;g[u>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;t=b+1872|0;v6(t|0,u|0,64)|0;c[b+2e3>>2]=168}u=b+1711|0;do{if((a[u]&1)!=0){a[u]=0;t=b;v=b+1728|0;w=b+1732|0;fa[c[(c[t>>2]|0)+36>>2]&127](c[v>>2]|0,c[w>>2]|0);if((a[s]&1)==0){iv(b,c[v>>2]|0,c[w>>2]|0,1);break}w=b+1636|0;if((c[w>>2]|0)>0){v=b+740|0;x=v;y=b+612|0;z=y;A=b+676|0;B=0;while(1){C=c[x+(B*24|0)+8>>2]|0;D=x+(B*24|0)+16|0;E=c[x+(B*24|0)+12>>2]|0;F=x+(B*24|0)+20|0;if(C>>>0>(c[D>>2]|0)>>>0){G=561}else{if(E>>>0>(c[F>>2]|0)>>>0){G=561}}do{if((G|0)==561){G=0;H=(C>>>0>E>>>0?C:E)-1|0;I=H>>>1|H;H=I>>>2|I;I=H>>>4|H;H=I>>>8|I;I=(H>>>16|H)+1|0;c[F>>2]=I;c[D>>2]=I;b$(36160,c[z+(B<<2)>>2]|0);I=A+(B<<2)|0;aY(3553,c[I>>2]|0);d1(3553,0,32993,c[D>>2]|0,c[F>>2]|0,0,32993,5121,0);dr(36160,36064,3553,c[I>>2]|0,0);if((ck(36160)|0)!=36053){I=c[191244]|0;H=(I|0)!=0?I:c[q>>2]|0;a3(37720,50,1,H|0)|0;H=c[191244]|0;I=(H|0)!=0?H:c[q>>2]|0;aZ(I|0)|0}if((a[607928]&1)==0){break}I=c[191244]|0;H=(I|0)!=0?I:c[q>>2]|0;I=c[D>>2]|0;J=c[F>>2]|0;eb(H|0,36448,(H=i,i=i+24|0,c[H>>2]=B,c[H+8>>2]=I,c[H+16>>2]=J,H)|0)|0;i=H;H=c[191244]|0;J=(H|0)!=0?H:c[q>>2]|0;aZ(J|0)|0}}while(0);F=B+1|0;if((F|0)<(c[w>>2]|0)){B=F}else{K=y;L=v;break}}}else{K=b+612|0;L=b+740|0}aY(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);b$(36160,c[K>>2]|0);v=c[L>>2]|0;y=c[b+744>>2]|0;B=c[(c[t>>2]|0)+24>>2]|0;if((B|0)!=0){+fk[B&3](v,y)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=v;c[b+1748>>2]=y;eD(0,0,v|0,y|0);y=b+1936|0;v3(y|0,0,48);g[b+1996>>2]=1.0;g[y>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;v=b+1872|0;v6(v|0,y|0,64)|0;c[b+2e3>>2]=168}}while(0);L=b+44|0;K=c[L>>2]|0;L784:do{if((d|0)==0){aY(3553,c[b+12+(K<<2)>>2]|0);M=b+1708|0}else{u=b+48|0;y=((K+1|0)>>>0)%((c[u>>2]|0)>>>0)|0;c[L>>2]=y;aY(3553,c[b+12+(y<<2)>>2]|0);y=b+1708|0;if((a[y]&1)!=0){M=y;break}v=c[L>>2]|0;B=b+1768|0;w=B+(v<<2)|0;if((c[w>>2]|0)==(e|0)){if((c[b+1800+(v<<2)>>2]|0)==(f|0)){G=575}else{G=573}}else{G=573}do{if((G|0)==573){A=b+472|0;if((c[A>>2]|0)==0){G=575;break}c[w>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;e2(3317,(e<<2&4^4)+4|0);z=b+1832|0;x=b+1836|0;d3(3553,0,0,0,c[z>>2]|0,c[x>>2]|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[A>>2]|0);N=+(e>>>0>>>0)/+((c[z>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[x>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==575){w=c[u>>2]|0;t=((v-1+w|0)>>>0)%(w>>>0)|0;if((c[B+(t<<2)>>2]|0)==(e|0)){if((c[b+1800+(t<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[b+2472|0]&1)!=0){c[o>>2]=0;B=e6[c[(c[b>>2]|0)+60>>2]&3](d,e,f,h,(c[b+2044>>2]|0)==4,c[L>>2]|0,o)|0;v=c[o>>2]|0;if((v|0)==0){u=c[191244]|0;t=(u|0)!=0?u:c[q>>2]|0;a3(38704,55,1,t|0)|0;t=c[191244]|0;u=(t|0)!=0?t:c[q>>2]|0;aZ(u|0)|0;M=y;break}if(!B){M=y;break}fa[c[191824]&127](3553,v);M=y;break}v=b+2044|0;B=ac(c[v>>2]|0,e)|0;do{if((B&1|0)==0){if((B&2|0)!=0){P=2;break}P=(B&4^4)+4|0}else{P=1}}while(0);e2(3317,P|0);B=c[v>>2]|0;do{if((B|0)==4){if((a[766412]&1)==0){break}u=b+476|0;t=c[u>>2]|0;w=b+480|0;x=w;z=w;w=b+484|0;if((c[z>>2]|0)==(e|0)){if((c[w>>2]|0)!=(f|0)){G=590}}else{G=590}if((G|0)==590){c[z>>2]=e;c[w>>2]=f;c[b+492>>2]=e;c[b+496>>2]=f;c[b+504>>2]=0;c[b+508>>2]=1;c[b+512>>2]=1;hI(x)|0}c[b+488>>2]=h;c[b+500>>2]=e<<2;hU(x,t,d);d3(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y;break L784}}while(0);if(((h>>>0)/(B>>>0)|0|0)==(e|0)){d3(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,d|0);M=y;break}v=ac(B,e)|0;u=b+476|0;if((f|0)!=0){t=c[u>>2]|0;x=d;w=0;while(1){v6(t|0,x|0,v)|0;z=w+1|0;if(z>>>0<f>>>0){t=t+v|0;x=x+h|0;w=z}else{break}}}d3(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y}}while(0);if((a[M]&1)!=0){h=c[L>>2]|0;d=b+1768|0;P=d+(h<<2)|0;if((c[P>>2]|0)==(e|0)){if((c[b+1800+(h<<2)>>2]|0)==(f|0)){G=604}else{G=602}}else{G=602}do{if((G|0)==602){if((c[b+472>>2]|0)==0){G=604;break}c[P>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;N=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==604){P=c[b+48>>2]|0;o=((h-1+P|0)>>>0)%(P>>>0)|0;if((c[d+(o<<2)>>2]|0)==(e|0)){if((c[b+1800+(o<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[s]&1)==0){b$(36160,0);iv(b,c[b+1728>>2]|0,c[b+1732>>2]|0,1)}c9(2929);c9(2960);c9(2884);c9(3024);c9(3042);ey(770,771);aP(0.0,0.0,0.0,1.0)}d=p;v3(d|0,0,52);c[p>>2]=c[b+12+(c[L>>2]<<2)>>2];g[p+4>>2]=+(e>>>0>>>0);g[p+8>>2]=+(f>>>0>>>0);L=b+1832|0;g[p+12>>2]=+((c[L>>2]|0)>>>0>>>0);h=b+1836|0;g[p+16>>2]=+((c[h>>2]|0)>>>0>>>0);G=p+20|0;o=b+1840|0;v6(G|0,o|0,32)|0;de(16384);if((a[505610]&1)!=0){fx[c[(c[b>>2]|0)+44>>2]&127]();de(16384)}G=c[r>>2]|0;do{if((G|0)==0){P=b+2e3|0;K=b+1872|0;Q=P;R=P;S=K;T=K}else{fd[c[G+8>>2]&3](e,f,c[L>>2]|0,c[h>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[191184]|0,p,b+52|0,0,0);K=c[r>>2]|0;P=b+2e3|0;w=P;x=b+1872|0;v=x;if((K|0)==0){Q=P;R=w;S=x;T=v;break}t=c[K+32>>2]|0;fc[t&127](w)|0;t=c[r>>2]|0;if((t|0)==0){Q=P;R=w;S=x;T=v;break}K=c[t+36>>2]|0;fc[K&127](v)|0;Q=P;R=w;S=x;T=v}}while(0);c4(5,0,4);if((a[s]&1)!=0){s=m;v3(s|0,0,32);h=b+2008|0;c[h>>2]=m;L=b+1636|0;f=c[L>>2]|0;e=b+740|0;G=m+8|0;v=m+24|0;x=m+20|0;w=m+28|0;if((f|0)>1){m=b+676|0;P=b+612|0;K=b;t=b+1740|0;B=b+1736|0;z=b+1744|0;A=b+1748|0;F=b+1936|0;D=b+52|0;E=n|0;C=F;J=b+1956|0;H=b+1976|0;I=b+1996|0;U=b+1984|0;V=b+1988|0;W=b+1992|0;X=1;Y=0;while(1){Z=X-1|0;_=e+(Z*24|0)|0;N=+((c[_>>2]|0)>>>0>>>0);$=e+(Z*24|0)+16|0;O=+((c[$>>2]|0)>>>0>>>0);aa=N/O;ab=e+(Z*24|0)+4|0;ad=+((c[ab>>2]|0)>>>0>>>0);ae=e+(Z*24|0)+20|0;af=+((c[ae>>2]|0)>>>0>>>0);ag=ad/af;g[G>>2]=aa;g[v>>2]=aa;g[x>>2]=ag;g[w>>2]=ag;ah=m+(Z<<2)|0;c[n+(Z*52|0)>>2]=c[ah>>2];g[n+(Z*52|0)+4>>2]=N;g[n+(Z*52|0)+8>>2]=ad;g[n+(Z*52|0)+12>>2]=O;g[n+(Z*52|0)+16>>2]=af;ai=n+(Z*52|0)+20|0;v6(ai|0,s|0,32)|0;b$(36160,c[P+(X<<2)>>2]|0);ai=c[r>>2]|0;if((ai|0)!=0){e9[c[ai+12>>2]&2047](X+1|0)}aY(3553,c[ah>>2]|0);de(16384);ah=c[e+(X*24|0)>>2]|0;ai=c[e+(X*24|0)+4>>2]|0;Z=c[(c[K>>2]|0)+24>>2]|0;if((Z|0)!=0){+fk[Z&3](ah,ai)}c[t>>2]=0;c[B>>2]=0;c[z>>2]=ah;c[A>>2]=ai;eD(0,0,ah|0,ai|0);v3(F|0,0,48);g[I>>2]=1.0;g[C>>2]=2.0;g[J>>2]=2.0;g[H>>2]=-1.0;g[U>>2]=-1.0;g[V>>2]=-1.0;g[W>>2]=-0.0;v6(S|0,F|0,64)|0;ai=c[r>>2]|0;do{if((ai|0)!=0){fd[c[ai+8>>2]&3](c[_>>2]|0,c[ab>>2]|0,c[$>>2]|0,c[ae>>2]|0,c[z>>2]|0,c[A>>2]|0,c[191184]|0,p,D,E,Y);ah=c[r>>2]|0;if((ah|0)==0){break}Z=c[ah+32>>2]|0;fc[Z&127](R)|0;Z=c[r>>2]|0;if((Z|0)==0){break}ah=c[Z+36>>2]|0;fc[ah&127](T)|0}}while(0);c4(5,0,4);ae=Y+1|0;$=X+1|0;ab=c[L>>2]|0;if(($|0)<(ab|0)){X=$;Y=ae}else{aj=ae;ak=ab;break}}}else{aj=0;ak=f}f=ak-1|0;ak=e+(f*24|0)|0;Y=e+(f*24|0)+16|0;af=+((c[ak>>2]|0)>>>0>>>0)/+((c[Y>>2]|0)>>>0>>>0);X=e+(f*24|0)+4|0;E=e+(f*24|0)+20|0;O=+((c[X>>2]|0)>>>0>>>0)/+((c[E>>2]|0)>>>0>>>0);g[G>>2]=af;g[v>>2]=af;g[x>>2]=O;g[w>>2]=O;b$(36160,0);w=c[r>>2]|0;if((w|0)!=0){e9[c[w+12>>2]&2047]((c[L>>2]|0)+1|0)}aY(3553,c[b+676+((c[L>>2]|0)-1<<2)>>2]|0);de(16384);iv(b,c[b+1728>>2]|0,c[b+1732>>2]|0,1);L=c[r>>2]|0;do{if((L|0)==0){c[Q>>2]=c[b+2016>>2]}else{fd[c[L+8>>2]&3](c[ak>>2]|0,c[X>>2]|0,c[Y>>2]|0,c[E>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[191184]|0,p,b+52|0,n|0,aj);w=c[r>>2]|0;c[Q>>2]=c[b+2016>>2];if((w|0)==0){break}x=c[w+32>>2]|0;fc[x&127](R)|0;x=c[r>>2]|0;if((x|0)==0){break}w=c[x+36>>2]|0;fc[w&127](T)|0}}while(0);c4(5,0,4);c[h>>2]=o}h=b+52|0;wa(b+104|0,h|0,((c[b+48>>2]|0)*52|0)-52|0);v6(h|0,d|0,52)|0;do{if((a[b+2576|0]&1)!=0){d=c[b+2572>>2]|0;if((d|0)==0){break}h=l|0;g[h>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2580>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;T=Q;c[T>>2]=136;aj=b+2008|0;c[aj>>2]=808;n=b+2004|0;c[n>>2]=h;aY(3553,d|0);d=c[r>>2]|0;do{if((d|0)!=0){e9[c[d+12>>2]&2047](15);h=c[r>>2]|0;p=b+1936|0;if((h|0)==0){break}E=c[h+32>>2]|0;fc[E&127](R)|0;E=c[r>>2]|0;if((E|0)==0){break}h=c[E+36>>2]|0;fc[h&127](p)|0}}while(0);ej(3042);if((a[b+2577|0]&1)==0){c4(5,0,4)}else{eD(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);c4(5,0,4);eD(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}c9(3042);c[T>>2]=c[b+2016>>2];c[aj>>2]=o;c[n>>2]=c[b+2020>>2]}}while(0);do{if((j|0)!=0){d=c[b+2052>>2]|0;if((d|0)==0){break}fw[c[d+8>>2]&127](b,j,0)}}while(0);if((a[b+2496|0]&1)!=0){aY(3553,c[b+2500>>2]|0);j=l|0;g[j>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2568>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;l=c[r>>2]|0;if((l|0)!=0){e9[c[l+12>>2]&2047](15)}ej(3042);l=Q;c[l>>2]=b+2536;Q=b+2008|0;c[Q>>2]=b+2504;d=b+2004|0;c[d>>2]=j;j=b+1936|0;p=c[r>>2]|0;do{if((p|0)!=0){h=c[p+32>>2]|0;fc[h&127](R)|0;h=c[r>>2]|0;if((h|0)==0){break}E=c[h+36>>2]|0;fc[E&127](j)|0}}while(0);if((a[b+2497|0]&1)==0){c4(5,0,4)}else{eD(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);c4(5,0,4);eD(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}c9(3042);c[l>>2]=c[b+2016>>2];c[Q>>2]=o;c[d>>2]=c[b+2020>>2]}d=b;fx[c[(c[d>>2]|0)+28>>2]&127]();if((a[M]&1)==0){al=c[d>>2]|0;am=al+44|0;an=c[am>>2]|0;fx[an&127]();ao=c[191184]|0;ap=ao+1|0;c[191184]=ap;i=k;return 1}M=c[r>>2]|0;if((M|0)!=0){e9[c[M+12>>2]&2047](0)}aY(3553,0);al=c[d>>2]|0;am=al+44|0;an=c[am>>2]|0;fx[an&127]();ao=c[191184]|0;ap=ao+1|0;c[191184]=ap;i=k;return 1}function iy(a,b){a=a|0;b=b|0;c[b>>2]=9168;return}function iz(a,b){a=a|0;b=b|0;c[b>>2]=9128;return}function iA(a){a=a|0;return c[a+1644+(((((c[a+44>>2]|0)+1|0)>>>0)%((c[a+48>>2]|0)>>>0)|0)<<2)>>2]|0}function iB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;if((a[607928]&1)!=0){f=c[191244]|0;g=(f|0)!=0?f:c[q>>2]|0;f=d?40656:39672;eb(g|0,41648,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;g=c[191244]|0;f=(g|0)!=0?g:c[q>>2]|0;aZ(f|0)|0}e9[c[(c[b>>2]|0)+12>>2]&2047](d?0:c[126403]|0);i=e;return}function iC(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;f=d+8|0;e8[c[(c[b>>2]|0)+32>>2]&15](e,f,b+1728|0,b+1732|0,c[191184]|0);do{if((a[e]&1)==0){if((a[f]&1)==0){break}a[b+1711|0]=1}else{a[b+1712|0]=1}}while(0);i=d;return(a[b+1712|0]&1)==0|0}function iD(a){a=a|0;return fu[c[(c[a>>2]|0)+40>>2]&31]()|0}function iE(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+8|0;h=f|0;j=b;if((d|0)==3){k=0;i=f;return k|0}l=b+4|0;m=c[l>>2]|0;if((m|0)!=0){fx[c[m+4>>2]&127]()}m=(d|0)==2;c[l>>2]=m?9192:0;if(!m){m=c[191244]|0;d=(m|0)!=0?m:c[q>>2]|0;eb(d|0,28704,(n=i,i=i+8|0,c[n>>2]=e,n)|0)|0;i=n;d=c[191244]|0;m=(d|0)!=0?d:c[q>>2]|0;aZ(m|0)|0;k=0;i=f;return k|0}m=b+1640|0;if((a[m]&1)!=0){d=b+1636|0;bf(c[d>>2]|0,b+676|0);o=b+612|0;b5(c[d>>2]|0,o|0);a[m]=0;c[d>>2]=0;v3(o|0,0,128)}o=b+44|0;d=b+12|0;aY(3553,c[d+(c[o>>2]<<2)>>2]|0);if(!(fc[c[c[l>>2]>>2]&127](e)|0)){e=c[191244]|0;m=(e|0)!=0?e:c[q>>2]|0;a3(24648,81,1,m|0)|0;m=c[191244]|0;e=(m|0)!=0?m:c[q>>2]|0;aZ(e|0)|0;if(fc[c[c[l>>2]>>2]&127](0)|0){k=0;i=f;return k|0}c[l>>2]=0;k=0;i=f;return k|0}a[h]=0;e=c[l>>2]|0;if((e|0)==0){p=691}else{if(!(fr[c[e+20>>2]&63](1,h)|0)){p=691}}if((p|0)==691){a[h]=a[505620]&1}e=c[l>>2]|0;do{if((e|0)==0){r=33071}else{m=fc[c[e+24>>2]&127](1)|0;if((m|0)==2){r=10497;break}else if((m|0)==3){r=33648;break}else if((m|0)==0|(m|0)==1){r=33071;break}else{r=0;break}}}while(0);e=a[h]&1;a[b+2487|0]=e;h=e<<24>>24!=0?9729:9728;e=b+468|0;m=b+2040|0;if((h|0)==(c[e>>2]|0)){if((r|0)!=(c[m>>2]|0)){p=699}}else{p=699}if((p|0)==699){c[e>>2]=h;c[m>>2]=r;r=b+48|0;h=c[r>>2]|0;if((h|0)!=0){p=0;s=h;while(1){h=c[j+12+(p<<2)>>2]|0;if((h|0)==0){t=s}else{aY(3553,h|0);eV(3553,10242,c[m>>2]|0);eV(3553,10243,c[m>>2]|0);eV(3553,10240,c[e>>2]|0);eV(3553,10241,c[e>>2]|0);t=c[r>>2]|0}h=p+1|0;if(h>>>0<t>>>0){p=h;s=t}else{break}}}aY(3553,c[j+12+(c[o>>2]<<2)>>2]|0)}t=c[l>>2]|0;do{if((t|0)!=0){s=(fu[c[t+40>>2]&31]()|0)+1|0;p=b+48|0;r=c[p>>2]|0;if(s>>>0<=r>>>0){break}e=b+1708|0;if((a[e]&1)!=0){b5(r|0,b+1644|0)}if((a[b+1709|0]&1)!=0){bL(c[p>>2]|0,b+1676|0)}a[e]=0;e=d;bf(c[p>>2]|0,e|0);c[p>>2]=s;if((a[607928]&1)!=0){r=c[191244]|0;m=(r|0)!=0?r:c[q>>2]|0;eb(m|0,21584,(n=i,i=i+8|0,c[n>>2]=s,n)|0)|0;i=n;s=c[191244]|0;m=(s|0)!=0?s:c[q>>2]|0;aZ(m|0)|0}c[o>>2]=0;iY(b,b+2476|0);do{if((c[p>>2]|0)!=0){m=b+1832|0;s=b+1768|0;r=b+1836|0;h=b+1800|0;u=0;do{c[s+(u<<2)>>2]=c[m>>2];c[h+(u<<2)>>2]=c[r>>2];u=u+1|0;v=c[p>>2]|0;}while(u>>>0<v>>>0);if((v|0)==0){break}u=b+52|0;h=0;do{c[u+(h*52|0)>>2]=c[e>>2];g[u+(h*52|0)+4>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+12>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+8>>2]=+((c[r>>2]|0)>>>0>>>0);g[u+(h*52|0)+16>>2]=+((c[r>>2]|0)>>>0>>>0);s=u+(h*52|0)+20|0;v6(s|0,808,32)|0;h=h+1|0;}while(h>>>0<(c[p>>2]|0)>>>0)}}while(0);if((a[b+1710|0]&1)==0){break}p=c[b+1832>>2]|0;e=c[b+1836>>2]|0;iZ(j,p,e)|0}}while(0);it(b,c[b+1832>>2]|0,c[b+1836>>2]|0);j=c[l>>2]|0;if((j|0)!=0){e9[c[j+12>>2]&2047](0)}j=b+1728|0;v=b+1732|0;iv(b,c[j>>2]|0,c[v>>2]|0,1);o=c[l>>2]|0;if((o|0)!=0){e9[c[o+12>>2]&2047](1)}iv(b,c[j>>2]|0,c[v>>2]|0,1);k=1;i=f;return k|0}function iF(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[b+2052>>2]|0;if((d|0)!=0){e9[c[d+4>>2]&2047](b)}d=b+4|0;e=c[d>>2]|0;if((e|0)!=0){fx[c[e+4>>2]&127]()}c[d>>2]=0;d=b+48|0;bf(c[d>>2]|0,b+12|0);e=b+2572|0;if((c[e>>2]|0)!=0){bf(1,e|0)}e=b+2500|0;if((c[e>>2]|0)!=0){bf(1,e|0)}e=b+544|0;v_(c[e>>2]|0);v_(c[b+556>>2]|0);v_(c[b+560>>2]|0);v_(c[b+572>>2]|0);v_(c[b+584>>2]|0);v_(c[b+576>>2]|0);v_(c[b+600>>2]|0);v3(e|0,0,64);e=b+1640|0;if((a[e]&1)!=0){f=b+1636|0;bf(c[f>>2]|0,b+676|0);g=b+612|0;b5(c[f>>2]|0,g|0);a[e]=0;c[f>>2]=0;v3(g|0,0,128)}g=b+1708|0;if((a[g]&1)!=0){b5(c[d>>2]|0,b+1644|0)}if((a[b+1709|0]&1)==0){a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;fx[k&127]();l=b+472|0;m=l;n=c[m>>2]|0;v_(n);o=b+476|0;p=o;q=c[p>>2]|0;v_(q);v_(b);return}bL(c[d>>2]|0,b+1676|0);a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;fx[k&127]();l=b+472|0;m=l;n=c[m>>2]|0;v_(n);o=b+476|0;p=o;q=c[p>>2]|0;v_(q);v_(b);return}function iG(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=d;c[e>>2]=c[2272];c[e+4>>2]=c[2273];c[e+8>>2]=c[2274];c[e+12>>2]=c[2275];c[e+16>>2]=c[2276];a[d+9|0]=a[505608]&1;a[d+10|0]=0;a[d+11|0]=a[505620]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[126408]|0)==7){c[d>>2]=c[191231];c[d+4>>2]=c[191232]}e=iw(d,0,0)|0;c[191562]=e;c[191610]=9128;c[e+2052>>2]=i0(e,517933,+g[130508])|0?9112:0;i=b;return}function iH(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=c[191562]|0;if((e|0)==0){i=b;return}c[191562]=0;iF(e);e=d;c[e>>2]=c[2272];c[e+4>>2]=c[2273];c[e+8>>2]=c[2274];c[e+12>>2]=c[2275];c[e+16>>2]=c[2276];a[d+9|0]=a[505608]&1;a[d+10|0]=0;a[d+11|0]=a[505620]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[126408]|0)==7){c[d>>2]=c[191231];c[d+4>>2]=c[191232]}e=iw(d,0,0)|0;c[191562]=e;c[191610]=9128;c[e+2052>>2]=i0(e,517933,+g[130508])|0?9112:0;i=b;return}function iI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0.0,j=0.0,k=0.0;d=i;i=i+64|0;e=d|0;f=b*90|0;c[a+1716>>2]=f;b=a+1936|0;v3(b|0,0,48);g[a+1996>>2]=1.0;g[b>>2]=2.0;g[a+1956>>2]=2.0;g[a+1976>>2]=-1.0;g[a+1984>>2]=-1.0;g[a+1988>>2]=-1.0;g[a+1992>>2]=-0.0;h=+(f>>>0>>>0)*3.141592653589793/180.0;j=+U(+h);k=+V(+h);v3(e|0,0,60);g[e+40>>2]=1.0;g[e+60>>2]=1.0;g[e>>2]=j;g[e+20>>2]=j;g[e+16>>2]=-0.0-k;g[e+4>>2]=k;i_(a+1872|0,e,b);i=d;return}function iJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+1736|0;e=b;c[e>>2]=c[d>>2];c[e+4>>2]=c[d+4>>2];c[e+8>>2]=c[d+8>>2];c[e+12>>2]=c[d+12>>2];c[e+16>>2]=c[d+16>>2];c[e+20>>2]=c[d+20>>2];c[b+16>>2]=c[a+1728>>2];d=a+1732|0;c[b+20>>2]=c[d>>2];a=b+4|0;c[a>>2]=(c[d>>2]|0)-((c[b+12>>2]|0)+(c[a>>2]|0));return}function iK(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((a[b+1708|0]&1)==0){if((a[b+1640|0]&1)!=0){e=762}}else{e=762}if((e|0)==762){b$(36160,0)}e=b+1736|0;f=b+1744|0;g=(c[f>>2]|0)*3|0;do{if((g&1|0)==0){if((g&2|0)!=0){h=2;break}h=(g&4^4)+4|0}else{h=1}}while(0);e2(3333,h|0);h=b+1748|0;dL(c[e>>2]|0,c[b+1740>>2]|0,c[f>>2]|0,c[h>>2]|0,6407,5121,d|0);b=ac(c[h>>2]|0,c[f>>2]|0)|0;f=0;h=d;while(1){d=h+2|0;e=a[d]|0;a[d]=a[h]|0;a[h]=e;e=f+1|0;if(e>>>0>b>>>0){break}else{f=e;h=h+3|0}}return 1}function iL(a,b){a=a|0;b=b|0;return fc[c[(c[a>>2]|0)+52>>2]&127](b)|0}function iM(b){b=b|0;a[b+1711|0]=1;return}function iN(b,c,d){b=b|0;c=c|0;d=d|0;a[b+2576|0]=c&1;a[b+2577|0]=d&1;return}function iO(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;g[a+2504>>2]=b;g[a+2508>>2]=c;f=b+d;g[a+2512>>2]=f;g[a+2516>>2]=c;g[a+2520>>2]=b;b=c+e;g[a+2524>>2]=b;g[a+2528>>2]=f;g[a+2532>>2]=b;return}function iP(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;f=1.0-c;g[a+2536>>2]=b;g[a+2540>>2]=f;c=b+d;g[a+2544>>2]=c;g[a+2548>>2]=f;g[a+2552>>2]=b;b=f-e;g[a+2556>>2]=b;g[a+2560>>2]=c;g[a+2564>>2]=b;return}function iQ(b,c){b=b|0;c=c|0;a[b+2497|0]=c&1;return}function iR(a,b){a=a|0;b=+b;g[a+2568>>2]=b;return}function iS(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0;e=i;L1067:do{if((d|0)==5){f=c[175558]|0;h=c[175559]|0;if((f|0)==0|(h|0)==0){break}j=f>>>0<h>>>0?f:h;if(j>>>0>1){k=1;l=1;while(1){if(((f>>>0)%(k>>>0)|0|0)==0){m=((h>>>0)%(k>>>0)|0|0)==0?k:l}else{m=l}n=k+1|0;if(n>>>0<j>>>0){k=n;l=m}else{o=m;break}}}else{o=1}l=(f>>>0)/(o>>>0)|0;k=(h>>>0)/(o>>>0)|0;bN(12012,64,30088,(j=i,i=i+16|0,c[j>>2]=l,c[j+8>>2]=k,j)|0)|0;i=j;g[3019]=+(l>>>0>>>0)/+(k>>>0>>>0)}else if((d|0)==6){if((a[764980]&1)==0){break}p=+g[175562];if(p>0.0){g[3036]=p;break}else{g[3036]=+((c[175558]|0)>>>0>>>0)/+((c[175559]|0)>>>0>>>0);break}}else if((d|0)==4){p=+g[126406];if(p>=0.0){g[3002]=p;break}p=+g[175562];do{if(p>0.0){if((a[505628]&1)==0){break}g[3002]=p;break L1067}}while(0);g[3002]=+((c[175558]|0)>>>0>>>0)/+((c[175559]|0)>>>0>>>0)}}while(0);g[175568]=+g[11736+(d*68|0)>>2];a[b+1714|0]=1;a[b+1711|0]=1;i=e;return}function iT(b,d,e,f,h,i){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=+i;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=b+2572|0;k=c[j>>2]|0;if((k|0)==0){bx(1,j|0);aY(3553,c[j>>2]|0);eV(3553,10242,33071);eV(3553,10243,33071);eV(3553,10240,9729);eV(3553,10241,9729)}else{aY(3553,k|0)}g[b+2580>>2]=i;k=ac(e?4:2,f)|0;if((k&2|0)==0){l=(k&4^4)+4|0}else{l=2}e2(3317,l|0);if(e){e=(a[766412]&1)!=0?6408:32993;d1(3553,0,e|0,f|0,h|0,0,e|0,5121,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;aY(3553,s|0);return}else{d1(3553,0,6408,f|0,h|0,0,6408,32819,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;aY(3553,s|0);return}}function iU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+2052>>2]|0;if((e|0)==0){return}fw[c[e+8>>2]&127](a,b,d);return}function iV(a,b){a=a|0;b=b|0;var d=0;d=c[(c[a>>2]|0)+64>>2]|0;if((d|0)==0){return}e9[d&2047](b);return}function iW(b,d){b=b|0;d=d|0;var e=0;a[b+2496|0]=d&1;e=c[(c[b>>2]|0)+64>>2]|0;if((e|0)==0){return}if((a[b+1713|0]&1)==0){return}e9[e&2047](d);return}function iX(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0;h=b+2500|0;i=c[h>>2]|0;if((i|0)==0){bx(1,h|0);j=c[h>>2]|0}else{j=i}aY(3553,j|0);eV(3553,10242,33071);eV(3553,10243,33071);eV(3553,10240,9729);eV(3553,10241,9729);e2(3317,(e<<2&4^4)+4|0);j=(a[766412]&1)!=0?6408:32993;d1(3553,0,j|0,e|0,f|0,0,j|0,5121,d|0);g[b+2504>>2]=0.0;g[b+2508>>2]=0.0;g[b+2512>>2]=1.0;g[b+2516>>2]=0.0;g[b+2520>>2]=0.0;g[b+2524>>2]=1.0;g[b+2528>>2]=1.0;g[b+2532>>2]=1.0;g[b+2536>>2]=0.0;g[b+2540>>2]=1.0;g[b+2544>>2]=1.0;g[b+2548>>2]=1.0;g[b+2552>>2]=0.0;g[b+2556>>2]=0.0;g[b+2560>>2]=1.0;g[b+2564>>2]=0.0;return 1}function iY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;f=b+1710|0;g=a[f]|0;if((g&1)==0&(c[191824]|0)!=0){h=(fc[c[(c[b>>2]|0)+56>>2]&127](d)|0)&1;j=h;k=a[f]|0}else{j=0;k=g}g=b+2472|0;a[g]=j;j=c[b+2028>>2]|0;f=c[b+2032>>2]|0;h=c[b+2036>>2]|0;do{if((k&1)==0){l=j;m=h;n=f}else{if((c[b+2044>>2]|0)!=4){l=j;m=h;n=f;break}d=b+2584|0;do{if((a[d]&1)==0){o=a2(7939)|0;if((o|0)==0){p=0;break}p=(bu(o|0,45224)|0)!=0}else{p=0}}while(0);if((a[607928]&1)!=0){o=c[191244]|0;r=(o|0)!=0?o:c[q>>2]|0;o=p?48872:46680;eb(r|0,51104,(s=i,i=i+16|0,c[s>>2]=45224,c[s+8>>2]=o,s)|0)|0;i=s;o=c[191244]|0;r=(o|0)!=0?o:c[q>>2]|0;aZ(r|0)|0}if(p){l=6408;m=5121;n=6408;break}do{if((a[d]&1)==0){r=a2(7939)|0;if((r|0)==0){t=0;break}t=(bu(r|0,44312)|0)!=0}else{t=0}}while(0);if((a[607928]&1)!=0){d=c[191244]|0;r=(d|0)!=0?d:c[q>>2]|0;d=t?48872:46680;eb(r|0,51104,(s=i,i=i+16|0,c[s>>2]=44312,c[s+8>>2]=d,s)|0)|0;i=s;d=c[191244]|0;r=(d|0)!=0?d:c[q>>2]|0;aZ(r|0)|0}if(t){l=6408;m=5121;n=6408;break}r=c[191244]|0;d=(r|0)!=0?r:c[q>>2]|0;a3(42936,76,1,d|0)|0;d=c[191244]|0;r=(d|0)!=0?d:c[q>>2]|0;aZ(r|0)|0;l=6407;m=33635;n=6407}}while(0);t=b+48|0;s=b+12|0;p=s;bx(c[t>>2]|0,s|0);if((c[t>>2]|0)==0){u=b+44|0;v=u;w=c[v>>2]|0;x=p+(w<<2)|0;y=c[x>>2]|0;aY(3553,y|0);i=e;return}s=b+2040|0;f=b+468|0;h=b+1832|0;j=b+1836|0;k=b+472|0;r=0;do{aY(3553,c[p+(r<<2)>>2]|0);eV(3553,10242,c[s>>2]|0);eV(3553,10243,c[s>>2]|0);eV(3553,10240,c[f>>2]|0);eV(3553,10241,c[f>>2]|0);if((a[g]&1)==0){d1(3553,0,l|0,c[h>>2]|0,c[j>>2]|0,0,n|0,m|0,c[k>>2]|0)}r=r+1|0;}while(r>>>0<(c[t>>2]|0)>>>0);u=b+44|0;v=u;w=c[v>>2]|0;x=p+(w<<2)|0;y=c[x>>2]|0;aY(3553,y|0);i=e;return}
function uY(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+4|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{kg(f,c[194146]|0);i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{kg(g,c[194147]|0);f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{kg(j,c[194148]|0);h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{kg(l,c[194149]|0);k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{kg(n,c[194150]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{kg(p,c[194151]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{kg(r,c[194152]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{kg(t,c[194153]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&256|0)==0){x=v;y=w}else{kg(v,c[194154]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&512|0)==0){z=x;A=y}else{kg(x,c[194155]|0);w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{kg(z,c[194156]|0);y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{kg(B,c[194157]|0);A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E}else{kg(D,c[194158]|0);C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&8192|0)==0){H=F;I=G}else{kg(F,c[194159]|0);E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&16384|0)==0){J=H;K=I}else{kg(H,c[194160]|0);G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&32768|0)!=0){kg(J,(c[194161]|0)+4|0);b=J>>>24&15;J=d[((K|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(J&1^1|J))-1}}while(0);c[204526]=J+1+(c[204526]|0)}J=(c[194193]|0)>>>24&15;do{if((J-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}K=b&255;if((b&2|0)==0){c[194192]=K>>>1|b&-256;L=(d[130328+J|0]|0)-1|0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}else{c[194192]=K>>>2|b&-256;L=0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}}}while(0);c[194192]=0;L=d[130616+J|0]|0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}function uZ(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+4|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{c[194146]=ke(f)|0;i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{c[194147]=ke(g)|0;f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{c[194148]=ke(j)|0;h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{c[194149]=ke(l)|0;k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{c[194150]=ke(n)|0;m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{c[194151]=ke(p)|0;o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{c[194152]=ke(r)|0;q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{c[194153]=ke(t)|0;s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&256|0)==0){x=v;y=w}else{c[194154]=ke(v)|0;u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&512|0)==0){z=x;A=y}else{c[194155]=ke(x)|0;w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{c[194156]=ke(z)|0;y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{c[194157]=ke(B)|0;A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E}else{c[194158]=ke(D)|0;C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&8192|0)==0){H=F;I=G}else{c[194159]=ke(F)|0;E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&16384|0)==0){J=H;K=I}else{c[194160]=ke(H)|0;G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&32768|0)==0){L=c[194193]|0}else{b=ke(J)|0;c[194161]=b;I=J>>>24&15;J=d[((K|0)==0?130616:125296)+I|0]|0;if((I-2|0)>>>0>5){c[194192]=0;a[776764]=0;M=J+1+(c[204526]|0)|0}else{if((a[776764]&1)!=0){c[194192]=((c[194192]|0)+1<<(J&1^1|J))-1}M=J+1+(c[204526]|0)|0}c[204526]=M;c[194193]=b;J=b+4|0;c[194161]=J;I=b>>>24;c[203402]=c[(c[774536+(I<<3)>>2]|0)+(c[774540+(I<<3)>>2]&b)>>2];K=J>>>24;c[203400]=c[(c[774536+(K<<3)>>2]|0)+(c[774540+(K<<3)>>2]&J)>>2];J=I&15;do{if((J-8|0)>>>0<6){I=c[194192]|0;if((I&1|0)==0){if(I>>>0<=255){N=4452;break}c[194192]=0;O=d[130616+J|0]|0;break}K=I&255;if((I&2|0)==0){c[194192]=K>>>1|I&-256;O=d[130328+J|0]|0;break}else{c[194192]=K>>>2|I&-256;O=0;break}}else{N=4452}}while(0);if((N|0)==4452){O=d[125296+J|0]|0}c[204526]=M+1+O;L=b}b=L>>>24&15;do{if((b-8|0)>>>0<6){L=c[194192]|0;if((L&1|0)==0){break}O=L&255;if((L&2|0)==0){c[194192]=O>>>1|L&-256;P=(d[130328+b|0]|0)-1|0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}else{c[194192]=O>>>2|L&-256;P=0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}}}while(0);c[194192]=0;P=d[130616+b|0]|0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}function u_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;g=f+4|0;h=g&-4;if((b&1|0)==0){i=h;j=0}else{kg(h,c[194146]|0);k=g>>>24&15;g=d[130616+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);c[e>>2]=f;i=h+4|0;j=1}if((b&2|0)==0){l=i;m=j}else{kg(i,c[194147]|0);h=i>>>24&15;g=d[((j|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);c[e>>2]=f;l=i+4|0;m=j+1|0}if((b&4|0)==0){n=l;o=m}else{kg(l,c[194148]|0);j=l>>>24&15;i=d[((m|0)==0?130616:125296)+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);c[204526]=i+1+(c[204526]|0);c[e>>2]=f;n=l+4|0;o=m+1|0}if((b&8|0)==0){p=n;q=o}else{kg(n,c[194149]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);c[e>>2]=f;p=n+4|0;q=o+1|0}if((b&16|0)==0){r=p;s=q}else{kg(p,c[194150]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);c[e>>2]=f;r=p+4|0;s=q+1|0}if((b&32|0)==0){t=r;u=s}else{kg(r,c[194151]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);c[e>>2]=f;t=r+4|0;u=s+1|0}if((b&64|0)==0){v=t;w=u}else{kg(t,c[194152]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);c[e>>2]=f;v=t+4|0;w=u+1|0}if((b&128|0)==0){x=v;y=w}else{kg(v,c[194153]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;x=v+4|0;y=w+1|0}if((b&256|0)==0){z=x;A=y}else{kg(x,c[194154]|0);w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);c[e>>2]=f;z=x+4|0;A=y+1|0}if((b&512|0)==0){B=z;C=A}else{kg(z,c[194155]|0);y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);c[e>>2]=f;B=z+4|0;C=A+1|0}if((b&1024|0)==0){D=B;E=C}else{kg(B,c[194156]|0);A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);c[e>>2]=f;D=B+4|0;E=C+1|0}if((b&2048|0)==0){F=D;G=E}else{kg(D,c[194157]|0);C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);c[e>>2]=f;F=D+4|0;G=E+1|0}if((b&4096|0)==0){H=F;I=G}else{kg(F,c[194158]|0);E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);c[e>>2]=f;H=F+4|0;I=G+1|0}if((b&8192|0)==0){J=H;K=I}else{kg(H,c[194159]|0);G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);c[e>>2]=f;J=H+4|0;K=I+1|0}if((b&16384|0)==0){L=J;M=K}else{kg(J,c[194160]|0);I=J>>>24&15;H=d[((K|0)==0?130616:125296)+I|0]|0;do{if((I-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(H&1^1|H))-1}}while(0);c[204526]=H+1+(c[204526]|0);c[e>>2]=f;L=J+4|0;M=K+1|0}if((b&32768|0)!=0){kg(L,(c[194161]|0)+4|0);b=L>>>24&15;L=d[((M|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);c[e>>2]=f}f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}L=e&255;if((e&2|0)==0){c[194192]=L>>>1|e&-256;N=(d[130328+f|0]|0)-1|0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}else{c[194192]=L>>>2|e&-256;N=0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}}}while(0);c[194192]=0;N=d[130616+f|0]|0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}function u$(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>16&15;f=776584+(e<<2)|0;g=(c[f>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;h=g+4|0;i=h&-4;if((b&1|0)==0){j=i;k=0}else{c[194146]=ke(i)|0;l=h>>>24&15;h=d[130616+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);c[204526]=h+1+(c[204526]|0);j=i+4|0;k=1}if((b&2|0)==0){m=j;n=k}else{c[194147]=ke(j)|0;i=j>>>24&15;h=d[((k|0)==0?130616:125296)+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);c[204526]=h+1+(c[204526]|0);m=j+4|0;n=k+1|0}if((b&4|0)==0){o=m;p=n}else{c[194148]=ke(m)|0;k=m>>>24&15;j=d[((n|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);o=m+4|0;p=n+1|0}if((b&8|0)==0){q=o;r=p}else{c[194149]=ke(o)|0;n=o>>>24&15;m=d[((p|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+4|0;r=p+1|0}if((b&16|0)==0){s=q;t=r}else{c[194150]=ke(q)|0;p=q>>>24&15;o=d[((r|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+4|0;t=r+1|0}if((b&32|0)==0){u=s;v=t}else{c[194151]=ke(s)|0;r=s>>>24&15;q=d[((t|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+4|0;v=t+1|0}if((b&64|0)==0){w=u;x=v}else{c[194152]=ke(u)|0;t=u>>>24&15;s=d[((v|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);w=u+4|0;x=v+1|0}if((b&128|0)==0){y=w;z=x}else{c[194153]=ke(w)|0;v=w>>>24&15;u=d[((x|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);y=w+4|0;z=x+1|0}if((b&256|0)==0){A=y;B=z}else{c[194154]=ke(y)|0;x=y>>>24&15;w=d[((z|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);A=y+4|0;B=z+1|0}if((b&512|0)==0){C=A;D=B}else{c[194155]=ke(A)|0;z=A>>>24&15;y=d[((B|0)==0?130616:125296)+z|0]|0;do{if((z-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(y&1^1|y))-1}}while(0);c[204526]=y+1+(c[204526]|0);C=A+4|0;D=B+1|0}if((b&1024|0)==0){E=C;F=D}else{c[194156]=ke(C)|0;B=C>>>24&15;A=d[((D|0)==0?130616:125296)+B|0]|0;do{if((B-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(A&1^1|A))-1}}while(0);c[204526]=A+1+(c[204526]|0);E=C+4|0;F=D+1|0}if((b&2048|0)==0){G=E;H=F}else{c[194157]=ke(E)|0;D=E>>>24&15;C=d[((F|0)==0?130616:125296)+D|0]|0;do{if((D-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(C&1^1|C))-1}}while(0);c[204526]=C+1+(c[204526]|0);G=E+4|0;H=F+1|0}if((b&4096|0)==0){I=G;J=H}else{c[194158]=ke(G)|0;F=G>>>24&15;E=d[((H|0)==0?130616:125296)+F|0]|0;do{if((F-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(E&1^1|E))-1}}while(0);c[204526]=E+1+(c[204526]|0);I=G+4|0;J=H+1|0}if((b&8192|0)==0){K=I;L=J}else{c[194159]=ke(I)|0;H=I>>>24&15;G=d[((J|0)==0?130616:125296)+H|0]|0;do{if((H-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(G&1^1|G))-1}}while(0);c[204526]=G+1+(c[204526]|0);K=I+4|0;L=J+1|0}if((b&16384|0)==0){M=K;N=L}else{c[194160]=ke(K)|0;J=K>>>24&15;I=d[((L|0)==0?130616:125296)+J|0]|0;do{if((J-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(I&1^1|I))-1}}while(0);c[204526]=I+1+(c[204526]|0);M=K+4|0;N=L+1|0}if((b&32768|0)==0){O=c[194193]|0}else{L=ke(M)|0;c[194161]=L;K=M>>>24&15;M=d[((N|0)==0?130616:125296)+K|0]|0;if((K-2|0)>>>0>5){c[194192]=0;a[776764]=0;P=M+1+(c[204526]|0)|0}else{if((a[776764]&1)!=0){c[194192]=((c[194192]|0)+1<<(M&1^1|M))-1}P=M+1+(c[204526]|0)|0}c[204526]=P;c[194193]=L;M=L+4|0;c[194161]=M;K=L>>>24;c[203402]=c[(c[774536+(K<<3)>>2]|0)+(c[774540+(K<<3)>>2]&L)>>2];N=M>>>24;c[203400]=c[(c[774536+(N<<3)>>2]|0)+(c[774540+(N<<3)>>2]&M)>>2];M=K&15;do{if((M-8|0)>>>0<6){K=c[194192]|0;if((K&1|0)==0){if(K>>>0<=255){Q=4678;break}c[194192]=0;R=d[130616+M|0]|0;break}N=K&255;if((K&2|0)==0){c[194192]=N>>>1|K&-256;R=d[130328+M|0]|0;break}else{c[194192]=N>>>2|K&-256;R=0;break}}else{Q=4678}}while(0);if((Q|0)==4678){R=d[125296+M|0]|0}c[204526]=P+1+R;O=L}L=O>>>24&15;do{if((L-8|0)>>>0<6){O=c[194192]|0;if((O&1|0)==0){Q=4685;break}R=O&255;if((O&2|0)==0){c[194192]=R>>>1|O&-256;S=(d[130328+L|0]|0)-1|0;break}else{c[194192]=R>>>2|O&-256;S=0;break}}else{Q=4685}}while(0);if((Q|0)==4685){c[194192]=0;S=d[130616+L|0]|0}c[204526]=S+2+(c[204526]|0);if((1<<e&b|0)!=0){return}c[f>>2]=g;return}function u0(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+4|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{kg(f,c[194146]|0);i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{kg(g,c[194147]|0);f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{kg(j,c[194148]|0);h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{kg(l,c[194149]|0);k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{kg(n,c[194150]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{kg(p,c[194151]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{kg(r,c[194152]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{kg(t,c[194153]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}u=(b&256|0)!=0;do{if((c[31194]|0)==17){if(u){kg(v,c[194183]|0);t=v>>>24&15;r=d[((w|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);x=v+4|0;y=w+1|0}else{x=v;y=w}if((b&512|0)==0){z=x;A=y}else{kg(x,c[194184]|0);t=x>>>24&15;s=d[((y|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{kg(z,c[194185]|0);t=z>>>24&15;r=d[((A|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{kg(B,c[194186]|0);t=B>>>24&15;s=d[((C|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E;break}kg(D,c[194187]|0);t=D>>>24&15;r=d[((E|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);F=D+4|0;G=E+1|0}else{if(u){kg(v,c[194154]|0);t=v>>>24&15;s=d[((w|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);H=v+4|0;I=w+1|0}else{H=v;I=w}if((b&512|0)==0){J=H;K=I}else{kg(H,c[194155]|0);t=H>>>24&15;r=d[((I|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&1024|0)==0){L=J;M=K}else{kg(J,c[194156]|0);t=J>>>24&15;s=d[((K|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);L=J+4|0;M=K+1|0}if((b&2048|0)==0){N=L;O=M}else{kg(L,c[194157]|0);t=L>>>24&15;r=d[((M|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);N=L+4|0;O=M+1|0}if((b&4096|0)==0){F=N;G=O;break}kg(N,c[194158]|0);t=N>>>24&15;s=d[((O|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);F=N+4|0;G=O+1|0}}while(0);O=c[31194]|0;N=(b&8192|0)!=0;do{if((O|0)==31|(O|0)==16){if(N){kg(F,c[194159]|0);M=F>>>24&15;L=d[((G|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);P=F+4|0;Q=G+1|0}else{P=F;Q=G}if((b&16384|0)==0){R=P;S=Q;break}kg(P,c[194160]|0);M=P>>>24&15;s=d[((Q|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);R=P+4|0;S=Q+1|0}else{if(N){kg(F,c[194172]|0);M=F>>>24&15;L=d[((G|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);T=F+4|0;U=G+1|0}else{T=F;U=G}if((b&16384|0)==0){R=T;S=U;break}kg(T,c[194173]|0);M=T>>>24&15;s=d[((U|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);R=T+4|0;S=U+1|0}}while(0);if((b&32768|0)!=0){kg(R,(c[194161]|0)+4|0);b=R>>>24&15;R=d[((S|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(R&1^1|R))-1}}while(0);c[204526]=R+1+(c[204526]|0)}R=(c[194193]|0)>>>24&15;do{if((R-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}S=b&255;if((b&2|0)==0){c[194192]=S>>>1|b&-256;V=(d[130328+R|0]|0)-1|0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}else{c[194192]=S>>>2|b&-256;V=0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}}}while(0);c[194192]=0;V=d[130616+R|0]|0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}function u1(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=(c[776584+((b>>>16&15)<<2)>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+4|0;g=f&-4;if((b&1|0)==0){h=g;i=0}else{c[194146]=ke(g)|0;j=f>>>24&15;f=d[130616+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);h=g+4|0;i=1}if((b&2|0)==0){k=h;l=i}else{c[194147]=ke(h)|0;g=h>>>24&15;f=d[((i|0)==0?130616:125296)+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);k=h+4|0;l=i+1|0}if((b&4|0)==0){m=k;n=l}else{c[194148]=ke(k)|0;i=k>>>24&15;h=d[((l|0)==0?130616:125296)+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);c[204526]=h+1+(c[204526]|0);m=k+4|0;n=l+1|0}if((b&8|0)==0){o=m;p=n}else{c[194149]=ke(m)|0;l=m>>>24&15;k=d[((n|0)==0?130616:125296)+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);o=m+4|0;p=n+1|0}if((b&16|0)==0){q=o;r=p}else{c[194150]=ke(o)|0;n=o>>>24&15;m=d[((p|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+4|0;r=p+1|0}if((b&32|0)==0){s=q;t=r}else{c[194151]=ke(q)|0;p=q>>>24&15;o=d[((r|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+4|0;t=r+1|0}if((b&64|0)==0){u=s;v=t}else{c[194152]=ke(s)|0;r=s>>>24&15;q=d[((t|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+4|0;v=t+1|0}if((b&128|0)==0){w=u;x=v}else{c[194153]=ke(u)|0;t=u>>>24&15;s=d[((v|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);w=u+4|0;x=v+1|0}v=(b&32768|0)!=0;do{if(v){if((b&256|0)==0){y=w;z=x}else{c[194154]=ke(w)|0;u=w>>>24&15;s=d[((x|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);y=w+4|0;z=x+1|0}if((b&512|0)==0){A=y;B=z}else{c[194155]=ke(y)|0;u=y>>>24&15;t=d[((z|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);A=y+4|0;B=z+1|0}if((b&1024|0)==0){C=A;D=B}else{c[194156]=ke(A)|0;u=A>>>24&15;s=d[((B|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);C=A+4|0;D=B+1|0}if((b&2048|0)==0){E=C;F=D}else{c[194157]=ke(C)|0;u=C>>>24&15;t=d[((D|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);E=C+4|0;F=D+1|0}if((b&4096|0)==0){G=E;H=F}else{c[194158]=ke(E)|0;u=E>>>24&15;s=d[((F|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);G=E+4|0;H=F+1|0}if((b&8192|0)==0){I=G;J=H}else{c[194159]=ke(G)|0;u=G>>>24&15;t=d[((H|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);I=G+4|0;J=H+1|0}if((b&16384|0)==0){K=I;L=J}else{c[194160]=ke(I)|0;u=I>>>24&15;s=d[((J|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);K=I+4|0;L=J+1|0}c[194161]=ke(K)|0;u=K>>>24&15;t=d[((L|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0)}else{u=(b&256|0)!=0;do{if((c[31194]|0)==17){if(u){c[194183]=ke(w)|0;s=w>>>24&15;q=d[((x|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);M=w+4|0;N=x+1|0}else{M=w;N=x}if((b&512|0)==0){O=M;P=N}else{c[194184]=ke(M)|0;s=M>>>24&15;r=d[((N|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);O=M+4|0;P=N+1|0}if((b&1024|0)==0){Q=O;R=P}else{c[194185]=ke(O)|0;s=O>>>24&15;q=d[((P|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);Q=O+4|0;R=P+1|0}if((b&2048|0)==0){S=Q;T=R}else{c[194186]=ke(Q)|0;s=Q>>>24&15;r=d[((R|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);S=Q+4|0;T=R+1|0}if((b&4096|0)==0){U=S;V=T;break}c[194187]=ke(S)|0;s=S>>>24&15;q=d[((T|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);U=S+4|0;V=T+1|0}else{if(u){c[194154]=ke(w)|0;s=w>>>24&15;r=d[((x|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);W=w+4|0;X=x+1|0}else{W=w;X=x}if((b&512|0)==0){Y=W;Z=X}else{c[194155]=ke(W)|0;s=W>>>24&15;q=d[((X|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);Y=W+4|0;Z=X+1|0}if((b&1024|0)==0){_=Y;$=Z}else{c[194156]=ke(Y)|0;s=Y>>>24&15;r=d[((Z|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);_=Y+4|0;$=Z+1|0}if((b&2048|0)==0){aa=_;ab=$}else{c[194157]=ke(_)|0;s=_>>>24&15;q=d[(($|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);aa=_+4|0;ab=$+1|0}if((b&4096|0)==0){U=aa;V=ab;break}c[194158]=ke(aa)|0;s=aa>>>24&15;r=d[((ab|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);U=aa+4|0;V=ab+1|0}}while(0);u=c[31194]|0;t=(b&8192|0)!=0;if((u|0)==31|(u|0)==16){if(t){c[194159]=ke(U)|0;u=U>>>24&15;s=d[((V|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);ac=U+4|0;ad=V+1|0}else{ac=U;ad=V}if((b&16384|0)==0){break}c[194160]=ke(ac)|0;u=ac>>>24&15;q=d[((ad|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);break}else{if(t){c[194172]=ke(U)|0;u=U>>>24&15;s=d[((V|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);ae=U+4|0;af=V+1|0}else{ae=U;af=V}if((b&16384|0)==0){break}c[194173]=ke(ae)|0;u=ae>>>24&15;t=d[((af|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);break}}}while(0);if(v){v=c[194163]&31;if((c[31194]|0)!=(v|0)){km(v,0,1)}v=c[194161]|0;if((a[52040]&1)==0){af=v&-2;c[194193]=af;ae=af+2|0;c[194161]=ae;b=v>>>24;c[203402]=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&af)>>1]|0;b=ae>>>24;ag=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&ae)>>1]|0;ah=af}else{af=v&-4;c[194193]=af;ae=af+4|0;c[194161]=ae;b=v>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&af)>>2];b=ae>>>24;ag=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&ae)>>2]|0;ah=af}c[203400]=ag;ag=ah>>>24&15;do{if((ag-8|0)>>>0<6){af=c[194192]|0;if((af&1|0)==0){if(af>>>0<=255){ai=5041;break}c[194192]=0;aj=d[130616+ag|0]|0;break}ae=af&255;if((af&2|0)==0){c[194192]=ae>>>1|af&-256;aj=d[130328+ag|0]|0;break}else{c[194192]=ae>>>2|af&-256;aj=0;break}}else{ai=5041}}while(0);if((ai|0)==5041){aj=d[125296+ag|0]|0}c[204526]=aj+1+(c[204526]|0);ak=ah}else{ak=c[194193]|0}ah=ak>>>24&15;do{if((ah-8|0)>>>0<6){ak=c[194192]|0;if((ak&1|0)==0){break}aj=ak&255;if((ak&2|0)==0){c[194192]=aj>>>1|ak&-256;al=(d[130328+ah|0]|0)-1|0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}else{c[194192]=aj>>>2|ak&-256;al=0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}}}while(0);c[194192]=0;al=d[130616+ah|0]|0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}function u2(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;g=f+4|0;h=g&-4;if((b&1|0)==0){i=h;j=0}else{kg(h,c[194146]|0);k=g>>>24&15;g=d[130616+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);c[e>>2]=f;i=h+4|0;j=1}if((b&2|0)==0){l=i;m=j}else{kg(i,c[194147]|0);h=i>>>24&15;g=d[((j|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);c[e>>2]=f;l=i+4|0;m=j+1|0}if((b&4|0)==0){n=l;o=m}else{kg(l,c[194148]|0);j=l>>>24&15;i=d[((m|0)==0?130616:125296)+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);c[204526]=i+1+(c[204526]|0);c[e>>2]=f;n=l+4|0;o=m+1|0}if((b&8|0)==0){p=n;q=o}else{kg(n,c[194149]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);c[e>>2]=f;p=n+4|0;q=o+1|0}if((b&16|0)==0){r=p;s=q}else{kg(p,c[194150]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);c[e>>2]=f;r=p+4|0;s=q+1|0}if((b&32|0)==0){t=r;u=s}else{kg(r,c[194151]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);c[e>>2]=f;t=r+4|0;u=s+1|0}if((b&64|0)==0){v=t;w=u}else{kg(t,c[194152]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);c[e>>2]=f;v=t+4|0;w=u+1|0}if((b&128|0)==0){x=v;y=w}else{kg(v,c[194153]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;x=v+4|0;y=w+1|0}w=(b&256|0)!=0;do{if((c[31194]|0)==17){if(w){kg(x,c[194183]|0);v=x>>>24&15;t=d[((y|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;z=x+4|0;A=y+1|0}else{z=x;A=y}if((b&512|0)==0){B=z;C=A}else{kg(z,c[194184]|0);v=z>>>24&15;u=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;B=z+4|0;C=A+1|0}if((b&1024|0)==0){D=B;E=C}else{kg(B,c[194185]|0);v=B>>>24&15;t=d[((C|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;D=B+4|0;E=C+1|0}if((b&2048|0)==0){F=D;G=E}else{kg(D,c[194186]|0);v=D>>>24&15;u=d[((E|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;F=D+4|0;G=E+1|0}if((b&4096|0)==0){H=F;I=G;break}kg(F,c[194187]|0);v=F>>>24&15;t=d[((G|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;H=F+4|0;I=G+1|0}else{if(w){kg(x,c[194154]|0);v=x>>>24&15;u=d[((y|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;J=x+4|0;K=y+1|0}else{J=x;K=y}if((b&512|0)==0){L=J;M=K}else{kg(J,c[194155]|0);v=J>>>24&15;t=d[((K|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;L=J+4|0;M=K+1|0}if((b&1024|0)==0){N=L;O=M}else{kg(L,c[194156]|0);v=L>>>24&15;u=d[((M|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;N=L+4|0;O=M+1|0}if((b&2048|0)==0){P=N;Q=O}else{kg(N,c[194157]|0);v=N>>>24&15;t=d[((O|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;P=N+4|0;Q=O+1|0}if((b&4096|0)==0){H=P;I=Q;break}kg(P,c[194158]|0);v=P>>>24&15;u=d[((Q|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;H=P+4|0;I=Q+1|0}}while(0);Q=c[31194]|0;P=(b&8192|0)!=0;do{if((Q|0)==31|(Q|0)==16){if(P){kg(H,c[194159]|0);O=H>>>24&15;N=d[((I|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(N&1^1|N))-1}}while(0);c[204526]=N+1+(c[204526]|0);c[e>>2]=f;R=H+4|0;S=I+1|0}else{R=H;S=I}if((b&16384|0)==0){T=R;U=S;break}kg(R,c[194160]|0);O=R>>>24&15;u=d[((S|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;T=R+4|0;U=S+1|0}else{if(P){kg(H,c[194172]|0);O=H>>>24&15;N=d[((I|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(N&1^1|N))-1}}while(0);c[204526]=N+1+(c[204526]|0);c[e>>2]=f;V=H+4|0;W=I+1|0}else{V=H;W=I}if((b&16384|0)==0){T=V;U=W;break}kg(V,c[194173]|0);O=V>>>24&15;u=d[((W|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;T=V+4|0;U=W+1|0}}while(0);if((b&32768|0)!=0){kg(T,(c[194161]|0)+4|0);b=T>>>24&15;T=d[((U|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(T&1^1|T))-1}}while(0);c[204526]=T+1+(c[204526]|0);c[e>>2]=f}f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}T=e&255;if((e&2|0)==0){c[194192]=T>>>1|e&-256;X=(d[130328+f|0]|0)-1|0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}else{c[194192]=T>>>2|e&-256;X=0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}}}while(0);c[194192]=0;X=d[130616+f|0]|0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}function u3(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;i=h+4|0;j=i&-4;if((b&1|0)==0){k=j;l=0}else{c[194146]=ke(j)|0;m=i>>>24&15;i=d[130616+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);c[204526]=i+1+(c[204526]|0);k=j+4|0;l=1}if((b&2|0)==0){n=k;o=l}else{c[194147]=ke(k)|0;j=k>>>24&15;i=d[((l|0)==0?130616:125296)+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);c[204526]=i+1+(c[204526]|0);n=k+4|0;o=l+1|0}if((b&4|0)==0){p=n;q=o}else{c[194148]=ke(n)|0;l=n>>>24&15;k=d[((o|0)==0?130616:125296)+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&8|0)==0){r=p;s=q}else{c[194149]=ke(p)|0;o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&16|0)==0){t=r;u=s}else{c[194150]=ke(r)|0;q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&32|0)==0){v=t;w=u}else{c[194151]=ke(t)|0;s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&64|0)==0){x=v;y=w}else{c[194152]=ke(v)|0;u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&128|0)==0){z=x;A=y}else{c[194153]=ke(x)|0;w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}y=(b&32768|0)!=0;do{if(y){if((b&256|0)==0){B=z;C=A}else{c[194154]=ke(z)|0;x=z>>>24&15;v=d[((A|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&512|0)==0){D=B;E=C}else{c[194155]=ke(B)|0;x=B>>>24&15;w=d[((C|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&1024|0)==0){F=D;G=E}else{c[194156]=ke(D)|0;x=D>>>24&15;v=d[((E|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&2048|0)==0){H=F;I=G}else{c[194157]=ke(F)|0;x=F>>>24&15;w=d[((G|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&4096|0)==0){J=H;K=I}else{c[194158]=ke(H)|0;x=H>>>24&15;v=d[((I|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&8192|0)==0){L=J;M=K}else{c[194159]=ke(J)|0;x=J>>>24&15;w=d[((K|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);L=J+4|0;M=K+1|0}if((b&16384|0)==0){N=L;O=M}else{c[194160]=ke(L)|0;x=L>>>24&15;v=d[((M|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);N=L+4|0;O=M+1|0}c[194161]=ke(N)|0;x=N>>>24&15;w=d[((O|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0)}else{x=(b&256|0)!=0;do{if((c[31194]|0)==17){if(x){c[194183]=ke(z)|0;v=z>>>24&15;t=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);P=z+4|0;Q=A+1|0}else{P=z;Q=A}if((b&512|0)==0){R=P;S=Q}else{c[194184]=ke(P)|0;v=P>>>24&15;u=d[((Q|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);R=P+4|0;S=Q+1|0}if((b&1024|0)==0){T=R;U=S}else{c[194185]=ke(R)|0;v=R>>>24&15;t=d[((S|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);T=R+4|0;U=S+1|0}if((b&2048|0)==0){V=T;W=U}else{c[194186]=ke(T)|0;v=T>>>24&15;u=d[((U|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);V=T+4|0;W=U+1|0}if((b&4096|0)==0){X=V;Y=W;break}c[194187]=ke(V)|0;v=V>>>24&15;t=d[((W|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);X=V+4|0;Y=W+1|0}else{if(x){c[194154]=ke(z)|0;v=z>>>24&15;u=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);Z=z+4|0;_=A+1|0}else{Z=z;_=A}if((b&512|0)==0){$=Z;aa=_}else{c[194155]=ke(Z)|0;v=Z>>>24&15;t=d[((_|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);$=Z+4|0;aa=_+1|0}if((b&1024|0)==0){ab=$;ac=aa}else{c[194156]=ke($)|0;v=$>>>24&15;u=d[((aa|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);ab=$+4|0;ac=aa+1|0}if((b&2048|0)==0){ad=ab;ae=ac}else{c[194157]=ke(ab)|0;v=ab>>>24&15;t=d[((ac|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);ad=ab+4|0;ae=ac+1|0}if((b&4096|0)==0){X=ad;Y=ae;break}c[194158]=ke(ad)|0;v=ad>>>24&15;u=d[((ae|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);X=ad+4|0;Y=ae+1|0}}while(0);x=c[31194]|0;w=(b&8192|0)!=0;if((x|0)==31|(x|0)==16){if(w){c[194159]=ke(X)|0;x=X>>>24&15;v=d[((Y|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);af=X+4|0;ag=Y+1|0}else{af=X;ag=Y}if((b&16384|0)==0){break}c[194160]=ke(af)|0;x=af>>>24&15;t=d[((ag|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);break}else{if(w){c[194172]=ke(X)|0;x=X>>>24&15;v=d[((Y|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);ah=X+4|0;ai=Y+1|0}else{ah=X;ai=Y}if((b&16384|0)==0){break}c[194173]=ke(ah)|0;x=ah>>>24&15;w=d[((ai|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);break}}}while(0);if((1<<f&b|0)==0){c[g>>2]=h}if(y){y=c[194163]&31;if((c[31194]|0)!=(y|0)){km(y,0,1)}y=c[194161]|0;if((a[52040]&1)==0){h=y&-2;c[194193]=h;g=h+2|0;c[194161]=g;b=y>>>24;c[203402]=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&h)>>1]|0;b=g>>>24;aj=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>1]|0;ak=h}else{h=y&-4;c[194193]=h;g=h+4|0;c[194161]=g;b=y>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&h)>>2];b=g>>>24;aj=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2]|0;ak=h}c[203400]=aj;aj=ak>>>24&15;do{if((aj-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){al=5405;break}c[194192]=0;am=d[130616+aj|0]|0;break}g=h&255;if((h&2|0)==0){c[194192]=g>>>1|h&-256;am=d[130328+aj|0]|0;break}else{c[194192]=g>>>2|h&-256;am=0;break}}else{al=5405}}while(0);if((al|0)==5405){am=d[125296+aj|0]|0}c[204526]=am+1+(c[204526]|0);an=ak}else{an=c[194193]|0}ak=an>>>24&15;do{if((ak-8|0)>>>0<6){an=c[194192]|0;if((an&1|0)==0){break}am=an&255;if((an&2|0)==0){c[194192]=am>>>1|an&-256;ao=(d[130328+ak|0]|0)-1|0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}else{c[194192]=am>>>2|an&-256;ao=0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}}}while(0);c[194192]=0;ao=d[130616+ak|0]|0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}function u4(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=c[776584+((b>>>16&15)<<2)>>2]|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{kg(f,c[194146]|0);i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{kg(g,c[194147]|0);f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{kg(j,c[194148]|0);h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{kg(l,c[194149]|0);k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{kg(n,c[194150]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{kg(p,c[194151]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{kg(r,c[194152]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{kg(t,c[194153]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&256|0)==0){x=v;y=w}else{kg(v,c[194154]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&512|0)==0){z=x;A=y}else{kg(x,c[194155]|0);w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{kg(z,c[194156]|0);y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{kg(B,c[194157]|0);A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E}else{kg(D,c[194158]|0);C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&8192|0)==0){H=F;I=G}else{kg(F,c[194159]|0);E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&16384|0)==0){J=H;K=I}else{kg(H,c[194160]|0);G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&32768|0)!=0){kg(J,(c[194161]|0)+4|0);b=J>>>24&15;J=d[((K|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(J&1^1|J))-1}}while(0);c[204526]=J+1+(c[204526]|0)}J=(c[194193]|0)>>>24&15;do{if((J-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}K=b&255;if((b&2|0)==0){c[194192]=K>>>1|b&-256;L=(d[130328+J|0]|0)-1|0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}else{c[194192]=K>>>2|b&-256;L=0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}}}while(0);c[194192]=0;L=d[130616+J|0]|0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}function u5(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=c[776584+((b>>>16&15)<<2)>>2]|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{c[194146]=ke(f)|0;i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{c[194147]=ke(g)|0;f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{c[194148]=ke(j)|0;h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{c[194149]=ke(l)|0;k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{c[194150]=ke(n)|0;m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{c[194151]=ke(p)|0;o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{c[194152]=ke(r)|0;q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{c[194153]=ke(t)|0;s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&256|0)==0){x=v;y=w}else{c[194154]=ke(v)|0;u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&512|0)==0){z=x;A=y}else{c[194155]=ke(x)|0;w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{c[194156]=ke(z)|0;y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{c[194157]=ke(B)|0;A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E}else{c[194158]=ke(D)|0;C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&8192|0)==0){H=F;I=G}else{c[194159]=ke(F)|0;E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&16384|0)==0){J=H;K=I}else{c[194160]=ke(H)|0;G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&32768|0)==0){L=c[194193]|0}else{b=ke(J)|0;c[194161]=b;I=J>>>24&15;J=d[((K|0)==0?130616:125296)+I|0]|0;if((I-2|0)>>>0>5){c[194192]=0;a[776764]=0;M=J+1+(c[204526]|0)|0}else{if((a[776764]&1)!=0){c[194192]=((c[194192]|0)+1<<(J&1^1|J))-1}M=J+1+(c[204526]|0)|0}c[204526]=M;c[194193]=b;J=b+4|0;c[194161]=J;I=b>>>24;c[203402]=c[(c[774536+(I<<3)>>2]|0)+(c[774540+(I<<3)>>2]&b)>>2];K=J>>>24;c[203400]=c[(c[774536+(K<<3)>>2]|0)+(c[774540+(K<<3)>>2]&J)>>2];J=I&15;do{if((J-8|0)>>>0<6){I=c[194192]|0;if((I&1|0)==0){if(I>>>0<=255){N=5631;break}c[194192]=0;O=d[130616+J|0]|0;break}K=I&255;if((I&2|0)==0){c[194192]=K>>>1|I&-256;O=d[130328+J|0]|0;break}else{c[194192]=K>>>2|I&-256;O=0;break}}else{N=5631}}while(0);if((N|0)==5631){O=d[125296+J|0]|0}c[204526]=M+1+O;L=b}b=L>>>24&15;do{if((b-8|0)>>>0<6){L=c[194192]|0;if((L&1|0)==0){break}O=L&255;if((L&2|0)==0){c[194192]=O>>>1|L&-256;P=(d[130328+b|0]|0)-1|0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}else{c[194192]=O>>>2|L&-256;P=0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}}}while(0);c[194192]=0;P=d[130616+b|0]|0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}function u6(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;g=f&-4;h=((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+f|0;if((b&1|0)==0){i=g;j=0}else{kg(g,c[194146]|0);k=f>>>24&15;f=d[130616+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);c[e>>2]=h;i=g+4|0;j=1}if((b&2|0)==0){l=i;m=j}else{kg(i,c[194147]|0);g=i>>>24&15;f=d[((j|0)==0?130616:125296)+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);c[e>>2]=h;l=i+4|0;m=j+1|0}if((b&4|0)==0){n=l;o=m}else{kg(l,c[194148]|0);j=l>>>24&15;i=d[((m|0)==0?130616:125296)+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);c[204526]=i+1+(c[204526]|0);c[e>>2]=h;n=l+4|0;o=m+1|0}if((b&8|0)==0){p=n;q=o}else{kg(n,c[194149]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);c[e>>2]=h;p=n+4|0;q=o+1|0}if((b&16|0)==0){r=p;s=q}else{kg(p,c[194150]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);c[e>>2]=h;r=p+4|0;s=q+1|0}if((b&32|0)==0){t=r;u=s}else{kg(r,c[194151]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);c[e>>2]=h;t=r+4|0;u=s+1|0}if((b&64|0)==0){v=t;w=u}else{kg(t,c[194152]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);c[e>>2]=h;v=t+4|0;w=u+1|0}if((b&128|0)==0){x=v;y=w}else{kg(v,c[194153]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=h;x=v+4|0;y=w+1|0}if((b&256|0)==0){z=x;A=y}else{kg(x,c[194154]|0);w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);c[e>>2]=h;z=x+4|0;A=y+1|0}if((b&512|0)==0){B=z;C=A}else{kg(z,c[194155]|0);y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);c[e>>2]=h;B=z+4|0;C=A+1|0}if((b&1024|0)==0){D=B;E=C}else{kg(B,c[194156]|0);A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);c[e>>2]=h;D=B+4|0;E=C+1|0}if((b&2048|0)==0){F=D;G=E}else{kg(D,c[194157]|0);C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);c[e>>2]=h;F=D+4|0;G=E+1|0}if((b&4096|0)==0){H=F;I=G}else{kg(F,c[194158]|0);E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);c[e>>2]=h;H=F+4|0;I=G+1|0}if((b&8192|0)==0){J=H;K=I}else{kg(H,c[194159]|0);G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);c[e>>2]=h;J=H+4|0;K=I+1|0}if((b&16384|0)==0){L=J;M=K}else{kg(J,c[194160]|0);I=J>>>24&15;H=d[((K|0)==0?130616:125296)+I|0]|0;do{if((I-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(H&1^1|H))-1}}while(0);c[204526]=H+1+(c[204526]|0);c[e>>2]=h;L=J+4|0;M=K+1|0}if((b&32768|0)!=0){kg(L,(c[194161]|0)+4|0);b=L>>>24&15;L=d[((M|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);c[e>>2]=h}h=(c[194193]|0)>>>24&15;do{if((h-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}L=e&255;if((e&2|0)==0){c[194192]=L>>>1|e&-256;N=(d[130328+h|0]|0)-1|0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}else{c[194192]=L>>>2|e&-256;N=0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}}}while(0);c[194192]=0;N=d[130616+h|0]|0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}function u7(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>16&15;f=776584+(e<<2)|0;g=c[f>>2]|0;h=((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+g|0;i=g&-4;if((b&1|0)==0){j=i;k=0}else{c[194146]=ke(i)|0;l=g>>>24&15;g=d[130616+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);j=i+4|0;k=1}if((b&2|0)==0){m=j;n=k}else{c[194147]=ke(j)|0;i=j>>>24&15;g=d[((k|0)==0?130616:125296)+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);m=j+4|0;n=k+1|0}if((b&4|0)==0){o=m;p=n}else{c[194148]=ke(m)|0;k=m>>>24&15;j=d[((n|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);o=m+4|0;p=n+1|0}if((b&8|0)==0){q=o;r=p}else{c[194149]=ke(o)|0;n=o>>>24&15;m=d[((p|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+4|0;r=p+1|0}if((b&16|0)==0){s=q;t=r}else{c[194150]=ke(q)|0;p=q>>>24&15;o=d[((r|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+4|0;t=r+1|0}if((b&32|0)==0){u=s;v=t}else{c[194151]=ke(s)|0;r=s>>>24&15;q=d[((t|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+4|0;v=t+1|0}if((b&64|0)==0){w=u;x=v}else{c[194152]=ke(u)|0;t=u>>>24&15;s=d[((v|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);w=u+4|0;x=v+1|0}if((b&128|0)==0){y=w;z=x}else{c[194153]=ke(w)|0;v=w>>>24&15;u=d[((x|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);y=w+4|0;z=x+1|0}if((b&256|0)==0){A=y;B=z}else{c[194154]=ke(y)|0;x=y>>>24&15;w=d[((z|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);A=y+4|0;B=z+1|0}if((b&512|0)==0){C=A;D=B}else{c[194155]=ke(A)|0;z=A>>>24&15;y=d[((B|0)==0?130616:125296)+z|0]|0;do{if((z-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(y&1^1|y))-1}}while(0);c[204526]=y+1+(c[204526]|0);C=A+4|0;D=B+1|0}if((b&1024|0)==0){E=C;F=D}else{c[194156]=ke(C)|0;B=C>>>24&15;A=d[((D|0)==0?130616:125296)+B|0]|0;do{if((B-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(A&1^1|A))-1}}while(0);c[204526]=A+1+(c[204526]|0);E=C+4|0;F=D+1|0}if((b&2048|0)==0){G=E;H=F}else{c[194157]=ke(E)|0;D=E>>>24&15;C=d[((F|0)==0?130616:125296)+D|0]|0;do{if((D-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(C&1^1|C))-1}}while(0);c[204526]=C+1+(c[204526]|0);G=E+4|0;H=F+1|0}if((b&4096|0)==0){I=G;J=H}else{c[194158]=ke(G)|0;F=G>>>24&15;E=d[((H|0)==0?130616:125296)+F|0]|0;do{if((F-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(E&1^1|E))-1}}while(0);c[204526]=E+1+(c[204526]|0);I=G+4|0;J=H+1|0}if((b&8192|0)==0){K=I;L=J}else{c[194159]=ke(I)|0;H=I>>>24&15;G=d[((J|0)==0?130616:125296)+H|0]|0;do{if((H-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(G&1^1|G))-1}}while(0);c[204526]=G+1+(c[204526]|0);K=I+4|0;L=J+1|0}if((b&16384|0)==0){M=K;N=L}else{c[194160]=ke(K)|0;J=K>>>24&15;I=d[((L|0)==0?130616:125296)+J|0]|0;do{if((J-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(I&1^1|I))-1}}while(0);c[204526]=I+1+(c[204526]|0);M=K+4|0;N=L+1|0}if((b&32768|0)==0){O=c[194193]|0}else{L=ke(M)|0;c[194161]=L;K=M>>>24&15;M=d[((N|0)==0?130616:125296)+K|0]|0;if((K-2|0)>>>0>5){c[194192]=0;a[776764]=0;P=M+1+(c[204526]|0)|0}else{if((a[776764]&1)!=0){c[194192]=((c[194192]|0)+1<<(M&1^1|M))-1}P=M+1+(c[204526]|0)|0}c[204526]=P;c[194193]=L;M=L+4|0;c[194161]=M;K=L>>>24;c[203402]=c[(c[774536+(K<<3)>>2]|0)+(c[774540+(K<<3)>>2]&L)>>2];N=M>>>24;c[203400]=c[(c[774536+(N<<3)>>2]|0)+(c[774540+(N<<3)>>2]&M)>>2];M=K&15;do{if((M-8|0)>>>0<6){K=c[194192]|0;if((K&1|0)==0){if(K>>>0<=255){Q=5857;break}c[194192]=0;R=d[130616+M|0]|0;break}N=K&255;if((K&2|0)==0){c[194192]=N>>>1|K&-256;R=d[130328+M|0]|0;break}else{c[194192]=N>>>2|K&-256;R=0;break}}else{Q=5857}}while(0);if((Q|0)==5857){R=d[125296+M|0]|0}c[204526]=P+1+R;O=L}L=O>>>24&15;do{if((L-8|0)>>>0<6){O=c[194192]|0;if((O&1|0)==0){Q=5864;break}R=O&255;if((O&2|0)==0){c[194192]=R>>>1|O&-256;S=(d[130328+L|0]|0)-1|0;break}else{c[194192]=R>>>2|O&-256;S=0;break}}else{Q=5864}}while(0);if((Q|0)==5864){c[194192]=0;S=d[130616+L|0]|0}c[204526]=S+2+(c[204526]|0);if((1<<e&b|0)!=0){return}c[f>>2]=h;return}function u8(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=c[776584+((b>>>16&15)<<2)>>2]|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{kg(f,c[194146]|0);i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{kg(g,c[194147]|0);f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{kg(j,c[194148]|0);h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{kg(l,c[194149]|0);k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{kg(n,c[194150]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{kg(p,c[194151]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{kg(r,c[194152]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{kg(t,c[194153]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}u=(b&256|0)!=0;do{if((c[31194]|0)==17){if(u){kg(v,c[194183]|0);t=v>>>24&15;r=d[((w|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);x=v+4|0;y=w+1|0}else{x=v;y=w}if((b&512|0)==0){z=x;A=y}else{kg(x,c[194184]|0);t=x>>>24&15;s=d[((y|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{kg(z,c[194185]|0);t=z>>>24&15;r=d[((A|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{kg(B,c[194186]|0);t=B>>>24&15;s=d[((C|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E;break}kg(D,c[194187]|0);t=D>>>24&15;r=d[((E|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);F=D+4|0;G=E+1|0}else{if(u){kg(v,c[194154]|0);t=v>>>24&15;s=d[((w|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);H=v+4|0;I=w+1|0}else{H=v;I=w}if((b&512|0)==0){J=H;K=I}else{kg(H,c[194155]|0);t=H>>>24&15;r=d[((I|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&1024|0)==0){L=J;M=K}else{kg(J,c[194156]|0);t=J>>>24&15;s=d[((K|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);L=J+4|0;M=K+1|0}if((b&2048|0)==0){N=L;O=M}else{kg(L,c[194157]|0);t=L>>>24&15;r=d[((M|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);N=L+4|0;O=M+1|0}if((b&4096|0)==0){F=N;G=O;break}kg(N,c[194158]|0);t=N>>>24&15;s=d[((O|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);F=N+4|0;G=O+1|0}}while(0);O=c[31194]|0;N=(b&8192|0)!=0;do{if((O|0)==31|(O|0)==16){if(N){kg(F,c[194159]|0);M=F>>>24&15;L=d[((G|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);P=F+4|0;Q=G+1|0}else{P=F;Q=G}if((b&16384|0)==0){R=P;S=Q;break}kg(P,c[194160]|0);M=P>>>24&15;s=d[((Q|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);R=P+4|0;S=Q+1|0}else{if(N){kg(F,c[194172]|0);M=F>>>24&15;L=d[((G|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);T=F+4|0;U=G+1|0}else{T=F;U=G}if((b&16384|0)==0){R=T;S=U;break}kg(T,c[194173]|0);M=T>>>24&15;s=d[((U|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);R=T+4|0;S=U+1|0}}while(0);if((b&32768|0)!=0){kg(R,(c[194161]|0)+4|0);b=R>>>24&15;R=d[((S|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(R&1^1|R))-1}}while(0);c[204526]=R+1+(c[204526]|0)}R=(c[194193]|0)>>>24&15;do{if((R-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}S=b&255;if((b&2|0)==0){c[194192]=S>>>1|b&-256;V=(d[130328+R|0]|0)-1|0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}else{c[194192]=S>>>2|b&-256;V=0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}}}while(0);c[194192]=0;V=d[130616+R|0]|0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}function u9(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=c[776584+((b>>>16&15)<<2)>>2]|0;g=f&-4;if((b&1|0)==0){h=g;i=0}else{c[194146]=ke(g)|0;j=f>>>24&15;f=d[130616+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);h=g+4|0;i=1}if((b&2|0)==0){k=h;l=i}else{c[194147]=ke(h)|0;g=h>>>24&15;f=d[((i|0)==0?130616:125296)+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);k=h+4|0;l=i+1|0}if((b&4|0)==0){m=k;n=l}else{c[194148]=ke(k)|0;i=k>>>24&15;h=d[((l|0)==0?130616:125296)+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);c[204526]=h+1+(c[204526]|0);m=k+4|0;n=l+1|0}if((b&8|0)==0){o=m;p=n}else{c[194149]=ke(m)|0;l=m>>>24&15;k=d[((n|0)==0?130616:125296)+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);o=m+4|0;p=n+1|0}if((b&16|0)==0){q=o;r=p}else{c[194150]=ke(o)|0;n=o>>>24&15;m=d[((p|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+4|0;r=p+1|0}if((b&32|0)==0){s=q;t=r}else{c[194151]=ke(q)|0;p=q>>>24&15;o=d[((r|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+4|0;t=r+1|0}if((b&64|0)==0){u=s;v=t}else{c[194152]=ke(s)|0;r=s>>>24&15;q=d[((t|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+4|0;v=t+1|0}if((b&128|0)==0){w=u;x=v}else{c[194153]=ke(u)|0;t=u>>>24&15;s=d[((v|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);w=u+4|0;x=v+1|0}v=(b&32768|0)!=0;do{if(v){if((b&256|0)==0){y=w;z=x}else{c[194154]=ke(w)|0;u=w>>>24&15;s=d[((x|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);y=w+4|0;z=x+1|0}if((b&512|0)==0){A=y;B=z}else{c[194155]=ke(y)|0;u=y>>>24&15;t=d[((z|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);A=y+4|0;B=z+1|0}if((b&1024|0)==0){C=A;D=B}else{c[194156]=ke(A)|0;u=A>>>24&15;s=d[((B|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);C=A+4|0;D=B+1|0}if((b&2048|0)==0){E=C;F=D}else{c[194157]=ke(C)|0;u=C>>>24&15;t=d[((D|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);E=C+4|0;F=D+1|0}if((b&4096|0)==0){G=E;H=F}else{c[194158]=ke(E)|0;u=E>>>24&15;s=d[((F|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);G=E+4|0;H=F+1|0}if((b&8192|0)==0){I=G;J=H}else{c[194159]=ke(G)|0;u=G>>>24&15;t=d[((H|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);I=G+4|0;J=H+1|0}if((b&16384|0)==0){K=I;L=J}else{c[194160]=ke(I)|0;u=I>>>24&15;s=d[((J|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);K=I+4|0;L=J+1|0}c[194161]=ke(K)|0;u=K>>>24&15;t=d[((L|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0)}else{u=(b&256|0)!=0;do{if((c[31194]|0)==17){if(u){c[194183]=ke(w)|0;s=w>>>24&15;q=d[((x|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);M=w+4|0;N=x+1|0}else{M=w;N=x}if((b&512|0)==0){O=M;P=N}else{c[194184]=ke(M)|0;s=M>>>24&15;r=d[((N|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);O=M+4|0;P=N+1|0}if((b&1024|0)==0){Q=O;R=P}else{c[194185]=ke(O)|0;s=O>>>24&15;q=d[((P|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);Q=O+4|0;R=P+1|0}if((b&2048|0)==0){S=Q;T=R}else{c[194186]=ke(Q)|0;s=Q>>>24&15;r=d[((R|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);S=Q+4|0;T=R+1|0}if((b&4096|0)==0){U=S;V=T;break}c[194187]=ke(S)|0;s=S>>>24&15;q=d[((T|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);U=S+4|0;V=T+1|0}else{if(u){c[194154]=ke(w)|0;s=w>>>24&15;r=d[((x|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);W=w+4|0;X=x+1|0}else{W=w;X=x}if((b&512|0)==0){Y=W;Z=X}else{c[194155]=ke(W)|0;s=W>>>24&15;q=d[((X|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);Y=W+4|0;Z=X+1|0}if((b&1024|0)==0){_=Y;$=Z}else{c[194156]=ke(Y)|0;s=Y>>>24&15;r=d[((Z|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);_=Y+4|0;$=Z+1|0}if((b&2048|0)==0){aa=_;ab=$}else{c[194157]=ke(_)|0;s=_>>>24&15;q=d[(($|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);aa=_+4|0;ab=$+1|0}if((b&4096|0)==0){U=aa;V=ab;break}c[194158]=ke(aa)|0;s=aa>>>24&15;r=d[((ab|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);U=aa+4|0;V=ab+1|0}}while(0);u=c[31194]|0;t=(b&8192|0)!=0;if((u|0)==31|(u|0)==16){if(t){c[194159]=ke(U)|0;u=U>>>24&15;s=d[((V|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);ac=U+4|0;ad=V+1|0}else{ac=U;ad=V}if((b&16384|0)==0){break}c[194160]=ke(ac)|0;u=ac>>>24&15;q=d[((ad|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);break}else{if(t){c[194172]=ke(U)|0;u=U>>>24&15;s=d[((V|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);ae=U+4|0;af=V+1|0}else{ae=U;af=V}if((b&16384|0)==0){break}c[194173]=ke(ae)|0;u=ae>>>24&15;t=d[((af|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);break}}}while(0);if(v){v=c[194163]&31;if((c[31194]|0)!=(v|0)){km(v,0,1)}v=c[194161]|0;if((a[52040]&1)==0){af=v&-2;c[194193]=af;ae=af+2|0;c[194161]=ae;b=v>>>24;c[203402]=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&af)>>1]|0;b=ae>>>24;ag=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&ae)>>1]|0;ah=af}else{af=v&-4;c[194193]=af;ae=af+4|0;c[194161]=ae;b=v>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&af)>>2];b=ae>>>24;ag=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&ae)>>2]|0;ah=af}c[203400]=ag;ag=ah>>>24&15;do{if((ag-8|0)>>>0<6){af=c[194192]|0;if((af&1|0)==0){if(af>>>0<=255){ai=6220;break}c[194192]=0;aj=d[130616+ag|0]|0;break}ae=af&255;if((af&2|0)==0){c[194192]=ae>>>1|af&-256;aj=d[130328+ag|0]|0;break}else{c[194192]=ae>>>2|af&-256;aj=0;break}}else{ai=6220}}while(0);if((ai|0)==6220){aj=d[125296+ag|0]|0}c[204526]=aj+1+(c[204526]|0);ak=ah}else{ak=c[194193]|0}ah=ak>>>24&15;do{if((ah-8|0)>>>0<6){ak=c[194192]|0;if((ak&1|0)==0){break}aj=ak&255;if((ak&2|0)==0){c[194192]=aj>>>1|ak&-256;al=(d[130328+ah|0]|0)-1|0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}else{c[194192]=aj>>>2|ak&-256;al=0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}}}while(0);c[194192]=0;al=d[130616+ah|0]|0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}function va(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;g=f&-4;h=((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+f|0;if((b&1|0)==0){i=g;j=0}else{kg(g,c[194146]|0);k=f>>>24&15;f=d[130616+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);c[e>>2]=h;i=g+4|0;j=1}if((b&2|0)==0){l=i;m=j}else{kg(i,c[194147]|0);g=i>>>24&15;f=d[((j|0)==0?130616:125296)+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);c[e>>2]=h;l=i+4|0;m=j+1|0}if((b&4|0)==0){n=l;o=m}else{kg(l,c[194148]|0);j=l>>>24&15;i=d[((m|0)==0?130616:125296)+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);c[204526]=i+1+(c[204526]|0);c[e>>2]=h;n=l+4|0;o=m+1|0}if((b&8|0)==0){p=n;q=o}else{kg(n,c[194149]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);c[e>>2]=h;p=n+4|0;q=o+1|0}if((b&16|0)==0){r=p;s=q}else{kg(p,c[194150]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);c[e>>2]=h;r=p+4|0;s=q+1|0}if((b&32|0)==0){t=r;u=s}else{kg(r,c[194151]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);c[e>>2]=h;t=r+4|0;u=s+1|0}if((b&64|0)==0){v=t;w=u}else{kg(t,c[194152]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);c[e>>2]=h;v=t+4|0;w=u+1|0}if((b&128|0)==0){x=v;y=w}else{kg(v,c[194153]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=h;x=v+4|0;y=w+1|0}w=(b&256|0)!=0;do{if((c[31194]|0)==17){if(w){kg(x,c[194183]|0);v=x>>>24&15;t=d[((y|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=h;z=x+4|0;A=y+1|0}else{z=x;A=y}if((b&512|0)==0){B=z;C=A}else{kg(z,c[194184]|0);v=z>>>24&15;u=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=h;B=z+4|0;C=A+1|0}if((b&1024|0)==0){D=B;E=C}else{kg(B,c[194185]|0);v=B>>>24&15;t=d[((C|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=h;D=B+4|0;E=C+1|0}if((b&2048|0)==0){F=D;G=E}else{kg(D,c[194186]|0);v=D>>>24&15;u=d[((E|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=h;F=D+4|0;G=E+1|0}if((b&4096|0)==0){H=F;I=G;break}kg(F,c[194187]|0);v=F>>>24&15;t=d[((G|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=h;H=F+4|0;I=G+1|0}else{if(w){kg(x,c[194154]|0);v=x>>>24&15;u=d[((y|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=h;J=x+4|0;K=y+1|0}else{J=x;K=y}if((b&512|0)==0){L=J;M=K}else{kg(J,c[194155]|0);v=J>>>24&15;t=d[((K|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=h;L=J+4|0;M=K+1|0}if((b&1024|0)==0){N=L;O=M}else{kg(L,c[194156]|0);v=L>>>24&15;u=d[((M|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=h;N=L+4|0;O=M+1|0}if((b&2048|0)==0){P=N;Q=O}else{kg(N,c[194157]|0);v=N>>>24&15;t=d[((O|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=h;P=N+4|0;Q=O+1|0}if((b&4096|0)==0){H=P;I=Q;break}kg(P,c[194158]|0);v=P>>>24&15;u=d[((Q|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=h;H=P+4|0;I=Q+1|0}}while(0);Q=c[31194]|0;P=(b&8192|0)!=0;do{if((Q|0)==31|(Q|0)==16){if(P){kg(H,c[194159]|0);O=H>>>24&15;N=d[((I|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(N&1^1|N))-1}}while(0);c[204526]=N+1+(c[204526]|0);c[e>>2]=h;R=H+4|0;S=I+1|0}else{R=H;S=I}if((b&16384|0)==0){T=R;U=S;break}kg(R,c[194160]|0);O=R>>>24&15;u=d[((S|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=h;T=R+4|0;U=S+1|0}else{if(P){kg(H,c[194172]|0);O=H>>>24&15;N=d[((I|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(N&1^1|N))-1}}while(0);c[204526]=N+1+(c[204526]|0);c[e>>2]=h;V=H+4|0;W=I+1|0}else{V=H;W=I}if((b&16384|0)==0){T=V;U=W;break}kg(V,c[194173]|0);O=V>>>24&15;u=d[((W|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=h;T=V+4|0;U=W+1|0}}while(0);if((b&32768|0)!=0){kg(T,(c[194161]|0)+4|0);b=T>>>24&15;T=d[((U|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(T&1^1|T))-1}}while(0);c[204526]=T+1+(c[204526]|0);c[e>>2]=h}h=(c[194193]|0)>>>24&15;do{if((h-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}T=e&255;if((e&2|0)==0){c[194192]=T>>>1|e&-256;X=(d[130328+h|0]|0)-1|0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}else{c[194192]=T>>>2|e&-256;X=0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}}}while(0);c[194192]=0;X=d[130616+h|0]|0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}function vb(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;i=((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+h|0;j=h&-4;if((b&1|0)==0){k=j;l=0}else{c[194146]=ke(j)|0;m=h>>>24&15;h=d[130616+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);c[204526]=h+1+(c[204526]|0);k=j+4|0;l=1}if((b&2|0)==0){n=k;o=l}else{c[194147]=ke(k)|0;j=k>>>24&15;h=d[((l|0)==0?130616:125296)+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);c[204526]=h+1+(c[204526]|0);n=k+4|0;o=l+1|0}if((b&4|0)==0){p=n;q=o}else{c[194148]=ke(n)|0;l=n>>>24&15;k=d[((o|0)==0?130616:125296)+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&8|0)==0){r=p;s=q}else{c[194149]=ke(p)|0;o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&16|0)==0){t=r;u=s}else{c[194150]=ke(r)|0;q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&32|0)==0){v=t;w=u}else{c[194151]=ke(t)|0;s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&64|0)==0){x=v;y=w}else{c[194152]=ke(v)|0;u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&128|0)==0){z=x;A=y}else{c[194153]=ke(x)|0;w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}y=(b&32768|0)!=0;do{if(y){if((b&256|0)==0){B=z;C=A}else{c[194154]=ke(z)|0;x=z>>>24&15;v=d[((A|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&512|0)==0){D=B;E=C}else{c[194155]=ke(B)|0;x=B>>>24&15;w=d[((C|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&1024|0)==0){F=D;G=E}else{c[194156]=ke(D)|0;x=D>>>24&15;v=d[((E|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&2048|0)==0){H=F;I=G}else{c[194157]=ke(F)|0;x=F>>>24&15;w=d[((G|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&4096|0)==0){J=H;K=I}else{c[194158]=ke(H)|0;x=H>>>24&15;v=d[((I|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&8192|0)==0){L=J;M=K}else{c[194159]=ke(J)|0;x=J>>>24&15;w=d[((K|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);L=J+4|0;M=K+1|0}if((b&16384|0)==0){N=L;O=M}else{c[194160]=ke(L)|0;x=L>>>24&15;v=d[((M|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);N=L+4|0;O=M+1|0}c[194161]=ke(N)|0;x=N>>>24&15;w=d[((O|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0)}else{x=(b&256|0)!=0;do{if((c[31194]|0)==17){if(x){c[194183]=ke(z)|0;v=z>>>24&15;t=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);P=z+4|0;Q=A+1|0}else{P=z;Q=A}if((b&512|0)==0){R=P;S=Q}else{c[194184]=ke(P)|0;v=P>>>24&15;u=d[((Q|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);R=P+4|0;S=Q+1|0}if((b&1024|0)==0){T=R;U=S}else{c[194185]=ke(R)|0;v=R>>>24&15;t=d[((S|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);T=R+4|0;U=S+1|0}if((b&2048|0)==0){V=T;W=U}else{c[194186]=ke(T)|0;v=T>>>24&15;u=d[((U|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);V=T+4|0;W=U+1|0}if((b&4096|0)==0){X=V;Y=W;break}c[194187]=ke(V)|0;v=V>>>24&15;t=d[((W|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);X=V+4|0;Y=W+1|0}else{if(x){c[194154]=ke(z)|0;v=z>>>24&15;u=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);Z=z+4|0;_=A+1|0}else{Z=z;_=A}if((b&512|0)==0){$=Z;aa=_}else{c[194155]=ke(Z)|0;v=Z>>>24&15;t=d[((_|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);$=Z+4|0;aa=_+1|0}if((b&1024|0)==0){ab=$;ac=aa}else{c[194156]=ke($)|0;v=$>>>24&15;u=d[((aa|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);ab=$+4|0;ac=aa+1|0}if((b&2048|0)==0){ad=ab;ae=ac}else{c[194157]=ke(ab)|0;v=ab>>>24&15;t=d[((ac|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);ad=ab+4|0;ae=ac+1|0}if((b&4096|0)==0){X=ad;Y=ae;break}c[194158]=ke(ad)|0;v=ad>>>24&15;u=d[((ae|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);X=ad+4|0;Y=ae+1|0}}while(0);x=c[31194]|0;w=(b&8192|0)!=0;if((x|0)==31|(x|0)==16){if(w){c[194159]=ke(X)|0;x=X>>>24&15;v=d[((Y|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);af=X+4|0;ag=Y+1|0}else{af=X;ag=Y}if((b&16384|0)==0){break}c[194160]=ke(af)|0;x=af>>>24&15;t=d[((ag|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);break}else{if(w){c[194172]=ke(X)|0;x=X>>>24&15;v=d[((Y|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);ah=X+4|0;ai=Y+1|0}else{ah=X;ai=Y}if((b&16384|0)==0){break}c[194173]=ke(ah)|0;x=ah>>>24&15;w=d[((ai|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);break}}}while(0);if((1<<f&b|0)==0){c[g>>2]=i}if(y){y=c[194163]&31;if((c[31194]|0)!=(y|0)){km(y,0,1)}y=c[194161]|0;if((a[52040]&1)==0){i=y&-2;c[194193]=i;g=i+2|0;c[194161]=g;b=y>>>24;c[203402]=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&i)>>1]|0;b=g>>>24;aj=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>1]|0;ak=i}else{i=y&-4;c[194193]=i;g=i+4|0;c[194161]=g;b=y>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&i)>>2];b=g>>>24;aj=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2]|0;ak=i}c[203400]=aj;aj=ak>>>24&15;do{if((aj-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){al=6584;break}c[194192]=0;am=d[130616+aj|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;am=d[130328+aj|0]|0;break}else{c[194192]=g>>>2|i&-256;am=0;break}}else{al=6584}}while(0);if((al|0)==6584){am=d[125296+aj|0]|0}c[204526]=am+1+(c[204526]|0);an=ak}else{an=c[194193]|0}ak=an>>>24&15;do{if((ak-8|0)>>>0<6){an=c[194192]|0;if((an&1|0)==0){break}am=an&255;if((an&2|0)==0){c[194192]=am>>>1|an&-256;ao=(d[130328+ak|0]|0)-1|0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}else{c[194192]=am>>>2|an&-256;ao=0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}}}while(0);c[194192]=0;ao=d[130616+ak|0]|0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}function vc(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{kg(f,c[194146]|0);i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{kg(g,c[194147]|0);f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{kg(j,c[194148]|0);h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{kg(l,c[194149]|0);k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{kg(n,c[194150]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{kg(p,c[194151]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{kg(r,c[194152]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{kg(t,c[194153]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&256|0)==0){x=v;y=w}else{kg(v,c[194154]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&512|0)==0){z=x;A=y}else{kg(x,c[194155]|0);w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{kg(z,c[194156]|0);y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{kg(B,c[194157]|0);A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E}else{kg(D,c[194158]|0);C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&8192|0)==0){H=F;I=G}else{kg(F,c[194159]|0);E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&16384|0)==0){J=H;K=I}else{kg(H,c[194160]|0);G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&32768|0)!=0){kg(J,(c[194161]|0)+4|0);b=J>>>24&15;J=d[((K|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(J&1^1|J))-1}}while(0);c[204526]=J+1+(c[204526]|0)}J=(c[194193]|0)>>>24&15;do{if((J-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}K=b&255;if((b&2|0)==0){c[194192]=K>>>1|b&-256;L=(d[130328+J|0]|0)-1|0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}else{c[194192]=K>>>2|b&-256;L=0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}}}while(0);c[194192]=0;L=d[130616+J|0]|0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}function vd(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{c[194146]=ke(f)|0;i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{c[194147]=ke(g)|0;f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{c[194148]=ke(j)|0;h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{c[194149]=ke(l)|0;k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{c[194150]=ke(n)|0;m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{c[194151]=ke(p)|0;o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{c[194152]=ke(r)|0;q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{c[194153]=ke(t)|0;s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&256|0)==0){x=v;y=w}else{c[194154]=ke(v)|0;u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&512|0)==0){z=x;A=y}else{c[194155]=ke(x)|0;w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{c[194156]=ke(z)|0;y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{c[194157]=ke(B)|0;A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E}else{c[194158]=ke(D)|0;C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&8192|0)==0){H=F;I=G}else{c[194159]=ke(F)|0;E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&16384|0)==0){J=H;K=I}else{c[194160]=ke(H)|0;G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&32768|0)==0){L=c[194193]|0}else{b=ke(J)|0;c[194161]=b;I=J>>>24&15;J=d[((K|0)==0?130616:125296)+I|0]|0;if((I-2|0)>>>0>5){c[194192]=0;a[776764]=0;M=J+1+(c[204526]|0)|0}else{if((a[776764]&1)!=0){c[194192]=((c[194192]|0)+1<<(J&1^1|J))-1}M=J+1+(c[204526]|0)|0}c[204526]=M;c[194193]=b;J=b+4|0;c[194161]=J;I=b>>>24;c[203402]=c[(c[774536+(I<<3)>>2]|0)+(c[774540+(I<<3)>>2]&b)>>2];K=J>>>24;c[203400]=c[(c[774536+(K<<3)>>2]|0)+(c[774540+(K<<3)>>2]&J)>>2];J=I&15;do{if((J-8|0)>>>0<6){I=c[194192]|0;if((I&1|0)==0){if(I>>>0<=255){N=6810;break}c[194192]=0;O=d[130616+J|0]|0;break}K=I&255;if((I&2|0)==0){c[194192]=K>>>1|I&-256;O=d[130328+J|0]|0;break}else{c[194192]=K>>>2|I&-256;O=0;break}}else{N=6810}}while(0);if((N|0)==6810){O=d[125296+J|0]|0}c[204526]=M+1+O;L=b}b=L>>>24&15;do{if((b-8|0)>>>0<6){L=c[194192]|0;if((L&1|0)==0){break}O=L&255;if((L&2|0)==0){c[194192]=O>>>1|L&-256;P=(d[130328+b|0]|0)-1|0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}else{c[194192]=O>>>2|L&-256;P=0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}}}while(0);c[194192]=0;P=d[130616+b|0]|0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}function ve(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;g=f&-4;if((b&1|0)==0){h=g;i=0}else{kg(g,c[194146]|0);j=f>>>24&15;k=d[130616+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);c[e>>2]=f;h=g+4|0;i=1}if((b&2|0)==0){l=h;m=i}else{kg(h,c[194147]|0);g=h>>>24&15;k=d[((i|0)==0?130616:125296)+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);c[e>>2]=f;l=h+4|0;m=i+1|0}if((b&4|0)==0){n=l;o=m}else{kg(l,c[194148]|0);i=l>>>24&15;h=d[((m|0)==0?130616:125296)+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);c[204526]=h+1+(c[204526]|0);c[e>>2]=f;n=l+4|0;o=m+1|0}if((b&8|0)==0){p=n;q=o}else{kg(n,c[194149]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);c[e>>2]=f;p=n+4|0;q=o+1|0}if((b&16|0)==0){r=p;s=q}else{kg(p,c[194150]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);c[e>>2]=f;r=p+4|0;s=q+1|0}if((b&32|0)==0){t=r;u=s}else{kg(r,c[194151]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);c[e>>2]=f;t=r+4|0;u=s+1|0}if((b&64|0)==0){v=t;w=u}else{kg(t,c[194152]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);c[e>>2]=f;v=t+4|0;w=u+1|0}if((b&128|0)==0){x=v;y=w}else{kg(v,c[194153]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;x=v+4|0;y=w+1|0}if((b&256|0)==0){z=x;A=y}else{kg(x,c[194154]|0);w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);c[e>>2]=f;z=x+4|0;A=y+1|0}if((b&512|0)==0){B=z;C=A}else{kg(z,c[194155]|0);y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);c[e>>2]=f;B=z+4|0;C=A+1|0}if((b&1024|0)==0){D=B;E=C}else{kg(B,c[194156]|0);A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);c[e>>2]=f;D=B+4|0;E=C+1|0}if((b&2048|0)==0){F=D;G=E}else{kg(D,c[194157]|0);C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);c[e>>2]=f;F=D+4|0;G=E+1|0}if((b&4096|0)==0){H=F;I=G}else{kg(F,c[194158]|0);E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);c[e>>2]=f;H=F+4|0;I=G+1|0}if((b&8192|0)==0){J=H;K=I}else{kg(H,c[194159]|0);G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);c[e>>2]=f;J=H+4|0;K=I+1|0}if((b&16384|0)==0){L=J;M=K}else{kg(J,c[194160]|0);I=J>>>24&15;H=d[((K|0)==0?130616:125296)+I|0]|0;do{if((I-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(H&1^1|H))-1}}while(0);c[204526]=H+1+(c[204526]|0);c[e>>2]=f;L=J+4|0;M=K+1|0}if((b&32768|0)!=0){kg(L,(c[194161]|0)+4|0);b=L>>>24&15;L=d[((M|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);c[e>>2]=f}f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}L=e&255;if((e&2|0)==0){c[194192]=L>>>1|e&-256;N=(d[130328+f|0]|0)-1|0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}else{c[194192]=L>>>2|e&-256;N=0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}}}while(0);c[194192]=0;N=d[130616+f|0]|0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}function vf(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>16&15;f=776584+(e<<2)|0;g=(c[f>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;h=g&-4;if((b&1|0)==0){i=h;j=0}else{c[194146]=ke(h)|0;k=g>>>24&15;l=d[130616+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);i=h+4|0;j=1}if((b&2|0)==0){m=i;n=j}else{c[194147]=ke(i)|0;h=i>>>24&15;l=d[((j|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);m=i+4|0;n=j+1|0}if((b&4|0)==0){o=m;p=n}else{c[194148]=ke(m)|0;j=m>>>24&15;i=d[((n|0)==0?130616:125296)+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);c[204526]=i+1+(c[204526]|0);o=m+4|0;p=n+1|0}if((b&8|0)==0){q=o;r=p}else{c[194149]=ke(o)|0;n=o>>>24&15;m=d[((p|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+4|0;r=p+1|0}if((b&16|0)==0){s=q;t=r}else{c[194150]=ke(q)|0;p=q>>>24&15;o=d[((r|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+4|0;t=r+1|0}if((b&32|0)==0){u=s;v=t}else{c[194151]=ke(s)|0;r=s>>>24&15;q=d[((t|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+4|0;v=t+1|0}if((b&64|0)==0){w=u;x=v}else{c[194152]=ke(u)|0;t=u>>>24&15;s=d[((v|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);w=u+4|0;x=v+1|0}if((b&128|0)==0){y=w;z=x}else{c[194153]=ke(w)|0;v=w>>>24&15;u=d[((x|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);y=w+4|0;z=x+1|0}if((b&256|0)==0){A=y;B=z}else{c[194154]=ke(y)|0;x=y>>>24&15;w=d[((z|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);A=y+4|0;B=z+1|0}if((b&512|0)==0){C=A;D=B}else{c[194155]=ke(A)|0;z=A>>>24&15;y=d[((B|0)==0?130616:125296)+z|0]|0;do{if((z-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(y&1^1|y))-1}}while(0);c[204526]=y+1+(c[204526]|0);C=A+4|0;D=B+1|0}if((b&1024|0)==0){E=C;F=D}else{c[194156]=ke(C)|0;B=C>>>24&15;A=d[((D|0)==0?130616:125296)+B|0]|0;do{if((B-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(A&1^1|A))-1}}while(0);c[204526]=A+1+(c[204526]|0);E=C+4|0;F=D+1|0}if((b&2048|0)==0){G=E;H=F}else{c[194157]=ke(E)|0;D=E>>>24&15;C=d[((F|0)==0?130616:125296)+D|0]|0;do{if((D-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(C&1^1|C))-1}}while(0);c[204526]=C+1+(c[204526]|0);G=E+4|0;H=F+1|0}if((b&4096|0)==0){I=G;J=H}else{c[194158]=ke(G)|0;F=G>>>24&15;E=d[((H|0)==0?130616:125296)+F|0]|0;do{if((F-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(E&1^1|E))-1}}while(0);c[204526]=E+1+(c[204526]|0);I=G+4|0;J=H+1|0}if((b&8192|0)==0){K=I;L=J}else{c[194159]=ke(I)|0;H=I>>>24&15;G=d[((J|0)==0?130616:125296)+H|0]|0;do{if((H-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(G&1^1|G))-1}}while(0);c[204526]=G+1+(c[204526]|0);K=I+4|0;L=J+1|0}if((b&16384|0)==0){M=K;N=L}else{c[194160]=ke(K)|0;J=K>>>24&15;I=d[((L|0)==0?130616:125296)+J|0]|0;do{if((J-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(I&1^1|I))-1}}while(0);c[204526]=I+1+(c[204526]|0);M=K+4|0;N=L+1|0}if((b&32768|0)==0){O=c[194193]|0}else{L=ke(M)|0;c[194161]=L;K=M>>>24&15;M=d[((N|0)==0?130616:125296)+K|0]|0;if((K-2|0)>>>0>5){c[194192]=0;a[776764]=0;P=M+1+(c[204526]|0)|0}else{if((a[776764]&1)!=0){c[194192]=((c[194192]|0)+1<<(M&1^1|M))-1}P=M+1+(c[204526]|0)|0}c[204526]=P;c[194193]=L;M=L+4|0;c[194161]=M;K=L>>>24;c[203402]=c[(c[774536+(K<<3)>>2]|0)+(c[774540+(K<<3)>>2]&L)>>2];N=M>>>24;c[203400]=c[(c[774536+(N<<3)>>2]|0)+(c[774540+(N<<3)>>2]&M)>>2];M=K&15;do{if((M-8|0)>>>0<6){K=c[194192]|0;if((K&1|0)==0){if(K>>>0<=255){Q=7036;break}c[194192]=0;R=d[130616+M|0]|0;break}N=K&255;if((K&2|0)==0){c[194192]=N>>>1|K&-256;R=d[130328+M|0]|0;break}else{c[194192]=N>>>2|K&-256;R=0;break}}else{Q=7036}}while(0);if((Q|0)==7036){R=d[125296+M|0]|0}c[204526]=P+1+R;O=L}L=O>>>24&15;do{if((L-8|0)>>>0<6){O=c[194192]|0;if((O&1|0)==0){Q=7043;break}R=O&255;if((O&2|0)==0){c[194192]=R>>>1|O&-256;S=(d[130328+L|0]|0)-1|0;break}else{c[194192]=R>>>2|O&-256;S=0;break}}else{Q=7043}}while(0);if((Q|0)==7043){c[194192]=0;S=d[130616+L|0]|0}c[204526]=S+2+(c[204526]|0);if((1<<e&b|0)!=0){return}c[f>>2]=g;return}function vg(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{kg(f,c[194146]|0);i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{kg(g,c[194147]|0);f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{kg(j,c[194148]|0);h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{kg(l,c[194149]|0);k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{kg(n,c[194150]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{kg(p,c[194151]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{kg(r,c[194152]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{kg(t,c[194153]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}u=(b&256|0)!=0;do{if((c[31194]|0)==17){if(u){kg(v,c[194183]|0);t=v>>>24&15;r=d[((w|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);x=v+4|0;y=w+1|0}else{x=v;y=w}if((b&512|0)==0){z=x;A=y}else{kg(x,c[194184]|0);t=x>>>24&15;s=d[((y|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{kg(z,c[194185]|0);t=z>>>24&15;r=d[((A|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{kg(B,c[194186]|0);t=B>>>24&15;s=d[((C|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E;break}kg(D,c[194187]|0);t=D>>>24&15;r=d[((E|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);F=D+4|0;G=E+1|0}else{if(u){kg(v,c[194154]|0);t=v>>>24&15;s=d[((w|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);H=v+4|0;I=w+1|0}else{H=v;I=w}if((b&512|0)==0){J=H;K=I}else{kg(H,c[194155]|0);t=H>>>24&15;r=d[((I|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&1024|0)==0){L=J;M=K}else{kg(J,c[194156]|0);t=J>>>24&15;s=d[((K|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);L=J+4|0;M=K+1|0}if((b&2048|0)==0){N=L;O=M}else{kg(L,c[194157]|0);t=L>>>24&15;r=d[((M|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);N=L+4|0;O=M+1|0}if((b&4096|0)==0){F=N;G=O;break}kg(N,c[194158]|0);t=N>>>24&15;s=d[((O|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);F=N+4|0;G=O+1|0}}while(0);O=c[31194]|0;N=(b&8192|0)!=0;do{if((O|0)==31|(O|0)==16){if(N){kg(F,c[194159]|0);M=F>>>24&15;L=d[((G|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);P=F+4|0;Q=G+1|0}else{P=F;Q=G}if((b&16384|0)==0){R=P;S=Q;break}kg(P,c[194160]|0);M=P>>>24&15;s=d[((Q|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);R=P+4|0;S=Q+1|0}else{if(N){kg(F,c[194172]|0);M=F>>>24&15;L=d[((G|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);T=F+4|0;U=G+1|0}else{T=F;U=G}if((b&16384|0)==0){R=T;S=U;break}kg(T,c[194173]|0);M=T>>>24&15;s=d[((U|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);R=T+4|0;S=U+1|0}}while(0);if((b&32768|0)!=0){kg(R,(c[194161]|0)+4|0);b=R>>>24&15;R=d[((S|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(R&1^1|R))-1}}while(0);c[204526]=R+1+(c[204526]|0)}R=(c[194193]|0)>>>24&15;do{if((R-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}S=b&255;if((b&2|0)==0){c[194192]=S>>>1|b&-256;V=(d[130328+R|0]|0)-1|0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}else{c[194192]=S>>>2|b&-256;V=0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}}}while(0);c[194192]=0;V=d[130616+R|0]|0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}function vh(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=(c[776584+((b>>>16&15)<<2)>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;g=f&-4;if((b&1|0)==0){h=g;i=0}else{c[194146]=ke(g)|0;j=f>>>24&15;f=d[130616+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);h=g+4|0;i=1}if((b&2|0)==0){k=h;l=i}else{c[194147]=ke(h)|0;g=h>>>24&15;f=d[((i|0)==0?130616:125296)+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);k=h+4|0;l=i+1|0}if((b&4|0)==0){m=k;n=l}else{c[194148]=ke(k)|0;i=k>>>24&15;h=d[((l|0)==0?130616:125296)+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);c[204526]=h+1+(c[204526]|0);m=k+4|0;n=l+1|0}if((b&8|0)==0){o=m;p=n}else{c[194149]=ke(m)|0;l=m>>>24&15;k=d[((n|0)==0?130616:125296)+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);o=m+4|0;p=n+1|0}if((b&16|0)==0){q=o;r=p}else{c[194150]=ke(o)|0;n=o>>>24&15;m=d[((p|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+4|0;r=p+1|0}if((b&32|0)==0){s=q;t=r}else{c[194151]=ke(q)|0;p=q>>>24&15;o=d[((r|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+4|0;t=r+1|0}if((b&64|0)==0){u=s;v=t}else{c[194152]=ke(s)|0;r=s>>>24&15;q=d[((t|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+4|0;v=t+1|0}if((b&128|0)==0){w=u;x=v}else{c[194153]=ke(u)|0;t=u>>>24&15;s=d[((v|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);w=u+4|0;x=v+1|0}v=(b&32768|0)!=0;do{if(v){if((b&256|0)==0){y=w;z=x}else{c[194154]=ke(w)|0;u=w>>>24&15;s=d[((x|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);y=w+4|0;z=x+1|0}if((b&512|0)==0){A=y;B=z}else{c[194155]=ke(y)|0;u=y>>>24&15;t=d[((z|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);A=y+4|0;B=z+1|0}if((b&1024|0)==0){C=A;D=B}else{c[194156]=ke(A)|0;u=A>>>24&15;s=d[((B|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);C=A+4|0;D=B+1|0}if((b&2048|0)==0){E=C;F=D}else{c[194157]=ke(C)|0;u=C>>>24&15;t=d[((D|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);E=C+4|0;F=D+1|0}if((b&4096|0)==0){G=E;H=F}else{c[194158]=ke(E)|0;u=E>>>24&15;s=d[((F|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);G=E+4|0;H=F+1|0}if((b&8192|0)==0){I=G;J=H}else{c[194159]=ke(G)|0;u=G>>>24&15;t=d[((H|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);I=G+4|0;J=H+1|0}if((b&16384|0)==0){K=I;L=J}else{c[194160]=ke(I)|0;u=I>>>24&15;s=d[((J|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);K=I+4|0;L=J+1|0}c[194161]=ke(K)|0;u=K>>>24&15;t=d[((L|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0)}else{u=(b&256|0)!=0;do{if((c[31194]|0)==17){if(u){c[194183]=ke(w)|0;s=w>>>24&15;q=d[((x|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);M=w+4|0;N=x+1|0}else{M=w;N=x}if((b&512|0)==0){O=M;P=N}else{c[194184]=ke(M)|0;s=M>>>24&15;r=d[((N|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);O=M+4|0;P=N+1|0}if((b&1024|0)==0){Q=O;R=P}else{c[194185]=ke(O)|0;s=O>>>24&15;q=d[((P|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);Q=O+4|0;R=P+1|0}if((b&2048|0)==0){S=Q;T=R}else{c[194186]=ke(Q)|0;s=Q>>>24&15;r=d[((R|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);S=Q+4|0;T=R+1|0}if((b&4096|0)==0){U=S;V=T;break}c[194187]=ke(S)|0;s=S>>>24&15;q=d[((T|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);U=S+4|0;V=T+1|0}else{if(u){c[194154]=ke(w)|0;s=w>>>24&15;r=d[((x|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);W=w+4|0;X=x+1|0}else{W=w;X=x}if((b&512|0)==0){Y=W;Z=X}else{c[194155]=ke(W)|0;s=W>>>24&15;q=d[((X|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);Y=W+4|0;Z=X+1|0}if((b&1024|0)==0){_=Y;$=Z}else{c[194156]=ke(Y)|0;s=Y>>>24&15;r=d[((Z|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);_=Y+4|0;$=Z+1|0}if((b&2048|0)==0){aa=_;ab=$}else{c[194157]=ke(_)|0;s=_>>>24&15;q=d[(($|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);aa=_+4|0;ab=$+1|0}if((b&4096|0)==0){U=aa;V=ab;break}c[194158]=ke(aa)|0;s=aa>>>24&15;r=d[((ab|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);U=aa+4|0;V=ab+1|0}}while(0);u=c[31194]|0;t=(b&8192|0)!=0;if((u|0)==31|(u|0)==16){if(t){c[194159]=ke(U)|0;u=U>>>24&15;s=d[((V|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);ac=U+4|0;ad=V+1|0}else{ac=U;ad=V}if((b&16384|0)==0){break}c[194160]=ke(ac)|0;u=ac>>>24&15;q=d[((ad|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);break}else{if(t){c[194172]=ke(U)|0;u=U>>>24&15;s=d[((V|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);ae=U+4|0;af=V+1|0}else{ae=U;af=V}if((b&16384|0)==0){break}c[194173]=ke(ae)|0;u=ae>>>24&15;t=d[((af|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);break}}}while(0);if(v){v=c[194163]&31;if((c[31194]|0)!=(v|0)){km(v,0,1)}v=c[194161]|0;if((a[52040]&1)==0){af=v&-2;c[194193]=af;ae=af+2|0;c[194161]=ae;b=v>>>24;c[203402]=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&af)>>1]|0;b=ae>>>24;ag=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&ae)>>1]|0;ah=af}else{af=v&-4;c[194193]=af;ae=af+4|0;c[194161]=ae;b=v>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&af)>>2];b=ae>>>24;ag=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&ae)>>2]|0;ah=af}c[203400]=ag;ag=ah>>>24&15;do{if((ag-8|0)>>>0<6){af=c[194192]|0;if((af&1|0)==0){if(af>>>0<=255){ai=7399;break}c[194192]=0;aj=d[130616+ag|0]|0;break}ae=af&255;if((af&2|0)==0){c[194192]=ae>>>1|af&-256;aj=d[130328+ag|0]|0;break}else{c[194192]=ae>>>2|af&-256;aj=0;break}}else{ai=7399}}while(0);if((ai|0)==7399){aj=d[125296+ag|0]|0}c[204526]=aj+1+(c[204526]|0);ak=ah}else{ak=c[194193]|0}ah=ak>>>24&15;do{if((ah-8|0)>>>0<6){ak=c[194192]|0;if((ak&1|0)==0){break}aj=ak&255;if((ak&2|0)==0){c[194192]=aj>>>1|ak&-256;al=(d[130328+ah|0]|0)-1|0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}else{c[194192]=aj>>>2|ak&-256;al=0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}}}while(0);c[194192]=0;al=d[130616+ah|0]|0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}function vi(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=(c[e>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;g=f&-4;if((b&1|0)==0){h=g;i=0}else{kg(g,c[194146]|0);j=f>>>24&15;k=d[130616+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);c[e>>2]=f;h=g+4|0;i=1}if((b&2|0)==0){l=h;m=i}else{kg(h,c[194147]|0);g=h>>>24&15;k=d[((i|0)==0?130616:125296)+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);c[e>>2]=f;l=h+4|0;m=i+1|0}if((b&4|0)==0){n=l;o=m}else{kg(l,c[194148]|0);i=l>>>24&15;h=d[((m|0)==0?130616:125296)+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);c[204526]=h+1+(c[204526]|0);c[e>>2]=f;n=l+4|0;o=m+1|0}if((b&8|0)==0){p=n;q=o}else{kg(n,c[194149]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);c[e>>2]=f;p=n+4|0;q=o+1|0}if((b&16|0)==0){r=p;s=q}else{kg(p,c[194150]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);c[e>>2]=f;r=p+4|0;s=q+1|0}if((b&32|0)==0){t=r;u=s}else{kg(r,c[194151]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);c[e>>2]=f;t=r+4|0;u=s+1|0}if((b&64|0)==0){v=t;w=u}else{kg(t,c[194152]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);c[e>>2]=f;v=t+4|0;w=u+1|0}if((b&128|0)==0){x=v;y=w}else{kg(v,c[194153]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;x=v+4|0;y=w+1|0}w=(b&256|0)!=0;do{if((c[31194]|0)==17){if(w){kg(x,c[194183]|0);v=x>>>24&15;t=d[((y|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;z=x+4|0;A=y+1|0}else{z=x;A=y}if((b&512|0)==0){B=z;C=A}else{kg(z,c[194184]|0);v=z>>>24&15;u=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;B=z+4|0;C=A+1|0}if((b&1024|0)==0){D=B;E=C}else{kg(B,c[194185]|0);v=B>>>24&15;t=d[((C|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;D=B+4|0;E=C+1|0}if((b&2048|0)==0){F=D;G=E}else{kg(D,c[194186]|0);v=D>>>24&15;u=d[((E|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;F=D+4|0;G=E+1|0}if((b&4096|0)==0){H=F;I=G;break}kg(F,c[194187]|0);v=F>>>24&15;t=d[((G|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;H=F+4|0;I=G+1|0}else{if(w){kg(x,c[194154]|0);v=x>>>24&15;u=d[((y|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;J=x+4|0;K=y+1|0}else{J=x;K=y}if((b&512|0)==0){L=J;M=K}else{kg(J,c[194155]|0);v=J>>>24&15;t=d[((K|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;L=J+4|0;M=K+1|0}if((b&1024|0)==0){N=L;O=M}else{kg(L,c[194156]|0);v=L>>>24&15;u=d[((M|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;N=L+4|0;O=M+1|0}if((b&2048|0)==0){P=N;Q=O}else{kg(N,c[194157]|0);v=N>>>24&15;t=d[((O|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=f;P=N+4|0;Q=O+1|0}if((b&4096|0)==0){H=P;I=Q;break}kg(P,c[194158]|0);v=P>>>24&15;u=d[((Q|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;H=P+4|0;I=Q+1|0}}while(0);Q=c[31194]|0;P=(b&8192|0)!=0;do{if((Q|0)==31|(Q|0)==16){if(P){kg(H,c[194159]|0);O=H>>>24&15;N=d[((I|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(N&1^1|N))-1}}while(0);c[204526]=N+1+(c[204526]|0);c[e>>2]=f;R=H+4|0;S=I+1|0}else{R=H;S=I}if((b&16384|0)==0){T=R;U=S;break}kg(R,c[194160]|0);O=R>>>24&15;u=d[((S|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;T=R+4|0;U=S+1|0}else{if(P){kg(H,c[194172]|0);O=H>>>24&15;N=d[((I|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(N&1^1|N))-1}}while(0);c[204526]=N+1+(c[204526]|0);c[e>>2]=f;V=H+4|0;W=I+1|0}else{V=H;W=I}if((b&16384|0)==0){T=V;U=W;break}kg(V,c[194173]|0);O=V>>>24&15;u=d[((W|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=f;T=V+4|0;U=W+1|0}}while(0);if((b&32768|0)!=0){kg(T,(c[194161]|0)+4|0);b=T>>>24&15;T=d[((U|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(T&1^1|T))-1}}while(0);c[204526]=T+1+(c[204526]|0);c[e>>2]=f}f=(c[194193]|0)>>>24&15;do{if((f-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}T=e&255;if((e&2|0)==0){c[194192]=T>>>1|e&-256;X=(d[130328+f|0]|0)-1|0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}else{c[194192]=T>>>2|e&-256;X=0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}}}while(0);c[194192]=0;X=d[130616+f|0]|0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}function vj(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=b>>>16&15;g=776584+(f<<2)|0;h=(c[g>>2]|0)-((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)|0;i=h&-4;if((b&1|0)==0){j=i;k=0}else{c[194146]=ke(i)|0;l=h>>>24&15;m=d[130616+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);j=i+4|0;k=1}if((b&2|0)==0){n=j;o=k}else{c[194147]=ke(j)|0;i=j>>>24&15;m=d[((k|0)==0?130616:125296)+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);n=j+4|0;o=k+1|0}if((b&4|0)==0){p=n;q=o}else{c[194148]=ke(n)|0;k=n>>>24&15;j=d[((o|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&8|0)==0){r=p;s=q}else{c[194149]=ke(p)|0;o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&16|0)==0){t=r;u=s}else{c[194150]=ke(r)|0;q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&32|0)==0){v=t;w=u}else{c[194151]=ke(t)|0;s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&64|0)==0){x=v;y=w}else{c[194152]=ke(v)|0;u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&128|0)==0){z=x;A=y}else{c[194153]=ke(x)|0;w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}y=(b&32768|0)!=0;do{if(y){if((b&256|0)==0){B=z;C=A}else{c[194154]=ke(z)|0;x=z>>>24&15;v=d[((A|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&512|0)==0){D=B;E=C}else{c[194155]=ke(B)|0;x=B>>>24&15;w=d[((C|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&1024|0)==0){F=D;G=E}else{c[194156]=ke(D)|0;x=D>>>24&15;v=d[((E|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&2048|0)==0){H=F;I=G}else{c[194157]=ke(F)|0;x=F>>>24&15;w=d[((G|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&4096|0)==0){J=H;K=I}else{c[194158]=ke(H)|0;x=H>>>24&15;v=d[((I|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&8192|0)==0){L=J;M=K}else{c[194159]=ke(J)|0;x=J>>>24&15;w=d[((K|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);L=J+4|0;M=K+1|0}if((b&16384|0)==0){N=L;O=M}else{c[194160]=ke(L)|0;x=L>>>24&15;v=d[((M|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);N=L+4|0;O=M+1|0}c[194161]=ke(N)|0;x=N>>>24&15;w=d[((O|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0)}else{x=(b&256|0)!=0;do{if((c[31194]|0)==17){if(x){c[194183]=ke(z)|0;v=z>>>24&15;t=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);P=z+4|0;Q=A+1|0}else{P=z;Q=A}if((b&512|0)==0){R=P;S=Q}else{c[194184]=ke(P)|0;v=P>>>24&15;u=d[((Q|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);R=P+4|0;S=Q+1|0}if((b&1024|0)==0){T=R;U=S}else{c[194185]=ke(R)|0;v=R>>>24&15;t=d[((S|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);T=R+4|0;U=S+1|0}if((b&2048|0)==0){V=T;W=U}else{c[194186]=ke(T)|0;v=T>>>24&15;u=d[((U|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);V=T+4|0;W=U+1|0}if((b&4096|0)==0){X=V;Y=W;break}c[194187]=ke(V)|0;v=V>>>24&15;t=d[((W|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);X=V+4|0;Y=W+1|0}else{if(x){c[194154]=ke(z)|0;v=z>>>24&15;u=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);Z=z+4|0;_=A+1|0}else{Z=z;_=A}if((b&512|0)==0){$=Z;aa=_}else{c[194155]=ke(Z)|0;v=Z>>>24&15;t=d[((_|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);$=Z+4|0;aa=_+1|0}if((b&1024|0)==0){ab=$;ac=aa}else{c[194156]=ke($)|0;v=$>>>24&15;u=d[((aa|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);ab=$+4|0;ac=aa+1|0}if((b&2048|0)==0){ad=ab;ae=ac}else{c[194157]=ke(ab)|0;v=ab>>>24&15;t=d[((ac|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);ad=ab+4|0;ae=ac+1|0}if((b&4096|0)==0){X=ad;Y=ae;break}c[194158]=ke(ad)|0;v=ad>>>24&15;u=d[((ae|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);X=ad+4|0;Y=ae+1|0}}while(0);x=c[31194]|0;w=(b&8192|0)!=0;if((x|0)==31|(x|0)==16){if(w){c[194159]=ke(X)|0;x=X>>>24&15;v=d[((Y|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);af=X+4|0;ag=Y+1|0}else{af=X;ag=Y}if((b&16384|0)==0){break}c[194160]=ke(af)|0;x=af>>>24&15;t=d[((ag|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);break}else{if(w){c[194172]=ke(X)|0;x=X>>>24&15;v=d[((Y|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);ah=X+4|0;ai=Y+1|0}else{ah=X;ai=Y}if((b&16384|0)==0){break}c[194173]=ke(ah)|0;x=ah>>>24&15;w=d[((ai|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);break}}}while(0);if((1<<f&b|0)==0){c[g>>2]=h}if(y){y=c[194163]&31;if((c[31194]|0)!=(y|0)){km(y,0,1)}y=c[194161]|0;if((a[52040]&1)==0){h=y&-2;c[194193]=h;g=h+2|0;c[194161]=g;b=y>>>24;c[203402]=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&h)>>1]|0;b=g>>>24;aj=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>1]|0;ak=h}else{h=y&-4;c[194193]=h;g=h+4|0;c[194161]=g;b=y>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&h)>>2];b=g>>>24;aj=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2]|0;ak=h}c[203400]=aj;aj=ak>>>24&15;do{if((aj-8|0)>>>0<6){h=c[194192]|0;if((h&1|0)==0){if(h>>>0<=255){al=201;break}c[194192]=0;am=d[130616+aj|0]|0;break}g=h&255;if((h&2|0)==0){c[194192]=g>>>1|h&-256;am=d[130328+aj|0]|0;break}else{c[194192]=g>>>2|h&-256;am=0;break}}else{al=201}}while(0);if((al|0)==201){am=d[125296+aj|0]|0}c[204526]=am+1+(c[204526]|0);an=ak}else{an=c[194193]|0}ak=an>>>24&15;do{if((ak-8|0)>>>0<6){an=c[194192]|0;if((an&1|0)==0){break}am=an&255;if((an&2|0)==0){c[194192]=am>>>1|an&-256;ao=(d[130328+ak|0]|0)-1|0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}else{c[194192]=am>>>2|an&-256;ao=0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}}}while(0);c[194192]=0;ao=d[130616+ak|0]|0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}function vk(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)+4|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{kg(f,c[194146]|0);i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{kg(g,c[194147]|0);f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{kg(j,c[194148]|0);h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{kg(l,c[194149]|0);k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{kg(n,c[194150]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{kg(p,c[194151]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{kg(r,c[194152]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{kg(t,c[194153]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&256|0)==0){x=v;y=w}else{kg(v,c[194154]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&512|0)==0){z=x;A=y}else{kg(x,c[194155]|0);w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{kg(z,c[194156]|0);y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{kg(B,c[194157]|0);A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E}else{kg(D,c[194158]|0);C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&8192|0)==0){H=F;I=G}else{kg(F,c[194159]|0);E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&16384|0)==0){J=H;K=I}else{kg(H,c[194160]|0);G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&32768|0)!=0){kg(J,(c[194161]|0)+4|0);b=J>>>24&15;J=d[((K|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(J&1^1|J))-1}}while(0);c[204526]=J+1+(c[204526]|0)}J=(c[194193]|0)>>>24&15;do{if((J-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}K=b&255;if((b&2|0)==0){c[194192]=K>>>1|b&-256;L=(d[130328+J|0]|0)-1|0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}else{c[194192]=K>>>2|b&-256;L=0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}}}while(0);c[194192]=0;L=d[130616+J|0]|0;M=L+1|0;N=c[204526]|0;O=M+N|0;c[204526]=O;return}function vl(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)+4|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{c[194146]=ke(f)|0;i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{c[194147]=ke(g)|0;f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{c[194148]=ke(j)|0;h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{c[194149]=ke(l)|0;k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{c[194150]=ke(n)|0;m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{c[194151]=ke(p)|0;o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{c[194152]=ke(r)|0;q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{c[194153]=ke(t)|0;s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&256|0)==0){x=v;y=w}else{c[194154]=ke(v)|0;u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&512|0)==0){z=x;A=y}else{c[194155]=ke(x)|0;w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{c[194156]=ke(z)|0;y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{c[194157]=ke(B)|0;A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E}else{c[194158]=ke(D)|0;C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&8192|0)==0){H=F;I=G}else{c[194159]=ke(F)|0;E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&16384|0)==0){J=H;K=I}else{c[194160]=ke(H)|0;G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&32768|0)==0){L=c[194193]|0}else{b=ke(J)|0;c[194161]=b;I=J>>>24&15;J=d[((K|0)==0?130616:125296)+I|0]|0;if((I-2|0)>>>0>5){c[194192]=0;a[776764]=0;M=J+1+(c[204526]|0)|0}else{if((a[776764]&1)!=0){c[194192]=((c[194192]|0)+1<<(J&1^1|J))-1}M=J+1+(c[204526]|0)|0}c[204526]=M;c[194193]=b;J=b+4|0;c[194161]=J;I=b>>>24;c[203402]=c[(c[774536+(I<<3)>>2]|0)+(c[774540+(I<<3)>>2]&b)>>2];K=J>>>24;c[203400]=c[(c[774536+(K<<3)>>2]|0)+(c[774540+(K<<3)>>2]&J)>>2];J=I&15;do{if((J-8|0)>>>0<6){I=c[194192]|0;if((I&1|0)==0){if(I>>>0<=255){N=427;break}c[194192]=0;O=d[130616+J|0]|0;break}K=I&255;if((I&2|0)==0){c[194192]=K>>>1|I&-256;O=d[130328+J|0]|0;break}else{c[194192]=K>>>2|I&-256;O=0;break}}else{N=427}}while(0);if((N|0)==427){O=d[125296+J|0]|0}c[204526]=M+1+O;L=b}b=L>>>24&15;do{if((b-8|0)>>>0<6){L=c[194192]|0;if((L&1|0)==0){break}O=L&255;if((L&2|0)==0){c[194192]=O>>>1|L&-256;P=(d[130328+b|0]|0)-1|0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}else{c[194192]=O>>>2|L&-256;P=0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}}}while(0);c[194192]=0;P=d[130616+b|0]|0;Q=P+2|0;R=c[204526]|0;S=Q+R|0;c[204526]=S;return}function vm(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;g=f+4|0;h=g&-4;i=((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+f|0;if((b&1|0)==0){j=h;k=0}else{kg(h,c[194146]|0);f=g>>>24&15;g=d[130616+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);c[e>>2]=i;j=h+4|0;k=1}if((b&2|0)==0){l=j;m=k}else{kg(j,c[194147]|0);h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);c[e>>2]=i;l=j+4|0;m=k+1|0}if((b&4|0)==0){n=l;o=m}else{kg(l,c[194148]|0);k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);c[e>>2]=i;n=l+4|0;o=m+1|0}if((b&8|0)==0){p=n;q=o}else{kg(n,c[194149]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);c[e>>2]=i;p=n+4|0;q=o+1|0}if((b&16|0)==0){r=p;s=q}else{kg(p,c[194150]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);c[e>>2]=i;r=p+4|0;s=q+1|0}if((b&32|0)==0){t=r;u=s}else{kg(r,c[194151]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);c[e>>2]=i;t=r+4|0;u=s+1|0}if((b&64|0)==0){v=t;w=u}else{kg(t,c[194152]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);c[e>>2]=i;v=t+4|0;w=u+1|0}if((b&128|0)==0){x=v;y=w}else{kg(v,c[194153]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=i;x=v+4|0;y=w+1|0}if((b&256|0)==0){z=x;A=y}else{kg(x,c[194154]|0);w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);c[e>>2]=i;z=x+4|0;A=y+1|0}if((b&512|0)==0){B=z;C=A}else{kg(z,c[194155]|0);y=z>>>24&15;x=d[((A|0)==0?130616:125296)+y|0]|0;do{if((y-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(x&1^1|x))-1}}while(0);c[204526]=x+1+(c[204526]|0);c[e>>2]=i;B=z+4|0;C=A+1|0}if((b&1024|0)==0){D=B;E=C}else{kg(B,c[194156]|0);A=B>>>24&15;z=d[((C|0)==0?130616:125296)+A|0]|0;do{if((A-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(z&1^1|z))-1}}while(0);c[204526]=z+1+(c[204526]|0);c[e>>2]=i;D=B+4|0;E=C+1|0}if((b&2048|0)==0){F=D;G=E}else{kg(D,c[194157]|0);C=D>>>24&15;B=d[((E|0)==0?130616:125296)+C|0]|0;do{if((C-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(B&1^1|B))-1}}while(0);c[204526]=B+1+(c[204526]|0);c[e>>2]=i;F=D+4|0;G=E+1|0}if((b&4096|0)==0){H=F;I=G}else{kg(F,c[194158]|0);E=F>>>24&15;D=d[((G|0)==0?130616:125296)+E|0]|0;do{if((E-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(D&1^1|D))-1}}while(0);c[204526]=D+1+(c[204526]|0);c[e>>2]=i;H=F+4|0;I=G+1|0}if((b&8192|0)==0){J=H;K=I}else{kg(H,c[194159]|0);G=H>>>24&15;F=d[((I|0)==0?130616:125296)+G|0]|0;do{if((G-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(F&1^1|F))-1}}while(0);c[204526]=F+1+(c[204526]|0);c[e>>2]=i;J=H+4|0;K=I+1|0}if((b&16384|0)==0){L=J;M=K}else{kg(J,c[194160]|0);I=J>>>24&15;H=d[((K|0)==0?130616:125296)+I|0]|0;do{if((I-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(H&1^1|H))-1}}while(0);c[204526]=H+1+(c[204526]|0);c[e>>2]=i;L=J+4|0;M=K+1|0}if((b&32768|0)!=0){kg(L,(c[194161]|0)+4|0);b=L>>>24&15;L=d[((M|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);c[e>>2]=i}i=(c[194193]|0)>>>24&15;do{if((i-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}L=e&255;if((e&2|0)==0){c[194192]=L>>>1|e&-256;N=(d[130328+i|0]|0)-1|0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}else{c[194192]=L>>>2|e&-256;N=0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}}}while(0);c[194192]=0;N=d[130616+i|0]|0;O=N+1|0;P=c[204526]|0;Q=O+P|0;c[204526]=Q;return}function vn(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=b>>>16&15;f=776584+(e<<2)|0;g=c[f>>2]|0;h=((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+g|0;i=g+4|0;g=i&-4;if((b&1|0)==0){j=g;k=0}else{c[194146]=ke(g)|0;l=i>>>24&15;i=d[130616+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);c[204526]=i+1+(c[204526]|0);j=g+4|0;k=1}if((b&2|0)==0){m=j;n=k}else{c[194147]=ke(j)|0;g=j>>>24&15;i=d[((k|0)==0?130616:125296)+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(i&1^1|i))-1}}while(0);c[204526]=i+1+(c[204526]|0);m=j+4|0;n=k+1|0}if((b&4|0)==0){o=m;p=n}else{c[194148]=ke(m)|0;k=m>>>24&15;j=d[((n|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);o=m+4|0;p=n+1|0}if((b&8|0)==0){q=o;r=p}else{c[194149]=ke(o)|0;n=o>>>24&15;m=d[((p|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+4|0;r=p+1|0}if((b&16|0)==0){s=q;t=r}else{c[194150]=ke(q)|0;p=q>>>24&15;o=d[((r|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+4|0;t=r+1|0}if((b&32|0)==0){u=s;v=t}else{c[194151]=ke(s)|0;r=s>>>24&15;q=d[((t|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+4|0;v=t+1|0}if((b&64|0)==0){w=u;x=v}else{c[194152]=ke(u)|0;t=u>>>24&15;s=d[((v|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);w=u+4|0;x=v+1|0}if((b&128|0)==0){y=w;z=x}else{c[194153]=ke(w)|0;v=w>>>24&15;u=d[((x|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);y=w+4|0;z=x+1|0}if((b&256|0)==0){A=y;B=z}else{c[194154]=ke(y)|0;x=y>>>24&15;w=d[((z|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);A=y+4|0;B=z+1|0}if((b&512|0)==0){C=A;D=B}else{c[194155]=ke(A)|0;z=A>>>24&15;y=d[((B|0)==0?130616:125296)+z|0]|0;do{if((z-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(y&1^1|y))-1}}while(0);c[204526]=y+1+(c[204526]|0);C=A+4|0;D=B+1|0}if((b&1024|0)==0){E=C;F=D}else{c[194156]=ke(C)|0;B=C>>>24&15;A=d[((D|0)==0?130616:125296)+B|0]|0;do{if((B-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(A&1^1|A))-1}}while(0);c[204526]=A+1+(c[204526]|0);E=C+4|0;F=D+1|0}if((b&2048|0)==0){G=E;H=F}else{c[194157]=ke(E)|0;D=E>>>24&15;C=d[((F|0)==0?130616:125296)+D|0]|0;do{if((D-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(C&1^1|C))-1}}while(0);c[204526]=C+1+(c[204526]|0);G=E+4|0;H=F+1|0}if((b&4096|0)==0){I=G;J=H}else{c[194158]=ke(G)|0;F=G>>>24&15;E=d[((H|0)==0?130616:125296)+F|0]|0;do{if((F-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(E&1^1|E))-1}}while(0);c[204526]=E+1+(c[204526]|0);I=G+4|0;J=H+1|0}if((b&8192|0)==0){K=I;L=J}else{c[194159]=ke(I)|0;H=I>>>24&15;G=d[((J|0)==0?130616:125296)+H|0]|0;do{if((H-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(G&1^1|G))-1}}while(0);c[204526]=G+1+(c[204526]|0);K=I+4|0;L=J+1|0}if((b&16384|0)==0){M=K;N=L}else{c[194160]=ke(K)|0;J=K>>>24&15;I=d[((L|0)==0?130616:125296)+J|0]|0;do{if((J-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(I&1^1|I))-1}}while(0);c[204526]=I+1+(c[204526]|0);M=K+4|0;N=L+1|0}if((b&32768|0)==0){O=c[194193]|0}else{L=ke(M)|0;c[194161]=L;K=M>>>24&15;M=d[((N|0)==0?130616:125296)+K|0]|0;if((K-2|0)>>>0>5){c[194192]=0;a[776764]=0;P=M+1+(c[204526]|0)|0}else{if((a[776764]&1)!=0){c[194192]=((c[194192]|0)+1<<(M&1^1|M))-1}P=M+1+(c[204526]|0)|0}c[204526]=P;c[194193]=L;M=L+4|0;c[194161]=M;K=L>>>24;c[203402]=c[(c[774536+(K<<3)>>2]|0)+(c[774540+(K<<3)>>2]&L)>>2];N=M>>>24;c[203400]=c[(c[774536+(N<<3)>>2]|0)+(c[774540+(N<<3)>>2]&M)>>2];M=K&15;do{if((M-8|0)>>>0<6){K=c[194192]|0;if((K&1|0)==0){if(K>>>0<=255){Q=653;break}c[194192]=0;R=d[130616+M|0]|0;break}N=K&255;if((K&2|0)==0){c[194192]=N>>>1|K&-256;R=d[130328+M|0]|0;break}else{c[194192]=N>>>2|K&-256;R=0;break}}else{Q=653}}while(0);if((Q|0)==653){R=d[125296+M|0]|0}c[204526]=P+1+R;O=L}L=O>>>24&15;do{if((L-8|0)>>>0<6){O=c[194192]|0;if((O&1|0)==0){Q=660;break}R=O&255;if((O&2|0)==0){c[194192]=R>>>1|O&-256;S=(d[130328+L|0]|0)-1|0;break}else{c[194192]=R>>>2|O&-256;S=0;break}}else{Q=660}}while(0);if((Q|0)==660){c[194192]=0;S=d[130616+L|0]|0}c[204526]=S+2+(c[204526]|0);if((1<<e&b|0)!=0){return}c[f>>2]=h;return}
function vo(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=(c[776584+((b>>>16&15)<<2)>>2]|0)+4|0;f=e&-4;if((b&1|0)==0){g=f;h=0}else{kg(f,c[194146]|0);i=e>>>24&15;e=d[130616+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);g=f+4|0;h=1}if((b&2|0)==0){j=g;k=h}else{kg(g,c[194147]|0);f=g>>>24&15;e=d[((h|0)==0?130616:125296)+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(e&1^1|e))-1}}while(0);c[204526]=e+1+(c[204526]|0);j=g+4|0;k=h+1|0}if((b&4|0)==0){l=j;m=k}else{kg(j,c[194148]|0);h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);l=j+4|0;m=k+1|0}if((b&8|0)==0){n=l;o=m}else{kg(l,c[194149]|0);k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=l+4|0;o=m+1|0}if((b&16|0)==0){p=n;q=o}else{kg(n,c[194150]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&32|0)==0){r=p;s=q}else{kg(p,c[194151]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&64|0)==0){t=r;u=s}else{kg(r,c[194152]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&128|0)==0){v=t;w=u}else{kg(t,c[194153]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}u=(b&256|0)!=0;do{if((c[31194]|0)==17){if(u){kg(v,c[194183]|0);t=v>>>24&15;r=d[((w|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);x=v+4|0;y=w+1|0}else{x=v;y=w}if((b&512|0)==0){z=x;A=y}else{kg(x,c[194184]|0);t=x>>>24&15;s=d[((y|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);z=x+4|0;A=y+1|0}if((b&1024|0)==0){B=z;C=A}else{kg(z,c[194185]|0);t=z>>>24&15;r=d[((A|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&2048|0)==0){D=B;E=C}else{kg(B,c[194186]|0);t=B>>>24&15;s=d[((C|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&4096|0)==0){F=D;G=E;break}kg(D,c[194187]|0);t=D>>>24&15;r=d[((E|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);F=D+4|0;G=E+1|0}else{if(u){kg(v,c[194154]|0);t=v>>>24&15;s=d[((w|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);H=v+4|0;I=w+1|0}else{H=v;I=w}if((b&512|0)==0){J=H;K=I}else{kg(H,c[194155]|0);t=H>>>24&15;r=d[((I|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&1024|0)==0){L=J;M=K}else{kg(J,c[194156]|0);t=J>>>24&15;s=d[((K|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);L=J+4|0;M=K+1|0}if((b&2048|0)==0){N=L;O=M}else{kg(L,c[194157]|0);t=L>>>24&15;r=d[((M|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);N=L+4|0;O=M+1|0}if((b&4096|0)==0){F=N;G=O;break}kg(N,c[194158]|0);t=N>>>24&15;s=d[((O|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);F=N+4|0;G=O+1|0}}while(0);O=c[31194]|0;N=(b&8192|0)!=0;do{if((O|0)==31|(O|0)==16){if(N){kg(F,c[194159]|0);M=F>>>24&15;L=d[((G|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);P=F+4|0;Q=G+1|0}else{P=F;Q=G}if((b&16384|0)==0){R=P;S=Q;break}kg(P,c[194160]|0);M=P>>>24&15;s=d[((Q|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);R=P+4|0;S=Q+1|0}else{if(N){kg(F,c[194172]|0);M=F>>>24&15;L=d[((G|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(L&1^1|L))-1}}while(0);c[204526]=L+1+(c[204526]|0);T=F+4|0;U=G+1|0}else{T=F;U=G}if((b&16384|0)==0){R=T;S=U;break}kg(T,c[194173]|0);M=T>>>24&15;s=d[((U|0)==0?130616:125296)+M|0]|0;do{if((M-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);R=T+4|0;S=U+1|0}}while(0);if((b&32768|0)!=0){kg(R,(c[194161]|0)+4|0);b=R>>>24&15;R=d[((S|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(R&1^1|R))-1}}while(0);c[204526]=R+1+(c[204526]|0)}R=(c[194193]|0)>>>24&15;do{if((R-8|0)>>>0<6){b=c[194192]|0;if((b&1|0)==0){break}S=b&255;if((b&2|0)==0){c[194192]=S>>>1|b&-256;V=(d[130328+R|0]|0)-1|0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}else{c[194192]=S>>>2|b&-256;V=0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}}}while(0);c[194192]=0;V=d[130616+R|0]|0;W=V+1|0;X=c[204526]|0;Y=W+X|0;c[204526]=Y;return}function vp(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=(c[776584+((b>>>16&15)<<2)>>2]|0)+4|0;g=f&-4;if((b&1|0)==0){h=g;i=0}else{c[194146]=ke(g)|0;j=f>>>24&15;f=d[130616+j|0]|0;do{if((j-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);h=g+4|0;i=1}if((b&2|0)==0){k=h;l=i}else{c[194147]=ke(h)|0;g=h>>>24&15;f=d[((i|0)==0?130616:125296)+g|0]|0;do{if((g-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(f&1^1|f))-1}}while(0);c[204526]=f+1+(c[204526]|0);k=h+4|0;l=i+1|0}if((b&4|0)==0){m=k;n=l}else{c[194148]=ke(k)|0;i=k>>>24&15;h=d[((l|0)==0?130616:125296)+i|0]|0;do{if((i-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(h&1^1|h))-1}}while(0);c[204526]=h+1+(c[204526]|0);m=k+4|0;n=l+1|0}if((b&8|0)==0){o=m;p=n}else{c[194149]=ke(m)|0;l=m>>>24&15;k=d[((n|0)==0?130616:125296)+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);o=m+4|0;p=n+1|0}if((b&16|0)==0){q=o;r=p}else{c[194150]=ke(o)|0;n=o>>>24&15;m=d[((p|0)==0?130616:125296)+n|0]|0;do{if((n-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(m&1^1|m))-1}}while(0);c[204526]=m+1+(c[204526]|0);q=o+4|0;r=p+1|0}if((b&32|0)==0){s=q;t=r}else{c[194151]=ke(q)|0;p=q>>>24&15;o=d[((r|0)==0?130616:125296)+p|0]|0;do{if((p-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(o&1^1|o))-1}}while(0);c[204526]=o+1+(c[204526]|0);s=q+4|0;t=r+1|0}if((b&64|0)==0){u=s;v=t}else{c[194152]=ke(s)|0;r=s>>>24&15;q=d[((t|0)==0?130616:125296)+r|0]|0;do{if((r-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);u=s+4|0;v=t+1|0}if((b&128|0)==0){w=u;x=v}else{c[194153]=ke(u)|0;t=u>>>24&15;s=d[((v|0)==0?130616:125296)+t|0]|0;do{if((t-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);w=u+4|0;x=v+1|0}v=(b&32768|0)!=0;do{if(v){if((b&256|0)==0){y=w;z=x}else{c[194154]=ke(w)|0;u=w>>>24&15;s=d[((x|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);y=w+4|0;z=x+1|0}if((b&512|0)==0){A=y;B=z}else{c[194155]=ke(y)|0;u=y>>>24&15;t=d[((z|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);A=y+4|0;B=z+1|0}if((b&1024|0)==0){C=A;D=B}else{c[194156]=ke(A)|0;u=A>>>24&15;s=d[((B|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);C=A+4|0;D=B+1|0}if((b&2048|0)==0){E=C;F=D}else{c[194157]=ke(C)|0;u=C>>>24&15;t=d[((D|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);E=C+4|0;F=D+1|0}if((b&4096|0)==0){G=E;H=F}else{c[194158]=ke(E)|0;u=E>>>24&15;s=d[((F|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);G=E+4|0;H=F+1|0}if((b&8192|0)==0){I=G;J=H}else{c[194159]=ke(G)|0;u=G>>>24&15;t=d[((H|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);I=G+4|0;J=H+1|0}if((b&16384|0)==0){K=I;L=J}else{c[194160]=ke(I)|0;u=I>>>24&15;s=d[((J|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);K=I+4|0;L=J+1|0}c[194161]=ke(K)|0;u=K>>>24&15;t=d[((L|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0)}else{u=(b&256|0)!=0;do{if((c[31194]|0)==17){if(u){c[194183]=ke(w)|0;s=w>>>24&15;q=d[((x|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);M=w+4|0;N=x+1|0}else{M=w;N=x}if((b&512|0)==0){O=M;P=N}else{c[194184]=ke(M)|0;s=M>>>24&15;r=d[((N|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);O=M+4|0;P=N+1|0}if((b&1024|0)==0){Q=O;R=P}else{c[194185]=ke(O)|0;s=O>>>24&15;q=d[((P|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);Q=O+4|0;R=P+1|0}if((b&2048|0)==0){S=Q;T=R}else{c[194186]=ke(Q)|0;s=Q>>>24&15;r=d[((R|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);S=Q+4|0;T=R+1|0}if((b&4096|0)==0){U=S;V=T;break}c[194187]=ke(S)|0;s=S>>>24&15;q=d[((T|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);U=S+4|0;V=T+1|0}else{if(u){c[194154]=ke(w)|0;s=w>>>24&15;r=d[((x|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);W=w+4|0;X=x+1|0}else{W=w;X=x}if((b&512|0)==0){Y=W;Z=X}else{c[194155]=ke(W)|0;s=W>>>24&15;q=d[((X|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);Y=W+4|0;Z=X+1|0}if((b&1024|0)==0){_=Y;$=Z}else{c[194156]=ke(Y)|0;s=Y>>>24&15;r=d[((Z|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);_=Y+4|0;$=Z+1|0}if((b&2048|0)==0){aa=_;ab=$}else{c[194157]=ke(_)|0;s=_>>>24&15;q=d[(($|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);aa=_+4|0;ab=$+1|0}if((b&4096|0)==0){U=aa;V=ab;break}c[194158]=ke(aa)|0;s=aa>>>24&15;r=d[((ab|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);U=aa+4|0;V=ab+1|0}}while(0);u=c[31194]|0;t=(b&8192|0)!=0;if((u|0)==31|(u|0)==16){if(t){c[194159]=ke(U)|0;u=U>>>24&15;s=d[((V|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);ac=U+4|0;ad=V+1|0}else{ac=U;ad=V}if((b&16384|0)==0){break}c[194160]=ke(ac)|0;u=ac>>>24&15;q=d[((ad|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(q&1^1|q))-1}}while(0);c[204526]=q+1+(c[204526]|0);break}else{if(t){c[194172]=ke(U)|0;u=U>>>24&15;s=d[((V|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(s&1^1|s))-1}}while(0);c[204526]=s+1+(c[204526]|0);ae=U+4|0;af=V+1|0}else{ae=U;af=V}if((b&16384|0)==0){break}c[194173]=ke(ae)|0;u=ae>>>24&15;t=d[((af|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);break}}}while(0);if(v){v=c[194163]&31;if((c[31194]|0)!=(v|0)){km(v,0,1)}v=c[194161]|0;if((a[52040]&1)==0){af=v&-2;c[194193]=af;ae=af+2|0;c[194161]=ae;b=v>>>24;c[203402]=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&af)>>1]|0;b=ae>>>24;ag=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&ae)>>1]|0;ah=af}else{af=v&-4;c[194193]=af;ae=af+4|0;c[194161]=ae;b=v>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&af)>>2];b=ae>>>24;ag=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&ae)>>2]|0;ah=af}c[203400]=ag;ag=ah>>>24&15;do{if((ag-8|0)>>>0<6){af=c[194192]|0;if((af&1|0)==0){if(af>>>0<=255){ai=1016;break}c[194192]=0;aj=d[130616+ag|0]|0;break}ae=af&255;if((af&2|0)==0){c[194192]=ae>>>1|af&-256;aj=d[130328+ag|0]|0;break}else{c[194192]=ae>>>2|af&-256;aj=0;break}}else{ai=1016}}while(0);if((ai|0)==1016){aj=d[125296+ag|0]|0}c[204526]=aj+1+(c[204526]|0);ak=ah}else{ak=c[194193]|0}ah=ak>>>24&15;do{if((ah-8|0)>>>0<6){ak=c[194192]|0;if((ak&1|0)==0){break}aj=ak&255;if((ak&2|0)==0){c[194192]=aj>>>1|ak&-256;al=(d[130328+ah|0]|0)-1|0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}else{c[194192]=aj>>>2|ak&-256;al=0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}}}while(0);c[194192]=0;al=d[130616+ah|0]|0;am=al+2|0;an=c[204526]|0;ao=am+an|0;c[204526]=ao;return}function vq(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}e=776584+((b>>>16&15)<<2)|0;f=c[e>>2]|0;g=f+4|0;h=g&-4;i=((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+f|0;if((b&1|0)==0){j=h;k=0}else{kg(h,c[194146]|0);f=g>>>24&15;g=d[130616+f|0]|0;do{if((f-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);c[e>>2]=i;j=h+4|0;k=1}if((b&2|0)==0){l=j;m=k}else{kg(j,c[194147]|0);h=j>>>24&15;g=d[((k|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(g&1^1|g))-1}}while(0);c[204526]=g+1+(c[204526]|0);c[e>>2]=i;l=j+4|0;m=k+1|0}if((b&4|0)==0){n=l;o=m}else{kg(l,c[194148]|0);k=l>>>24&15;j=d[((m|0)==0?130616:125296)+k|0]|0;do{if((k-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);c[e>>2]=i;n=l+4|0;o=m+1|0}if((b&8|0)==0){p=n;q=o}else{kg(n,c[194149]|0);m=n>>>24&15;l=d[((o|0)==0?130616:125296)+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(l&1^1|l))-1}}while(0);c[204526]=l+1+(c[204526]|0);c[e>>2]=i;p=n+4|0;q=o+1|0}if((b&16|0)==0){r=p;s=q}else{kg(p,c[194150]|0);o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);c[e>>2]=i;r=p+4|0;s=q+1|0}if((b&32|0)==0){t=r;u=s}else{kg(r,c[194151]|0);q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);c[e>>2]=i;t=r+4|0;u=s+1|0}if((b&64|0)==0){v=t;w=u}else{kg(t,c[194152]|0);s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);c[e>>2]=i;v=t+4|0;w=u+1|0}if((b&128|0)==0){x=v;y=w}else{kg(v,c[194153]|0);u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=i;x=v+4|0;y=w+1|0}w=(b&256|0)!=0;do{if((c[31194]|0)==17){if(w){kg(x,c[194183]|0);v=x>>>24&15;t=d[((y|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=i;z=x+4|0;A=y+1|0}else{z=x;A=y}if((b&512|0)==0){B=z;C=A}else{kg(z,c[194184]|0);v=z>>>24&15;u=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=i;B=z+4|0;C=A+1|0}if((b&1024|0)==0){D=B;E=C}else{kg(B,c[194185]|0);v=B>>>24&15;t=d[((C|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=i;D=B+4|0;E=C+1|0}if((b&2048|0)==0){F=D;G=E}else{kg(D,c[194186]|0);v=D>>>24&15;u=d[((E|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=i;F=D+4|0;G=E+1|0}if((b&4096|0)==0){H=F;I=G;break}kg(F,c[194187]|0);v=F>>>24&15;t=d[((G|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=i;H=F+4|0;I=G+1|0}else{if(w){kg(x,c[194154]|0);v=x>>>24&15;u=d[((y|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=i;J=x+4|0;K=y+1|0}else{J=x;K=y}if((b&512|0)==0){L=J;M=K}else{kg(J,c[194155]|0);v=J>>>24&15;t=d[((K|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=i;L=J+4|0;M=K+1|0}if((b&1024|0)==0){N=L;O=M}else{kg(L,c[194156]|0);v=L>>>24&15;u=d[((M|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=i;N=L+4|0;O=M+1|0}if((b&2048|0)==0){P=N;Q=O}else{kg(N,c[194157]|0);v=N>>>24&15;t=d[((O|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);c[e>>2]=i;P=N+4|0;Q=O+1|0}if((b&4096|0)==0){H=P;I=Q;break}kg(P,c[194158]|0);v=P>>>24&15;u=d[((Q|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=i;H=P+4|0;I=Q+1|0}}while(0);Q=c[31194]|0;P=(b&8192|0)!=0;do{if((Q|0)==31|(Q|0)==16){if(P){kg(H,c[194159]|0);O=H>>>24&15;N=d[((I|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(N&1^1|N))-1}}while(0);c[204526]=N+1+(c[204526]|0);c[e>>2]=i;R=H+4|0;S=I+1|0}else{R=H;S=I}if((b&16384|0)==0){T=R;U=S;break}kg(R,c[194160]|0);O=R>>>24&15;u=d[((S|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=i;T=R+4|0;U=S+1|0}else{if(P){kg(H,c[194172]|0);O=H>>>24&15;N=d[((I|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(N&1^1|N))-1}}while(0);c[204526]=N+1+(c[204526]|0);c[e>>2]=i;V=H+4|0;W=I+1|0}else{V=H;W=I}if((b&16384|0)==0){T=V;U=W;break}kg(V,c[194173]|0);O=V>>>24&15;u=d[((W|0)==0?130616:125296)+O|0]|0;do{if((O-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);c[e>>2]=i;T=V+4|0;U=W+1|0}}while(0);if((b&32768|0)!=0){kg(T,(c[194161]|0)+4|0);b=T>>>24&15;T=d[((U|0)==0?130616:125296)+b|0]|0;do{if((b-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(T&1^1|T))-1}}while(0);c[204526]=T+1+(c[204526]|0);c[e>>2]=i}i=(c[194193]|0)>>>24&15;do{if((i-8|0)>>>0<6){e=c[194192]|0;if((e&1|0)==0){break}T=e&255;if((e&2|0)==0){c[194192]=T>>>1|e&-256;X=(d[130328+i|0]|0)-1|0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}else{c[194192]=T>>>2|e&-256;X=0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}}}while(0);c[194192]=0;X=d[130616+i|0]|0;Y=X+1|0;Z=c[204526]|0;_=Y+Z|0;c[204526]=_;return}function vr(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;if((c[194192]|0)==0){a[776764]=a[776765]&1}f=b>>>16&15;g=776584+(f<<2)|0;h=c[g>>2]|0;i=((d[817848+(b>>>8&255)|0]|0)+(d[817848+(b&255)|0]|0)<<2)+h|0;j=h+4|0;h=j&-4;if((b&1|0)==0){k=h;l=0}else{c[194146]=ke(h)|0;m=j>>>24&15;j=d[130616+m|0]|0;do{if((m-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);k=h+4|0;l=1}if((b&2|0)==0){n=k;o=l}else{c[194147]=ke(k)|0;h=k>>>24&15;j=d[((l|0)==0?130616:125296)+h|0]|0;do{if((h-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(j&1^1|j))-1}}while(0);c[204526]=j+1+(c[204526]|0);n=k+4|0;o=l+1|0}if((b&4|0)==0){p=n;q=o}else{c[194148]=ke(n)|0;l=n>>>24&15;k=d[((o|0)==0?130616:125296)+l|0]|0;do{if((l-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(k&1^1|k))-1}}while(0);c[204526]=k+1+(c[204526]|0);p=n+4|0;q=o+1|0}if((b&8|0)==0){r=p;s=q}else{c[194149]=ke(p)|0;o=p>>>24&15;n=d[((q|0)==0?130616:125296)+o|0]|0;do{if((o-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(n&1^1|n))-1}}while(0);c[204526]=n+1+(c[204526]|0);r=p+4|0;s=q+1|0}if((b&16|0)==0){t=r;u=s}else{c[194150]=ke(r)|0;q=r>>>24&15;p=d[((s|0)==0?130616:125296)+q|0]|0;do{if((q-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(p&1^1|p))-1}}while(0);c[204526]=p+1+(c[204526]|0);t=r+4|0;u=s+1|0}if((b&32|0)==0){v=t;w=u}else{c[194151]=ke(t)|0;s=t>>>24&15;r=d[((u|0)==0?130616:125296)+s|0]|0;do{if((s-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(r&1^1|r))-1}}while(0);c[204526]=r+1+(c[204526]|0);v=t+4|0;w=u+1|0}if((b&64|0)==0){x=v;y=w}else{c[194152]=ke(v)|0;u=v>>>24&15;t=d[((w|0)==0?130616:125296)+u|0]|0;do{if((u-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);x=v+4|0;y=w+1|0}if((b&128|0)==0){z=x;A=y}else{c[194153]=ke(x)|0;w=x>>>24&15;v=d[((y|0)==0?130616:125296)+w|0]|0;do{if((w-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);z=x+4|0;A=y+1|0}y=(b&32768|0)!=0;do{if(y){if((b&256|0)==0){B=z;C=A}else{c[194154]=ke(z)|0;x=z>>>24&15;v=d[((A|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);B=z+4|0;C=A+1|0}if((b&512|0)==0){D=B;E=C}else{c[194155]=ke(B)|0;x=B>>>24&15;w=d[((C|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);D=B+4|0;E=C+1|0}if((b&1024|0)==0){F=D;G=E}else{c[194156]=ke(D)|0;x=D>>>24&15;v=d[((E|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);F=D+4|0;G=E+1|0}if((b&2048|0)==0){H=F;I=G}else{c[194157]=ke(F)|0;x=F>>>24&15;w=d[((G|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);H=F+4|0;I=G+1|0}if((b&4096|0)==0){J=H;K=I}else{c[194158]=ke(H)|0;x=H>>>24&15;v=d[((I|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);J=H+4|0;K=I+1|0}if((b&8192|0)==0){L=J;M=K}else{c[194159]=ke(J)|0;x=J>>>24&15;w=d[((K|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);L=J+4|0;M=K+1|0}if((b&16384|0)==0){N=L;O=M}else{c[194160]=ke(L)|0;x=L>>>24&15;v=d[((M|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);N=L+4|0;O=M+1|0}c[194161]=ke(N)|0;x=N>>>24&15;w=d[((O|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0)}else{x=(b&256|0)!=0;do{if((c[31194]|0)==17){if(x){c[194183]=ke(z)|0;v=z>>>24&15;t=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);P=z+4|0;Q=A+1|0}else{P=z;Q=A}if((b&512|0)==0){R=P;S=Q}else{c[194184]=ke(P)|0;v=P>>>24&15;u=d[((Q|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);R=P+4|0;S=Q+1|0}if((b&1024|0)==0){T=R;U=S}else{c[194185]=ke(R)|0;v=R>>>24&15;t=d[((S|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);T=R+4|0;U=S+1|0}if((b&2048|0)==0){V=T;W=U}else{c[194186]=ke(T)|0;v=T>>>24&15;u=d[((U|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);V=T+4|0;W=U+1|0}if((b&4096|0)==0){X=V;Y=W;break}c[194187]=ke(V)|0;v=V>>>24&15;t=d[((W|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);X=V+4|0;Y=W+1|0}else{if(x){c[194154]=ke(z)|0;v=z>>>24&15;u=d[((A|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);Z=z+4|0;_=A+1|0}else{Z=z;_=A}if((b&512|0)==0){$=Z;aa=_}else{c[194155]=ke(Z)|0;v=Z>>>24&15;t=d[((_|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);$=Z+4|0;aa=_+1|0}if((b&1024|0)==0){ab=$;ac=aa}else{c[194156]=ke($)|0;v=$>>>24&15;u=d[((aa|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);ab=$+4|0;ac=aa+1|0}if((b&2048|0)==0){ad=ab;ae=ac}else{c[194157]=ke(ab)|0;v=ab>>>24&15;t=d[((ac|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);ad=ab+4|0;ae=ac+1|0}if((b&4096|0)==0){X=ad;Y=ae;break}c[194158]=ke(ad)|0;v=ad>>>24&15;u=d[((ae|0)==0?130616:125296)+v|0]|0;do{if((v-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(u&1^1|u))-1}}while(0);c[204526]=u+1+(c[204526]|0);X=ad+4|0;Y=ae+1|0}}while(0);x=c[31194]|0;w=(b&8192|0)!=0;if((x|0)==31|(x|0)==16){if(w){c[194159]=ke(X)|0;x=X>>>24&15;v=d[((Y|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);af=X+4|0;ag=Y+1|0}else{af=X;ag=Y}if((b&16384|0)==0){break}c[194160]=ke(af)|0;x=af>>>24&15;t=d[((ag|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(t&1^1|t))-1}}while(0);c[204526]=t+1+(c[204526]|0);break}else{if(w){c[194172]=ke(X)|0;x=X>>>24&15;v=d[((Y|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(v&1^1|v))-1}}while(0);c[204526]=v+1+(c[204526]|0);ah=X+4|0;ai=Y+1|0}else{ah=X;ai=Y}if((b&16384|0)==0){break}c[194173]=ke(ah)|0;x=ah>>>24&15;w=d[((ai|0)==0?130616:125296)+x|0]|0;do{if((x-2|0)>>>0>5){c[194192]=0;a[776764]=0}else{if((a[776764]&1)==0){break}c[194192]=((c[194192]|0)+1<<(w&1^1|w))-1}}while(0);c[204526]=w+1+(c[204526]|0);break}}}while(0);if((1<<f&b|0)==0){c[g>>2]=i}if(y){y=c[194163]&31;if((c[31194]|0)!=(y|0)){km(y,0,1)}y=c[194161]|0;if((a[52040]&1)==0){i=y&-2;c[194193]=i;g=i+2|0;c[194161]=g;b=y>>>24;c[203402]=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&i)>>1]|0;b=g>>>24;aj=e[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>1]|0;ak=i}else{i=y&-4;c[194193]=i;g=i+4|0;c[194161]=g;b=y>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&i)>>2];b=g>>>24;aj=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&g)>>2]|0;ak=i}c[203400]=aj;aj=ak>>>24&15;do{if((aj-8|0)>>>0<6){i=c[194192]|0;if((i&1|0)==0){if(i>>>0<=255){al=1380;break}c[194192]=0;am=d[130616+aj|0]|0;break}g=i&255;if((i&2|0)==0){c[194192]=g>>>1|i&-256;am=d[130328+aj|0]|0;break}else{c[194192]=g>>>2|i&-256;am=0;break}}else{al=1380}}while(0);if((al|0)==1380){am=d[125296+aj|0]|0}c[204526]=am+1+(c[204526]|0);an=ak}else{an=c[194193]|0}ak=an>>>24&15;do{if((ak-8|0)>>>0<6){an=c[194192]|0;if((an&1|0)==0){break}am=an&255;if((an&2|0)==0){c[194192]=am>>>1|an&-256;ao=(d[130328+ak|0]|0)-1|0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}else{c[194192]=am>>>2|an&-256;ao=0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}}}while(0);c[194192]=0;ao=d[130616+ak|0]|0;ap=ao+2|0;aq=c[204526]|0;ar=ap+aq|0;c[204526]=ar;return}function vs(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=(c[194161]|0)+(((a&8388608|0)==0?a&16777215:a|-16777216)<<2)|0;c[194193]=b;a=b+4|0;c[194161]=a;e=b>>>24;c[203402]=c[(c[774536+(e<<3)>>2]|0)+(c[774540+(e<<3)>>2]&b)>>2];b=a>>>24;c[203400]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&a)>>2];a=e&15;e=(a-8|0)>>>0<6;do{if(e){b=c[194192]|0;if((b&1|0)==0){if(b>>>0<=255){f=1399;break}c[194192]=0;g=130616+a|0;f=1400;break}h=b&255;if((b&2|0)==0){c[194192]=h>>>1|b&-256;g=130328+a|0;f=1400;break}else{i=h>>>2|b&-256;c[194192]=i;j=0;k=i;f=1402;break}}else{f=1399}}while(0);if((f|0)==1399){g=125296+a|0;f=1400}do{if((f|0)==1400){i=d[g]|0;if(!e){l=i;break}j=i;k=c[194192]|0;f=1402}}while(0);do{if((f|0)==1402){if((k&1|0)==0){l=j;break}e=k&255;if((k&2|0)==0){c[194192]=e>>>1|k&-256;m=(d[130328+a|0]|0)-1|0;n=j;o=n<<1;p=m+5|0;q=p+o|0;c[194192]=0;c[204526]=q;return}else{c[194192]=e>>>2|k&-256;m=0;n=j;o=n<<1;p=m+5|0;q=p+o|0;c[194192]=0;c[204526]=q;return}}}while(0);c[194192]=0;m=d[130616+a|0]|0;n=l;o=n<<1;p=m+5|0;q=p+o|0;c[194192]=0;c[204526]=q;return}function vt(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[194161]|0;c[194160]=b-4;e=b+(((a&8388608|0)==0?a&16777215:a|-16777216)<<2)|0;c[194193]=e;a=e+4|0;c[194161]=a;b=e>>>24;c[203402]=c[(c[774536+(b<<3)>>2]|0)+(c[774540+(b<<3)>>2]&e)>>2];e=a>>>24;c[203400]=c[(c[774536+(e<<3)>>2]|0)+(c[774540+(e<<3)>>2]&a)>>2];a=b&15;b=(a-8|0)>>>0<6;do{if(b){e=c[194192]|0;if((e&1|0)==0){if(e>>>0<=255){f=1418;break}c[194192]=0;g=130616+a|0;f=1419;break}h=e&255;if((e&2|0)==0){c[194192]=h>>>1|e&-256;g=130328+a|0;f=1419;break}else{i=h>>>2|e&-256;c[194192]=i;j=0;k=i;f=1421;break}}else{f=1418}}while(0);if((f|0)==1418){g=125296+a|0;f=1419}do{if((f|0)==1419){i=d[g]|0;if(!b){l=i;break}j=i;k=c[194192]|0;f=1421}}while(0);do{if((f|0)==1421){if((k&1|0)==0){l=j;break}b=k&255;if((k&2|0)==0){c[194192]=b>>>1|k&-256;m=(d[130328+a|0]|0)-1|0;n=j;o=n<<1;p=m+5|0;q=p+o|0;c[194192]=0;c[204526]=q;return}else{c[194192]=b>>>2|k&-256;m=0;n=j;o=n<<1;p=m+5|0;q=p+o|0;c[194192]=0;c[204526]=q;return}}}while(0);c[194192]=0;m=d[130616+a|0]|0;n=l;o=n<<1;p=m+5|0;q=p+o|0;c[194192]=0;c[204526]=q;return}function vu(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=(c[194193]|0)>>>24&15;e=(b-8|0)>>>0<6;do{if(e){f=c[194192]|0;if((f&1|0)==0){if(f>>>0<=255){g=1437;break}c[194192]=0;h=130616+b|0;g=1438;break}i=f&255;if((f&2|0)==0){c[194192]=i>>>1|f&-256;h=130328+b|0;g=1438;break}else{j=i>>>2|f&-256;c[194192]=j;k=0;l=j;g=1440;break}}else{g=1437}}while(0);if((g|0)==1437){h=125296+b|0;g=1438}do{if((g|0)==1438){j=d[h]|0;if(!e){m=j;g=1444;break}k=j;l=c[194192]|0;g=1440}}while(0);do{if((g|0)==1440){if((l&1|0)==0){m=k;g=1444;break}e=l&255;if((l&2|0)==0){c[194192]=e>>>1|l&-256;n=(d[130328+b|0]|0)-1|0;o=k;break}else{c[194192]=e>>>2|l&-256;n=0;o=k;break}}}while(0);if((g|0)==1444){c[194192]=0;n=d[130616+b|0]|0;o=m}c[194192]=0;c[204526]=n+5+(o<<1);n$(a&16777215);return}function vv(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=c[36850]|0;f=(b[390344]&16)!=0?d+40960|0:d;d=b[390350]|0;g=(d&65535)<<25&100663296;h=b[384164]|0;i=h&65535;j=i<<16&134152192|(e[384160]|0);k=j|-134217728;l=(i&2048|0)==0?j:k;i=b[384156]|0;m=i&65535;n=m<<16&134152192|(e[384152]|0);o=n|-134217728;p=(m&2048|0)==0?n:o;m=e[390360]|0;q=(m&32768|0)==0?m&32767:m|-32768;m=e[390361]|0;r=(m&32768|0)==0?m&32767:m|-32768;m=e[390362]|0;s=(m&32768|0)==0?m&32767:m|-32768;m=e[390363]|0;t=(m&32768|0)==0?m&32767:m|-32768;m=b[390347]|0;u=m<<16>>16==0?3:a;a=(c[192054]|0)+r|0;c[192054]=a;v=t+(c[192052]|0)|0;c[192052]=v;do{if((u&1|0)==0){w=a}else{c[192054]=j;if((h&2048)==0){w=j;break}c[192054]=k;w=k}}while(0);do{if((u&2|0)==0){x=v}else{c[192052]=n;if((i&2048)==0){x=n;break}c[192052]=o;x=o}}while(0);o=d&64;if(o<<16>>16==0){y=x;z=w}else{w=m&65535;m=w-((w>>>0)%((((e[384124]|0)>>>4&15)+1|0)>>>0)|0)|0;w=(ac(m,r)|0)+l|0;y=(ac(m,t)|0)+p|0;z=w}v3(770528,-1|0,960);w=z;z=y;y=0;while(1){p=z>>8;t=w>>8;if(t>>>0<160&p>>>0<128){c[770528+(y<<2)>>2]=g|(e[f+((p*160|0)+t<<1)>>1]|0)|16777216}t=y+1|0;if(t>>>0<240){w=w+q|0;z=z+s|0;y=t}else{break}}y=(b[384124]&15)+1|0;if(!(o<<16>>16!=0&y>>>0>1)){return}c[192633]=c[192632];o=(y|0)==2;s=2;z=o;q=o?2:1;do{s=z?2:s+1|0;o=q+1|0;c[770528+(o<<2)>>2]=c[770528+(q<<2)>>2];z=(s|0)==(y|0);q=(z?o:q)+1|0;}while(q>>>0<239);return}function vw(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=c[191862]|0;g=c[36850]|0;h=(b[390344]&16)!=0?g+40960|0:g;g=b[390350]|0;i=(g&65535)<<25&100663296;j=b[384164]|0;k=j&65535;l=k<<16&134152192|(e[384160]|0);m=l|-134217728;n=(k&2048|0)==0?l:m;k=b[384156]|0;o=k&65535;p=o<<16&134152192|(e[384152]|0);q=p|-134217728;r=(o&2048|0)==0?p:q;o=e[390360]|0;s=(o&32768|0)==0?o&32767:o|-32768;o=e[390361]|0;t=(o&32768|0)==0?o&32767:o|-32768;o=e[390362]|0;u=(o&32768|0)==0?o&32767:o|-32768;o=e[390363]|0;v=(o&32768|0)==0?o&32767:o|-32768;o=b[390347]|0;w=o<<16>>16==0?3:d;d=(c[192054]|0)+t|0;c[192054]=d;x=v+(c[192052]|0)|0;c[192052]=x;do{if((w&1|0)==0){y=d}else{c[192054]=l;if((j&2048)==0){y=l;break}c[192054]=m;y=m}}while(0);do{if((w&2|0)==0){z=x}else{c[192052]=p;if((k&2048)==0){z=p;break}c[192052]=q;z=q}}while(0);q=(g&64)==0;if(q){A=z;B=y}else{y=o&65535;o=y-((y>>>0)%((((e[384124]|0)>>>4&15)+1|0)>>>0)|0)|0;y=(ac(o,t)|0)+n|0;A=(ac(o,v)|0)+r|0;B=y}v3(770528,-1|0,960);y=B;B=A;A=0;while(1){r=B>>8;v=y>>8;o=a[h+((r*240|0)+v)|0]|0;if(!(r>>>0>159|v>>>0>239|o<<24>>24==0)){c[770528+(A<<2)>>2]=i|(e[f+((o&255)<<1)>>1]|0)|16777216}o=A+1|0;if(o>>>0<240){y=y+s|0;B=B+u|0;A=o}else{break}}if(q){return}q=(b[384124]&15)+1|0;if(q>>>0<=1){return}c[192633]=c[192632];A=(q|0)==2;u=2;B=A;s=A?2:1;do{u=B?2:u+1|0;A=s+1|0;c[770528+(A<<2)>>2]=c[770528+(s<<2)>>2];B=(u|0)==(q|0);s=(B?A:s)+1|0;}while(s>>>0<239);return}function vx(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[36850]|0;f=b[390350]|0;g=(f&65535)<<25&100663296;h=e[390360]|0;i=(h&32768|0)==0?h&32767:h|-32768;h=e[390361]|0;j=(h&32768|0)==0?h&32767:h|-32768;h=e[390362]|0;k=(h&32768|0)==0?h&32767:h|-32768;h=e[390363]|0;l=(h&32768|0)==0?h&32767:h|-32768;h=b[390347]|0;m=h<<16>>16==0?3:a;a=(c[192054]|0)+j|0;c[192054]=a;n=l+(c[192052]|0)|0;c[192052]=n;do{if((m&1|0)==0){o=a}else{p=b[384164]|0;q=(p&65535)<<16&134152192|(e[384160]|0);c[192054]=q;if((p&2048)==0){o=q;break}p=q|-134217728;c[192054]=p;o=p}}while(0);do{if((m&2|0)==0){r=n}else{a=b[384156]|0;p=(a&65535)<<16&134152192|(e[384152]|0);c[192052]=p;if((a&2048)==0){r=p;break}a=p|-134217728;c[192052]=a;r=a}}while(0);n=(f&64)==0;if(n){s=r;t=o}else{f=((h&65535)>>>0)%((((e[384124]|0)>>>4&15)+1|0)>>>0)|0;h=o-(ac(f,j)|0)|0;s=r-(ac(f,l)|0)|0;t=h}v3(770528,-1|0,960);h=t;t=s;s=0;while(1){l=t>>8;f=h>>8;if(f>>>0<240&l>>>0<160){c[770528+(s<<2)>>2]=g|(e[d+((l*240|0)+f<<1)>>1]|0)|16777216}f=s+1|0;if(f>>>0<240){h=h+i|0;t=t+k|0;s=f}else{break}}if(n){return}n=(b[384124]&15)+1|0;if(n>>>0<=1){return}c[192633]=c[192632];s=(n|0)==2;k=2;t=s;i=s?2:1;do{k=t?2:k+1|0;s=i+1|0;c[770528+(s<<2)>>2]=c[770528+(i<<2)>>2];t=(k|0)==(n|0);i=(t?s:i)+1|0;}while(i>>>0<239);return}function vy(){return 1}function vz(a){a=a|0;c[191850]=a;return}function vA(a){a=a|0;return}function vB(a){a=a|0;c[195142]=a;return}function vC(a){a=a|0;c[192046]=a;return}function vD(a){a=a|0;c[191860]=a;return}function vE(a,b){a=a|0;b=b|0;return}function vF(){return}function vG(a){a=a|0;return((a|0)==0?341e3:0)|0}function vH(a){a=a|0;return((a|0)==0?c[31316]|0:0)|0}function vI(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;j=i;i=i+32|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=d&1;a[k|0]=o;a[k+1|0]=f&1;a[k+2|0]=g&1;a[k+3|0]=h&1;b[l>>1]=b[390348]|0;b[l+2>>1]=b[390349]|0;b[l+4>>1]=b[390350]|0;b[l+6>>1]=b[390351]|0;b[m>>1]=b[390352]|0;b[m+2>>1]=b[390354]|0;b[m+4>>1]=b[390356]|0;b[m+6>>1]=b[390358]|0;b[n>>1]=b[390353]|0;b[n+2>>1]=b[390355]|0;b[n+4>>1]=b[390357]|0;b[n+6>>1]=b[390359]|0;h=c[36850]|0;g=0;f=o;while(1){do{if((f&1)!=0){o=c[51680+(g<<2)>>2]|0;d=c[191862]|0;p=e[l+(g<<1)>>1]|0;q=p>>>2<<14&49152;r=p>>>8<<11&63488;s=h+r|0;t=p<<25&100663296|16777216;u=p>>>14;v=c[147088+(u<<2)>>2]|0;w=(c[147024+(u<<2)>>2]|0)-1|0;x=v+65535&(e[m+(g<<1)>>1]|0);y=e[390347]|0;z=y+(e[n+(g<<1)>>1]|0)|0;A=z&w;B=e[384124]|0;C=(B&15)+1|0;D=(p&64|0)!=0;do{if(D){E=(y>>>0)%(((B>>>4&15)+1|0)>>>0)|0;if((E|0)==0){F=A;break}F=z-E&w}else{F=A}}while(0);do{if((F|0)>255){if((u-2|0)>>>0>=2){G=s;H=F;break}A=F&255;if((u|0)!=3){G=h+(r+2048)|0;H=A;break}G=h+(r+4096)|0;H=A}else{G=s;H=F}}while(0);s=H>>>3<<5;r=G+(s+(x>>>8<<10|x>>>3&31)<<1)|0;A=H&7;w=A^7;z=G+(s<<1)|0;B=G+(s+1024<<1)|0;if((p&128|0)==0){s=r;y=0;E=x;while(1){I=e[s>>1]|0;J=E&7;K=(J|0)==7?s+2|0:s;L=(I&1024|0)==0?J:J^7;J=a[h+((((I&2048|0)==0?A:w)<<2|I<<5&32736|L>>>1)+q)|0]|0;M=(L&1|0)==0?J&15:(J&255)>>>4;if(M<<24>>24==0){N=-2147483648}else{N=e[d+((M&255|I>>>8&240)<<1)>>1]|0|t}c[o+(y<<2)>>2]=N;I=E+1|0;do{if((I|0)==256){if((u|0)==3|(u|0)==1){O=256;P=B;break}O=0;P=z}else{M=I>>>0<v>>>0;O=M?I:0;P=M?K:z}}while(0);K=y+1|0;if(K>>>0<240){s=P;y=K;E=O}else{break}}}else{if((u|0)==3){E=0;y=r;s=x;while(1){p=e[y>>1]|0;K=s&7;I=a[h+((((p&1024|0)==0?K:K^7)|p<<6&65472|((p&2048|0)==0?A:w)<<3)+q)|0]|0;if(I<<24>>24==0){Q=-2147483648}else{Q=e[d+((I&255)<<1)>>1]|0|t}c[o+(E<<2)>>2]=Q;I=s+1|0;if((I|0)==256){R=256;S=B}else{p=I>>>0<v>>>0;R=p?I:0;S=p?(K|0)==7?y+2|0:y:z}K=E+1|0;if(K>>>0<240){E=K;y=S;s=R}else{break}}}else if((u|0)==1){s=0;y=r;E=x;while(1){K=e[y>>1]|0;p=E&7;I=a[h+((((K&1024|0)==0?p:p^7)|K<<6&65472|((K&2048|0)==0?A:w)<<3)+q)|0]|0;if(I<<24>>24==0){T=-2147483648}else{T=e[d+((I&255)<<1)>>1]|0|t}c[o+(s<<2)>>2]=T;I=E+1|0;if((I|0)==256){U=256;V=B}else{K=I>>>0<v>>>0;U=K?I:0;V=K?(p|0)==7?y+2|0:y:z}p=s+1|0;if(p>>>0<240){s=p;y=V;E=U}else{break}}}else{E=0;y=r;s=x;while(1){p=e[y>>1]|0;K=s&7;I=(K|0)==7?y+2|0:y;M=a[h+((((p&1024|0)==0?K:K^7)|p<<6&65472|((p&2048|0)==0?A:w)<<3)+q)|0]|0;if(M<<24>>24==0){W=-2147483648}else{W=e[d+((M&255)<<1)>>1]|0|t}c[o+(E<<2)>>2]=W;M=s+1|0;do{if((M|0)==256){if((u|0)==3|(u|0)==1){X=256;Y=B;break}X=0;Y=z}else{p=M>>>0<v>>>0;X=p?M:0;Y=p?I:z}}while(0);I=E+1|0;if(I>>>0<240){E=I;y=Y;s=X}else{break}}}}if(D&C>>>0>1){Z=1;_=0}else{break}while(1){s=_+1|0;c[o+(s<<2)>>2]=c[o+(_<<2)>>2];y=Z+1|0;E=(y|0)==(C|0);z=(E?s:_)+1|0;if(z>>>0<239){Z=E?1:y;_=z}else{break}}}}while(0);C=g+1|0;if((C|0)>=4){break}g=C;f=a[k+C|0]|0}i=j;return}function vJ(b){b=b|0;a[b+12|0]=1;c[b+8>>2]=33744;c[b+4>>2]=28056;c[b>>2]=24e3;a[b+13|0]=0;return}function vK(a){a=a|0;c[a>>2]=240;c[a+4>>2]=160;c[a+8>>2]=240;c[a+12>>2]=160;h[a+24>>3]=59.72750056960583;h[a+32>>3]=32.0e3;return}function vL(f,g,h,i,j,k,l,m,n,o,p,q,r){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;s=c[191862]|0;t=f&65535;f=t>>>2<<14&49152;u=c[36850]|0;v=t>>>8<<11&63488;w=t<<25&100663296|16777216;x=t>>>14;y=c[130344+(x<<2)>>2]|0;z=y-1|0;A=x|4;x=k&65535;k=(x&32768|0)==0?x&32767:x|-32768;x=l&65535;l=(x&32768|0)==0?x&32767:x|-32768;x=m&65535;m=(x&32768|0)==0?x&32767:x|-32768;x=n&65535;n=(x&32768|0)==0?x&32767:x|-32768;x=(b[390347]|0)==0?3:q;c[o>>2]=(c[o>>2]|0)+l;c[p>>2]=(c[p>>2]|0)+n;do{if((x&1|0)!=0){q=h&65535;B=q<<16&134152192|g&65535;c[o>>2]=B;if((q&2048|0)==0){break}c[o>>2]=B|-134217728}}while(0);do{if((x&2|0)==0){C=c[p>>2]|0}else{g=j&65535;h=g<<16&134152192|i&65535;c[p>>2]=h;if((g&2048|0)==0){C=h;break}g=h|-134217728;c[p>>2]=g;C=g}}while(0);p=c[o>>2]|0;o=(t&64|0)!=0;if(o){i=((e[390347]|0)>>>0)%((((e[384124]|0)>>>4&15)+1|0)>>>0)|0;j=p-(ac(i,l)|0)|0;D=j;E=C-(ac(i,n)|0)|0}else{D=p;E=C}v3(r|0,-1|0,960);if((t&8192|0)==0){t=0;C=E;p=D;while(1){n=p>>8;i=C>>8;do{if(n>>>0<y>>>0&i>>>0<y>>>0){j=a[u+(n&7|f|i<<3&56|d[u+((n>>>3)+v+(i>>>3<<A))|0]<<6)|0]|0;if(j<<24>>24==0){break}c[r+(t<<2)>>2]=e[s+((j&255)<<1)>>1]|w}}while(0);i=t+1|0;if(i>>>0<240){t=i;C=C+m|0;p=p+k|0}else{break}}}else{p=0;C=E;E=D;while(1){D=E>>8&z;t=C>>8&z;y=a[u+(D&7|f|t<<3&56|d[u+((D>>3)+v+(t>>3<<A))|0]<<6)|0]|0;if(y<<24>>24!=0){c[r+(p<<2)>>2]=e[s+((y&255)<<1)>>1]|w}y=p+1|0;if(y>>>0<240){p=y;C=C+m|0;E=E+k|0}else{break}}}if(!o){return}o=(b[384124]&15)+1|0;if(o>>>0<=1){return}c[r+4>>2]=c[r>>2];k=(o|0)==2;E=2;m=k;C=k?2:1;do{E=m?2:E+1|0;k=C+1|0;c[r+(k<<2)>>2]=c[r+(C<<2)>>2];m=(E|0)==(o|0);C=(m?k:C)+1|0;}while(C>>>0<239);return}function vM(a){a=a|0;var b=0,d=0;b=i;i=i+16|0;c[204452]=a;d=b|0;c[d>>2]=c[12932];c[d+4>>2]=c[12933];c[d+8>>2]=c[12934];c[d+12>>2]=c[12935];fr[a&63](16,d)|0;i=b;return}function vN(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+8|0;d=b|0;v3(341e3,-1|0,139264);e=0;while(1){if(e>>>0>=512){f=0;g=1588;break}if((a[341e3+e|0]|0)==-1){e=e+1|0}else{h=0;g=1585;break}}L2097:do{if((g|0)==1585){while(1){g=0;if(h>>>0>=138752){break}if((a[h+341512|0]|0)==-1){h=h+1|0;g=1585}else{f=0;g=1588;break L2097}}c[31316]=512;a3(41584,23,1,c[q>>2]|0)|0}}while(0);L2102:do{if((g|0)==1588){while(1){g=0;if(f>>>0>=8192){j=0;break}if((a[341e3+f|0]|0)==-1){f=f+1|0;g=1588}else{k=0;g=1590;break}}L2106:do{if((g|0)==1590){while(1){g=0;if(k>>>0>=131072){break}if((a[k+349192|0]|0)==-1){k=k+1|0;g=1590}else{j=0;break L2106}}c[31316]=8192;a3(40584,24,1,c[q>>2]|0)|0;break L2102}}while(0);while(1){if(j>>>0>=65536){l=0;break}if((a[341e3+j|0]|0)==-1){j=j+1|0}else{m=0;g=1595;break}}L2114:do{if((g|0)==1595){while(1){g=0;if(m>>>0>=73728){break}if((a[m+406536|0]|0)==-1){m=m+1|0;g=1595}else{l=0;break L2114}}c[31316]=65536;a3(39536,24,1,c[q>>2]|0)|0;break L2102}}while(0);while(1){if(l>>>0>=131072){break}if((a[341e3+l|0]|0)==-1){l=l+1|0}else{n=0;g=1600;break}}L2122:do{if((g|0)==1600){while(1){g=0;if(n>>>0>=8192){break}if((a[n+472072|0]|0)==-1){n=n+1|0;g=1600}else{break L2122}}c[31316]=131072;a3(38640,22,1,c[q>>2]|0)|0;break L2102}}while(0);a3(37528,41,1,c[q>>2]|0)|0}}while(0);g=c[31316]|0;if((g|0)==8192|(g|0)==512){c[2374]=341e3}fr[c[204452]&63](3,767976)|0;c[d>>2]=2;if(!(fr[c[204452]&63](10,d)|0)){i=b;return}a3(20656,62,1,c[q>>2]|0)|0;i=b;return}function vO(){kk();return}function vP(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0;f=i;i=i+16|0;g=f|0;h=f+8|0;a[h]=0;do{if(fr[c[204452]&63](17,h)|0){if((a[h]&1)==0){break}c[g>>2]=30176;j=g+4|0;c[j>>2]=0;if(!(fr[c[204452]&63](15,g)|0)){break}k=c[j>>2]|0;if((cJ(k|0,44248)|0)==0){a[9504]=0;break}if((cJ(k|0,42888)|0)!=0){break}a[9504]=1}}while(0);fx[c[192046]&127]();g=0;h=0;do{g=(fv[c[191860]&15](0,1,0,c[(a[9504]|0?124784:125208)+(h<<2)>>2]|0)|0)<<16>>16<<h|g;h=h+1|0;}while(h>>>0<10);c[120066]=g;c[120067]=0;a[51768]=0;do{c[194192]=0;c[195148]=0;g=c[191865]|0;h=c[322]|0;k=(h|0)<(g|0)?h:g;if((a[767432]&1)==0){l=k}else{g=c[203380]|0;l=(g|0)<(k|0)?g:k}do{if((a[767424]&1)==0){m=l}else{if((b[390475]&4)!=0){m=l;break}k=c[203376]|0;m=(k|0)<(l|0)?k:l}}while(0);do{if((a[767416]&1)==0){n=m}else{if((b[390477]&4)!=0){n=m;break}k=c[203372]|0;n=(k|0)<(m|0)?k:m}}while(0);do{if((a[767408]&1)==0){o=n}else{if((b[390479]&4)!=0){o=n;break}k=c[203368]|0;o=(k|0)<(n|0)?k:n}}while(0);k=c[191996]|0;g=(k|0)!=0&(k|0)<(o|0)?k:o;k=(g|0)>25e4?25e4:g;c[203364]=k;g=25e4;h=k;L2167:while(1){k=a[767384]|0;j=h;while(1){L2171:do{if((k&1)==0){if((a[52040]&1)==0){while(1){c[204526]=0;p=c[203402]|0;c[203402]=c[203400];a[776764]=0;q=c[194193]|0;r=c[194161]|0;c[194193]=r;s=r+2|0;c[194161]=s;r=s>>>24;c[203400]=e[(c[774536+(r<<3)>>2]|0)+(s&c[774540+(r<<3)>>2])>>1]|0;e9[c[125312+(p>>>6<<2)>>2]&2047](p);p=c[204526]|0;if((p|0)<0){break L2167}if((p|0)==0){r=q>>>24&15;do{if((r-8|0)>>>0<6){q=c[194192]|0;if((q&1|0)!=0){c[194192]=q>>>1&127|q&-256;t=0;break}if(q>>>0<=255){u=1679;break}c[194192]=0;t=d[147072+r|0]|0}else{c[194192]=0;u=1679}}while(0);if((u|0)==1679){u=0;t=d[130328+r|0]|0}q=t+1|0;c[204526]=q;v=q}else{v=p}q=(c[195148]|0)+v|0;c[195148]=q;s=c[203364]|0;w=a[767384]|0;if(((q|0)<(s|0)&~(a[52040]&1)&~(w&1)|0)==0){x=0;y=w;z=q;A=s;break L2171}}}while(1){c[204526]=0;s=c[194193]|0;if((s&134479871|0)==134348800){c[194192]=256;B=256}else{B=c[194192]|256}q=c[203402]|0;c[203402]=c[203400];a[776764]=0;c[194192]=B;w=c[194161]|0;c[194193]=w;C=w+4|0;c[194161]=C;w=C>>>24;c[203400]=c[(c[774536+(w<<3)>>2]|0)+(C&c[774540+(w<<3)>>2])>>2];L2196:do{switch(q>>>28|0){case 13:{if((a[768224]&1)!=0){u=1659;break L2196}if(((a[768232]^a[768240])&1)==0){u=1661}else{u=1659}break};case 14:{u=1659;break};case 10:{if(((a[768232]^a[768240])&1)==0){u=1659}else{u=1661}break};case 11:{if(((a[768232]^a[768240])&1)==0){u=1661}else{u=1659}break};case 12:{if((a[768224]&1)!=0){u=1661;break L2196}if(((a[768232]^a[768240])&1)==0){u=1659}else{u=1661}break};case 8:{if((a[768256]&1)==0){u=1661;break L2196}if((a[768224]&1)==0){u=1659}else{u=1661}break};case 9:{if((a[768256]&1)==0){u=1659;break L2196}if((a[768224]&1)==0){u=1661}else{u=1659}break};case 0:{if((a[768224]&1)==0){u=1661}else{u=1659}break};case 1:{if((a[768224]&1)==0){u=1659}else{u=1661}break};case 2:{if((a[768256]&1)==0){u=1661}else{u=1659}break};case 3:{if((a[768256]&1)==0){u=1659}else{u=1661}break};case 4:{if((a[768240]&1)==0){u=1661}else{u=1659}break};case 5:{if((a[768240]&1)==0){u=1659}else{u=1661}break};case 6:{if((a[768232]&1)==0){u=1661}else{u=1659}break};case 7:{if((a[768232]&1)==0){u=1659}else{u=1661}break};default:{u=1661}}}while(0);if((u|0)==1659){u=0;e9[c[130640+((q>>>16&4080|q>>>4&15)<<2)>>2]&2047](q);p=c[204526]|0;if((p|0)<0){break L2167}if((p|0)==0){u=1661}else{D=p}}if((u|0)==1661){u=0;p=s>>>24&15;do{if((p-8|0)>>>0<6){r=c[194192]|0;if((r&1|0)==0){if(r>>>0<=255){u=1668;break}c[194192]=0;E=d[130616+p|0]|0;break}w=r&255;if((r&2|0)==0){c[194192]=w>>>1|r&-256;E=d[130328+p|0]|0;break}else{c[194192]=w>>>2|r&-256;E=0;break}}else{u=1668}}while(0);if((u|0)==1668){u=0;E=d[125296+p|0]|0}s=E+1|0;c[204526]=s;D=s}s=(c[195148]|0)+D|0;c[195148]=s;q=c[203364]|0;r=a[767384]|0;if((d[52040]&(s|0)<(q|0)&~(r&1)|0)==0){x=0;y=r;z=s;A=q;break L2171}}}else{q=c[191865]|0;s=c[322]|0;r=(s|0)<(q|0)?s:q;if((a[767432]&1)==0){F=r}else{q=c[203380]|0;F=(q|0)<(r|0)?q:r}do{if((a[767424]&1)==0){G=F}else{if((b[390475]&4)!=0){G=F;break}r=c[203376]|0;G=(r|0)<(F|0)?r:F}}while(0);do{if((a[767416]&1)==0){H=G}else{if((b[390477]&4)!=0){H=G;break}r=c[203372]|0;H=(r|0)<(G|0)?r:G}}while(0);do{if((a[767408]&1)==0){I=H}else{if((b[390479]&4)!=0){I=H;break}r=c[203368]|0;I=(r|0)<(H|0)?r:H}}while(0);r=c[191996]|0;x=(r|0)!=0&(r|0)<(I|0)?r:I;y=k;z=c[195148]|0;A=j}}while(0);c[204526]=x;J=x+z|0;c[195148]=J;if((J|0)<(A|0)){k=y;j=A}else{break}}c[204526]=A;c[195148]=0;j=g;k=J-A|0;r=A;q=c[191996]|0;while(1){s=j;w=q;C=r;while(1){do{if((w|0)!=0){K=w-C|0;c[191996]=K;if((K|0)>=0){break}c[191996]=0}}while(0);K=(c[191865]|0)-C|0;c[191865]=K;do{if((K|0)<1){L=b[390346]|0;M=L&65535;N=(M&2|0)!=0;if((M&1|0)!=0){do{if(N){c[191865]=K+1008;M=(b[390347]|0)+1&65535;b[390347]=M;O=c[120068]|0;b[O+6>>1]=M;M=b[390346]&-3;b[390346]=M;P=O+4|0;b[P>>1]=M;M=b[390346]|0;do{if((e[390347]|0)==((M&65535)>>>8|0)){Q=M|4;b[390346]=Q;b[P>>1]=Q;if((b[390346]&32)==0){break}Q=b[390601]|4;b[390601]=Q;b[O+514>>1]=Q}else{Q=M&-5;b[390346]=Q;b[P>>1]=Q}}while(0);P=c[191864]|0;if((P|0)<=0){R=O;break}M=P-1|0;c[191864]=M;if((M|0)!=1){R=O;break}c[191863]=e[390344]|0;R=O}else{c[191865]=K+224;M=L|2;b[390346]=M;P=c[120068]|0;b[P+4>>1]=M;if((b[390346]&16)==0){R=P;break}M=b[390601]|2;b[390601]=M;b[P+514>>1]=M;R=P}}while(0);if((e[390347]|0)<=227){break}L=b[390346]&-4;b[390346]=L;p=R+4|0;b[p>>1]=L;b[390347]=0;b[R+6>>1]=0;L=b[390346]|0;do{if((e[390347]|0)==((L&65535)>>>8|0)){P=L|4;b[390346]=P;b[p>>1]=P;if((b[390346]&32)==0){break}P=b[390601]|4;b[390601]=P;b[R+514>>1]=P}else{P=L&-5;b[390346]=P;b[p>>1]=P}}while(0);p=c[191864]|0;if((p|0)<=0){break}L=p-1|0;c[191864]=L;if((L|0)!=1){break}c[191863]=e[390344]|0;break}if(N){L=(b[390347]|0)+1&65535;b[390347]=L;p=c[120068]|0;b[p+6>>1]=L;c[191865]=(c[191865]|0)+1008;L=b[390346]&-3;b[390346]=L;if((b[390347]|0)==160){P=(c[120066]&1023^1023)&65535;b[390496]=P;b[p+304>>1]=P;P=b[p+306>>1]|0;b[390497]=P;if((P&16384)==0){if((a[767376]&1)!=0){u=1724}}else{u=1724}do{if((u|0)==1724){u=0;M=P&65535;Q=P&1023^1023;if((M&32768|0)==0){if((Q&P)<<16>>16==0){break}S=b[390601]|4096;b[390601]=S;b[p+514>>1]=S;break}else{if((Q&65535|0)!=(M&1023|0)){break}M=b[390601]|4096;b[390601]=M;b[p+514>>1]=M;break}}}while(0);P=b[390346]&-4|1;b[390346]=P;b[p+4>>1]=P;if((b[390346]&8)!=0){P=b[390601]|1;b[390601]=P;b[p+514>>1]=P}kj(1,15);fy[c[191850]&63](c[37236]|0,240,160,512);c[195138]=(c[195138]|0)+1;a[51768]=1;T=b[390346]|0;U=c[120068]|0}else{T=L;U=p}P=U+4|0;b[P>>1]=T;N=b[390346]|0;do{if((e[390347]|0)==((N&65535)>>>8|0)){M=N|4;b[390346]=M;b[P>>1]=M;if((b[390346]&32)==0){break}M=b[390601]|4;b[390601]=M;b[U+514>>1]=M}else{M=N&-5;b[390346]=M;b[P>>1]=M}}while(0);P=c[191864]|0;if((P|0)<=0){break}N=P-1|0;c[191864]=N;if((N|0)!=1){break}c[191863]=e[390344]|0;break}N=c[191863]|0;P=(N&36864|0)==36864;v3(772448,-1|0,960);L2310:do{if((N&4096|0)!=0){p=b[390344]|0;L=c[37240]|0;M=(c[191862]|0)+512|0;Q=((e[384124]|0)>>>12)+1|0;S=(p&7)>>>0>2;V=p&64;W=V<<16>>16!=0;X=V<<16>>16==0;V=(N&32768|0)==0;Y=c[36850]|0;Z=0;_=L;$=(p&32)!=0?954:1226;while(1){p=b[_>>1]|0;aa=b[_+2>>1]|0;ab=b[_+4>>1]|0;ad=_+8|0;c[780040+(Z<<2)>>2]=$;ae=$-2|0;if((ae|0)==0){break L2310}af=(p&3072)==3072?p&-3073:p;p=(af&65535)>>>14;ag=p&65535;if(p<<16>>16==3){ah=af&16383;ai=aa&16383}else{ah=af;ai=aa}aa=ai&65535;af=8<<(aa>>>14);do{if((ag&1|0)==0){if((ag&2|0)==0){aj=af;ak=af;break}aj=af>>>((af>>>0>8|0)>>>0);ak=af<<(af>>>0<32)}else{aj=af<<(af>>>0<32);ak=af>>>((af>>>0>8|0)>>>0)}}while(0);af=ah&65535;ag=af&255;p=aa&511;al=af&3072;L2323:do{if((al|0)==2048){if(V){am=ae;break}if((af&768|0)==768){an=aj<<1;ao=ak<<1}else{an=aj;ao=ak}ap=(ao+ag|0)>>>0>256?af|-256:ag;aq=(an+p|0)>>>0>512;ar=aq?aa|-512:p;as=ar+an|0;if(aq){at=as;au=0}else{at=as>>>0>240?240-ar|0:an;au=ar}ar=e[390347]|0;if((ar|0)<(ap|0)){am=ae;break}if(!(ar>>>0<(ap+ao|0)>>>0&(au|0)<240)){am=ae;break}ap=$-at|0;if((af&256|0)==0){am=ap;break}am=-10-at+ap|0}else{if((af&768|0)==512){am=ae;break}if((af&256|0)!=0){if((af&512|0)==0){av=aj;aw=ak}else{av=aj<<1;aw=ak<<1}ap=(e[390347]|0)-((aw+ag|0)>>>0>256?af|-256:ag)|0;if(ap>>>0>=aw>>>0){am=ae;break}ar=(av+p|0)>>>0>512?512-p|0:0;if(p>>>0>239&(ar|0)==0){am=ae;break}as=$-10|0;aq=aa>>>9<<4&496;ax=e[L+((aq|3)<<1)>>1]|0;ay=(ax&32768|0)==0?ax:ax|-32768;ax=e[L+((aq|7)<<1)>>1]|0;az=e[L+((aq|11)<<1)>>1]|0;aA=(az&32768|0)==0?az:az|-32768;az=e[L+((aq|15)<<1)>>1]|0;if((af&4096|0)==0){aB=ap}else{aB=ap-((ap|0)%(Q|0)|0)|0}ap=av>>>1;aq=(aj<<7)-(ac(ay,ap)|0)|0;aC=aB-(aw>>>1)|0;aD=(ac(aC,(ax&32768|0)==0?ax:ax|-32768)|0)+aq|0;aq=(ak<<7)-(ac(aA,ap)|0)|0;ap=(ac(aC,(az&32768|0)==0?az:az|-32768)|0)+aq|0;aq=ab&65535;az=aq>>>10;aC=al<<6|az<<25&100663296;if(S&(aq&512)>>>0<512){am=as;break}if((af&8192|0)==0){ax=X?32:aj>>>3;aE=aq>>>8&240;if((av|0)==0){am=as;break}aF=az&3;aG=aD;aH=ap;aI=p;aJ=0;aK=as;while(1){aL=aJ>>>0<ar>>>0?aK:aK-2|0;aM=aG>>8;aN=aH>>8;do{if(aM>>>0<aj>>>0&aN>>>0<ak>>>0&aI>>>0<240){aO=d[Y+(aM>>>1&3|((ac(aN>>>3,ax)|0)+aq<<5|aN<<2&28)+(aM>>>3<<5)&32767|65536)|0]|0;aP=(aM&1|0)==0?aO&15:aO>>>4;aO=772448+(aI<<2)|0;aQ=c[aO>>2]|0;if((aP|0)==0){if(aF>>>0>=(aQ>>>25&3)>>>0){break}c[aO>>2]=aQ&-100663297|aC;break}else{if(aC>>>0>=(aQ&-16777216)>>>0){break}c[aO>>2]=e[M+((aP|aE)<<1)>>1]|aC;break}}}while(0);aM=aJ+1|0;if(aM>>>0<av>>>0){aG=aG+ay|0;aH=aH+aA|0;aI=aI+1&511;aJ=aM;aK=aL}else{am=aL;break L2323}}}else{aK=X?aq&1022:aq;aJ=X?32:aj>>>2;if((av|0)==0){am=as;break}aI=az&3;aH=aD;aG=ap;aE=0;aF=p;ax=as;while(1){aM=aE>>>0<ar>>>0?ax:ax-2|0;aN=aH>>8;aP=aG>>8;do{if(aN>>>0<aj>>>0&aP>>>0<ak>>>0&aF>>>0<240){aO=a[Y+(aN&7|(aN>>>3<<6|aP<<3&56)+((ac(aP>>>3,aJ)|0)+aK<<5)&32767|65536)|0]|0;aQ=aO&255;aR=772448+(aF<<2)|0;aS=c[aR>>2]|0;if(aO<<24>>24==0){if(aI>>>0>=(aS>>>25&3)>>>0){break}c[aR>>2]=aS&-100663297|aC;break}else{if(aC>>>0>=(aS&-16777216)>>>0){break}c[aR>>2]=e[M+(aQ<<1)>>1]|aC;break}}}while(0);aP=aE+1|0;if(aP>>>0<av>>>0){aH=aH+ay|0;aG=aG+aA|0;aE=aP;aF=aF+1&511;ax=aM}else{am=aM;break L2323}}}}ax=(e[390347]|0)-((ak+ag|0)>>>0>256?af|-256:ag)|0;if(ax>>>0>=ak>>>0){am=ae;break}aF=(aj+p|0)>>>0>512?512-p|0:0;if(p>>>0>239&(aF|0)==0){am=ae;break}if((aa&8192|0)==0){aT=ax}else{aT=ak-1-ax|0}ax=ab&65535;if(S&(ax&512)>>>0<512){am=$;break}aE=(aa&4096|0)!=0;aA=aE?aj-1|0:0;if((af&4096|0)==0){aU=aT}else{aU=aT-((aT|0)%(Q|0)|0)|0}if((af&8192|0)!=0){aG=ax>>>10;ay=al<<6|aG<<25&100663296;if((aj|0)==0){am=$;break}aH=aG&3;aG=p;aC=aE?7:0;aI=aA&7|((ac(aU>>3,W?aj>>>2:32)|0)+(W?ax:ax&1022)<<5)+(aU<<3&56|aA>>>3<<6)&32767|65536;aK=0;aJ=$;while(1){ar=((aK>>>0>=aF>>>0)<<31>>31)+aJ|0;do{if(aG>>>0<240){as=a[Y+aI|0]|0;ap=as&255;aD=772448+(aG<<2)|0;az=c[aD>>2]|0;if(as<<24>>24==0){if(aH>>>0>=(az>>>25&3)>>>0){break}c[aD>>2]=az&-100663297|ay;break}else{if(ay>>>0>=(az&-16777216)>>>0){break}c[aD>>2]=e[M+(ap<<1)>>1]|ay;break}}}while(0);aM=aG+1&511;do{if(aE){ap=(aC|0)==0;aD=ap?7:aC-1|0;az=(ap?-57:-1)+aI|0;if((az|0)>=65536){aV=az;aW=aD;break}aV=az+32768|0;aW=aD}else{aD=aC+1|0;az=(aD|0)==8;ap=az?0:aD;aD=(az?57:1)+aI|0;if((aD|0)<=98303){aV=aD;aW=ap;break}aV=aD-32768|0;aW=ap}}while(0);ap=aK+1|0;if(ap>>>0<aj>>>0){aG=aM;aC=aW;aI=aV;aK=ap;aJ=ar}else{am=ar;break L2323}}}aJ=aA>>>1&3|((ac(aU>>3,W?aj>>>3:32)|0)+ax<<5|aU<<2&28)+(aA>>>3<<5)&32767|65536;aK=ax>>>10;aI=al<<6|aK<<25&100663296;aC=ax>>>8&240;if(aE){aG=aK&3;ay=aj;aH=$;ap=aJ;aD=7;az=p;while(1){as=ay-1|0;aq=(((as|0)>=(aF|0))<<31>>31)+aH|0;do{if(az>>>0<240){aP=a[Y+ap|0]|0;aN=as&1;aL=(aN|0)==0?aP&15:(aP&255)>>>4;aP=aL&255;aQ=772448+(az<<2)|0;aR=c[aQ>>2]|0;if(aL<<24>>24==0){if(aG>>>0>=(aR>>>25&3)>>>0){aX=aN;break}c[aQ>>2]=aR&-100663297|aI;aX=aN;break}else{if(aI>>>0>=(aR&-16777216)>>>0){aX=aN;break}c[aQ>>2]=e[M+((aP|aC)<<1)>>1]|aI;aX=aN;break}}else{aX=as&1}}while(0);ar=ap-1+aX|0;aM=(aD|0)==0;aN=aM?ar-28|0:ar;if((as|0)>0){ay=as;aH=aq;ap=(aN|0)<65536?aN+32768|0:aN;aD=aM?7:aD-1|0;az=az+1&511}else{am=aq;break L2323}}}if((aj|0)==0){am=$;break}az=aK&3;aD=p;ap=aA;aH=aJ;ay=$;aG=0;while(1){aE=((aG>>>0>=aF>>>0)<<31>>31)+ay|0;do{if(aD>>>0<240){ax=a[Y+aH|0]|0;aM=aG&1;aN=(aM|0)==0?ax&15:(ax&255)>>>4;ax=aN&255;ar=772448+(aD<<2)|0;aP=c[ar>>2]|0;if(aN<<24>>24==0){if(az>>>0>=(aP>>>25&3)>>>0){aY=aM;break}c[ar>>2]=aP&-100663297|aI;aY=aM;break}else{if(aI>>>0>=(aP&-16777216)>>>0){aY=aM;break}c[ar>>2]=e[M+((ax|aC)<<1)>>1]|aI;aY=aM;break}}else{aY=aG&1}}while(0);aq=aY+aH|0;as=ap+1|0;aM=(as|0)==8;ax=aM?aq+28|0:aq;aq=aG+1|0;if(aq>>>0<aj>>>0){aD=aD+1&511;ap=aM?0:as;aH=(ax|0)>98303?ax-32768|0:ax;ay=aE;aG=aq}else{am=aE;break}}}}while(0);p=Z+1|0;if(p>>>0<128){Z=p;_=ad;$=am}else{break}}}}while(0);L2431:do{if(a[125248]|0){v3(773408,-1|0,960);if(!P){break}N=c[37240]|0;$=c[36850]|0;_=0;Z=N;do{M=c[780040+(_<<2)>>2]|0;Y=b[Z>>1]|0;W=b[Z+2>>1]|0;Q=b[Z+4>>1]|0;Z=Z+8|0;if((M|0)<1){break L2431}S=Y&65535;L2437:do{if(!((S&3072|0)!=2048|(S&768|0)==512)){X=(Y&65535)>>>14;L=X&65535;if(X<<16>>16==3){aZ=Y&16383;a_=W&16383}else{aZ=Y;a_=W}X=a_&65535;V=8<<(X>>>14);do{if((L&1|0)==0){if((L&2|0)==0){a$=V;a0=V;break}a$=V>>((V|0)>8);a0=V<<((V|0)<32)}else{a$=V<<((V|0)<32);a0=V>>((V|0)>8)}}while(0);V=aZ&65535;L=V&255;if((V&256|0)!=0){if((V&512|0)==0){a1=a0;a2=a$}else{a1=a0<<1;a2=a$<<1}O=(e[390347]|0)-((a1+L|0)>256?V|-256:L)|0;if(!((O|0)>-1&(O|0)<(a1|0))){break}p=X&511;al=(a2+p|0)>512?512-p|0:0;if(p>>>0>239&(al|0)==0){break}af=X>>>9<<4&496;aa=e[N+((af|3)<<1)>>1]|0;ab=(aa&32768|0)==0?aa:aa|-32768;aa=e[N+((af|7)<<1)>>1]|0;ae=(aa&32768|0)==0?aa:aa|-32768;aa=e[N+((af|11)<<1)>>1]|0;ag=(aa&32768|0)==0?aa:aa|-32768;aa=e[N+((af|15)<<1)>>1]|0;af=(aa&32768|0)==0?aa:aa|-32768;aa=a2>>1;aG=a1>>1;ay=Q&1023;aH=b[390344]|0;if((aH&7)>>>0>2&ay>>>0<512){break}ap=(V&8192|0)==0;aD=(aH&64)==0?32:a$>>3;if((a2|0)<=0){break}aH=ac(ab,aa)|0;aI=ac(ag,aa)|0;aa=ac(ae,aG)|0;aC=ac(af,aG)|0;aG=ac(ae,O)|0;ae=p;p=(a$<<7)-aH-aa+aG|0;aG=(a0<<7)-aI-aC+(ac(af,O)|0)|0;O=0;af=M-8|0;while(1){aC=(O|0)<(al|0)?af:af-2|0;if((aC|0)<0){a3=aG;a4=p;a5=ae}else{aI=p>>8;aa=aG>>8;do{if(!((aI|0)>=(a$|0)|(aI|0)<0|(aa|0)<0|(aa|0)>=(a0|0)|(ae|0)>239)){aH=(ac(aG>>11,aD)|0)+ay<<5;az=aa&7;do{if(ap){aF=d[$+(aI>>>1&3|(aH|az<<2)+(p>>11<<5)&32767|65536)|0]|0;if((aI&1|0)==0){a6=aF&15;break}else{a6=aF>>>4;break}}else{a6=d[$+(aI&7|(az<<3|p>>11<<6)+aH&32767|65536)|0]|0}}while(0);if((a6|0)==0){break}c[773408+(ae<<2)>>2]=1}}while(0);a3=aG+ag|0;a4=p+ab|0;a5=ae+1&511}aI=O+1|0;if((aI|0)<(a2|0)){ae=a5;p=a4;aG=a3;O=aI;af=aC}else{break L2437}}}af=(e[390347]|0)-((a0+L|0)>256?V|-256:L)|0;if(!((af|0)>-1&(af|0)<(a0|0))){break}O=X&511;aG=(a$+O|0)>512?512-O|0:0;if(O>>>0>239&(aG|0)==0){break}p=M+2|0;if((X&8192|0)==0){a7=af}else{a7=a0-1-af|0}af=Q&65535;ae=b[390344]|0;if((ae&7)>>>0>2&(af&512)>>>0<512){break}ab=(ae&64)==0;if((V&8192|0)!=0){ae=(X&4096|0)!=0;ag=ae?a$-1|0:0;if((a$|0)<=0){break}ap=p;ay=O;aD=ae?7:0;al=ag&7|((ac(ab?32:a$>>2,a7>>3)|0)+(ab?af&1022:af)<<5)+(a7<<3&56|ag>>>3<<6)&32767|65536;ag=0;while(1){aI=ap+(((ag|0)>=(aG|0))<<31>>31)|0;do{if((aI|0)<0){a8=al;a9=aD;ba=ay}else{do{if((ay|0)<240){if((a[$+al|0]|0)==0){break}c[773408+(ay<<2)>>2]=1}}while(0);aa=ay+1&511;if(ae){aE=(aD|0)==0;aH=aE?7:aD-1|0;az=(aE?-57:-1)+al|0;if((az|0)>=65536){a8=az;a9=aH;ba=aa;break}a8=az+32768|0;a9=aH;ba=aa;break}else{aH=aD+1|0;az=(aH|0)==8;aE=az?0:aH;aH=(az?57:1)+al|0;if((aH|0)<=98303){a8=aH;a9=aE;ba=aa;break}a8=aH-32768|0;a9=aE;ba=aa;break}}}while(0);aC=ag+1|0;if((aC|0)<(a$|0)){ap=aI;ay=ba;aD=a9;al=a8;ag=aC}else{break L2437}}}ag=(X&4096|0)!=0;al=ag?a$-1|0:0;aD=al>>>1&3|((ac(ab?32:a$>>3,a7>>3)|0)+af<<5|a7<<2&28)+(al>>>3<<5)&32767|65536;if(ag){ag=a$;ay=aD;ap=7;ae=O;V=p;while(1){L=ag;aC=V;while(1){bb=L-1|0;if((L|0)<=0){break L2437}bc=(((bb|0)>=(aG|0))<<31>>31)+aC|0;if((bc|0)<0){L=bb;aC=bc}else{break}}do{if(ae>>>0<240){aC=a[$+ay|0]|0;L=bb&1;if(((L|0)==0?aC&15:(aC&255)>>>4)<<24>>24==0){bd=L;break}c[773408+(ae<<2)>>2]=1;bd=L}else{bd=bb&1}}while(0);L=ay-1+bd|0;aC=(ap|0)==0;aI=aC?L-28|0:L;ag=bb;ay=(aI|0)<65536?aI+32768|0:aI;ap=aC?7:ap-1|0;ae=ae+1&511;V=bc}}else{if((a$|0)>0){be=p;bf=O;bg=al;bh=aD;bi=0}else{break}while(1){V=be+(((bi|0)>=(aG|0))<<31>>31)|0;if((V|0)<0){bj=bh;bk=bg;bl=bf}else{do{if((bf|0)<240){ae=a[$+bh|0]|0;ap=bi&1;if(((ap|0)==0?ae&15:(ae&255)>>>4)<<24>>24==0){bm=ap;break}c[773408+(bf<<2)>>2]=1;bm=ap}else{bm=bi&1}}while(0);ap=bg+1|0;ae=bm+bh|0;ay=(ap|0)==8;ag=ay?ae+28|0:ae;bj=(ag|0)>98303?ag-32768|0:ag;bk=ay?0:ap;bl=bf+1&511}ap=bi+1|0;if((ap|0)<(a$|0)){be=V;bf=bl;bg=bk;bh=bj;bi=ap}else{break}}}}}while(0);_=_+1|0;}while((_|0)<128)}}while(0);fx[c[36766]&127]();P=b[390346]|2;b[390346]=P;b[(c[120068]|0)+4>>1]=P;c[191865]=(c[191865]|0)+224;kj(2,15);if((b[390346]&16)==0){break}P=b[390601]|2;b[390601]=P;b[(c[120068]|0)+514>>1]=P}}while(0);K=c[204526]|0;P=c[322]|0;c[322]=P-K;if((P|0)==(K|0)){K=(c[193612]|0)-167772|0;c[193612]=(K|0)<-2048?-2048:K;K=(c[193631]|0)-167772|0;c[193631]=(K|0)<-2048?-2048:K;K=c[126289]|0;if((K|0)<167772){jJ(167772);bn=c[126289]|0}else{bn=K}c[126290]=(c[126290]|0)-167772;c[126289]=bn-167772;K=(c[203424]|0)+((c[203423]|0)*167772|0)|0;c[203424]=K;P=(c[203416]|0)+((c[203415]|0)*167772|0)|0;c[203416]=P;_=(c[203408]|0)+((c[203407]|0)*167772|0)|0;c[203408]=_;$=c[194196]|0;N=(_>>>16)-$<<1;Z=_-$<<1;Q=(Z|0)<(N|0)?Z:N;N=Q>>1;if((N|0)!=0){Z=N+$|0;c[194196]=Z;$=Q-1|0;M=c[203417]|0;W=c[203425]|0;Y=c[203427]|0;S=-N|0;ad=S;aG=Y;aD=c[203419]|0;do{al=aG+aD|0;O=al>>14;p=ad+Z|0;aD=(c[M+(p<<2)>>2]|0)+(aD-(aD>>9))|0;aG=aG-(aG>>9)+(c[W+(p<<2)>>2]|0)|0;if((O<<16>>16|0)==(O|0)){bo=O&65535}else{bo=(al>>31^32767)&65535}ad=ad+1|0;b[776832+($+(ad<<1)<<1)>>1]=bo;}while((ad|0)!=0);c[203419]=aD;ad=Q-2|0;$=c[203409]|0;aG=S;M=Y;al=c[203411]|0;do{O=M+al|0;p=O>>14;ap=aG+Z|0;al=(c[$+(ap<<2)>>2]|0)+(al-(al>>9))|0;M=(c[W+(ap<<2)>>2]|0)+(M-(M>>9))|0;if((p<<16>>16|0)==(p|0)){bp=p&65535}else{bp=(O>>31^32767)&65535}aG=aG+1|0;b[776832+(ad+(aG<<1)<<1)>>1]=bp;}while((aG|0)!=0);c[203411]=al;c[203427]=M;aG=Z<<16;ad=_-aG|0;c[203408]=ad;c[203416]=P-aG;c[203424]=K-aG;aG=(ad>>>16)+18|0;wa($|0,$+(Z<<2)|0,aG<<2|0);ad=Z<<2;v3((c[203409]|0)+(aG<<2)|0,0,ad|0);aG=((c[203416]|0)>>>16)+18|0;W=c[203417]|0;wa(W|0,W+(Z<<2)|0,aG<<2|0);v3((c[203417]|0)+(aG<<2)|0,0,ad|0);aG=((c[203424]|0)>>>16)+18|0;W=c[203425]|0;wa(W|0,W+(Z<<2)|0,aG<<2|0);v3((c[203425]|0)+(aG<<2)|0,0,ad|0);c[194196]=0}ad=c[195142]|0;fr[ad&63](776832,N)|0;c[195140]=(c[195140]|0)+N;c[322]=(c[322]|0)+167772}do{if((a[767376]&1)==0){if((a[767432]&1)==0){bq=0}else{ad=(c[203380]|0)-(c[204526]|0)|0;c[203380]=ad;do{if((ad|0)<1){c[203380]=(65536-(c[195158]|0)<<c[194204])+ad;do{if((c[193610]|0)==0){if((a[774384]&1)==0){break}jI(0)}}while(0);do{if((c[193629]|0)==0){if((a[774460]&1)==0){break}jI(1)}}while(0);if((b[390473]&64)==0){br=1;break}aG=b[390601]|8;b[390601]=aG;b[(c[120068]|0)+514>>1]=aG;br=1}else{br=0}}while(0);ad=65535-(c[203380]>>c[194204])&65535;b[390472]=ad;b[(c[120068]|0)+256>>1]=ad;bq=br}do{if((a[767424]&1)==0){bs=bq}else{if((b[390475]&4)==0){ad=(c[203376]|0)-(c[204526]|0)|0;c[203376]=ad;do{if((ad|0)<1){c[203376]=(65536-(c[195156]|0)<<c[194202])+ad;aG=bq|2;do{if((c[193610]|0)==1){if((a[774384]&1)==0){break}jI(0)}}while(0);do{if((c[193629]|0)==1){if((a[774460]&1)==0){break}jI(1)}}while(0);if((b[390475]&64)==0){bt=aG;break}W=b[390601]|16;b[390601]=W;b[(c[120068]|0)+514>>1]=W;bt=aG}else{bt=bq}}while(0);ad=65535-(c[203376]>>c[194202])&65535;b[390474]=ad;b[(c[120068]|0)+260>>1]=ad;bs=bt;break}if((bq&1|0)==0){bs=bq;break}ad=(b[390474]|0)+1&65535;b[390474]=ad;do{if(ad<<16>>16==0){b[390474]=c[195156]&65535;W=bq|2;do{if((c[193610]|0)==1){if((a[774384]&1)==0){break}jI(0)}}while(0);do{if((c[193629]|0)==1){if((a[774460]&1)==0){break}jI(1)}}while(0);if((b[390475]&64)==0){bu=W;break}aG=b[390601]|16;b[390601]=aG;b[(c[120068]|0)+514>>1]=aG;bu=W}else{bu=bq}}while(0);b[(c[120068]|0)+260>>1]=b[390474]|0;bs=bu}}while(0);do{if((a[767416]&1)==0){bv=bs}else{ad=b[390477]|0;if((ad&4)==0){aG=(c[203372]|0)-(c[204526]|0)|0;c[203372]=aG;do{if((aG|0)<1){Y=(65536-(c[195154]|0)<<c[194200])+aG|0;c[203372]=Y;S=bs|4;if((ad&64)==0){bw=S;bx=Y;break}Y=b[390601]|32;b[390601]=Y;b[(c[120068]|0)+514>>1]=Y;bw=S;bx=c[203372]|0}else{bw=bs;bx=aG}}while(0);aG=65535-(bx>>c[194200])&65535;b[390476]=aG;b[(c[120068]|0)+264>>1]=aG;bv=bw;break}if((bs&2|0)==0){bv=bs;break}aG=(b[390476]|0)+1&65535;b[390476]=aG;do{if(aG<<16>>16==0){S=c[195154]&65535;b[390476]=S;Y=bs|4;if((ad&64)==0){by=Y;bz=S;break}S=b[390601]|32;b[390601]=S;b[(c[120068]|0)+514>>1]=S;by=Y;bz=b[390476]|0}else{by=bs;bz=aG}}while(0);b[(c[120068]|0)+264>>1]=bz;bv=by}}while(0);if((a[767408]&1)==0){break}aG=b[390479]|0;if((aG&4)==0){ad=(c[203368]|0)-(c[204526]|0)|0;c[203368]=ad;do{if((ad|0)<1){Y=(65536-(c[195152]|0)<<c[194198])+ad|0;c[203368]=Y;if((aG&64)==0){bA=Y;break}Y=b[390601]|64;b[390601]=Y;b[(c[120068]|0)+514>>1]=Y;bA=c[203368]|0}else{bA=ad}}while(0);ad=65535-(bA>>c[194198])&65535;b[390478]=ad;b[(c[120068]|0)+268>>1]=ad;break}if((bv&4|0)==0){break}ad=(b[390478]|0)+1&65535;b[390478]=ad;do{if(ad<<16>>16==0){Y=c[195152]&65535;b[390478]=Y;if((aG&64)==0){bB=Y;break}Y=b[390601]|64;b[390601]=Y;b[(c[120068]|0)+514>>1]=Y;bB=b[390478]|0}else{bB=ad}}while(0);b[(c[120068]|0)+268>>1]=bB}}while(0);bC=s-(c[204526]|0)|0;N=c[191865]|0;bD=c[322]|0;Z=(bD|0)<(N|0)?bD:N;if((a[767432]&1)==0){bE=Z}else{N=c[203380]|0;bE=(N|0)<(Z|0)?N:Z}do{if((a[767424]&1)==0){bF=bE}else{if((b[390475]&4)!=0){bF=bE;break}Z=c[203376]|0;bF=(Z|0)<(bE|0)?Z:bE}}while(0);do{if((a[767416]&1)==0){bG=bF}else{if((b[390477]&4)!=0){bG=bF;break}Z=c[203372]|0;bG=(Z|0)<(bF|0)?Z:bF}}while(0);do{if((a[767408]&1)==0){bH=bG}else{if((b[390479]&4)!=0){bH=bG;break}Z=c[203368]|0;bH=(Z|0)<(bG|0)?Z:bG}}while(0);bI=c[191996]|0;bJ=(bI|0)!=0&(bI|0)<(bH|0)?bI:bH;c[203364]=bJ;Z=c[194194]|0;if((Z|0)<=0){break}N=(Z|0)>(bJ|0)?bJ:Z;c[204526]=N;$=Z-N|0;c[194194]=($|0)<0?0:$;s=bC;w=bI;C=N}C=b[390601]|0;do{if(C<<16>>16==0){bK=bI}else{if((b[390604]&1)==0){bK=bI;break}if((a[130632]&1)==0){bK=bI;break}w=b[390600]&C&65535;if((((a[767376]&1)==0?w:w&12416)|0)==0){bK=bI;break}if(a[52032]|0){if((bI|0)!=0){bK=bI;break}w=c[194161]|0;s=(a[52040]&1)==0;if((c[31194]|0)!=18){km(18,1,0)}c[194160]=s?w+2|0:w;a[52040]=1;a[130632]=0;c[194193]=24;c[194161]=28;w=c[193635]|0;s=c[193634]|0;c[203402]=c[s+(w&24)>>2];c[203400]=c[s+(w&28)>>2];a[780600]=2;a[780601]=-64;a[780602]=94;a[780603]=-27;a[52032]=0;a[767384]=0;a[767376]=0;bK=0;break}if((a[767384]&1)==0){a[52032]=1;c[191996]=7;if((bJ|0)<=7){bK=7;break}c[203364]=7;bK=7;break}w=c[194161]|0;s=(a[52040]&1)==0;if((c[31194]|0)!=18){km(18,1,0)}c[194160]=s?w+2|0:w;a[52040]=1;a[130632]=0;c[194193]=24;c[194161]=28;w=c[193635]|0;s=c[193634]|0;c[203402]=c[s+(w&24)>>2];c[203400]=c[s+(w&28)>>2];a[780600]=2;a[780601]=-64;a[780602]=94;a[780603]=-27;a[767384]=0;a[767376]=0;bK=bI}}while(0);if((k|0)<=0){break}C=c[203364]|0;w=(k|0)>(C|0)?C:k;c[204526]=w;C=k-w|0;j=bC;k=(C|0)<0?0:C;r=w;q=bK}q=a[776824]|0;if(q<<24>>24==0){bL=c[203364]|0}else{if((q&1)!=0){r=b[406756]|0;k=c[147040+((r&3)<<2)>>2]|0;c[194204]=k;do{if((a[767432]&1)==0){if((r&128)==0){break}j=c[195158]|0;w=j&65535;b[390472]=w;c[203380]=65536-(j&65535)<<k;b[(c[120068]|0)+256>>1]=w}}while(0);a[767432]=(r&65535)>>>7&1;k=r&199;b[390473]=k;b[(c[120068]|0)+258>>1]=k}if((q&2)!=0){k=b[406748]|0;w=c[147040+((k&3)<<2)>>2]|0;c[194202]=w;do{if((a[767424]&1)==0){if((k&128)==0){break}j=c[195156]|0;C=j&65535;b[390474]=C;c[203376]=65536-(j&65535)<<w;b[(c[120068]|0)+260>>1]=C}}while(0);a[767424]=(k&65535)>>>7&1;w=k&199;b[390475]=w;b[(c[120068]|0)+262>>1]=w}if((q&4)!=0){w=b[406740]|0;r=c[147040+((w&3)<<2)>>2]|0;c[194200]=r;do{if((a[767416]&1)==0){if((w&128)==0){break}C=c[195154]|0;j=C&65535;b[390476]=j;c[203372]=65536-(C&65535)<<r;b[(c[120068]|0)+264>>1]=j}}while(0);a[767416]=(w&65535)>>>7&1;r=w&199;b[390477]=r;b[(c[120068]|0)+266>>1]=r}if((q&8)!=0){r=b[406732]|0;k=c[147040+((r&3)<<2)>>2]|0;c[194198]=k;do{if((a[767408]&1)==0){if((r&128)==0){break}j=c[195152]|0;C=j&65535;b[390478]=C;c[203368]=65536-(j&65535)<<k;b[(c[120068]|0)+268>>1]=C}}while(0);a[767408]=(r&65535)>>>7&1;k=r&199;b[390479]=k;b[(c[120068]|0)+270>>1]=k}k=c[191865]|0;q=(bD|0)<(k|0)?bD:k;if((a[767432]&1)==0){bM=q}else{k=c[203380]|0;bM=(k|0)<(q|0)?k:q}do{if((a[767424]&1)==0){bN=bM}else{if((b[390475]&4)!=0){bN=bM;break}q=c[203376]|0;bN=(q|0)<(bM|0)?q:bM}}while(0);do{if((a[767416]&1)==0){bO=bN}else{if((b[390477]&4)!=0){bO=bN;break}r=c[203372]|0;bO=(r|0)<(bN|0)?r:bN}}while(0);do{if((a[767408]&1)==0){bP=bO}else{if((b[390479]&4)!=0){bP=bO;break}r=c[203368]|0;bP=(r|0)<(bO|0)?r:bO}}while(0);r=(bK|0)!=0&(bK|0)<(bP|0)?bK:bP;c[203364]=r;a[776824]=0;bL=r}if((bL|0)>(bC|0)){c[203364]=bC;bQ=bC}else{bQ=bL}if((bC|0)<1){break}else{g=bC;h=bQ}}}while(!(a[51768]|0));i=f;return}function vQ(){return}function vR(a,b,c){a=a|0;b=b|0;c=c|0;return}function vS(){return c[195008]|0}function vT(a,b){a=a|0;b=b|0;return(jV(a)|0)!=0|0}function vU(f,j){f=f|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0;j=i;i=i+16|0;k=j|0;l=f;if((d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)!=10){m=0;i=j;return m|0}l=f+4|0;v6(k|0,l|0,16)|0;if((wb((c[36856]|0)+160|0,k|0,16)|0)!=0){m=0;i=j;return m|0}k=f+24|0;v6(776584,k|0,180)|0;k=129408;l=780688;n=f+204|0;while(1){o=c[k+4>>2]|0;v6(l|0,n|0,o)|0;p=n+o|0;f=k+8|0;q=c[f>>2]|0;if((q|0)==0){break}else{k=f;l=q;n=p}}l=p;a[767376]=(d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0)!=0|0;l=n+(o+4)|0;p=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=n+(o+8)|0;c[191996]=p;if((p|0)>0){a[52032]=1}else{a[52032]=0;c[191996]=0}p=c[120070]|0;v6(p|0,l|0,32768)|0;l=n+(o+32776)|0;p=c[191862]|0;v6(p|0,l|0,1024)|0;l=n+(o+33800)|0;p=c[36848]|0;v6(p|0,l|0,262144)|0;l=n+(o+295944)|0;p=c[36850]|0;v6(p|0,l|0,131072)|0;l=n+(o+427016)|0;p=c[37240]|0;v6(p|0,l|0,1024)|0;l=n+(o+428040)|0;p=c[37236]|0;v6(p|0,l|0,163840)|0;l=n+(o+591880)|0;p=c[120068]|0;v6(p|0,l|0,1024)|0;l=9432;k=766128;q=n+(o+592904)|0;while(1){r=c[l+4>>2]|0;v6(k|0,q|0,r)|0;s=q+r|0;o=l+8|0;n=c[o>>2]|0;if((n|0)==0){break}else{l=o;k=n;q=s}}k=s;s=q+(r+4)|0;c[2356]=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24;k=c[2374]|0;v6(k|0,s|0,8192)|0;s=q+(r+8196)|0;c[191524]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;s=q+(r+8200)|0;c[191526]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;s=q+(r+8204)|0;c[2346]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;s=q+(r+8208)|0;c[191528]=d[s]|d[s+1|0]<<8|d[s+2|0]<<16|d[s+3|0]<<24;s=q+(r+8212)|0;v6(341e3,s|0,131072)|0;jM();c[194196]=0;c[203424]=0;c[203427]=0;s=c[203425]|0;if((s|0)!=0){v3(s|0,0,(c[203426]<<2)+72|0)}c[203416]=0;c[203419]=0;s=c[203417]|0;if((s|0)!=0){v3(s|0,0,(c[203418]<<2)+72|0)}c[203408]=0;c[203411]=0;s=c[203409]|0;if((s|0)!=0){v3(s|0,0,(c[203410]<<2)+72|0)}c[322]=167772;jN();s=51776;k=774428;l=q+(r+139284)|0;do{r=c[s+4>>2]|0;v6(k|0,l|0,r)|0;l=l+r|0;s=s+8|0;k=c[s>>2]|0;}while((k|0)!=0);if((c[192084]|0)==1346454087){v6(505089,768344,64)|0;c[126290]=c[192102];c[126292]=c[192103];c[126318]=c[192104];c[126319]=c[192105];a[505280]=(c[192106]|0)!=0|0;a[505281]=(c[192107]|0)!=0|0;c[126375]=c[192108];c[126354]=c[192109];k=3;while(1){s=c[505184+(k<<2)>>2]|0;c[s+44>>2]=c[768440+(k<<2)>>2];c[s+48>>2]=c[768456+(k<<2)>>2];c[s+52>>2]=c[768472+(k<<2)>>2];a[s+56|0]=(c[768488+(k<<2)>>2]|0)!=0|0;if((k|0)==2){k=1;continue}r=(k|0)>2?2:k;c[s+60>>2]=c[768504+(r<<2)>>2];c[s+64>>2]=c[768516+(r<<2)>>2];a[s+68|0]=(c[768528+(r<<2)>>2]|0)!=0|0;if((k|0)>0){k=k-1|0}else{t=3;break}}while(1){k=c[505184+(t<<2)>>2]|0;r=(d[505110]|0)>>>(t>>>0);s=c[k+((r>>>3&2|r&1)<<2)>>2]|0;r=k+16|0;q=c[r>>2]|0;if((q|0)!=(s|0)){n=k+32|0;k=c[n>>2]|0;o=-k|0;do{if((k|0)!=0){c[n>>2]=0;if((q|0)==0){break}f=ac(c[q+12>>2]|0,c[126289]|0)|0;u=f+(c[q+16>>2]|0)|0;f=ac(c[126379]|0,o)|0;v=c[q+20>>2]|0;w=u>>>16;x=v+(w<<2)|0;y=(c[x>>2]|0)+f|0;z=ac(f>>8,u>>>8&255)|0;u=v+(w+1<<2)|0;w=z+(c[u>>2]|0)|0;c[x>>2]=y-z;c[u>>2]=w}}while(0);c[r>>2]=s}if((t|0)<=0){break}t=t-1|0}t=~~(+h[63147]*.6*.25/15.0*.125*0.0*1073741824.0+.5);c[126377]=t;c[126379]=t;jJ(c[126289]|0);t=d[505109]|0;q=t>>>4&7;o=t&7;t=~~(+h[63147]*.6*.25/15.0*.125*+((q>>>0<o>>>0?o:q)+1|0)*1073741824.0+.5);c[126377]=t;c[126379]=t}t=p+130|0;q=t;o=b[q>>1]&30479;b[q>>1]=o&65535;jH(o,o>>>4);A=+g[52048+((a[t]&3)<<2)>>2];if(+h[63147]!=A){h[63147]=A;t=d[505109]|0;o=t>>>4&7;q=t&7;t=~~(A*.6*.25/15.0*.125*+((o>>>0<q>>>0?q:o)+1|0)*1073741824.0+.5);c[126377]=t;c[126379]=t}v6(780640,l|0,48)|0;l=e[390344]|0;c[191863]=l;a[125248]=0;L2766:do{switch(l&7|0){case 5:{t=(a[767392]&1)==0;do{if((a[774368]&1)==0){if(!t){break}if((l&32768|0)!=0){break}c[36766]=10;break L2766}else{if(!t){break}if((l&32768|0)!=0){break}c[36766]=64;break L2766}}while(0);c[36766]=4;a[125248]=1;break};case 0:{t=(a[767392]&1)==0;do{if((a[774368]&1)==0){if(!t){break}if((l&32768|0)!=0){break}c[36766]=76;break L2766}else{if(!t){break}if((l&32768|0)!=0){break}c[36766]=62;break L2766}}while(0);c[36766]=74;a[125248]=1;break};case 1:{t=(a[767392]&1)==0;do{if((a[774368]&1)==0){if(!t){break}if((l&32768|0)!=0){break}c[36766]=26;break L2766}else{if(!t){break}if((l&32768|0)!=0){break}c[36766]=30;break L2766}}while(0);c[36766]=20;a[125248]=1;break};case 2:{t=(a[767392]&1)==0;do{if((a[774368]&1)==0){if(!t){break}if((l&32768|0)!=0){break}c[36766]=42;break L2766}else{if(!t){break}if((l&32768|0)!=0){break}c[36766]=50;break L2766}}while(0);c[36766]=68;a[125248]=1;break};case 3:{t=(a[767392]&1)==0;do{if((a[774368]&1)==0){if(!t){break}if((l&32768|0)!=0){break}c[36766]=58;break L2766}else{if(!t){break}if((l&32768|0)!=0){break}c[36766]=52;break L2766}}while(0);c[36766]=8;a[125248]=1;break};case 4:{t=(a[767392]&1)==0;do{if((a[774368]&1)==0){if(!t){break}if((l&32768|0)!=0){break}c[36766]=94;break L2766}else{if(!t){break}if((l&32768|0)!=0){break}c[36766]=44;break L2766}}while(0);c[36766]=12;a[125248]=1;break};default:{}}}while(0);v3(768608,-1|0,3840);l=e[390376]|0;t=l>>>8;s=l&255;l=t>>>0<=s>>>0;r=~(l&1);o=0;do{q=(o|0)>=(t|0);n=(o|0)<(s|0);a[767704+o|0]=(q?n&l&1:0)|(q?1:n&1)&r;o=o+1|0;}while((o|0)<240);o=e[390377]|0;r=o>>>8;l=o&255;o=r>>>0<=l>>>0;s=~(o&1);t=0;do{n=(t|0)>=(r|0);q=(t|0)<(l|0);a[767464+t|0]=(n?q&o&1:0)|(n?1:q&1)&s;t=t+1|0;}while((t|0)<240);c[203382]=0;t=c[36854]|0;if((t|0)==0){c[2396]=96}else if((t|0)==1){c[2396]=48;c[203382]=1}else if((t|0)==2){c[2396]=104;c[203382]=2}else if((t|0)==5){c[203382]=5}if((a[766136]&1)!=0){c[203382]=3}t=c[194193]|0;s=t>>>24;o=(c[774536+(s<<3)>>2]|0)+(c[774540+(s<<3)>>2]&t)|0;if((a[52040]&1)==0){c[203402]=e[o>>1]|0;s=t+2|0;l=s>>>24;B=e[(c[774536+(l<<3)>>2]|0)+(c[774540+(l<<3)>>2]&s)>>1]|0}else{c[203402]=c[o>>2];o=t+4|0;t=o>>>24;B=c[(c[774536+(t<<3)>>2]|0)+(c[774540+(t<<3)>>2]&o)>>2]|0}c[203400]=B;B=b[(c[193642]|0)+(c[193643]&67109380)>>1]|0;o=a[125256+(B&3)|0]|0;a[130342]=o;a[147086]=o;a[147081]=3;a[147080]=3;a[130337]=1;a[130336]=1;a[147083]=3;a[147082]=3;a[130339]=1;a[130338]=1;a[147085]=3;a[147084]=3;a[130341]=1;a[130340]=1;a[130624]=5;a[125304]=3;a[130625]=5;a[125305]=3;a[130626]=5;a[125306]=3;a[130627]=5;a[125307]=3;a[130628]=5;a[125308]=3;a[130629]=5;a[125309]=3;t=o<<1|1;a[130630]=t;a[125310]=t;a[776765]=(B&65535)>>>14&1;a[776764]=0;c[194192]=0;b[p+516>>1]=B&32767;m=1;i=j;return m|0}function vV(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function vW(){return 0}function vX(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;g=e+8|0;c[g>>2]=30176;h=g+4|0;c[h>>2]=0;do{if(fr[c[204452]&63](15,g)|0){j=c[h>>2]|0;if((cJ(j|0,44248)|0)==0){a[9504]=0;break}if((cJ(j|0,42888)|0)!=0){break}a[9504]=1}}while(0);h=c[d>>2]|0;c[13016]=33554432;if((c[36856]|0)!=0){jW()}d=vZ(33554432)|0;c[36856]=d;L2855:do{if((d|0)==0){k=0}else{g=vZ(262144)|0;if((g|0)==0){c[36848]=0;k=0;break}if((c[g-4>>2]&3|0)!=0){v3(g|0,0,262144)}c[36848]=g;do{if((h|0)!=0){g=c2(h|0,34720)|0;eo(g|0,0,2)|0;c[13016]=cb(g|0)|0;ew(g|0);j=c[13016]|0;d5(d|0,1,j|0,g|0)|0;aR(g|0)|0;if((d|0)!=0){break}v_(c[36856]|0);c[36856]=0;v_(c[36848]|0);c[36848]=0;k=0;break L2855}}while(0);g=(c[13016]|0)+1&-2;if((g|0)<33554432){j=(c[36856]|0)+g|0;l=g;while(1){b[j>>1]=l>>>1&65535;g=l+2|0;if((g|0)<33554432){j=j+2|0;l=g}else{break}}}l=vZ(16384)|0;if((l|0)==0){c[191664]=0;jW();k=0;break}if((c[l-4>>2]&3|0)!=0){v3(l|0,0,16384)}c[191664]=l;l=vZ(32768)|0;if((l|0)==0){c[120070]=0;jW();k=0;break}if((c[l-4>>2]&3|0)!=0){v3(l|0,0,32768)}c[120070]=l;l=vZ(1024)|0;if((l|0)==0){c[191862]=0;jW();k=0;break}if((c[l-4>>2]&3|0)!=0){v3(l|0,0,1024)}c[191862]=l;l=vZ(131072)|0;if((l|0)==0){c[36850]=0;jW();k=0;break}if((c[l-4>>2]&3|0)!=0){v3(l|0,0,131072)}c[36850]=l;l=vZ(1024)|0;if((l|0)==0){c[37240]=0;jW();k=0;break}if((c[l-4>>2]&3|0)!=0){v3(l|0,0,1024)}c[37240]=l;l=vZ(163840)|0;if((l|0)==0){c[37236]=0;jW();k=0;break}if((c[l-4>>2]&3|0)!=0){v3(l|0,0,163840)}c[37236]=l;l=vZ(1024)|0;if((l|0)==0){c[120068]=0;jW();k=0;break}if((c[l-4>>2]&3|0)!=0){v3(l|0,0,1024)}c[120068]=l;v3(341e3,-1|0,131072);v3(c[2374]|0,-1|0,8192);v3(768608,-1|0,3840);k=(c[13016]|0)!=0}}while(0);c[191612]=0;c[2346]=65536;a[766120]=0;a[148992]=0;d=f|0;h=c[36856]|0;a[d]=a[h+172|0]|0;a[f+1|0]=a[h+173|0]|0;a[f+2|0]=a[h+174|0]|0;a[f+3|0]=a[h+175|0]|0;a[f+4|0]=0;eb(c[q>>2]|0,15376,(f=i,i=i+8|0,c[f>>2]=d,f)|0)|0;i=f;h=0;while(1){if((h|0)>=256){break}if((cJ(52328+(h*284|0)|0,d|0)|0)==0){m=2192;break}else{h=h+1|0}}if((m|0)==2192){m=c[q>>2]|0;a3(13256,28,1,m|0)|0;a[766120]=(c[52344+(h*284|0)>>2]|0)!=0|0;m=c[52336+(h*284|0)>>2]|0;c[2346]=(m|0)==0?65536:m;c[191612]=c[52340+(h*284|0)>>2];a[148992]=(c[52348+(h*284|0)>>2]|0)!=0|0}eb(c[q>>2]|0,50792,(f=i,i=i+8|0,c[f>>2]=a[766120]&1,f)|0)|0;i=f;eb(c[q>>2]|0,48576,(f=i,i=i+8|0,c[f>>2]=c[2346],f)|0)|0;i=f;eb(c[q>>2]|0,46200,(f=i,i=i+8|0,c[f>>2]=c[191612],f)|0)|0;i=f;eb(c[q>>2]|0,45152,(f=i,i=i+8|0,c[f>>2]=a[148992]&1,f)|0)|0;i=f;f=c[2346]|0;if((f|0)==131072|(f|0)==65536){h=(f|0)==65536;c[2350]=h?27:19;c[2348]=h?50:98;c[2346]=f}if((a[766120]&1)!=0){a[147056]=1}f=c[13016]&66060288;do{if(!(f>>>0>8388608|(a[148992]&1)==0)){h=(f|0)==0?1048576:f;if(f>>>0>=16777216){break}m=c[36856]|0;d=f;do{l=m+d|0;v6(l|0,m|0,h)|0;d=d+h|0;}while(d>>>0<16777216)}}while(0);if(!(a[1296]|0)){a[1296]=1;jL()}c[203382]=0;a[766136]=0;c[36854]=0;f=c[191664]|0;v6(f|0,6600,692)|0;a[780600]=0;a[780601]=-16;a[780602]=41;a[780603]=-31;f=0;do{a[817848+f|0]=(f>>>1&1)+(f&1)+(f>>>2&1)+(f>>>3&1)+(f>>>4&1)+(f>>>5&1)+(f>>>6&1)+(f>>>7&1)&255;f=f+1|0;}while((f|0)<256);v3(816784,1,772);v3(816800,0,56);y=0;a[816860]=y&255;y=y>>8;a[816861|0]=y&255;y=y>>8;a[816862|0]=y&255;y=y>>8;a[816863|0]=y&255;v3(816868,0,12);y=0;a[816924]=y&255;y=y>>8;a[816925|0]=y&255;y=y>>8;a[816926|0]=y&255;y=y>>8;a[816927|0]=y&255;v3(816944,0,24);f=816972;d=f|0;y=0;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=f+4|0;y=0;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=816984;f=d|0;y=0;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=d+4|0;y=0;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=816996;d=f|0;y=0;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=f+4|0;y=0;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;v3(817008,0,32);v3(817056,0,16);y=0;a[817084]=y&255;y=y>>8;a[817085|0]=y&255;y=y>>8;a[817086|0]=y&255;y=y>>8;a[817087|0]=y&255;d=817096;f=d|0;y=0;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=d+4|0;y=0;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;v3(817108,0,12);v3(817132,0,164);v3(817308,0,244);v3(817556,0,252);if((c[13016]|0)>=33431552){c[191863]=65280;c[191864]=1;b[390344]=128;b[390346]=0;c[191865]=208;c[203436]=780696;c[203438]=780698;c[203440]=780700;c[203442]=780702;c[203444]=780704;c[203446]=780706;c[203448]=780708;c[203450]=780710;c[203452]=780712;c[203454]=780714;c[203456]=780716;c[203458]=780718;c[203460]=780720;c[203462]=780722;c[203464]=780724;c[203466]=780726;c[203500]=780760;c[203502]=780762;c[203476]=780736;c[203478]=780738;c[203480]=780740;c[203482]=780742;c[203492]=780752;c[203494]=780754;c[203496]=780756;c[203498]=780758;kk();jK();n=vZ(2e6)|0;o=jV(n)|0;c[195008]=o;v_(n);i=e;return k|0}f=c[36856]|0;b[f+33431708>>1]=-8198;b[f+33431710>>1]=18288;c[191863]=65280;c[191864]=1;b[390344]=128;b[390346]=0;c[191865]=208;c[203436]=780696;c[203438]=780698;c[203440]=780700;c[203442]=780702;c[203444]=780704;c[203446]=780706;c[203448]=780708;c[203450]=780710;c[203452]=780712;c[203454]=780714;c[203456]=780716;c[203458]=780718;c[203460]=780720;c[203462]=780722;c[203464]=780724;c[203466]=780726;c[203500]=780760;c[203502]=780762;c[203476]=780736;c[203478]=780738;c[203480]=780740;c[203482]=780742;c[203492]=780752;c[203494]=780754;c[203496]=780756;c[203498]=780758;kk();jK();n=vZ(2e6)|0;o=jV(n)|0;c[195008]=o;v_(n);i=e;return k|0}function vY(){var a=0,b=0,d=0,e=0;a=i;b=c[195140]|0;d=c[195138]|0;eb(c[q>>2]|0,19016,(e=i,i=i+24|0,c[e>>2]=b,c[e+8>>2]=d,h[e+16>>3]=+(b>>>0>>>0)/+(d>>>0>>>0),e)|0)|0;i=e;c[195140]=0;c[195138]=0;i=a;return}function vZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;do{if(a>>>0<245){if(a>>>0<11){b=16}else{b=a+11&-8}d=b>>>3;e=c[191670]|0;f=e>>>(d>>>0);if((f&3|0)!=0){g=(f&1^1)+d|0;h=g<<1;i=766720+(h<<2)|0;j=766720+(h+2<<2)|0;h=c[j>>2]|0;k=h+8|0;l=c[k>>2]|0;do{if((i|0)==(l|0)){c[191670]=e&~(1<<g)}else{if(l>>>0<(c[191674]|0)>>>0){b3();return 0}m=l+12|0;if((c[m>>2]|0)==(h|0)){c[m>>2]=i;c[j>>2]=l;break}else{b3();return 0}}}while(0);l=g<<3;c[h+4>>2]=l|3;j=h+(l|4)|0;c[j>>2]=c[j>>2]|1;n=k;return n|0}if(b>>>0<=(c[191672]|0)>>>0){o=b;break}if((f|0)!=0){j=2<<d;l=f<<d&(j|-j);j=(l&-l)-1|0;l=j>>>12&16;i=j>>>(l>>>0);j=i>>>5&8;m=i>>>(j>>>0);i=m>>>2&4;p=m>>>(i>>>0);m=p>>>1&2;q=p>>>(m>>>0);p=q>>>1&1;r=(j|l|i|m|p)+(q>>>(p>>>0))|0;p=r<<1;q=766720+(p<<2)|0;m=766720+(p+2<<2)|0;p=c[m>>2]|0;i=p+8|0;l=c[i>>2]|0;do{if((q|0)==(l|0)){c[191670]=e&~(1<<r)}else{if(l>>>0<(c[191674]|0)>>>0){b3();return 0}j=l+12|0;if((c[j>>2]|0)==(p|0)){c[j>>2]=q;c[m>>2]=l;break}else{b3();return 0}}}while(0);l=r<<3;m=l-b|0;c[p+4>>2]=b|3;q=p;e=q+b|0;c[q+(b|4)>>2]=m|1;c[q+l>>2]=m;l=c[191672]|0;if((l|0)!=0){q=c[191675]|0;d=l>>>3;l=d<<1;f=766720+(l<<2)|0;k=c[191670]|0;h=1<<d;do{if((k&h|0)==0){c[191670]=k|h;s=f;t=766720+(l+2<<2)|0}else{d=766720+(l+2<<2)|0;g=c[d>>2]|0;if(g>>>0>=(c[191674]|0)>>>0){s=g;t=d;break}b3();return 0}}while(0);c[t>>2]=q;c[s+12>>2]=q;c[q+8>>2]=s;c[q+12>>2]=f}c[191672]=m;c[191675]=e;n=i;return n|0}l=c[191671]|0;if((l|0)==0){o=b;break}h=(l&-l)-1|0;l=h>>>12&16;k=h>>>(l>>>0);h=k>>>5&8;p=k>>>(h>>>0);k=p>>>2&4;r=p>>>(k>>>0);p=r>>>1&2;d=r>>>(p>>>0);r=d>>>1&1;g=c[766984+((h|l|k|p|r)+(d>>>(r>>>0))<<2)>>2]|0;r=g;d=g;p=(c[g+4>>2]&-8)-b|0;while(1){g=c[r+16>>2]|0;if((g|0)==0){k=c[r+20>>2]|0;if((k|0)==0){break}else{u=k}}else{u=g}g=(c[u+4>>2]&-8)-b|0;k=g>>>0<p>>>0;r=u;d=k?u:d;p=k?g:p}r=d;i=c[191674]|0;if(r>>>0<i>>>0){b3();return 0}e=r+b|0;m=e;if(r>>>0>=e>>>0){b3();return 0}e=c[d+24>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==(d|0)){q=d+20|0;g=c[q>>2]|0;if((g|0)==0){k=d+16|0;l=c[k>>2]|0;if((l|0)==0){v=0;break}else{w=l;x=k}}else{w=g;x=q}while(1){q=w+20|0;g=c[q>>2]|0;if((g|0)!=0){w=g;x=q;continue}q=w+16|0;g=c[q>>2]|0;if((g|0)==0){break}else{w=g;x=q}}if(x>>>0<i>>>0){b3();return 0}else{c[x>>2]=0;v=w;break}}else{q=c[d+8>>2]|0;if(q>>>0<i>>>0){b3();return 0}g=q+12|0;if((c[g>>2]|0)!=(d|0)){b3();return 0}k=f+8|0;if((c[k>>2]|0)==(d|0)){c[g>>2]=f;c[k>>2]=q;v=f;break}else{b3();return 0}}}while(0);L3022:do{if((e|0)!=0){f=d+28|0;i=766984+(c[f>>2]<<2)|0;do{if((d|0)==(c[i>>2]|0)){c[i>>2]=v;if((v|0)!=0){break}c[191671]=c[191671]&~(1<<c[f>>2]);break L3022}else{if(e>>>0<(c[191674]|0)>>>0){b3();return 0}q=e+16|0;if((c[q>>2]|0)==(d|0)){c[q>>2]=v}else{c[e+20>>2]=v}if((v|0)==0){break L3022}}}while(0);if(v>>>0<(c[191674]|0)>>>0){b3();return 0}c[v+24>>2]=e;f=c[d+16>>2]|0;do{if((f|0)!=0){if(f>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[v+16>>2]=f;c[f+24>>2]=v;break}}}while(0);f=c[d+20>>2]|0;if((f|0)==0){break}if(f>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[v+20>>2]=f;c[f+24>>2]=v;break}}}while(0);if(p>>>0<16){e=p+b|0;c[d+4>>2]=e|3;f=r+(e+4)|0;c[f>>2]=c[f>>2]|1}else{c[d+4>>2]=b|3;c[r+(b|4)>>2]=p|1;c[r+(p+b)>>2]=p;f=c[191672]|0;if((f|0)!=0){e=c[191675]|0;i=f>>>3;f=i<<1;q=766720+(f<<2)|0;k=c[191670]|0;g=1<<i;do{if((k&g|0)==0){c[191670]=k|g;y=q;z=766720+(f+2<<2)|0}else{i=766720+(f+2<<2)|0;l=c[i>>2]|0;if(l>>>0>=(c[191674]|0)>>>0){y=l;z=i;break}b3();return 0}}while(0);c[z>>2]=e;c[y+12>>2]=e;c[e+8>>2]=y;c[e+12>>2]=q}c[191672]=p;c[191675]=m}f=d+8|0;if((f|0)==0){o=b;break}else{n=f}return n|0}else{if(a>>>0>4294967231){o=-1;break}f=a+11|0;g=f&-8;k=c[191671]|0;if((k|0)==0){o=g;break}r=-g|0;i=f>>>8;do{if((i|0)==0){A=0}else{if(g>>>0>16777215){A=31;break}f=(i+1048320|0)>>>16&8;l=i<<f;h=(l+520192|0)>>>16&4;j=l<<h;l=(j+245760|0)>>>16&2;B=14-(h|f|l)+(j<<l>>>15)|0;A=g>>>((B+7|0)>>>0)&1|B<<1}}while(0);i=c[766984+(A<<2)>>2]|0;L3070:do{if((i|0)==0){C=0;D=r;E=0}else{if((A|0)==31){F=0}else{F=25-(A>>>1)|0}d=0;m=r;p=i;q=g<<F;e=0;while(1){B=c[p+4>>2]&-8;l=B-g|0;if(l>>>0<m>>>0){if((B|0)==(g|0)){C=p;D=l;E=p;break L3070}else{G=p;H=l}}else{G=d;H=m}l=c[p+20>>2]|0;B=c[p+16+(q>>>31<<2)>>2]|0;j=(l|0)==0|(l|0)==(B|0)?e:l;if((B|0)==0){C=G;D=H;E=j;break}else{d=G;m=H;p=B;q=q<<1;e=j}}}}while(0);if((E|0)==0&(C|0)==0){i=2<<A;r=(i|-i)&k;if((r|0)==0){o=g;break}i=(r&-r)-1|0;r=i>>>12&16;e=i>>>(r>>>0);i=e>>>5&8;q=e>>>(i>>>0);e=q>>>2&4;p=q>>>(e>>>0);q=p>>>1&2;m=p>>>(q>>>0);p=m>>>1&1;I=c[766984+((i|r|e|q|p)+(m>>>(p>>>0))<<2)>>2]|0}else{I=E}if((I|0)==0){J=D;K=C}else{p=I;m=D;q=C;while(1){e=(c[p+4>>2]&-8)-g|0;r=e>>>0<m>>>0;i=r?e:m;e=r?p:q;r=c[p+16>>2]|0;if((r|0)!=0){p=r;m=i;q=e;continue}r=c[p+20>>2]|0;if((r|0)==0){J=i;K=e;break}else{p=r;m=i;q=e}}}if((K|0)==0){o=g;break}if(J>>>0>=((c[191672]|0)-g|0)>>>0){o=g;break}q=K;m=c[191674]|0;if(q>>>0<m>>>0){b3();return 0}p=q+g|0;k=p;if(q>>>0>=p>>>0){b3();return 0}e=c[K+24>>2]|0;i=c[K+12>>2]|0;do{if((i|0)==(K|0)){r=K+20|0;d=c[r>>2]|0;if((d|0)==0){j=K+16|0;B=c[j>>2]|0;if((B|0)==0){L=0;break}else{M=B;N=j}}else{M=d;N=r}while(1){r=M+20|0;d=c[r>>2]|0;if((d|0)!=0){M=d;N=r;continue}r=M+16|0;d=c[r>>2]|0;if((d|0)==0){break}else{M=d;N=r}}if(N>>>0<m>>>0){b3();return 0}else{c[N>>2]=0;L=M;break}}else{r=c[K+8>>2]|0;if(r>>>0<m>>>0){b3();return 0}d=r+12|0;if((c[d>>2]|0)!=(K|0)){b3();return 0}j=i+8|0;if((c[j>>2]|0)==(K|0)){c[d>>2]=i;c[j>>2]=r;L=i;break}else{b3();return 0}}}while(0);L3120:do{if((e|0)!=0){i=K+28|0;m=766984+(c[i>>2]<<2)|0;do{if((K|0)==(c[m>>2]|0)){c[m>>2]=L;if((L|0)!=0){break}c[191671]=c[191671]&~(1<<c[i>>2]);break L3120}else{if(e>>>0<(c[191674]|0)>>>0){b3();return 0}r=e+16|0;if((c[r>>2]|0)==(K|0)){c[r>>2]=L}else{c[e+20>>2]=L}if((L|0)==0){break L3120}}}while(0);if(L>>>0<(c[191674]|0)>>>0){b3();return 0}c[L+24>>2]=e;i=c[K+16>>2]|0;do{if((i|0)!=0){if(i>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[L+16>>2]=i;c[i+24>>2]=L;break}}}while(0);i=c[K+20>>2]|0;if((i|0)==0){break}if(i>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[L+20>>2]=i;c[i+24>>2]=L;break}}}while(0);do{if(J>>>0<16){e=J+g|0;c[K+4>>2]=e|3;i=q+(e+4)|0;c[i>>2]=c[i>>2]|1}else{c[K+4>>2]=g|3;c[q+(g|4)>>2]=J|1;c[q+(J+g)>>2]=J;i=J>>>3;if(J>>>0<256){e=i<<1;m=766720+(e<<2)|0;r=c[191670]|0;j=1<<i;do{if((r&j|0)==0){c[191670]=r|j;O=m;P=766720+(e+2<<2)|0}else{i=766720+(e+2<<2)|0;d=c[i>>2]|0;if(d>>>0>=(c[191674]|0)>>>0){O=d;P=i;break}b3();return 0}}while(0);c[P>>2]=k;c[O+12>>2]=k;c[q+(g+8)>>2]=O;c[q+(g+12)>>2]=m;break}e=p;j=J>>>8;do{if((j|0)==0){Q=0}else{if(J>>>0>16777215){Q=31;break}r=(j+1048320|0)>>>16&8;i=j<<r;d=(i+520192|0)>>>16&4;B=i<<d;i=(B+245760|0)>>>16&2;l=14-(d|r|i)+(B<<i>>>15)|0;Q=J>>>((l+7|0)>>>0)&1|l<<1}}while(0);j=766984+(Q<<2)|0;c[q+(g+28)>>2]=Q;c[q+(g+20)>>2]=0;c[q+(g+16)>>2]=0;m=c[191671]|0;l=1<<Q;if((m&l|0)==0){c[191671]=m|l;c[j>>2]=e;c[q+(g+24)>>2]=j;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}if((Q|0)==31){R=0}else{R=25-(Q>>>1)|0}l=J<<R;m=c[j>>2]|0;while(1){if((c[m+4>>2]&-8|0)==(J|0)){break}S=m+16+(l>>>31<<2)|0;j=c[S>>2]|0;if((j|0)==0){T=2361;break}else{l=l<<1;m=j}}if((T|0)==2361){if(S>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[S>>2]=e;c[q+(g+24)>>2]=m;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}}l=m+8|0;j=c[l>>2]|0;i=c[191674]|0;if(m>>>0<i>>>0){b3();return 0}if(j>>>0<i>>>0){b3();return 0}else{c[j+12>>2]=e;c[l>>2]=e;c[q+(g+8)>>2]=j;c[q+(g+12)>>2]=m;c[q+(g+24)>>2]=0;break}}}while(0);q=K+8|0;if((q|0)==0){o=g;break}else{n=q}return n|0}}while(0);K=c[191672]|0;if(o>>>0<=K>>>0){S=K-o|0;J=c[191675]|0;if(S>>>0>15){R=J;c[191675]=R+o;c[191672]=S;c[R+(o+4)>>2]=S|1;c[R+K>>2]=S;c[J+4>>2]=o|3}else{c[191672]=0;c[191675]=0;c[J+4>>2]=K|3;S=J+(K+4)|0;c[S>>2]=c[S>>2]|1}n=J+8|0;return n|0}J=c[191673]|0;if(o>>>0<J>>>0){S=J-o|0;c[191673]=S;J=c[191676]|0;K=J;c[191676]=K+o;c[K+(o+4)>>2]=S|1;c[J+4>>2]=o|3;n=J+8|0;return n|0}do{if((c[37242]|0)==0){J=aQ(8)|0;if((J-1&J|0)==0){c[37244]=J;c[37243]=J;c[37245]=-1;c[37246]=-1;c[37247]=0;c[191781]=0;c[37242]=(eF(0)|0)&-16^1431655768;break}else{b3();return 0}}}while(0);J=o+48|0;S=c[37244]|0;K=o+47|0;R=S+K|0;Q=-S|0;S=R&Q;if(S>>>0<=o>>>0){n=0;return n|0}O=c[191780]|0;do{if((O|0)!=0){P=c[191778]|0;L=P+S|0;if(L>>>0<=P>>>0|L>>>0>O>>>0){n=0}else{break}return n|0}}while(0);L3212:do{if((c[191781]&4|0)==0){O=c[191676]|0;L3214:do{if((O|0)==0){T=2391}else{L=O;P=767128;while(1){U=P|0;M=c[U>>2]|0;if(M>>>0<=L>>>0){V=P+4|0;if((M+(c[V>>2]|0)|0)>>>0>L>>>0){break}}M=c[P+8>>2]|0;if((M|0)==0){T=2391;break L3214}else{P=M}}if((P|0)==0){T=2391;break}L=R-(c[191673]|0)&Q;if(L>>>0>=2147483647){W=0;break}m=dX(L|0)|0;e=(m|0)==((c[U>>2]|0)+(c[V>>2]|0)|0);X=e?m:-1;Y=e?L:0;Z=m;_=L;T=2400}}while(0);do{if((T|0)==2391){O=dX(0)|0;if((O|0)==-1){W=0;break}g=O;L=c[37243]|0;m=L-1|0;if((m&g|0)==0){$=S}else{$=S-g+(m+g&-L)|0}L=c[191778]|0;g=L+$|0;if(!($>>>0>o>>>0&$>>>0<2147483647)){W=0;break}m=c[191780]|0;if((m|0)!=0){if(g>>>0<=L>>>0|g>>>0>m>>>0){W=0;break}}m=dX($|0)|0;g=(m|0)==(O|0);X=g?O:-1;Y=g?$:0;Z=m;_=$;T=2400}}while(0);L3234:do{if((T|0)==2400){m=-_|0;if((X|0)!=-1){aa=Y;ab=X;T=2411;break L3212}do{if((Z|0)!=-1&_>>>0<2147483647&_>>>0<J>>>0){g=c[37244]|0;O=K-_+g&-g;if(O>>>0>=2147483647){ac=_;break}if((dX(O|0)|0)==-1){dX(m|0)|0;W=Y;break L3234}else{ac=O+_|0;break}}else{ac=_}}while(0);if((Z|0)==-1){W=Y}else{aa=ac;ab=Z;T=2411;break L3212}}}while(0);c[191781]=c[191781]|4;ad=W;T=2408}else{ad=0;T=2408}}while(0);do{if((T|0)==2408){if(S>>>0>=2147483647){break}W=dX(S|0)|0;Z=dX(0)|0;if(!((Z|0)!=-1&(W|0)!=-1&W>>>0<Z>>>0)){break}ac=Z-W|0;Z=ac>>>0>(o+40|0)>>>0;Y=Z?W:-1;if((Y|0)!=-1){aa=Z?ac:ad;ab=Y;T=2411}}}while(0);do{if((T|0)==2411){ad=(c[191778]|0)+aa|0;c[191778]=ad;if(ad>>>0>(c[191779]|0)>>>0){c[191779]=ad}ad=c[191676]|0;L3254:do{if((ad|0)==0){S=c[191674]|0;if((S|0)==0|ab>>>0<S>>>0){c[191674]=ab}c[191782]=ab;c[191783]=aa;c[191785]=0;c[191679]=c[37242];c[191678]=-1;S=0;do{Y=S<<1;ac=766720+(Y<<2)|0;c[766720+(Y+3<<2)>>2]=ac;c[766720+(Y+2<<2)>>2]=ac;S=S+1|0;}while(S>>>0<32);S=ab+8|0;if((S&7|0)==0){ae=0}else{ae=-S&7}S=aa-40-ae|0;c[191676]=ab+ae;c[191673]=S;c[ab+(ae+4)>>2]=S|1;c[ab+(aa-36)>>2]=40;c[191677]=c[37246]}else{S=767128;while(1){af=c[S>>2]|0;ag=S+4|0;ah=c[ag>>2]|0;if((ab|0)==(af+ah|0)){T=2423;break}ac=c[S+8>>2]|0;if((ac|0)==0){break}else{S=ac}}do{if((T|0)==2423){if((c[S+12>>2]&8|0)!=0){break}ac=ad;if(!(ac>>>0>=af>>>0&ac>>>0<ab>>>0)){break}c[ag>>2]=ah+aa;ac=c[191676]|0;Y=(c[191673]|0)+aa|0;Z=ac;W=ac+8|0;if((W&7|0)==0){ai=0}else{ai=-W&7}W=Y-ai|0;c[191676]=Z+ai;c[191673]=W;c[Z+(ai+4)>>2]=W|1;c[Z+(Y+4)>>2]=40;c[191677]=c[37246];break L3254}}while(0);if(ab>>>0<(c[191674]|0)>>>0){c[191674]=ab}S=ab+aa|0;Y=767128;while(1){aj=Y|0;if((c[aj>>2]|0)==(S|0)){T=2433;break}Z=c[Y+8>>2]|0;if((Z|0)==0){break}else{Y=Z}}do{if((T|0)==2433){if((c[Y+12>>2]&8|0)!=0){break}c[aj>>2]=ab;S=Y+4|0;c[S>>2]=(c[S>>2]|0)+aa;S=ab+8|0;if((S&7|0)==0){ak=0}else{ak=-S&7}S=ab+(aa+8)|0;if((S&7|0)==0){al=0}else{al=-S&7}S=ab+(al+aa)|0;Z=S;W=ak+o|0;ac=ab+W|0;_=ac;K=S-(ab+ak)-o|0;c[ab+(ak+4)>>2]=o|3;do{if((Z|0)==(c[191676]|0)){J=(c[191673]|0)+K|0;c[191673]=J;c[191676]=_;c[ab+(W+4)>>2]=J|1}else{if((Z|0)==(c[191675]|0)){J=(c[191672]|0)+K|0;c[191672]=J;c[191675]=_;c[ab+(W+4)>>2]=J|1;c[ab+(J+W)>>2]=J;break}J=aa+4|0;X=c[ab+(al+J)>>2]|0;if((X&3|0)==1){$=X&-8;V=X>>>3;L3299:do{if(X>>>0<256){U=c[ab+((al|8)+aa)>>2]|0;Q=c[ab+(aa+12+al)>>2]|0;R=766720+(V<<1<<2)|0;do{if((U|0)!=(R|0)){if(U>>>0<(c[191674]|0)>>>0){b3();return 0}if((c[U+12>>2]|0)==(Z|0)){break}b3();return 0}}while(0);if((Q|0)==(U|0)){c[191670]=c[191670]&~(1<<V);break}do{if((Q|0)==(R|0)){am=Q+8|0}else{if(Q>>>0<(c[191674]|0)>>>0){b3();return 0}m=Q+8|0;if((c[m>>2]|0)==(Z|0)){am=m;break}b3();return 0}}while(0);c[U+12>>2]=Q;c[am>>2]=U}else{R=S;m=c[ab+((al|24)+aa)>>2]|0;P=c[ab+(aa+12+al)>>2]|0;do{if((P|0)==(R|0)){O=al|16;g=ab+(O+J)|0;L=c[g>>2]|0;if((L|0)==0){e=ab+(O+aa)|0;O=c[e>>2]|0;if((O|0)==0){an=0;break}else{ao=O;ap=e}}else{ao=L;ap=g}while(1){g=ao+20|0;L=c[g>>2]|0;if((L|0)!=0){ao=L;ap=g;continue}g=ao+16|0;L=c[g>>2]|0;if((L|0)==0){break}else{ao=L;ap=g}}if(ap>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[ap>>2]=0;an=ao;break}}else{g=c[ab+((al|8)+aa)>>2]|0;if(g>>>0<(c[191674]|0)>>>0){b3();return 0}L=g+12|0;if((c[L>>2]|0)!=(R|0)){b3();return 0}e=P+8|0;if((c[e>>2]|0)==(R|0)){c[L>>2]=P;c[e>>2]=g;an=P;break}else{b3();return 0}}}while(0);if((m|0)==0){break}P=ab+(aa+28+al)|0;U=766984+(c[P>>2]<<2)|0;do{if((R|0)==(c[U>>2]|0)){c[U>>2]=an;if((an|0)!=0){break}c[191671]=c[191671]&~(1<<c[P>>2]);break L3299}else{if(m>>>0<(c[191674]|0)>>>0){b3();return 0}Q=m+16|0;if((c[Q>>2]|0)==(R|0)){c[Q>>2]=an}else{c[m+20>>2]=an}if((an|0)==0){break L3299}}}while(0);if(an>>>0<(c[191674]|0)>>>0){b3();return 0}c[an+24>>2]=m;R=al|16;P=c[ab+(R+aa)>>2]|0;do{if((P|0)!=0){if(P>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[an+16>>2]=P;c[P+24>>2]=an;break}}}while(0);P=c[ab+(R+J)>>2]|0;if((P|0)==0){break}if(P>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[an+20>>2]=P;c[P+24>>2]=an;break}}}while(0);aq=ab+(($|al)+aa)|0;ar=$+K|0}else{aq=Z;ar=K}J=aq+4|0;c[J>>2]=c[J>>2]&-2;c[ab+(W+4)>>2]=ar|1;c[ab+(ar+W)>>2]=ar;J=ar>>>3;if(ar>>>0<256){V=J<<1;X=766720+(V<<2)|0;P=c[191670]|0;m=1<<J;do{if((P&m|0)==0){c[191670]=P|m;as=X;at=766720+(V+2<<2)|0}else{J=766720+(V+2<<2)|0;U=c[J>>2]|0;if(U>>>0>=(c[191674]|0)>>>0){as=U;at=J;break}b3();return 0}}while(0);c[at>>2]=_;c[as+12>>2]=_;c[ab+(W+8)>>2]=as;c[ab+(W+12)>>2]=X;break}V=ac;m=ar>>>8;do{if((m|0)==0){au=0}else{if(ar>>>0>16777215){au=31;break}P=(m+1048320|0)>>>16&8;$=m<<P;J=($+520192|0)>>>16&4;U=$<<J;$=(U+245760|0)>>>16&2;Q=14-(J|P|$)+(U<<$>>>15)|0;au=ar>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=766984+(au<<2)|0;c[ab+(W+28)>>2]=au;c[ab+(W+20)>>2]=0;c[ab+(W+16)>>2]=0;X=c[191671]|0;Q=1<<au;if((X&Q|0)==0){c[191671]=X|Q;c[m>>2]=V;c[ab+(W+24)>>2]=m;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}if((au|0)==31){av=0}else{av=25-(au>>>1)|0}Q=ar<<av;X=c[m>>2]|0;while(1){if((c[X+4>>2]&-8|0)==(ar|0)){break}aw=X+16+(Q>>>31<<2)|0;m=c[aw>>2]|0;if((m|0)==0){T=2506;break}else{Q=Q<<1;X=m}}if((T|0)==2506){if(aw>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[aw>>2]=V;c[ab+(W+24)>>2]=X;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}}Q=X+8|0;m=c[Q>>2]|0;$=c[191674]|0;if(X>>>0<$>>>0){b3();return 0}if(m>>>0<$>>>0){b3();return 0}else{c[m+12>>2]=V;c[Q>>2]=V;c[ab+(W+8)>>2]=m;c[ab+(W+12)>>2]=X;c[ab+(W+24)>>2]=0;break}}}while(0);n=ab+(ak|8)|0;return n|0}}while(0);Y=ad;W=767128;while(1){ax=c[W>>2]|0;if(ax>>>0<=Y>>>0){ay=c[W+4>>2]|0;az=ax+ay|0;if(az>>>0>Y>>>0){break}}W=c[W+8>>2]|0}W=ax+(ay-39)|0;if((W&7|0)==0){aA=0}else{aA=-W&7}W=ax+(ay-47+aA)|0;ac=W>>>0<(ad+16|0)>>>0?Y:W;W=ac+8|0;_=ab+8|0;if((_&7|0)==0){aB=0}else{aB=-_&7}_=aa-40-aB|0;c[191676]=ab+aB;c[191673]=_;c[ab+(aB+4)>>2]=_|1;c[ab+(aa-36)>>2]=40;c[191677]=c[37246];c[ac+4>>2]=27;c[W>>2]=c[191782];c[W+4>>2]=c[767132>>2];c[W+8>>2]=c[767136>>2];c[W+12>>2]=c[767140>>2];c[191782]=ab;c[191783]=aa;c[191785]=0;c[191784]=W;W=ac+28|0;c[W>>2]=7;if((ac+32|0)>>>0<az>>>0){_=W;while(1){W=_+4|0;c[W>>2]=7;if((_+8|0)>>>0<az>>>0){_=W}else{break}}}if((ac|0)==(Y|0)){break}_=ac-ad|0;W=Y+(_+4)|0;c[W>>2]=c[W>>2]&-2;c[ad+4>>2]=_|1;c[Y+_>>2]=_;W=_>>>3;if(_>>>0<256){K=W<<1;Z=766720+(K<<2)|0;S=c[191670]|0;m=1<<W;do{if((S&m|0)==0){c[191670]=S|m;aC=Z;aD=766720+(K+2<<2)|0}else{W=766720+(K+2<<2)|0;Q=c[W>>2]|0;if(Q>>>0>=(c[191674]|0)>>>0){aC=Q;aD=W;break}b3();return 0}}while(0);c[aD>>2]=ad;c[aC+12>>2]=ad;c[ad+8>>2]=aC;c[ad+12>>2]=Z;break}K=ad;m=_>>>8;do{if((m|0)==0){aE=0}else{if(_>>>0>16777215){aE=31;break}S=(m+1048320|0)>>>16&8;Y=m<<S;ac=(Y+520192|0)>>>16&4;W=Y<<ac;Y=(W+245760|0)>>>16&2;Q=14-(ac|S|Y)+(W<<Y>>>15)|0;aE=_>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=766984+(aE<<2)|0;c[ad+28>>2]=aE;c[ad+20>>2]=0;c[ad+16>>2]=0;Z=c[191671]|0;Q=1<<aE;if((Z&Q|0)==0){c[191671]=Z|Q;c[m>>2]=K;c[ad+24>>2]=m;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}if((aE|0)==31){aF=0}else{aF=25-(aE>>>1)|0}Q=_<<aF;Z=c[m>>2]|0;while(1){if((c[Z+4>>2]&-8|0)==(_|0)){break}aG=Z+16+(Q>>>31<<2)|0;m=c[aG>>2]|0;if((m|0)==0){T=2541;break}else{Q=Q<<1;Z=m}}if((T|0)==2541){if(aG>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[aG>>2]=K;c[ad+24>>2]=Z;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}}Q=Z+8|0;_=c[Q>>2]|0;m=c[191674]|0;if(Z>>>0<m>>>0){b3();return 0}if(_>>>0<m>>>0){b3();return 0}else{c[_+12>>2]=K;c[Q>>2]=K;c[ad+8>>2]=_;c[ad+12>>2]=Z;c[ad+24>>2]=0;break}}}while(0);ad=c[191673]|0;if(ad>>>0<=o>>>0){break}_=ad-o|0;c[191673]=_;ad=c[191676]|0;Q=ad;c[191676]=Q+o;c[Q+(o+4)>>2]=_|1;c[ad+4>>2]=o|3;n=ad+8|0;return n|0}}while(0);c[(dR()|0)>>2]=12;n=0;return n|0}function v_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a|0)==0){return}b=a-8|0;d=b;e=c[191674]|0;if(b>>>0<e>>>0){b3()}f=c[a-4>>2]|0;g=f&3;if((g|0)==1){b3()}h=f&-8;i=a+(h-8)|0;j=i;L3471:do{if((f&1|0)==0){k=c[b>>2]|0;if((g|0)==0){return}l=-8-k|0;m=a+l|0;n=m;o=k+h|0;if(m>>>0<e>>>0){b3()}if((n|0)==(c[191675]|0)){p=a+(h-4)|0;if((c[p>>2]&3|0)!=3){q=n;r=o;break}c[191672]=o;c[p>>2]=c[p>>2]&-2;c[a+(l+4)>>2]=o|1;c[i>>2]=o;return}p=k>>>3;if(k>>>0<256){k=c[a+(l+8)>>2]|0;s=c[a+(l+12)>>2]|0;t=766720+(p<<1<<2)|0;do{if((k|0)!=(t|0)){if(k>>>0<e>>>0){b3()}if((c[k+12>>2]|0)==(n|0)){break}b3()}}while(0);if((s|0)==(k|0)){c[191670]=c[191670]&~(1<<p);q=n;r=o;break}do{if((s|0)==(t|0)){u=s+8|0}else{if(s>>>0<e>>>0){b3()}v=s+8|0;if((c[v>>2]|0)==(n|0)){u=v;break}b3()}}while(0);c[k+12>>2]=s;c[u>>2]=k;q=n;r=o;break}t=m;p=c[a+(l+24)>>2]|0;v=c[a+(l+12)>>2]|0;do{if((v|0)==(t|0)){w=a+(l+20)|0;x=c[w>>2]|0;if((x|0)==0){y=a+(l+16)|0;z=c[y>>2]|0;if((z|0)==0){A=0;break}else{B=z;C=y}}else{B=x;C=w}while(1){w=B+20|0;x=c[w>>2]|0;if((x|0)!=0){B=x;C=w;continue}w=B+16|0;x=c[w>>2]|0;if((x|0)==0){break}else{B=x;C=w}}if(C>>>0<e>>>0){b3()}else{c[C>>2]=0;A=B;break}}else{w=c[a+(l+8)>>2]|0;if(w>>>0<e>>>0){b3()}x=w+12|0;if((c[x>>2]|0)!=(t|0)){b3()}y=v+8|0;if((c[y>>2]|0)==(t|0)){c[x>>2]=v;c[y>>2]=w;A=v;break}else{b3()}}}while(0);if((p|0)==0){q=n;r=o;break}v=a+(l+28)|0;m=766984+(c[v>>2]<<2)|0;do{if((t|0)==(c[m>>2]|0)){c[m>>2]=A;if((A|0)!=0){break}c[191671]=c[191671]&~(1<<c[v>>2]);q=n;r=o;break L3471}else{if(p>>>0<(c[191674]|0)>>>0){b3()}k=p+16|0;if((c[k>>2]|0)==(t|0)){c[k>>2]=A}else{c[p+20>>2]=A}if((A|0)==0){q=n;r=o;break L3471}}}while(0);if(A>>>0<(c[191674]|0)>>>0){b3()}c[A+24>>2]=p;t=c[a+(l+16)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[191674]|0)>>>0){b3()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(l+20)>>2]|0;if((t|0)==0){q=n;r=o;break}if(t>>>0<(c[191674]|0)>>>0){b3()}else{c[A+20>>2]=t;c[t+24>>2]=A;q=n;r=o;break}}else{q=d;r=h}}while(0);d=q;if(d>>>0>=i>>>0){b3()}A=a+(h-4)|0;e=c[A>>2]|0;if((e&1|0)==0){b3()}do{if((e&2|0)==0){if((j|0)==(c[191676]|0)){B=(c[191673]|0)+r|0;c[191673]=B;c[191676]=q;c[q+4>>2]=B|1;if((q|0)!=(c[191675]|0)){return}c[191675]=0;c[191672]=0;return}if((j|0)==(c[191675]|0)){B=(c[191672]|0)+r|0;c[191672]=B;c[191675]=q;c[q+4>>2]=B|1;c[d+B>>2]=B;return}B=(e&-8)+r|0;C=e>>>3;L3574:do{if(e>>>0<256){u=c[a+h>>2]|0;g=c[a+(h|4)>>2]|0;b=766720+(C<<1<<2)|0;do{if((u|0)!=(b|0)){if(u>>>0<(c[191674]|0)>>>0){b3()}if((c[u+12>>2]|0)==(j|0)){break}b3()}}while(0);if((g|0)==(u|0)){c[191670]=c[191670]&~(1<<C);break}do{if((g|0)==(b|0)){D=g+8|0}else{if(g>>>0<(c[191674]|0)>>>0){b3()}f=g+8|0;if((c[f>>2]|0)==(j|0)){D=f;break}b3()}}while(0);c[u+12>>2]=g;c[D>>2]=u}else{b=i;f=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(b|0)){p=a+(h+12)|0;v=c[p>>2]|0;if((v|0)==0){m=a+(h+8)|0;k=c[m>>2]|0;if((k|0)==0){E=0;break}else{F=k;G=m}}else{F=v;G=p}while(1){p=F+20|0;v=c[p>>2]|0;if((v|0)!=0){F=v;G=p;continue}p=F+16|0;v=c[p>>2]|0;if((v|0)==0){break}else{F=v;G=p}}if(G>>>0<(c[191674]|0)>>>0){b3()}else{c[G>>2]=0;E=F;break}}else{p=c[a+h>>2]|0;if(p>>>0<(c[191674]|0)>>>0){b3()}v=p+12|0;if((c[v>>2]|0)!=(b|0)){b3()}m=t+8|0;if((c[m>>2]|0)==(b|0)){c[v>>2]=t;c[m>>2]=p;E=t;break}else{b3()}}}while(0);if((f|0)==0){break}t=a+(h+20)|0;u=766984+(c[t>>2]<<2)|0;do{if((b|0)==(c[u>>2]|0)){c[u>>2]=E;if((E|0)!=0){break}c[191671]=c[191671]&~(1<<c[t>>2]);break L3574}else{if(f>>>0<(c[191674]|0)>>>0){b3()}g=f+16|0;if((c[g>>2]|0)==(b|0)){c[g>>2]=E}else{c[f+20>>2]=E}if((E|0)==0){break L3574}}}while(0);if(E>>>0<(c[191674]|0)>>>0){b3()}c[E+24>>2]=f;b=c[a+(h+8)>>2]|0;do{if((b|0)!=0){if(b>>>0<(c[191674]|0)>>>0){b3()}else{c[E+16>>2]=b;c[b+24>>2]=E;break}}}while(0);b=c[a+(h+12)>>2]|0;if((b|0)==0){break}if(b>>>0<(c[191674]|0)>>>0){b3()}else{c[E+20>>2]=b;c[b+24>>2]=E;break}}}while(0);c[q+4>>2]=B|1;c[d+B>>2]=B;if((q|0)!=(c[191675]|0)){H=B;break}c[191672]=B;return}else{c[A>>2]=e&-2;c[q+4>>2]=r|1;c[d+r>>2]=r;H=r}}while(0);r=H>>>3;if(H>>>0<256){d=r<<1;e=766720+(d<<2)|0;A=c[191670]|0;E=1<<r;do{if((A&E|0)==0){c[191670]=A|E;I=e;J=766720+(d+2<<2)|0}else{r=766720+(d+2<<2)|0;h=c[r>>2]|0;if(h>>>0>=(c[191674]|0)>>>0){I=h;J=r;break}b3()}}while(0);c[J>>2]=q;c[I+12>>2]=q;c[q+8>>2]=I;c[q+12>>2]=e;return}e=q;I=H>>>8;do{if((I|0)==0){K=0}else{if(H>>>0>16777215){K=31;break}J=(I+1048320|0)>>>16&8;d=I<<J;E=(d+520192|0)>>>16&4;A=d<<E;d=(A+245760|0)>>>16&2;r=14-(E|J|d)+(A<<d>>>15)|0;K=H>>>((r+7|0)>>>0)&1|r<<1}}while(0);I=766984+(K<<2)|0;c[q+28>>2]=K;c[q+20>>2]=0;c[q+16>>2]=0;r=c[191671]|0;d=1<<K;do{if((r&d|0)==0){c[191671]=r|d;c[I>>2]=e;c[q+24>>2]=I;c[q+12>>2]=q;c[q+8>>2]=q}else{if((K|0)==31){L=0}else{L=25-(K>>>1)|0}A=H<<L;J=c[I>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(H|0)){break}M=J+16+(A>>>31<<2)|0;E=c[M>>2]|0;if((E|0)==0){N=2718;break}else{A=A<<1;J=E}}if((N|0)==2718){if(M>>>0<(c[191674]|0)>>>0){b3()}else{c[M>>2]=e;c[q+24>>2]=J;c[q+12>>2]=q;c[q+8>>2]=q;break}}A=J+8|0;B=c[A>>2]|0;E=c[191674]|0;if(J>>>0<E>>>0){b3()}if(B>>>0<E>>>0){b3()}else{c[B+12>>2]=e;c[A>>2]=e;c[q+8>>2]=B;c[q+12>>2]=J;c[q+24>>2]=0;break}}}while(0);q=(c[191678]|0)-1|0;c[191678]=q;if((q|0)==0){O=767136}else{return}while(1){q=c[O>>2]|0;if((q|0)==0){break}else{O=q+8|0}}c[191678]=-1;return}function v$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((a|0)==0){d=vZ(b)|0;return d|0}if(b>>>0>4294967231){c[(dR()|0)>>2]=12;d=0;return d|0}if(b>>>0<11){e=16}else{e=b+11&-8}f=a-8|0;g=a-4|0;h=c[g>>2]|0;i=h&-8;j=i-8|0;k=a+j|0;l=k;m=c[191674]|0;if(f>>>0<m>>>0){b3();return 0}n=h&3;if(!((n|0)!=1&(j|0)>-8)){b3();return 0}j=i|4;o=a+(j-8)|0;p=c[o>>2]|0;if((p&1|0)==0){b3();return 0}L3709:do{if((n|0)==0){if(e>>>0<256|i>>>0<(e|4)>>>0){break}if((i-e|0)>>>0>c[37244]<<1>>>0|(f|0)==0){break}else{d=a}return d|0}else{do{if(i>>>0<e>>>0){if((l|0)==(c[191676]|0)){q=(c[191673]|0)+i|0;if(q>>>0<=e>>>0){break L3709}r=q-e|0;c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=r|1;c[191676]=a+(e-8);c[191673]=r;break}if((l|0)==(c[191675]|0)){r=(c[191672]|0)+i|0;if(r>>>0<e>>>0){break L3709}q=r-e|0;if(q>>>0>15){c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=q|1;c[a+(r-8)>>2]=q;s=a+(r-4)|0;c[s>>2]=c[s>>2]&-2;t=a+(e-8)|0;u=q}else{c[g>>2]=h&1|r|2;q=a+(r-4)|0;c[q>>2]=c[q>>2]|1;t=0;u=0}c[191672]=u;c[191675]=t;break}if((p&2|0)!=0){break L3709}q=(p&-8)+i|0;if(q>>>0<e>>>0){break L3709}r=q-e|0;s=p>>>3;L3733:do{if(p>>>0<256){v=c[a+i>>2]|0;w=c[a+j>>2]|0;x=766720+(s<<1<<2)|0;do{if((v|0)!=(x|0)){if(v>>>0<m>>>0){b3();return 0}if((c[v+12>>2]|0)==(l|0)){break}b3();return 0}}while(0);if((w|0)==(v|0)){c[191670]=c[191670]&~(1<<s);break}do{if((w|0)==(x|0)){y=w+8|0}else{if(w>>>0<m>>>0){b3();return 0}z=w+8|0;if((c[z>>2]|0)==(l|0)){y=z;break}b3();return 0}}while(0);c[v+12>>2]=w;c[y>>2]=v}else{x=k;z=c[a+(i+16)>>2]|0;A=c[a+j>>2]|0;do{if((A|0)==(x|0)){B=a+(i+12)|0;C=c[B>>2]|0;if((C|0)==0){D=a+(i+8)|0;E=c[D>>2]|0;if((E|0)==0){F=0;break}else{G=E;H=D}}else{G=C;H=B}while(1){B=G+20|0;C=c[B>>2]|0;if((C|0)!=0){G=C;H=B;continue}B=G+16|0;C=c[B>>2]|0;if((C|0)==0){break}else{G=C;H=B}}if(H>>>0<m>>>0){b3();return 0}else{c[H>>2]=0;F=G;break}}else{B=c[a+i>>2]|0;if(B>>>0<m>>>0){b3();return 0}C=B+12|0;if((c[C>>2]|0)!=(x|0)){b3();return 0}D=A+8|0;if((c[D>>2]|0)==(x|0)){c[C>>2]=A;c[D>>2]=B;F=A;break}else{b3();return 0}}}while(0);if((z|0)==0){break}A=a+(i+20)|0;v=766984+(c[A>>2]<<2)|0;do{if((x|0)==(c[v>>2]|0)){c[v>>2]=F;if((F|0)!=0){break}c[191671]=c[191671]&~(1<<c[A>>2]);break L3733}else{if(z>>>0<(c[191674]|0)>>>0){b3();return 0}w=z+16|0;if((c[w>>2]|0)==(x|0)){c[w>>2]=F}else{c[z+20>>2]=F}if((F|0)==0){break L3733}}}while(0);if(F>>>0<(c[191674]|0)>>>0){b3();return 0}c[F+24>>2]=z;x=c[a+(i+8)>>2]|0;do{if((x|0)!=0){if(x>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[F+16>>2]=x;c[x+24>>2]=F;break}}}while(0);x=c[a+(i+12)>>2]|0;if((x|0)==0){break}if(x>>>0<(c[191674]|0)>>>0){b3();return 0}else{c[F+20>>2]=x;c[x+24>>2]=F;break}}}while(0);if(r>>>0>=16){c[g>>2]=c[g>>2]&1|e|2;c[a+((e|4)-8)>>2]=r|3;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;v0(a+(e-8)|0,r);break}c[g>>2]=q|c[g>>2]&1|2;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;d=a;return d|0}else{s=i-e|0;if(s>>>0<=15){break}c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=s|3;c[o>>2]=c[o>>2]|1;v0(a+(e-8)|0,s);d=a;return d|0}}while(0);if((f|0)==0){break}else{d=a}return d|0}}while(0);f=vZ(b)|0;if((f|0)==0){d=0;return d|0}e=c[g>>2]|0;g=(e&-8)-((e&3|0)==0?8:4)|0;e=g>>>0<b>>>0?g:b;v6(f|0,a|0,e)|0;v_(a);d=f;return d|0}function v0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=a;e=d+b|0;f=e;g=c[a+4>>2]|0;L3815:do{if((g&1|0)==0){h=c[a>>2]|0;if((g&3|0)==0){return}i=d+(-h|0)|0;j=i;k=h+b|0;l=c[191674]|0;if(i>>>0<l>>>0){b3()}if((j|0)==(c[191675]|0)){m=d+(b+4)|0;if((c[m>>2]&3|0)!=3){n=j;o=k;break}c[191672]=k;c[m>>2]=c[m>>2]&-2;c[d+(4-h)>>2]=k|1;c[e>>2]=k;return}m=h>>>3;if(h>>>0<256){p=c[d+(8-h)>>2]|0;q=c[d+(12-h)>>2]|0;r=766720+(m<<1<<2)|0;do{if((p|0)!=(r|0)){if(p>>>0<l>>>0){b3()}if((c[p+12>>2]|0)==(j|0)){break}b3()}}while(0);if((q|0)==(p|0)){c[191670]=c[191670]&~(1<<m);n=j;o=k;break}do{if((q|0)==(r|0)){s=q+8|0}else{if(q>>>0<l>>>0){b3()}t=q+8|0;if((c[t>>2]|0)==(j|0)){s=t;break}b3()}}while(0);c[p+12>>2]=q;c[s>>2]=p;n=j;o=k;break}r=i;m=c[d+(24-h)>>2]|0;t=c[d+(12-h)>>2]|0;do{if((t|0)==(r|0)){u=16-h|0;v=d+(u+4)|0;w=c[v>>2]|0;if((w|0)==0){x=d+u|0;u=c[x>>2]|0;if((u|0)==0){y=0;break}else{z=u;A=x}}else{z=w;A=v}while(1){v=z+20|0;w=c[v>>2]|0;if((w|0)!=0){z=w;A=v;continue}v=z+16|0;w=c[v>>2]|0;if((w|0)==0){break}else{z=w;A=v}}if(A>>>0<l>>>0){b3()}else{c[A>>2]=0;y=z;break}}else{v=c[d+(8-h)>>2]|0;if(v>>>0<l>>>0){b3()}w=v+12|0;if((c[w>>2]|0)!=(r|0)){b3()}x=t+8|0;if((c[x>>2]|0)==(r|0)){c[w>>2]=t;c[x>>2]=v;y=t;break}else{b3()}}}while(0);if((m|0)==0){n=j;o=k;break}t=d+(28-h)|0;l=766984+(c[t>>2]<<2)|0;do{if((r|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[191671]=c[191671]&~(1<<c[t>>2]);n=j;o=k;break L3815}else{if(m>>>0<(c[191674]|0)>>>0){b3()}i=m+16|0;if((c[i>>2]|0)==(r|0)){c[i>>2]=y}else{c[m+20>>2]=y}if((y|0)==0){n=j;o=k;break L3815}}}while(0);if(y>>>0<(c[191674]|0)>>>0){b3()}c[y+24>>2]=m;r=16-h|0;t=c[d+r>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[191674]|0)>>>0){b3()}else{c[y+16>>2]=t;c[t+24>>2]=y;break}}}while(0);t=c[d+(r+4)>>2]|0;if((t|0)==0){n=j;o=k;break}if(t>>>0<(c[191674]|0)>>>0){b3()}else{c[y+20>>2]=t;c[t+24>>2]=y;n=j;o=k;break}}else{n=a;o=b}}while(0);a=c[191674]|0;if(e>>>0<a>>>0){b3()}y=d+(b+4)|0;z=c[y>>2]|0;do{if((z&2|0)==0){if((f|0)==(c[191676]|0)){A=(c[191673]|0)+o|0;c[191673]=A;c[191676]=n;c[n+4>>2]=A|1;if((n|0)!=(c[191675]|0)){return}c[191675]=0;c[191672]=0;return}if((f|0)==(c[191675]|0)){A=(c[191672]|0)+o|0;c[191672]=A;c[191675]=n;c[n+4>>2]=A|1;c[n+A>>2]=A;return}A=(z&-8)+o|0;s=z>>>3;L3914:do{if(z>>>0<256){g=c[d+(b+8)>>2]|0;t=c[d+(b+12)>>2]|0;h=766720+(s<<1<<2)|0;do{if((g|0)!=(h|0)){if(g>>>0<a>>>0){b3()}if((c[g+12>>2]|0)==(f|0)){break}b3()}}while(0);if((t|0)==(g|0)){c[191670]=c[191670]&~(1<<s);break}do{if((t|0)==(h|0)){B=t+8|0}else{if(t>>>0<a>>>0){b3()}m=t+8|0;if((c[m>>2]|0)==(f|0)){B=m;break}b3()}}while(0);c[g+12>>2]=t;c[B>>2]=g}else{h=e;m=c[d+(b+24)>>2]|0;l=c[d+(b+12)>>2]|0;do{if((l|0)==(h|0)){i=d+(b+20)|0;p=c[i>>2]|0;if((p|0)==0){q=d+(b+16)|0;v=c[q>>2]|0;if((v|0)==0){C=0;break}else{D=v;E=q}}else{D=p;E=i}while(1){i=D+20|0;p=c[i>>2]|0;if((p|0)!=0){D=p;E=i;continue}i=D+16|0;p=c[i>>2]|0;if((p|0)==0){break}else{D=p;E=i}}if(E>>>0<a>>>0){b3()}else{c[E>>2]=0;C=D;break}}else{i=c[d+(b+8)>>2]|0;if(i>>>0<a>>>0){b3()}p=i+12|0;if((c[p>>2]|0)!=(h|0)){b3()}q=l+8|0;if((c[q>>2]|0)==(h|0)){c[p>>2]=l;c[q>>2]=i;C=l;break}else{b3()}}}while(0);if((m|0)==0){break}l=d+(b+28)|0;g=766984+(c[l>>2]<<2)|0;do{if((h|0)==(c[g>>2]|0)){c[g>>2]=C;if((C|0)!=0){break}c[191671]=c[191671]&~(1<<c[l>>2]);break L3914}else{if(m>>>0<(c[191674]|0)>>>0){b3()}t=m+16|0;if((c[t>>2]|0)==(h|0)){c[t>>2]=C}else{c[m+20>>2]=C}if((C|0)==0){break L3914}}}while(0);if(C>>>0<(c[191674]|0)>>>0){b3()}c[C+24>>2]=m;h=c[d+(b+16)>>2]|0;do{if((h|0)!=0){if(h>>>0<(c[191674]|0)>>>0){b3()}else{c[C+16>>2]=h;c[h+24>>2]=C;break}}}while(0);h=c[d+(b+20)>>2]|0;if((h|0)==0){break}if(h>>>0<(c[191674]|0)>>>0){b3()}else{c[C+20>>2]=h;c[h+24>>2]=C;break}}}while(0);c[n+4>>2]=A|1;c[n+A>>2]=A;if((n|0)!=(c[191675]|0)){F=A;break}c[191672]=A;return}else{c[y>>2]=z&-2;c[n+4>>2]=o|1;c[n+o>>2]=o;F=o}}while(0);o=F>>>3;if(F>>>0<256){z=o<<1;y=766720+(z<<2)|0;C=c[191670]|0;b=1<<o;do{if((C&b|0)==0){c[191670]=C|b;G=y;H=766720+(z+2<<2)|0}else{o=766720+(z+2<<2)|0;d=c[o>>2]|0;if(d>>>0>=(c[191674]|0)>>>0){G=d;H=o;break}b3()}}while(0);c[H>>2]=n;c[G+12>>2]=n;c[n+8>>2]=G;c[n+12>>2]=y;return}y=n;G=F>>>8;do{if((G|0)==0){I=0}else{if(F>>>0>16777215){I=31;break}H=(G+1048320|0)>>>16&8;z=G<<H;b=(z+520192|0)>>>16&4;C=z<<b;z=(C+245760|0)>>>16&2;o=14-(b|H|z)+(C<<z>>>15)|0;I=F>>>((o+7|0)>>>0)&1|o<<1}}while(0);G=766984+(I<<2)|0;c[n+28>>2]=I;c[n+20>>2]=0;c[n+16>>2]=0;o=c[191671]|0;z=1<<I;if((o&z|0)==0){c[191671]=o|z;c[G>>2]=y;c[n+24>>2]=G;c[n+12>>2]=n;c[n+8>>2]=n;return}if((I|0)==31){J=0}else{J=25-(I>>>1)|0}I=F<<J;J=c[G>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(F|0)){break}K=J+16+(I>>>31<<2)|0;G=c[K>>2]|0;if((G|0)==0){L=2984;break}else{I=I<<1;J=G}}if((L|0)==2984){if(K>>>0<(c[191674]|0)>>>0){b3()}c[K>>2]=y;c[n+24>>2]=J;c[n+12>>2]=n;c[n+8>>2]=n;return}K=J+8|0;L=c[K>>2]|0;I=c[191674]|0;if(J>>>0<I>>>0){b3()}if(L>>>0<I>>>0){b3()}c[L+12>>2]=y;c[K>>2]=y;c[n+8>>2]=L;c[n+12>>2]=J;c[n+24>>2]=0;return}function v1(b){b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0.0,x=0.0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0,L=0,M=0.0,N=0.0,O=0.0;d=b;while(1){e=d+1|0;if((bd(a[d]|0)|0)==0){break}else{d=e}}b=a[d]|0;if((b<<24>>24|0)==45){f=e;g=1}else if((b<<24>>24|0)==43){f=e;g=0}else{f=d;g=0}d=-1;e=0;b=f;while(1){i=a[b]|0;if(((i<<24>>24)-48|0)>>>0<10){j=d}else{if(i<<24>>24!=46|(d|0)>-1){break}else{j=e}}d=j;e=e+1|0;b=b+1|0}j=b+(-e|0)|0;f=(d|0)<0;k=((f^1)<<31>>31)+e|0;l=(k|0)>18;m=(l?-18:-k|0)+(f?e:d)|0;d=l?18:k;do{if((d|0)==0){n=0.0}else{if((d|0)>9){k=j;l=d;e=0;while(1){f=a[k]|0;o=k+1|0;if(f<<24>>24==46){p=a[o]|0;q=k+2|0}else{p=f;q=o}r=(e*10|0)-48+(p<<24>>24)|0;o=l-1|0;if((o|0)>9){k=q;l=o;e=r}else{break}}s=+(r|0)*1.0e9;t=9;u=q;v=3032}else{if((d|0)>0){s=0.0;t=d;u=j;v=3032}else{w=0.0;x=0.0}}if((v|0)==3032){e=u;l=t;k=0;while(1){o=a[e]|0;f=e+1|0;if(o<<24>>24==46){y=a[f]|0;z=e+2|0}else{y=o;z=f}A=(k*10|0)-48+(y<<24>>24)|0;f=l-1|0;if((f|0)>0){e=z;l=f;k=A}else{break}}w=+(A|0);x=s}B=x+w;do{if((i<<24>>24|0)==69|(i<<24>>24|0)==101){k=b+1|0;l=a[k]|0;if((l<<24>>24|0)==45){C=b+2|0;D=1}else if((l<<24>>24|0)==43){C=b+2|0;D=0}else{C=k;D=0}k=a[C]|0;if(((k<<24>>24)-48|0)>>>0<10){E=C;F=0;G=k}else{H=0;I=D;break}while(1){k=(G<<24>>24)-48+(F*10|0)|0;l=E+1|0;e=a[l]|0;if(((e<<24>>24)-48|0)>>>0<10){E=l;F=k;G=e}else{H=k;I=D;break}}}else{H=0;I=0}}while(0);k=m+((I|0)==0?H:-H|0)|0;e=(k|0)<0?-k|0:k;if((e|0)>511){c[(dR()|0)>>2]=34;J=1.0;K=6360;L=511;v=3049}else{if((e|0)==0){M=1.0}else{J=1.0;K=6360;L=e;v=3049}}if((v|0)==3049){while(1){v=0;if((L&1|0)==0){N=J}else{N=J*+h[K>>3]}e=L>>1;if((e|0)==0){M=N;break}else{J=N;K=K+8|0;L=e;v=3049}}}if((k|0)>-1){n=B*M;break}else{n=B/M;break}}}while(0);if((g|0)==0){O=n;return+O}O=-0.0-n;return+O}function v2(b){b=b|0;var c=0;c=b;while(a[c]|0){c=c+1|0}return c-b|0}function v3(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=b+e|0;if((e|0)>=20){d=d&255;e=b&3;g=d|d<<8|d<<16|d<<24;h=f&~3;if(e){e=b+4-e|0;while((b|0)<(e|0)){a[b]=d;b=b+1|0}}while((b|0)<(h|0)){c[b>>2]=g;b=b+4|0}}while((b|0)<(f|0)){a[b]=d;b=b+1|0}}function v4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;v=v+1|0;c[a>>2]=v;while((e|0)<40){if((c[d+(e<<2)>>2]|0)==0){c[d+(e<<2)>>2]=v;c[d+((e<<2)+4)>>2]=b;c[d+((e<<2)+8)>>2]=0;return 0}e=e+2|0}cE(116);cE(111);cE(111);cE(32);cE(109);cE(97);cE(110);cE(121);cE(32);cE(115);cE(101);cE(116);cE(106);cE(109);cE(112);cE(115);cE(32);cE(105);cE(110);cE(32);cE(97);cE(32);cE(102);cE(117);cE(110);cE(99);cE(116);cE(105);cE(111);cE(110);cE(32);cE(99);cE(97);cE(108);cE(108);cE(44);cE(32);cE(98);cE(117);cE(105);cE(108);cE(100);cE(32);cE(119);cE(105);cE(116);cE(104);cE(32);cE(97);cE(32);cE(104);cE(105);cE(103);cE(104);cE(101);cE(114);cE(32);cE(118);cE(97);cE(108);cE(117);cE(101);cE(32);cE(102);cE(111);cE(114);cE(32);cE(77);cE(65);cE(88);cE(95);cE(83);cE(69);cE(84);cE(74);cE(77);cE(80);cE(83);cE(10);ad(0);return 0}function v5(a,b){a=a|0;b=b|0;var d=0,e=0;while((d|0)<20){e=c[b+(d<<2)>>2]|0;if((e|0)==0)break;if((e|0)==(a|0)){return c[b+((d<<2)+4)>>2]|0}d=d+2|0}return 0}function v6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function v7(a){a=a|0;if((a|0)<65)return a|0;if((a|0)>90)return a|0;return a-65+97|0}function v8(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;while(e>>>0<d>>>0){f=v7(a[b+e|0]|0)|0;g=v7(a[c+e|0]|0)|0;if((f|0)==(g|0)&(f|0)==0)return 0;if((f|0)==0)return-1;if((g|0)==0)return 1;if((f|0)==(g|0)){e=e+1|0;continue}else{return(f>>>0>g>>>0?1:-1)|0}}return 0}function v9(a,b){a=a|0;b=b|0;return v8(a,b,-1)|0}function wa(b,c,d){b=b|0;c=c|0;d=d|0;if((c|0)<(b|0)&(b|0)<(c+d|0)){c=c+d|0;b=b+d|0;while((d|0)>0){b=b-1|0;c=c-1|0;d=d-1|0;a[b]=a[c]|0}}else{v6(b,c,d)|0}}function wb(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0;while((e|0)<(c|0)){f=d[a+e|0]|0;g=d[b+e|0]|0;if((f|0)!=(g|0))return((f|0)>(g|0)?1:-1)|0;e=e+1|0}return 0}function wc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(G=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function wd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(G=e,a-c>>>0|0)|0}function we(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}G=a<<c-32;return 0}function wf(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}G=0;return b>>>c-32|0}function wg(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}G=(b|0)<0?-1:0;return b>>c-32|0}function wh(b){b=b|0;var c=0;c=a[n+(b>>>24)|0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)|0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)|0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)|0]|0)+24|0}function wi(b){b=b|0;var c=0;c=a[m+(b&255)|0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)|0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)|0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)|0]|0)+24|0}function wj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ac(d,c)|0;f=a>>>16;a=(e>>>16)+(ac(d,f)|0)|0;d=b>>>16;b=ac(d,c)|0;return(G=(a>>>16)+(ac(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function wk(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=wd(e^a,f^b,e,f)|0;b=G;a=g^e;e=h^f;f=wd((wp(i,b,wd(g^c,h^d,g,h)|0,G,0)|0)^a,G^e,a,e)|0;return(G=G,f)|0}function wl(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=wd(h^a,j^b,h,j)|0;b=G;a=wd(k^d,l^e,k,l)|0;wp(m,b,a,G,g)|0;a=wd(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=G;i=f;return(G=j,a)|0}function wm(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=wj(e,a)|0;f=G;return(G=(ac(b,a)|0)+(ac(d,e)|0)+f|f&0,c|0|0)|0}function wn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=wp(a,b,c,d,0)|0;return(G=G,e)|0}function wo(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;wp(a,b,d,e,g)|0;i=f;return(G=c[g+4>>2]|0,c[g>>2]|0)|0}function wp(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(G=n,o)|0}else{if(!m){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(G=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(G=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(G=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((wi(l|0)|0)>>>0);return(G=n,o)|0}p=(wh(l|0)|0)-(wh(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(G=n,o)|0}else{if(!m){r=(wh(l|0)|0)-(wh(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(G=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(wh(j|0)|0)+33-(wh(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(G=n,o)|0}else{p=wi(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(G=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;F=0;H=0}else{g=d|0|0;d=k|e&0;e=wc(g,d,-1,-1)|0;k=G;i=w;w=v;v=u;u=t;t=s;s=0;while(1){I=w>>>31|i<<1;J=s|w<<1;j=u<<1|i>>>31|0;a=u>>>31|v<<1|0;wd(e,k,j,a)|0;b=G;h=b>>31|((b|0)<0?-1:0)<<1;K=h&1;L=wd(j,a,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;M=G;b=t-1|0;if((b|0)==0){break}else{i=I;w=J;v=M;u=L;t=b;s=K}}B=I;C=J;D=M;E=L;F=0;H=K}K=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(K|0)>>>31|(B|C)<<1|(C<<1|K>>>31)&0|F;o=(K<<1|0>>>31)&-2|H;return(G=n,o)|0}function wq(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ev(a|0,b|0,c|0,d|0,e|0)}function wr(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dr(a|0,b|0,c|0,d|0,e|0)}function ws(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;db(a|0,b|0,c|0,d|0,e|0)}function wt(a,b){a=a|0;b=+b;bB(a|0,+b)}function wu(a){a=a|0;bq(a|0)}function wv(a){a=a|0;cZ(a|0)}function ww(a){a=a|0;dj(a|0)}function wx(a){a=a|0;cY(a|0)}function wy(a){a=a|0;cc(a|0)}function wz(a){a=a|0;bv(a|0)}function wA(a){a=a|0;eX(a|0)}function wB(a){a=a|0;cG(a|0)}function wC(a){a=a|0;bM(a|0)}function wD(a){a=a|0;eO(a|0)}function wE(a){a=a|0;d0(a|0)}function wF(a){a=a|0;cM(a|0)}function wG(a){a=a|0;eW(a|0)}function wH(a){a=a|0;c9(a|0)}function wI(a){a=a|0;cI(a|0)}function wJ(a){a=a|0;e4(a|0)}function wK(a){a=a|0;ej(a|0)}function wL(a){a=a|0;bn(a|0)}function wM(a){a=a|0;a7(a|0)}function wN(a){a=a|0;by(a|0)}function wO(a){a=a|0;de(a|0)}function wP(a){a=a|0;cd(a|0)}function wQ(a){a=a|0;bc(a|0)}function wR(a){a=a|0;bl(a|0)}function wS(a){a=a|0;d4(a|0)}function wT(a,b){a=a|0;b=b|0;c0(a|0,b|0)}function wU(a,b){a=a|0;b=b|0;bF(a|0,b|0)}function wV(a,b){a=a|0;b=b|0;cg(a|0,b|0)}function wW(a,b){a=a|0;b=b|0;dS(a|0,b|0)}function wX(a,b){a=a|0;b=b|0;cX(a|0,b|0)}function wY(a,b){a=a|0;b=b|0;eZ(a|0,b|0)}function wZ(a,b){a=a|0;b=b|0;cs(a|0,b|0)}function w_(a,b){a=a|0;b=b|0;cK(a|0,b|0)}function w$(a,b){a=a|0;b=b|0;bV(a|0,b|0)}function w0(a,b){a=a|0;b=b|0;e5(a|0,b|0)}function w1(a,b){a=a|0;b=b|0;bU(a|0,b|0)}function w2(a,b){a=a|0;b=b|0;bx(a|0,b|0)}function w3(a,b){a=a|0;b=b|0;b$(a|0,b|0)}function w4(a,b){a=a|0;b=b|0;dM(a|0,b|0)}function w5(a,b){a=a|0;b=b|0;b5(a|0,b|0)}function w6(a,b){a=a|0;b=b|0;aY(a|0,b|0)}function w7(a,b){a=a|0;b=b|0;dI(a|0,b|0)}function w8(a,b){a=a|0;b=b|0;d_(a|0,b|0)}function w9(a,b){a=a|0;b=b|0;bf(a|0,b|0)}function xa(a,b){a=a|0;b=b|0;ey(a|0,b|0)}function xb(a,b){a=a|0;b=b|0;eu(a|0,b|0)}function xc(a,b){a=a|0;b=b|0;cC(a|0,b|0)}function xd(a,b){a=a|0;b=b|0;es(a|0,b|0)}function xe(a,b){a=a|0;b=b|0;e0(a|0,b|0)}function xf(a,b){a=a|0;b=b|0;cO(a|0,b|0)}function xg(a,b){a=a|0;b=b|0;bL(a|0,b|0)}function xh(a,b){a=a|0;b=b|0;eC(a|0,b|0)}function xi(a,b){a=a|0;b=b|0;e2(a|0,b|0)}function xj(a,b){a=a|0;b=b|0;eY(a|0,b|0)}function xk(a,b){a=a|0;b=b|0;dp(a|0,b|0)}function xl(a,b){a=a|0;b=b|0;bI(a|0,b|0)}function xm(a,b){a=a|0;b=b|0;dH(a|0,b|0)}function xn(a,b){a=a|0;b=b|0;cT(a|0,b|0)}function xo(a){a=a|0;return cj(a|0)|0}function xp(a){a=a|0;return ck(a|0)|0}function xq(a){a=a|0;return cE(a|0)|0}function xr(a){a=a|0;return aZ(a|0)|0}function xs(a){a=a|0;return b0(a|0)|0}function xt(a){a=a|0;return bG(a|0)|0}function xu(a){a=a|0;return b8(a|0)|0}function xv(a){a=a|0;return bt(a|0)|0}function xw(a){a=a|0;return dn(a|0)|0}function xx(a){a=a|0;return a2(a|0)|0}function xy(a){a=a|0;return d9(a|0)|0}function xz(a){a=a|0;return dV(a|0)|0}function xA(a){a=a|0;return dA(a|0)|0}function xB(a){a=a|0;return da(a|0)|0}function xC(a){a=a|0;return aR(a|0)|0}function xD(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;dq(a|0,+b,+c,+d,+e)}function xE(a,b,c){a=a|0;b=b|0;c=c|0;return cN(a|0,b|0,c|0)|0}function xF(a,b,c){a=a|0;b=b|0;c=c|0;return d7(a|0,b|0,c|0)|0}function xG(a,b,c){a=a|0;b=b|0;c=c|0;return eb(a|0,b|0,c|0)|0}function xH(a,b,c){a=a|0;b=b|0;c=c|0;return aW(a|0,b|0,c|0)|0}function xI(a,b,c){a=a|0;b=b|0;c=c|0;return bJ(a|0,b|0,c|0)|0}function xJ(a,b,c){a=a|0;b=b|0;c=c|0;return a0(a|0,b|0,c|0)|0}function xK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;bT(a|0,b|0,c|0,d|0,e|0,f|0)}function xL(a){a=+a;return+bH(+a)}function xM(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;bA(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function xN(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;d3(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function xO(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;d1(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function xP(a,b){a=a|0;b=b|0;return eB(a|0,b|0)|0}function xQ(a,b){a=a|0;b=b|0;return cJ(a|0,b|0)|0}function xR(a,b){a=a|0;b=b|0;return c2(a|0,b|0)|0}function xS(a,b){a=a|0;b=b|0;return c$(a|0,b|0)|0}function xT(a,b){a=a|0;b=b|0;return dz(a|0,b|0)|0}function xU(){return+a9()}function xV(){return dD()|0}function xW(){return ez()|0}function xX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return a3(a|0,b|0,c|0,d|0)|0}function xY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return bN(a|0,b|0,c|0,d|0)|0}function xZ(a,b,c){a=a|0;b=b|0;c=c|0;dF(a|0,b|0,c|0)}function x_(a,b,c){a=a|0;b=b|0;c=c|0;b7(a|0,b|0,c|0)}function x$(a,b,c){a=a|0;b=b|0;c=c|0;bO(a|0,b|0,c|0)}function x0(a,b,c){a=a|0;b=b|0;c=c|0;bp(a|0,b|0,c|0)}function x1(a,b,c){a=a|0;b=b|0;c=c|0;c4(a|0,b|0,c|0)}function x2(a,b,c){a=a|0;b=b|0;c=c|0;aT(a|0,b|0,c|0)}function x3(a,b,c){a=a|0;b=b|0;c=c|0;cF(a|0,b|0,c|0)}function x4(a,b,c){a=a|0;b=b|0;c=c|0;a_(a|0,b|0,c|0)}function x5(a,b,c){a=a|0;b=b|0;c=c|0;cq(a|0,b|0,c|0)}function x6(a,b,c){a=a|0;b=b|0;c=c|0;dK(a|0,b|0,c|0)}function x7(a,b,c){a=a|0;b=b|0;c=c|0;bs(a|0,b|0,c|0)}function x8(a,b,c){a=a|0;b=b|0;c=c|0;cD(a|0,b|0,c|0)}function x9(a,b,c){a=a|0;b=b|0;c=c|0;dE(a|0,b|0,c|0)}function ya(a,b,c){a=a|0;b=b|0;c=c|0;dG(a|0,b|0,c|0)}function yb(a,b,c){a=a|0;b=b|0;c=c|0;cP(a|0,b|0,c|0)}function yc(a,b,c){a=a|0;b=b|0;c=c|0;b2(a|0,b|0,c|0)}function yd(a,b,c){a=a|0;b=b|0;c=c|0;bb(a|0,b|0,c|0)}function ye(a,b,c){a=a|0;b=b|0;c=c|0;bo(a|0,b|0,c|0)}function yf(a,b,c){a=a|0;b=b|0;c=c|0;bQ(a|0,b|0,c|0)}function yg(a,b,c){a=a|0;b=b|0;c=c|0;a8(a|0,b|0,c|0)}function yh(a,b,c){a=a|0;b=b|0;c=c|0;eq(a|0,b|0,c|0)}function yi(a,b,c){a=a|0;b=b|0;c=c|0;eK(a|0,b|0,c|0)}function yj(a,b,c){a=a|0;b=b|0;c=c|0;aU(a|0,b|0,c|0)}function yk(a,b,c){a=a|0;b=b|0;c=c|0;eV(a|0,b|0,c|0)}function yl(a,b,c){a=a|0;b=b|0;c=c|0;eT(a|0,b|0,c|0)}function ym(a,b,c){a=a|0;b=b|0;c=c|0;dm(a|0,b|0,c|0)}function yn(a,b,c){a=a|0;b=b|0;c=c|0;eG(a|0,b|0,c|0)}function yo(a,b,c){a=a|0;b=b|0;c=c|0;bD(a|0,b|0,c|0)}function yp(a,b,c){a=a|0;b=b|0;c=c|0;dl(a|0,b|0,c|0)}function yq(){et()}function yr(){cr()}function ys(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ds(a|0,b|0,c|0,d|0)}function yt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eN(a|0,b|0,c|0,d|0)}function yu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dN(a|0,b|0,c|0,d|0)}function yv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eD(a|0,b|0,c|0,d|0)}function yw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dx(a|0,b|0,c|0,d|0)}function yx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ci(a|0,b|0,c|0,d|0)}function yy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dv(a|0,b|0,c|0,d|0)}function yz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bR(a|0,b|0,c|0,d|0)}function yA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cv(a|0,b|0,c|0,d|0)}function yB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dJ(a|0,b|0,c|0,d|0)}function yC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d6(a|0,b|0,c|0,d|0)}function yD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ek(a|0,b|0,c|0,d|0)}function yE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cw(a|0,b|0,c|0,d|0)}function yF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ce(a|0,b|0,c|0,d|0)}function yG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bi(a|0,b|0,c|0,d|0)}function yH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d$(a|0,b|0,c|0,d|0)}function yI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ei(a|0,b|0,c|0,d|0)}function yJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b_(a|0,b|0,c|0,d|0)}function yK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dy(a|0,b|0,c|0,d|0)}function yL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d8(a|0,b|0,c|0,d|0)}function yM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cS(a|0,b|0,c|0,d|0)}function yN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d2(a|0,b|0,c|0,d|0)}function yO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;aP(a|0,b|0,c|0,d|0)}function yP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ec(a|0,b|0,c|0,d|0)}function yQ(a,b,c){a=a|0;b=+b;c=+c;dg(a|0,+b,+c)}function yR(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;bh(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function yS(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;c8(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function yT(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;cu(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function yU(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;cp(a|0,+b,+c,+d)}function yV(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;dL(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function yW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;en(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function yX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eP(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function yY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return e6[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0)|0}function yZ(a,b,c){a=a|0;b=b|0;c=+c;e7[a&7](b|0,+c)}function y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;e8[a&15](b|0,c|0,d|0,e|0,f|0)}function y$(a,b){a=a|0;b=b|0;e9[a&2047](b|0)}function y0(a,b,c){a=a|0;b=b|0;c=c|0;fa[a&127](b|0,c|0)}function y1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return fb[a&15](b|0,c|0,d|0,e|0,f|0,g|0)|0}function y2(a,b){a=a|0;b=b|0;return fc[a&127](b|0)|0}function y3(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;fd[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0)}function y4(a,b,c,d,e,f){a=a|0;b=b|0;c=+c;d=+d;e=+e;f=+f;fe[a&7](b|0,+c,+d,+e,+f)}function y5(a,b){a=a|0;b=+b;return ff[a&3](+b)|0}function y6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return fg[a&63](b|0,c|0,d|0)|0}function y7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;fh[a&3](b|0,c|0,d|0,e|0,f|0,+g)}function y8(a,b,c,d){a=a|0;b=b|0;c=+c;d=+d;fi[a&3](b|0,+c,+d)}function y9(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=+d;e=+e;fj[a&3](b|0,+c,+d,+e)}function za(a,b,c){a=a|0;b=b|0;c=c|0;return+fk[a&3](b|0,c|0)}function zb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;return fl[a&3](b|0,c|0,+d)|0}function zc(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;fm[a&7](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function zd(a,b,c){a=a|0;b=b|0;c=+c;return fn[a&3](b|0,+c)|0}function ze(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;fo[a&7](b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function zf(a,b){a=a|0;b=+b;return+fp[a&3](+b)}function zg(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;fq[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0)}function zh(a,b,c){a=a|0;b=b|0;c=c|0;return fr[a&63](b|0,c|0)|0}function zi(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;fs[a&31](b|0,c|0,d|0,e|0,f|0,g|0)}function zj(a){a=a|0;return+ft[a&3]()}function zk(a){a=a|0;return fu[a&31]()|0}function zl(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fv[a&15](b|0,c|0,d|0,e|0)|0}function zm(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fw[a&127](b|0,c|0,d|0)}function zn(a){a=a|0;fx[a&127]()}function zo(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;fy[a&63](b|0,c|0,d|0,e|0)}function zp(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ad(0);return 0}function zq(a,b){a=a|0;b=+b;ad(1)}function zr(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ad(2)}function zs(a){a=a|0;ad(3)}function zt(a,b){a=a|0;b=b|0;ad(4)}function zu(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ad(5);return 0}function zv(a){a=a|0;ad(6);return 0}function zw(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;ad(7)}function zx(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;ad(8)}function zy(a){a=+a;ad(9);return 0}function zz(a,b,c){a=a|0;b=b|0;c=c|0;ad(10);return 0}function zA(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;ad(11)}function zB(a,b,c){a=a|0;b=+b;c=+c;ad(12)}function zC(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;ad(13)}function zD(a,b){a=a|0;b=b|0;ad(14);return 0.0}function zE(a,b,c){a=a|0;b=b|0;c=+c;ad(15);return 0}function zF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ad(16)}function zG(a,b){a=a|0;b=+b;ad(17);return 0}function zH(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ad(18)}function zI(a){a=+a;ad(19);return 0.0}function zJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ad(20)}function zK(a,b){a=a|0;b=b|0;ad(21);return 0}function zL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ad(22)}function zM(){ad(23);return 0.0}function zN(){ad(24);return 0}function zO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ad(25);return 0}function zP(a,b,c){a=a|0;b=b|0;c=c|0;ad(26)}function zQ(){ad(27)}function zR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ad(28)}
// EMSCRIPTEN_END_FUNCS
var e6=[zp,zp,i6,zp];var e7=[zq,zq,iR,zq,wt,zq,zq,zq];var e8=[zr,zr,wq,zr,jf,zr,wr,zr,ws,zr,zr,zr,zr,zr,zr,zr];var e9=[zs,zs,wu,zs,qq,zs,um,zs,qj,zs,ur,zs,sM,zs,tF,zs,kQ,zs,qP,zs,vt,zs,nZ,zs,uX,zs,pO,zs,m0,zs,mU,zs,vk,zs,kM,zs,wv,zs,oS,zs,lM,zs,sO,zs,oL,zs,st,zs,uv,zs,vd,zs,ui,zs,kr,zs,kF,zs,tW,zs,oE,zs,sX,zs,t5,zs,uT,zs,rK,zs,nR,zs,pZ,zs,uy,zs,kU,zs,hl,zs,tT,zs,nO,zs,o2,zs,rp,zs,ww,zs,qZ,zs,jo,zs,le,zs,n8,zs,qE,zs,o9,zs,kC,zs,tN,zs,po,zs,pv,zs,ok,zs,pe,zs,ty,zs,mR,zs,sb,zs,wx,zs,sU,zs,nV,zs,rk,zs,wy,zs,wz,zs,sf,zs,lj,zs,g5,zs,t3,zs,p2,zs,mJ,zs,vK,zs,lX,zs,s5,zs,lK,zs,sq,zs,oe,zs,my,zs,mj,zs,kP,zs,qd,zs,gg,zs,mc,zs,sS,zs,mY,zs,rQ,zs,mQ,zs,lk,zs,mw,zs,rv,zs,l0,zs,ub,zs,tY,zs,ln,zs,wA,zs,uk,zs,ko,zs,u$,zs,oU,zs,qm,zs,pY,zs,mC,zs,vm,zs,sI,zs,ma,zs,os,zs,pV,zs,sG,zs,kB,zs,sZ,zs,uR,zs,nw,zs,nN,zs,o3,zs,rs,zs,qW,zs,oW,zs,nF,zs,u5,zs,rz,zs,sm,zs,mX,zs,rh,zs,sx,zs,sz,zs,kJ,zs,hD,zs,tD,zs,nd,zs,iM,zs,ug,zs,pP,zs,ot,zs,wB,zs,t7,zs,tv,zs,kY,zs,mD,zs,pF,zs,ly,zs,k8,zs,kG,zs,q4,zs,s1,zs,tR,zs,nK,zs,ls,zs,to,zs,q9,zs,s0,zs,qv,zs,ii,zs,n5,zs,oh,zs,sa,zs,pr,zs,mZ,zs,nz,zs,gR,zs,qw,zs,wC,zs,rT,zs,mt,zs,l5,zs,r0,zs,rZ,zs,mr,zs,sh,zs,qe,zs,q7,zs,lR,zs,t_,zs,tK,zs,tg,zs,p6,zs,oz,zs,wD,zs,lT,zs,lG,zs,gS,zs,lo,zs,mm,zs,mV,zs,nY,zs,qx,zs,ni,zs,pn,zs,nE,zs,oI,zs,k4,zs,tP,zs,wE,zs,o$,zs,oD,zs,i2,zs,ks,zs,op,zs,th,zs,kE,zs,nQ,zs,pT,zs,td,zs,sA,zs,uM,zs,kV,zs,lx,zs,rn,zs,re,zs,qB,zs,pa,zs,k0,zs,ud,zs,s_,zs,oA,zs,mO,zs,pk,zs,vD,zs,lc,zs,kz,zs,pI,zs,rH,zs,tw,zs,qH,zs,lC,zs,py,zs,lP,zs,oZ,zs,se,zs,ta,zs,q0,zs,m7,zs,kT,zs,wF,zs,sJ,zs,lS,zs,qR,zs,vA,zs,lv,zs,od,zs,id,zs,lH,zs,rW,zs,vl,zs,rd,zs,rP,zs,sN,zs,gQ,zs,rX,zs,hw,zs,mb,zs,k1,zs,mx,zs,lN,zs,l1,zs,om,zs,nm,zs,mu,zs,ns,zs,qr,zs,hs,zs,ti,zs,qi,zs,pM,zs,p9,zs,kL,zs,m1,zs,nD,zs,rr,zs,oR,zs,rw,zs,f6,zs,oM,zs,q5,zs,lr,zs,tk,zs,kI,zs,ri,zs,m5,zs,q$,zs,tq,zs,mL,zs,sn,zs,ou,zs,sw,zs,rI,zs,ux,zs,kZ,zs,lB,zs,gE,zs,vp,zs,k7,zs,rL,zs,s9,zs,u3,zs,g9,zs,kv,zs,s6,zs,m8,zs,uB,zs,kx,zs,qF,zs,ol,zs,uV,zs,lg,zs,n9,zs,mS,zs,pf,zs,pg,zs,i$,zs,wG,zs,sL,zs,pb,zs,nt,zs,sW,zs,vi,zs,t0,zs,li,zs,uo,zs,vB,zs,tE,zs,qs,zs,lO,zs,lD,zs,tU,zs,nI,zs,qa,zs,l6,zs,vn,zs,p7,zs,sE,zs,qc,zs,kS,zs,lW,zs,mW,zs,s3,zs,nu,zs,uF,zs,nU,zs,u4,zs,k5,zs,mf,zs,oV,zs,lq,zs,oq,zs,mz,zs,t4,zs,qn,zs,kp,zs,ql,zs,l7,zs,vq,zs,t9,zs,sD,zs,gT,zs,pu,zs,sV,zs,nM,zs,s2,zs,mg,zs,wH,zs,rm,zs,u6,zs,u0,zs,rb,zs,pR,zs,sQ,zs,vs,zs,n_,zs,nk,zs,o4,zs,qy,zs,ss,zs,n6,zs,pl,zs,mP,zs,sj,zs,nB,zs,qG,zs,ts,zs,rM,zs,mB,zs,pH,zs,lb,zs,kA,zs,rj,zs,wI,zs,pq,zs,r9,zs,l9,zs,gF,zs,s$,zs,q1,zs,uL,zs,nH,zs,lV,zs,qU,zs,tm,zs,qX,zs,nc,zs,og,zs,uD,zs,pA,zs,r2,zs,nn,zs,rS,zs,gU,zs,mk,zs,r1,zs,me,zs,lm,zs,tZ,zs,tJ,zs,t2,zs,wJ,zs,hh,zs,rt,zs,oN,zs,tG,zs,qo,zs,uK,zs,un,zs,qh,zs,uq,zs,pN,zs,te,zs,uU,zs,qL,zs,uQ,zs,nC,zs,uH,zs,m2,zs,rq,zs,mH,zs,lu,zs,rB,zs,o5,zs,nh,zs,r6,zs,kD,zs,mE,zs,oQ,zs,kt,zs,o0,zs,oC,zs,so,zs,rR,zs,uj,zs,ob,zs,ov,zs,u2,zs,wK,zs,sr,zs,t6,zs,p0,zs,nf,zs,pS,zs,uP,zs,kW,zs,oY,zs,us,zs,sF,zs,la,zs,uz,zs,qI,zs,p$,zs,rf,zs,m4,zs,tS,zs,iF,zs,md,zs,lf,zs,mo,zs,oj,zs,r4,zs,n1,zs,qC,zs,va,zs,mK,zs,n4,zs,pd,zs,r8,zs,pt,zs,r_,zs,q8,zs,l$,zs,wL,zs,uI,zs,l3,zs,u_,zs,nJ,zs,ro,zs,rD,zs,m6,zs,lh,zs,ny,zs,qg,zs,k6,zs,qS,zs,tj,zs,p4,zs,lI,zs,lZ,zs,lw,zs,rV,zs,sH,zs,kN,zs,nX,zs,qN,zs,ox,zs,mp,zs,qV,zs,ua,zs,mi,zs,tl,zs,tO,zs,l2,zs,t$,zs,tL,zs,k2,zs,uW,zs,tr,zs,pB,zs,su,zs,kq,zs,p_,zs,ul,zs,ml,zs,pU,zs,uN,zs,s8,zs,nP,zs,qt,zs,nr,zs,lF,zs,rl,zs,sg,zs,rc,zs,o1,zs,vj,zs,tQ,zs,kH,zs,tC,zs,oy,zs,sk,zs,mM,zs,rF,zs,vc,zs,sv,zs,pJ,zs,rJ,zs,no,zs,ue,zs,sB,zs,sR,zs,uh,zs,k_,zs,mF,zs,pD,zs,oG,zs,vf,zs,ph,zs,tz,zs,vM,zs,o_,zs,uu,zs,tu,zs,tB,zs,q2,zs,vh,zs,na,zs,oa,zs,or,zs,uZ,zs,p1,zs,qM,zs,vo,zs,nb,zs,lY,zs,of,zs,s7,zs,wM,zs,rx,zs,lJ,zs,r3,zs,u8,zs,ll,zs,q6,zs,rE,zs,qQ,zs,sT,zs,mv,zs,jD,zs,rY,zs,uY,zs,px,zs,tX,zs,t8,zs,qu,zs,on,zs,vu,zs,qk,zs,lE,zs,kR,zs,p8,zs,vr,zs,oc,zs,v_,zs,qO,zs,lA,zs,nG,zs,l8,zs,m$,zs,nT,zs,ry,zs,mT,zs,lL,zs,tH,zs,oT,zs,ru,zs,mA,zs,lp,zs,oK,zs,oF,zs,sp,zs,ku,zs,ow,zs,kK,zs,ng,zs,g8,zs,tM,zs,qJ,zs,uw,zs,kX,zs,sC,zs,oi,zs,wN,zs,lz,zs,rg,zs,pL,zs,nL,zs,m3,zs,h6,zs,wO,zs,qY,zs,uA,zs,tn,zs,n7,zs,qz,zs,pc,zs,pw,zs,nj,zs,pG,zs,rN,zs,nq,zs,uc,zs,tA,zs,pm,zs,oP,zs,sc,zs,pp,zs,mq,zs,tx,zs,nv,zs,wP,zs,pX,zs,p3,zs,tV,zs,sd,zs,qf,zs,up,zs,p5,zs,lQ,zs,tf,zs,qb,zs,lU,zs,qT,zs,rU,zs,pQ,zs,vC,zs,mn,zs,nS,zs,ra,zs,kw,zs,m9,zs,rO,zs,mh,zs,k3,zs,uS,zs,oH,zs,pz,zs,sy,zs,hm,zs,oO,zs,u1,zs,qp,zs,nl,zs,pK,zs,kn,zs,nx,zs,qK,zs,uE,zs,uO,zs,pE,zs,sK,zs,pW,zs,uG,zs,wQ,zs,ve,zs,mI,zs,nW,zs,si,zs,rC,zs,r5,zs,o6,zs,lt,zs,oX,zs,wR,zs,nA,zs,qA,zs,sP,zs,tp,zs,sl,zs,mN,zs,o7,zs,u9,zs,rG,zs,tI,zs,k$,zs,oB,zs,pj,zs,vJ,zs,u7,zs,ut,zs,tt,zs,pi,zs,ld,zs,ky,zs,vb,zs,pC,zs,mG,zs,q_,zs,uJ,zs,q3,zs,kO,zs,ne,zs,oJ,zs,s4,zs,tc,zs,oo,zs,np,zs,uC,zs,uf,zs,vz,zs,n3,zs,qD,zs,o8,zs,m_,zs,ps,zs,sY,zs,r7,zs,r$,zs,rA,zs,l_,zs,ms,zs,l4,zs,t1,zs,k9,zs,vg,zs,wS,zs,tb,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs,zs];var fa=[zt,zt,i3,zt,wT,zt,iQ,zt,iI,zt,hi,zt,vE,zt,wU,zt,wV,zt,wW,zt,jg,zt,wX,zt,wY,zt,wZ,zt,w_,zt,ic,zt,w$,zt,jU,zt,w0,zt,i8,zt,hC,zt,iB,zt,w1,zt,w2,zt,jQ,zt,w3,zt,w4,zt,w5,zt,iW,zt,iV,zt,w6,zt,w7,zt,w8,zt,gP,zt,w9,zt,xa,zt,xb,zt,jq,zt,xc,zt,xd,zt,xe,zt,ig,zt,iz,zt,gc,zt,h5,zt,xf,zt,ga,zt,iJ,zt,jP,zt,xg,zt,jS,zt,iS,zt,jT,zt,xh,zt,gz,zt,xi,zt,xj,zt,xk,zt,xl,zt,xm,zt,iy,zt,xn,zt,zt,zt,zt,zt];var fb=[zu,zu,hj,zu,ho,zu,hn,zu,hp,zu,ix,zu,zu,zu,zu,zu];var fc=[zv,zv,vG,zv,hF,zv,hE,zv,iC,zv,vH,zv,g1,zv,vZ,zv,ie,zv,xo,zv,xp,zv,xq,zv,gW,zv,gw,zv,iA,zv,hA,zv,g2,zv,js,zv,ib,zv,i5,zv,xr,zv,ji,zv,xs,zv,v2,zv,xt,zv,xu,zv,xv,zv,hq,zv,ia,zv,iD,zv,gi,zv,hu,zv,gL,zv,jr,zv,vX,zv,xw,zv,xx,zv,gk,zv,xy,zv,jm,zv,xz,zv,xA,zv,jh,zv,hB,zv,xB,zv,xC,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv,zv];var fd=[zw,zw,jn,zw];var fe=[zx,zx,iO,zx,iP,zx,xD,zx];var ff=[zy,zy,ih,zy];var fg=[zz,zz,gZ,zz,xE,zz,xF,zz,xG,zz,h8,zz,h9,zz,xH,zz,jd,zz,xI,zz,i7,zz,gp,zz,hz,zz,iE,zz,iw,zz,vV,zz,hy,zz,xJ,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz,zz];var fh=[zA,zA,iT,zA];var fi=[zB,zB,yQ,zB];var fj=[zC,zC,yU,zC];var fk=[zD,zD,ja,zD];var fl=[zE,zE,i0,zE];var fm=[zF,zF,yR,zF,yS,zF,yT,zF];var fn=[zG,zG,h3,zG];var fo=[zH,zH,yV,zH,yW,zH,yX,zH];var fp=[zI,zI,xL,zI];var fq=[zJ,zJ,hX,zJ,xM,zJ,xN,zJ,xO,zJ,zJ,zJ,zJ,zJ,zJ,zJ];var fr=[zK,zK,hk,zK,xP,zK,vT,zK,xQ,zK,iL,zK,iK,zK,v9,zK,xR,zK,g$,zK,xS,zK,fW,zK,jl,zK,gf,zK,gK,zK,vU,zK,xT,zK,hc,zK,gN,zK,fS,zK,g0,zK,gm,zK,v$,zK,gG,zK,gn,zK,zK,zK,zK,zK,zK,zK,zK,zK,zK,zK,zK,zK,zK,zK];var fs=[zL,zL,hP,zL,hL,zL,hS,zL,hV,zL,hK,zL,hO,zL,xK,zL,hQ,zL,hR,zL,hN,zL,hJ,zL,hM,zL,zL,zL,zL,zL,zL,zL];var ft=[zM,zM,xU,zM];var fu=[zN,zN,h_,zN,g_,zN,xV,zN,vS,zN,vW,zN,vy,zN,hg,zN,jk,zN,xW,zN,jp,zN,gO,zN,i9,zN,gv,zN,jb,zN,gY,zN];var fv=[zO,zO,xX,zO,xY,zO,gd,zO,iX,zO,zO,zO,zO,zO,zO,zO];var fw=[zP,zP,xZ,zP,gJ,zP,i1,zP,iN,zP,x_,zP,x$,zP,x0,zP,x1,zP,x2,zP,x3,zP,gy,zP,x4,zP,x5,zP,x6,zP,hT,zP,x7,zP,x8,zP,x9,zP,ya,zP,ht,zP,yb,zP,yc,zP,yd,zP,ye,zP,wa,zP,yf,zP,yg,zP,yh,zP,g4,zP,yi,zP,yj,zP,iU,zP,yk,zP,yl,zP,gs,zP,vR,zP,ym,zP,yn,zP,hW,zP,yo,zP,yp,zP,h4,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP,zP];var fx=[zQ,zQ,gV,zQ,kc,zQ,gC,zQ,j6,zQ,ka,zQ,j9,zQ,yq,zQ,jj,zQ,iH,zQ,j0,zQ,g6,zQ,vQ,zQ,j_,zQ,f7,zQ,j$,zQ,g3,zQ,vN,zQ,i4,zQ,vP,zQ,f3,zQ,j1,zQ,j8,zQ,je,zQ,gX,zQ,j2,zQ,j5,zQ,gB,zQ,ge,zQ,j4,zQ,vO,zQ,jY,zQ,kb,zQ,iG,zQ,j3,zQ,vF,zQ,gD,zQ,jZ,zQ,jX,zQ,fZ,zQ,f$,zQ,g7,zQ,jc,zQ,ha,zQ,yr,zQ,vY,zQ,fY,zQ,j7,zQ,fR,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ,zQ];var fy=[zR,zR,ys,zR,yt,zR,yu,zR,fV,zR,yv,zR,yw,zR,yx,zR,yy,zR,yz,zR,yA,zR,yB,zR,yC,zR,yD,zR,yE,zR,yF,zR,yG,zR,yH,zR,yI,zR,yJ,zR,yK,zR,yL,zR,yM,zR,yN,zR,yO,zR,yP,zR,zR,zR,zR,zR,zR,zR,zR,zR,zR,zR,zR,zR];return{_testSetjmp:v5,_strncasecmp:v8,_tolower:v7,_free:v_,_main:fQ,_memcmp:wb,_memmove:wa,__GLOBAL__I_a:jO,_saveSetjmp:v4,_memset:v3,_malloc:vZ,_memcpy:v6,_strlen:v2,_strcasecmp:v9,_realloc:v$,runPostSets:fP,stackAlloc:fz,stackSave:fA,stackRestore:fB,setThrew:fC,setTempRet0:fF,setTempRet1:fG,setTempRet2:fH,setTempRet3:fI,setTempRet4:fJ,setTempRet5:fK,setTempRet6:fL,setTempRet7:fM,setTempRet8:fN,setTempRet9:fO,dynCall_iiiiiiii:yY,dynCall_vif:yZ,dynCall_viiiii:y_,dynCall_vi:y$,dynCall_vii:y0,dynCall_iiiiiii:y1,dynCall_ii:y2,dynCall_viiiiiiiiiii:y3,dynCall_viffff:y4,dynCall_if:y5,dynCall_iiii:y6,dynCall_viiiiif:y7,dynCall_viff:y8,dynCall_vifff:y9,dynCall_fii:za,dynCall_iiif:zb,dynCall_viiiiiiii:zc,dynCall_iif:zd,dynCall_viiiiiii:ze,dynCall_ff:zf,dynCall_viiiiiiiii:zg,dynCall_iii:zh,dynCall_viiiiii:zi,dynCall_f:zj,dynCall_i:zk,dynCall_iiiii:zl,dynCall_viii:zm,dynCall_v:zn,dynCall_viiii:zo}})
// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_iiiiiiii": invoke_iiiiiiii, "invoke_vif": invoke_vif, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiiiiii": invoke_iiiiiii, "invoke_ii": invoke_ii, "invoke_viiiiiiiiiii": invoke_viiiiiiiiiii, "invoke_viffff": invoke_viffff, "invoke_if": invoke_if, "invoke_iiii": invoke_iiii, "invoke_viiiiif": invoke_viiiiif, "invoke_viff": invoke_viff, "invoke_vifff": invoke_vifff, "invoke_fii": invoke_fii, "invoke_iiif": invoke_iiif, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_iif": invoke_iif, "invoke_viiiiiii": invoke_viiiiiii, "invoke_ff": invoke_ff, "invoke_viiiiiiiii": invoke_viiiiiiiii, "invoke_iii": invoke_iii, "invoke_viiiiii": invoke_viiiiii, "invoke_f": invoke_f, "invoke_i": invoke_i, "invoke_iiiii": invoke_iiiii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_viiii": invoke_viiii, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_RWebInputDestroy": _RWebInputDestroy, "_RWebAudioStop": _RWebAudioStop, "_glClearColor": _glClearColor, "_sysconf": _sysconf, "_fclose": _fclose, "_RWebAudioInit": _RWebAudioInit, "_glGetVertexAttribPointerv": _glGetVertexAttribPointerv, "_glGetRenderbufferParameteriv": _glGetRenderbufferParameteriv, "_eglDestroySurface": _eglDestroySurface, "_strtoul": _strtoul, "_strtoull": _strtoull, "_glBindTexture": _glBindTexture, "_fflush": _fflush, "_glGetUniformiv": _glGetUniformiv, "_fabsf": _fabsf, "_strtol": _strtol, "_fputc": _fputc, "_glGetString": _glGetString, "_fwrite": _fwrite, "_gluUnProject": _gluUnProject, "_send": _send, "_fputs": _fputs, "_glLineWidth": _glLineWidth, "_glUniform2fv": _glUniform2fv, "_emscripten_get_now": _emscripten_get_now, "_eglCreateContext": _eglCreateContext, "_glBindAttribLocation": _glBindAttribLocation, "_glCompileShader": _glCompileShader, "_isspace": _isspace, "_localtime": _localtime, "_glDeleteTextures": _glDeleteTextures, "_eglBindAPI": _eglBindAPI, "_glCompressedTexImage2D": _glCompressedTexImage2D, "_glStencilFuncSeparate": _glStencilFuncSeparate, "_read": _read, "_RWebAudioBufferSize": _RWebAudioBufferSize, "_glDeleteShader": _glDeleteShader, "_RWebInputInit": _RWebInputInit, "_glClearDepthf": _glClearDepthf, "_glUniform4iv": _glUniform4iv, "_glGetTexParameteriv": _glGetTexParameteriv, "_glClearStencil": _glClearStencil, "_glLoadIdentity": _glLoadIdentity, "_glUniform1fv": _glUniform1fv, "_glIsShader": _glIsShader, "_strstr": _strstr, "_glSampleCoverage": _glSampleCoverage, "_fsync": _fsync, "_glGenTextures": _glGenTextures, "_glDepthFunc": _glDepthFunc, "_remove": _remove, "_glCompressedTexSubImage2D": _glCompressedTexSubImage2D, "_glUniform1f": _glUniform1f, "_opendir": _opendir, "_glGetTexParameterfv": _glGetTexParameterfv, "_RWebAudioWrite": _RWebAudioWrite, "_glStencilMaskSeparate": _glStencilMaskSeparate, "_glCreateShader": _glCreateShader, "_round": _round, "_glUniform1i": _glUniform1i, "_strncmp": _strncmp, "_cosf": _cosf, "_glDeleteRenderbuffers": _glDeleteRenderbuffers, "_glLinkProgram": _glLinkProgram, "_snprintf": _snprintf, "_glUniform2i": _glUniform2i, "_fgetc": _fgetc, "_glStencilFunc": _glStencilFunc, "_glShaderSource": _glShaderSource, "_readdir": _readdir, "_glVertexAttribPointer": _glVertexAttribPointer, "_glHint": _glHint, "_glBindBuffer": _glBindBuffer, "_glVertexPointer": _glVertexPointer, "_fgets": _fgets, "_close": _close, "_getgid": _getgid, "_glGetAttachedShaders": _glGetAttachedShaders, "_glBindFramebuffer": _glBindFramebuffer, "_glIsFramebuffer": _glIsFramebuffer, "_strchr": _strchr, "_glUniform4fv": _glUniform4fv, "_abort": _abort, "___setErrNo": ___setErrNo, "_glDeleteFramebuffers": _glDeleteFramebuffers, "_eglTerminate": _eglTerminate, "_glGetVertexAttribfv": _glGetVertexAttribfv, "_glIsBuffer": _glIsBuffer, "_emscripten_GetProcAddress": _emscripten_GetProcAddress, "_eglGetProcAddress": _eglGetProcAddress, "_ftell": _ftell, "_glDeleteProgram": _glDeleteProgram, "_exit": _exit, "_glRenderbufferStorage": _glRenderbufferStorage, "_strrchr": _strrchr, "_glAttachShader": _glAttachShader, "_RWebInputPoll": _RWebInputPoll, "_glUniform3i": _glUniform3i, "_glIsProgram": _glIsProgram, "_glCheckFramebufferStatus": _glCheckFramebufferStatus, "__isLeapYear": __isLeapYear, "_gluProject": _gluProject, "_llvm_uadd_with_overflow_i32": _llvm_uadd_with_overflow_i32, "_localtime_r": _localtime_r, "_glUniform3f": _glUniform3f, "_glGetBufferParameteriv": _glGetBufferParameteriv, "_glFlush": _glFlush, "_glBlendEquationSeparate": _glBlendEquationSeparate, "_emscripten_get_canvas_size": _emscripten_get_canvas_size, "_glCopyTexImage2D": _glCopyTexImage2D, "_glDrawElements": _glDrawElements, "_glColorMask": _glColorMask, "_sinf": _sinf, "_gluLookAt": _gluLookAt, "_eglInitialize": _eglInitialize, "_recv": _recv, "__parseInt64": __parseInt64, "_glVertexAttrib1fv": _glVertexAttrib1fv, "_glUniform2iv": _glUniform2iv, "_putchar": _putchar, "_glUniform1iv": _glUniform1iv, "_glActiveTexture": _glActiveTexture, "_glMatrixMode": _glMatrixMode, "_glBlendEquation": _glBlendEquation, "_strcmp": _strcmp, "_glVertexAttrib1f": _glVertexAttrib1f, "_RWebAudioWriteAvail": _RWebAudioWriteAvail, "_glGenerateMipmap": _glGenerateMipmap, "_memchr": _memchr, "_glDetachShader": _glDetachShader, "_glGetShaderiv": _glGetShaderiv, "__exit": __exit, "_strftime": _strftime, "_glVertexAttrib3f": _glVertexAttrib3f, "_glGenRenderbuffers": _glGenRenderbuffers, "_tzset": _tzset, "_RWebAudioSampleRate": _RWebAudioSampleRate, "_glGetShaderPrecisionFormat": _glGetShaderPrecisionFormat, "_glVertexAttrib4fv": _glVertexAttrib4fv, "_glDepthMask": _glDepthMask, "_glDisableVertexAttribArray": _glDisableVertexAttribArray, "_glBegin": _glBegin, "_printf": _printf, "_glBindRenderbuffer": _glBindRenderbuffer, "_pread": _pread, "_fopen": _fopen, "_open": _open, "_glDrawArrays": _glDrawArrays, "_usleep": _usleep, "_llvm_pow_f32": _llvm_pow_f32, "__arraySum": __arraySum, "_glCopyTexSubImage2D": _glCopyTexSubImage2D, "_glDisable": _glDisable, "_puts": _puts, "_glUniform4i": _glUniform4i, "_exp2": _exp2, "_nanosleep": _nanosleep, "_glClear": _glClear, "_qsort": _qsort, "_glUniform2f": _glUniform2f, "_eglDestroyContext": _eglDestroyContext, "_isalpha": _isalpha, "_glEnableVertexAttribArray": _glEnableVertexAttribArray, "_rmdir": _rmdir, "_glUniform3fv": _glUniform3fv, "_glStencilOp": _glStencilOp, "_strdup": _strdup, "_glDepthRange": _glDepthRange, "_glUniform4f": _glUniform4f, "_glFramebufferTexture2D": _glFramebufferTexture2D, "_glUniformMatrix2fv": _glUniformMatrix2fv, "_glGenVertexArrays": _glGenVertexArrays, "_eglMakeCurrent": _eglMakeCurrent, "_glUniformMatrix3fv": _glUniformMatrix3fv, "_glutCreateWindow": _glutCreateWindow, "_glBufferData": _glBufferData, "_glBlendColor": _glBlendColor, "_glGetUniformLocation": _glGetUniformLocation, "_glIsEnabled": _glIsEnabled, "__formatString": __formatString, "_getenv": _getenv, "_glGetError": _glGetError, "_glGetVertexAttribiv": _glGetVertexAttribiv, "_glTexParameteriv": _glTexParameteriv, "_glGetProgramiv": _glGetProgramiv, "_glVertexAttrib3fv": _glVertexAttrib3fv, "_glGetFloatv": _glGetFloatv, "_glBufferSubData": _glBufferSubData, "_glUniform3iv": _glUniform3iv, "_glReadPixels": _glReadPixels, "_glGenFramebuffers": _glGenFramebuffers, "_glFramebufferRenderbuffer": _glFramebufferRenderbuffer, "_emscripten_procAddressTable": _emscripten_procAddressTable, "_atexit": _atexit, "_ceil": _ceil, "___errno_location": ___errno_location, "_glGetIntegerv": _glGetIntegerv, "_RWebAudioFree": _RWebAudioFree, "_llvm_lifetime_start": _llvm_lifetime_start, "_glIsRenderbuffer": _glIsRenderbuffer, "_llvm_bswap_i32": _llvm_bswap_i32, "_sbrk": _sbrk, "__parseInt": __parseInt, "_RWebAudioSetNonblockState": _RWebAudioSetNonblockState, "_glVertexAttrib2fv": _glVertexAttrib2fv, "_glGetFramebufferAttachmentParameteriv": _glGetFramebufferAttachmentParameteriv, "_glUseProgram": _glUseProgram, "_glTexImage2D": _glTexImage2D, "_glGetProgramInfoLog": _glGetProgramInfoLog, "_glTexSubImage2D": _glTexSubImage2D, "_glStencilMask": _glStencilMask, "_fread": _fread, "_glStencilOpSeparate": _glStencilOpSeparate, "_strtok_r": _strtok_r, "_glGetShaderInfoLog": _glGetShaderInfoLog, "_glIsTexture": _glIsTexture, "_eglCreateWindowSurface": _eglCreateWindowSurface, "_fprintf": _fprintf, "_glGetShaderSource": _glGetShaderSource, "_gluPerspective": _gluPerspective, "_eglChooseConfig": _eglChooseConfig, "___buildEnvironment": ___buildEnvironment, "_feof": _feof, "__addDays": __addDays, "_glScissor": _glScissor, "_glEnable": _glEnable, "_glBlendFuncSeparate": _glBlendFuncSeparate, "_floor": _floor, "__reallyNegative": __reallyNegative, "_glGetActiveAttrib": _glGetActiveAttrib, "_fseek": _fseek, "_sqrt": _sqrt, "_glTexParameterfv": _glTexParameterfv, "_write": _write, "_glGenBuffers": _glGenBuffers, "_glFinish": _glFinish, "_glGetAttribLocation": _glGetAttribLocation, "_glVertexAttrib4f": _glVertexAttrib4f, "_rewind": _rewind, "_sin": _sin, "_glBlendFunc": _glBlendFunc, "_glCreateProgram": _glCreateProgram, "_realpath": _realpath, "_stat": _stat, "_longjmp": _longjmp, "_glViewport": _glViewport, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_time": _time, "_glVertexAttrib2f": _glVertexAttrib2f, "_closedir": _closedir, "_isgraph": _isgraph, "_readlink": _readlink, "_glGetUniformfv": _glGetUniformfv, "_unlink": _unlink, "_gluOrtho2D": _gluOrtho2D, "_glUniformMatrix4fv": _glUniformMatrix4fv, "_glClearDepth": _glClearDepth, "_glGetActiveUniform": _glGetActiveUniform, "_glutDestroyWindow": _glutDestroyWindow, "_pwrite": _pwrite, "_fabs": _fabs, "_glTexParameterf": _glTexParameterf, "_RWebAudioStart": _RWebAudioStart, "_glTexParameteri": _glTexParameteri, "_glFrontFace": _glFrontFace, "_glCullFace": _glCullFace, "_glDepthRangef": _glDepthRangef, "_glDeleteBuffers": _glDeleteBuffers, "_eglGetDisplay": _eglGetDisplay, "_emscripten_set_canvas_size": _emscripten_set_canvas_size, "_glGetBooleanv": _glGetBooleanv, "_eglQuerySurface": _eglQuerySurface, "_glPixelStorei": _glPixelStorei, "_readdir_r": _readdir_r, "_glValidateProgram": _glValidateProgram, "_glPolygonOffset": _glPolygonOffset, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stdout": _stdout, "___dso_handle": ___dso_handle, "_stderr": _stderr }, buffer);
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var _strncasecmp = Module["_strncasecmp"] = asm["_strncasecmp"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _memcmp = Module["_memcmp"] = asm["_memcmp"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var __GLOBAL__I_a = Module["__GLOBAL__I_a"] = asm["__GLOBAL__I_a"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _strcasecmp = Module["_strcasecmp"] = asm["_strcasecmp"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_vif = Module["dynCall_vif"] = asm["dynCall_vif"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiiiiiiiii = Module["dynCall_viiiiiiiiiii"] = asm["dynCall_viiiiiiiiiii"];
var dynCall_viffff = Module["dynCall_viffff"] = asm["dynCall_viffff"];
var dynCall_if = Module["dynCall_if"] = asm["dynCall_if"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiiif = Module["dynCall_viiiiif"] = asm["dynCall_viiiiif"];
var dynCall_viff = Module["dynCall_viff"] = asm["dynCall_viff"];
var dynCall_vifff = Module["dynCall_vifff"] = asm["dynCall_vifff"];
var dynCall_fii = Module["dynCall_fii"] = asm["dynCall_fii"];
var dynCall_iiif = Module["dynCall_iiif"] = asm["dynCall_iiif"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_iif = Module["dynCall_iif"] = asm["dynCall_iif"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_ff = Module["dynCall_ff"] = asm["dynCall_ff"];
var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_f = Module["dynCall_f"] = asm["dynCall_f"];
var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };
// TODO: strip out parts of this we do not need
//======= begin closure i64 code =======
// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */
var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };
  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.
    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };
  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.
  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};
  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };
  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };
  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };
  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };
  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.
  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;
  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);
  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);
  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };
  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };
  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (this.isZero()) {
      return '0';
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }
    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };
  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };
  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };
  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };
  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };
  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };
  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };
  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };
  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };
  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };
  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };
  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);
      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };
  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };
  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };
  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };
  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };
  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };
  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };
  //======= begin jsbn =======
  var navigator = { appName: 'Modern Browser' }; // polyfill a little
  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/
  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */
  // Basic JavaScript BN library - subset useful for RSA encryption.
  // Bits per digit
  var dbits;
  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);
  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }
  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }
  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.
  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;
  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }
  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }
  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }
  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }
  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }
  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }
  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }
  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }
  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }
  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }
  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }
  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }
  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }
  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }
  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }
  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }
  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }
  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }
  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }
  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }
  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }
  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }
  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }
  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }
  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }
  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  // jsbn2 stuff
  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }
  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }
  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }
  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }
  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }
  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  //======= end jsbn =======
  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();
//======= end closure i64 code =======
// === Auto-generated postamble setup entry stuff ===
function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;
var initialStackTop;
var preloadStartTime = null;
Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');
  args = args || [];
  if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
    Module.printErr('preload time: ' + (Date.now() - preloadStartTime) + ' ms');
  }
  ensureInitRuntime();
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);
  initialStackTop = STACKTOP;
  try {
    var ret = Module['_main'](argc, argv, 0);
    // if we're not running an evented main loop, it's time to exit
    if (!Module['noExitRuntime']) {
      exit(ret);
    }
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      throw e;
    }
  }
}
function run(args) {
  args = args || Module['arguments'];
  if (preloadStartTime === null) preloadStartTime = Date.now();
  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }
  preRun();
  if (runDependencies > 0) {
    // a preRun added a dependency, run will be called later
    return;
  }
  function doRun() {
    ensureInitRuntime();
    preMain();
    calledRun = true;
    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }
    postRun();
  }
  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;
function exit(status) {
  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;
  // exit the runtime
  exitRuntime();
  // throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;
function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }
  ABORT = true;
  EXITSTATUS = 1;
  throw 'abort() at ' + (new Error().stack);
}
Module['abort'] = Module.abort = abort;
// {{PRE_RUN_ADDITIONS}}
if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}
// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}
run();
// {{POST_RUN_ADDITIONS}}
// {{MODULE_ADDITIONS}}
